import React from 'react';
import { withStyles } from '@material-ui/core/styles';
import { DataGrid } from '@mui/x-data-grid';
import {Stack} from '@mui/material';
import Cookies from 'js-cookie';
import Dialog from '@material-ui/core/Dialog';
import MuiDialogTitle from '@material-ui/core/DialogTitle';
import MuiDialogContent from '@material-ui/core/DialogContent';
import IconButton from '@material-ui/core/IconButton';
import CloseIcon from '@material-ui/icons/Close';
import Typography from '@material-ui/core/Typography';
import 'font-awesome/css/font-awesome.min.css';
import axios from 'axios';
import {API_URL} from '../utils/EnvVars';

const styles = (theme) => ({
  root: {
    margin: 0,
    padding: theme.spacing(2),
  },
  closeButton: {
    position: 'absolute',
    right: theme.spacing(1),
    top: theme.spacing(1),
    color: theme.palette.grey[500],
  },
});

const DialogTitle = withStyles(styles)((props) => {
  const { children, classes, onClose, ...other } = props;
  return (
    <MuiDialogTitle disableTypography className={classes.root} {...other}>
      <Typography variant="h6">{children}</Typography>
      {onClose ? (
        <IconButton aria-label="close" className={classes.closeButton} onClick={onClose}>
          <CloseIcon />
        </IconButton>
      ) : null}
    </MuiDialogTitle>
  );
});

const DialogContent = withStyles((theme) => ({
  root: {
    padding: theme.spacing(2),
  },
}))(MuiDialogContent);

const CustomizedDialogs = React.forwardRef((props, ref) => {  
  const [open, setOpen] = React.useState(false); 

  const [columns, setColumns] = React.useState([]);
	const [rows, setRows] = React.useState([]);

  const [deleteDialogShow, setDeleteDialogShow] = React.useState(false);
  const [users, setUsers] = React.useState([]);
  const [delId, setDelId] = React.useState(0);

  React.useImperativeHandle(ref, () => ({
    handleClickOpen(){
      setOpen(true);
    }
  }));
  
  const handleClose = () => {
    setOpen(false);
  };


  const deleteNow = () => {
    document.getElementById('rowId'+delId).style.display='none';
    props.deleteUser(delId);
    setDeleteDialogShow(false);
  };

  React.useEffect(() => {		
		if(props.dataObj && props.userObj.emailId && props.userObj.token){
			getApiData(props.userObj.emailId,props.userObj.token, props.dataObj.autoId);
		}
	}, [props.userObj,props.dataObj]);

	async function getApiData(emailId,token,id){
    axios.get(API_URL+'/admin-data-report-details?id='+id+'&loginEmailId='+emailId+'&token='+token)
       .then(response => {
          ///console.log("Just Checking >> "+response.data); 
          //setPageLoading(false);
       if(response.data && response.data.responseTxt==="success"){
          setColumns(response.data.columns);
          setRows(response.data.list);					
          //setAuthPrivileges(response.data.privileges);
       }else if(response.data && response.data.responseTxt==="InvalidToken"){ 
        Cookies.remove('isadminloggedin');
          window.location.href='login';
       }else{          
          setRows("");
       } 				
    })
    // .catch((error) => {
    //   alert("ERROR: "+error);
    // })
}
  
  return (
    <>
      <Dialog fullWidth maxWidth="md" onClose={handleClose} aria-labelledby="customized-dialog-title" open={open}>
        <DialogTitle style={{marginBottom:'-30px'}} onClose={handleClose}>{props.dataObj?props.dataObj.title:null}</DialogTitle>
          <DialogContent style={{height:'88vh'}}>
                   <DataGrid
                      rows={rows}
                      columns={columns}
                      pageSize={100}
                      rowHeight={40}
                      rowsPerPageOptions={[100]}                      	
                      style={{fontSize:12}}
                      components={{
                        NoRowsOverlay: () => (
                          <Stack height="100%" alignItems="center" justifyContent="center">
                          <span style={{color:'#FF0000',fontWeight:'bold'}}>No Records found!</span>
                          </Stack>
                        )}}	                      	
                    />
          </DialogContent>
      </Dialog>


        


    </>
  );

});

export default CustomizedDialogs;