import React from 'react';
import { withStyles } from '@material-ui/core/styles';
import {Grid, Box, Button} from '@material-ui/core';
import TextField from '@mui/material/TextField';
import { makeStyles } from "@material-ui/core/styles";
import Stack from '@mui/material/Stack';
import MenuItem from '@mui/material/MenuItem';
import Select from '@mui/material/Select';
import Snackbar from '@mui/material/Snackbar';
import Alert from '@mui/material/Alert';
import Dialog from '@material-ui/core/Dialog';
import MuiDialogTitle from '@material-ui/core/DialogTitle';
import MuiDialogContent from '@material-ui/core/DialogContent';
import IconButton from '@material-ui/core/IconButton';
import CloseIcon from '@material-ui/icons/Close';
import Typography from '@material-ui/core/Typography';
import axios from 'axios';
import { useSelector } from 'react-redux';
import {API_URL} from '../utils/EnvVars';

const styles = (theme) => ({
  root: {
    margin: 0,
    padding: theme.spacing(2),
  },
  closeButton: {
    position: 'absolute',
    right: theme.spacing(1),
    top: theme.spacing(1),
    color: theme.palette.grey[500],
  },
});

const useStyles = makeStyles({
  paper: {
    fontSize: '12px !important',    
  }
});

var vertical='top',horizontal='center';

const DialogTitle = withStyles(styles)((props) => {
  const { children, classes, onClose, ...other } = props;
  return (
    <MuiDialogTitle disableTypography className={classes.root} {...other}>
      <Typography variant="h6">{children}</Typography>
      {onClose ? (
        <IconButton aria-label="close" className={classes.closeButton} onClick={onClose}>
          <CloseIcon />
        </IconButton>
      ) : null}
    </MuiDialogTitle>
  );
});

const DialogContent = withStyles((theme) => ({
  root: {
    padding: theme.spacing(2),
  },
}))(MuiDialogContent);

const CustomizedDialogs = React.forwardRef((props, ref) => {  
  const classes = useStyles();
  const userObj = useSelector(state => state.userDetails);
  const [open, setOpen] = React.useState(false); 
  const [severityAlert, setSeverityAlert] = React.useState("error");
  const [showAlert, setShowAlert] = React.useState(false);
  const [alertMessage, setAlertMessage] = React.useState("");

  const [schoolName, setSchoolName] = React.useState("");
  const [websites, setWebsites] = React.useState([]);
  const [websiteId, setWebsiteId] = React.useState("noselect");
  const [webUrl, setWebUrl] = React.useState("");
  const [address, setAddress] = React.useState("");
  const [fullName, setFullName] = React.useState("");
  const [emailId, setEmailId] = React.useState("");
  const [newPassword, setNewPassword] = React.useState("");
  const [retypeNewPassword, setRetypeNewPassword] = React.useState("");

  React.useImperativeHandle(ref, () => ({
    handleClickOpen(){
      setOpen(true);
    }
  }));
  
  const handleClose = () => {
    setOpen(false);
  };

  function hideAlert(){
		setShowAlert(false);
	}


  React.useEffect(() => {	
    if(props.dataObj!=null && props.dataObj.autoId){	
      setSchoolName(props.dataObj.schoolName);
      if(props.dataObj.address){
        setAddress(props.dataObj.address);
      }else{
        setAddress("");
      }
      if(props.dataObj.websiteId){
        setWebsiteId(props.dataObj.websiteId);
        setWebUrl(props.dataObj.webUrl);
      }else{
        setWebsiteId("");
        setWebUrl("");
      }
    }
    if(userObj.emailId && userObj.token){
			getApiWebsites(userObj.emailId,userObj.token);
		}
	}, [props.dataObj,userObj]);

  async function getApiWebsites(emailId,token){
		axios.get(API_URL+'/admin-websites?loginEmailId='+emailId+'&token='+token)
		   .then(response => {
			 if(response.data.responseTxt==="success"){					 
				 setWebsites(response.data.list);
			 }	 				
		})
	}

	function saveData(){
    if(!schoolName){
      setSeverityAlert("error");
      setShowAlert(true);
      setAlertMessage("Enter academy name");			
      return false;
    }
    if(!props.dataObj && !fullName){
      setSeverityAlert("error");
      setShowAlert(true);
      setAlertMessage("Enter staff name");			
      return false;
    }
    if(!props.dataObj && !emailId){
      setSeverityAlert("error");
      setShowAlert(true);
      setAlertMessage("Enter email");			
      return false;
    }
    if(!props.dataObj && !newPassword){
      setSeverityAlert("error");
      setShowAlert(true);
      setAlertMessage("Enter new password");			
      return false;
    }
    if(!props.dataObj && newPassword && !retypeNewPassword){
      setSeverityAlert("error");
      setShowAlert(true);
      setAlertMessage("Retype new password");			
      return false;
    }
    if(!props.dataObj && retypeNewPassword && !newPassword){
      setSeverityAlert("error");
      setShowAlert(true);
      setAlertMessage("Enter new password");			
      return false;
    }
    if(!props.dataObj && newPassword && retypeNewPassword && newPassword!=retypeNewPassword){
      setSeverityAlert("error");
      setShowAlert(true);
      setAlertMessage("Enter new password does not match with retype new password");			
      return false;
    }

    
		if(schoolName && schoolName.length>1){ 
			let axiosHeader = {
				headers: {
					'Content-Type': 'multipart/mixed',
          'token': userObj.token,
          'loginEmailId': userObj.emailId,
				}
			}; 
			const data = new FormData();
      if(props.dataObj && props.dataObj.autoId){
        data.append('id', props.dataObj.autoId);
      }
      data.append('schoolName', schoolName);
      if(websiteId && webUrl){
        data.append('websiteId', websiteId);
        data.append('webUrl', webUrl);
      }
      if(address){
        data.append('address', address);
      }  

      if(!props.dataObj){
        data.append('fullName', fullName);
        data.append('emailId', emailId);
        data.append('newPassword', newPassword);
      }

      let apiURL='/admin-new-school';
      let myMessage="Academy has been created.";
      if(props.dataObj!=null && props.dataObj.autoId){
          apiURL='/admin-update-school';
          myMessage="Academy has been updated.";
      }
             
			axios.post(API_URL+apiURL, data, axiosHeader)
			.then((response) => {
				console.log("RESPONSE RECEIVED: ", response.data.responseTxt);
				if(response.data.responseTxt==="success"){
          setSchoolName("");
          setAddress("");
          setSeverityAlert("success");
          setOpen(false);
					setShowAlert(true);
					setAlertMessage(myMessage);
          ///window.location.reload();	
					return false;
        }else if(response.data.responseTxt==="AlreadyExistsError"){
            setSeverityAlert("error");
            setOpen(true);
            setShowAlert(true);
            setAlertMessage("This academy name was created earlier. Kindly enter another academy name");
            return false;  					
				}else{
          setSeverityAlert("error");
					setShowAlert(true);
					setAlertMessage("This academy could not be saved.");			
					return false;
				}
			})
			.catch((error) => {
				console.log("AXIOS ERROR: ", error);
			})	
		}		
	}
  
  function handleWebsite(webId){    
    if(webId>0 && websites.length>0){
      for(let i=0; i<websites.length; i++){
        if(websites[i].autoId===webId){
          setWebsiteId(websites[i].autoId);
          setWebUrl(websites[i].webUrl);
        }
      }
    }
  }

  return (
    <>
      <Dialog fullWidth maxWidth="md" onClose={handleClose} aria-labelledby="customized-dialog-title" open={open}>
        <DialogTitle style={{marginBottom:'-30px'}} onClose={handleClose}></DialogTitle>
          <DialogContent style={{height:'88vh'}}>
            <Grid item   md={12} xs={12} className="test-instructions" >
                  <div className="btmbdrgry"><h3>{props.dataObj!=null?<>Edit</>:<>New</>} Academy</h3></div>
                  <p>
                      <table style={{backgroundColor:'#000000',width:'100%' }} cellSpacing="1" cellPadding="3" >
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Academy Name</td>
                            <td style={{textAlign:'center'}} >
                            <TextField onChange={event => setSchoolName(event.target.value)} value={schoolName} placeholder={'Enter academy name'} sx={{width:'99%',fontSize: 10}} variant="standard" />
                            </td>                            
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Website</td>
                            <td style={{textAlign:'center'}} >
                            <Select 
                                style={{width:'100%'}}
                                classes={{ paper: classes.paper }}
                                labelId="select-class-label"
                                id="select-class"
                                value={websiteId}									
                                onChange={event => handleWebsite(event.target.value)}
                                variant="standard"
                              >
                                  <MenuItem value="noselect">Select Website</MenuItem>
                                  {websites?websites.map((myRow,mykey)=>(
                                    <MenuItem key={'tchr'+mykey} value={myRow.autoId}>{myRow.webUrl}</MenuItem>
                                  )):null}
                              </Select>
                            </td>                            
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Address</td>
                            <td style={{textAlign:'center'}} >
                            <TextField onChange={event => setAddress(event.target.value)} value={address} placeholder={'Enter address'} sx={{width:'99%',fontSize: 10}} variant="standard" />
                            </td>                            
                        </tr>
                        {!props.dataObj?<>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Staff Name</td>
                            <td style={{textAlign:'center'}} >
                            <TextField onChange={event => setFullName(event.target.value)} value={fullName} placeholder={'Enter staff name'} sx={{width:'99%',fontSize: 10}} variant="standard" />
                            </td>                            
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Email Id</td>
                            <td style={{textAlign:'center'}} >
                            <TextField onChange={event => setEmailId(event.target.value)} value={emailId} placeholder={'Enter email id'} sx={{width:'99%',fontSize: 10}} variant="standard" />
                            </td>                            
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>New Password</td>
                            <td style={{textAlign:'center'}} >
                            <TextField type='password' onChange={event => setNewPassword(event.target.value)} value={newPassword} placeholder={'Enter new password'} sx={{width:'99%',fontSize: 10}} variant="standard" />
                            </td>                            
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Retype New Password</td>
                            <td style={{textAlign:'center'}} >
                            <TextField type='password' onChange={event => setRetypeNewPassword(event.target.value)} value={retypeNewPassword} placeholder={'Enter retype new password'} sx={{width:'99%',fontSize: 10}} variant="standard" />
                            </td>                            
                        </tr>
                        </>
                        :null}  
                      </table>

                      <Box mt={2}>
                          <Button onClick={() => {handleClose()}} style={{marginRight:12}} size="small" variant="outlined" >Cancel</Button>
					    	          <Button onClick={() => {saveData()}} style={{marginRight:12}} size="small" variant="contained" style={{backgroundColor:'#008000',color:'#FFF',marginRight:10}} >Save</Button>
								      </Box>

                  </p>
            </Grid>
          </DialogContent>
      </Dialog>
      
        <Stack spacing={2} sx={{ width: '100%' }}>
					<Snackbar open={showAlert} autoHideDuration={6000} onClose={hideAlert} anchorOrigin={{vertical,horizontal}}  >
						<Alert onClose={hideAlert} variant="filled" severity={severityAlert} sx={{ width: '100%' }}>
							{alertMessage}
						</Alert>
					</Snackbar>
				</Stack>

    </>
  );

});

export default CustomizedDialogs;