import React from 'react';
import { withStyles } from '@material-ui/core/styles';
import {Grid, Box, Button} from '@material-ui/core';
import TextField from '@mui/material/TextField';
import { makeStyles } from "@material-ui/core/styles";
import Stack from '@mui/material/Stack';
import Snackbar from '@mui/material/Snackbar';
import Alert from '@mui/material/Alert';
import Dialog from '@material-ui/core/Dialog';
import MuiDialogTitle from '@material-ui/core/DialogTitle';
import MuiDialogContent from '@material-ui/core/DialogContent';
import IconButton from '@material-ui/core/IconButton';
import CloseIcon from '@material-ui/icons/Close';
import Typography from '@material-ui/core/Typography';
import axios from 'axios';
import { useSelector } from 'react-redux';
import {API_URL} from '../utils/EnvVars';

const styles = (theme) => ({
  root: {
    margin: 0,
    padding: theme.spacing(2),
  },
  closeButton: {
    position: 'absolute',
    right: theme.spacing(1),
    top: theme.spacing(1),
    color: theme.palette.grey[500],
  },
});

const useStyles = makeStyles({
  paper: {
    fontSize: '12px !important',    
  }
});

var vertical='top',horizontal='center';

const DialogTitle = withStyles(styles)((props) => {
  const { children, classes, onClose, ...other } = props;
  return (
    <MuiDialogTitle disableTypography className={classes.root} {...other}>
      <Typography variant="h6">{children}</Typography>
      {onClose ? (
        <IconButton aria-label="close" className={classes.closeButton} onClick={onClose}>
          <CloseIcon />
        </IconButton>
      ) : null}
    </MuiDialogTitle>
  );
});

const DialogContent = withStyles((theme) => ({
  root: {
    padding: theme.spacing(2),
  },
}))(MuiDialogContent);

const CustomizedDialogs = React.forwardRef((props, ref) => {  
  const userObj = useSelector(state => state.userDetails);
  const [open, setOpen] = React.useState(false); 
  const [severityAlert, setSeverityAlert] = React.useState("error");
  const [showAlert, setShowAlert] = React.useState(false);
  const [alertMessage, setAlertMessage] = React.useState("");

  const [schoolId, setSchoolId] = React.useState("");
  const [schoolName, setSchoolName] = React.useState("");
  const [fullName, setFullName] = React.useState("");
  const [emailId, setEmailId] = React.useState("");
  const [newPassword, setNewPassword] = React.useState("");
  const [retypeNewPassword, setRetypeNewPassword] = React.useState("");

  React.useImperativeHandle(ref, () => ({
    handleClickOpen(){
      setOpen(true);
    }
  }));
  
  const handleClose = () => {
    setOpen(false);
  };

  function hideAlert(){
		setShowAlert(false);
	}

  React.useEffect(() => {	
    if(props.schoolUserObj!=null && props.schoolUserObj.autoId){	
      setFullName(props.schoolUserObj.fullName);
      setEmailId(props.schoolUserObj.emailId);
    }else{
      setFullName('');
      setEmailId('');
      setNewPassword('');
      setRetypeNewPassword('');
    }
    if(props.dataObj!=null && props.dataObj.autoId){	
      setSchoolId(props.dataObj.autoId);
      setSchoolName(props.dataObj.schoolName);
    }
	}, [props.dataObj,props.schoolUserObj]);

	function saveData(){
    if(!fullName){
      setSeverityAlert("error");
      setShowAlert(true);
      setAlertMessage("Enter full name");			
      return false;
    }
    if(!emailId){
      setSeverityAlert("error");
      setShowAlert(true);
      setAlertMessage("Enter email id");			
      return false; 
    }
    if(!props.schoolUserObj && !newPassword){
      setSeverityAlert("error");
      setShowAlert(true);
      setAlertMessage("Enter new password");			
      return false;
    }
    if(newPassword && !retypeNewPassword){
      setSeverityAlert("error");
      setShowAlert(true);
      setAlertMessage("Retype new password");			
      return false;
    }
    if(retypeNewPassword && !newPassword){
      setSeverityAlert("error");
      setShowAlert(true);
      setAlertMessage("Enter new password");			
      return false;
    }
    if(newPassword && retypeNewPassword && newPassword!=retypeNewPassword){
      setSeverityAlert("error");
      setShowAlert(true);
      setAlertMessage("Enter new password does not match with retype new password");			
      return false;
    }

		if(emailId && emailId.length>1){ 
			let axiosHeader = {
				headers: {
					'Content-Type': 'multipart/mixed',
          'token': userObj.token,
          'loginEmailId': userObj.emailId,
				}
			}; 
			const data = new FormData();
      if(props.schoolUserObj && props.schoolUserObj.autoId){
        data.append('id', props.schoolUserObj.autoId);
      }
      data.append('fullName', fullName);
      data.append('emailId', emailId);
      data.append('schoolId', schoolId);
      data.append('schoolName', schoolName);

      if(newPassword && retypeNewPassword){
        data.append('newPassword', newPassword);
      }

      let apiURL='/admin-new-school-user';
      let myMessage="Academy staff has been created.";
      if(props.schoolUserObj!=null && props.schoolUserObj.autoId){
          apiURL='/admin-update-school-user';
          myMessage="Academy staff has been updated.";
      }
             
			axios.post(API_URL+apiURL, data, axiosHeader)
			.then((response) => {
				console.log("RESPONSE RECEIVED: ", response.data.responseTxt);
				if(response.data.responseTxt==="success"){
          setNewPassword("");
          setRetypeNewPassword("");
          setSeverityAlert("success");
          setOpen(false);
					setShowAlert(true);
					setAlertMessage(myMessage);
          ///window.location.reload();	
					return false;
        }else if(response.data.responseTxt==="AlreadyExistsError"){
            setSeverityAlert("error");
            setOpen(true);
            setShowAlert(true);
            setAlertMessage("This staff was created earlier. Kindly enter another staff email id");
            return false;  					
				}else{
          setSeverityAlert("error");
					setShowAlert(true);
					setAlertMessage("This staff could not be saved.");			
					return false;
				}
			})
			.catch((error) => {
				console.log("AXIOS ERROR: ", error);
			})	
		}		
	}
  
  return (
    <>
      <Dialog fullWidth maxWidth="md" onClose={handleClose} aria-labelledby="customized-dialog-title" open={open}>
        <DialogTitle style={{marginBottom:'-30px'}} onClose={handleClose}></DialogTitle>
          <DialogContent style={{height:'88vh'}}>
            <Grid item   md={12} xs={12} className="test-instructions" >
                  <div className="btmbdrgry"><h3>{props.schoolUserObj!=null?<>Edit</>:<>New</>} Academy Staff</h3></div>
                  <p>
                      <table style={{backgroundColor:'#000000',width:'100%' }} cellSpacing="1" cellPadding="3" >
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Full Name</td>
                            <td style={{textAlign:'center'}} >
                            <TextField onChange={event => setFullName(event.target.value)} value={fullName} placeholder={'Enter full name'} sx={{width:'99%',fontSize: 10}} variant="standard" />
                            </td>                            
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Email Id</td>
                            <td style={{textAlign:'center'}} >
                            <TextField onChange={event => setEmailId(event.target.value)} value={emailId} placeholder={'Enter email id'} sx={{width:'99%',fontSize: 10}} variant="standard" />
                            </td>                            
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>New Password</td>
                            <td style={{textAlign:'center'}} >
                            <TextField type='password' onChange={event => setNewPassword(event.target.value)} value={newPassword} placeholder={'Enter new password'} sx={{width:'99%',fontSize: 10}} variant="standard" />
                            </td>                            
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Retype New Password</td>
                            <td style={{textAlign:'center'}} >
                            <TextField type='password' onChange={event => setRetypeNewPassword(event.target.value)} value={retypeNewPassword} placeholder={'Enter retype new password'} sx={{width:'99%',fontSize: 10}} variant="standard" />
                            </td>                            
                        </tr>

                      </table>

                      <Box mt={2}>
                          <Button onClick={() => {handleClose()}} style={{marginRight:12}} size="small" variant="outlined" >Cancel</Button>
					    	          <Button onClick={() => {saveData()}} style={{marginRight:12}} size="small" variant="contained" style={{backgroundColor:'#008000',color:'#FFF',marginRight:10}} >Save</Button>
								      </Box>

                  </p>
            </Grid>
          </DialogContent>
      </Dialog>
      
        <Stack spacing={2} sx={{ width: '100%' }}>
					<Snackbar open={showAlert} autoHideDuration={6000} onClose={hideAlert} anchorOrigin={{vertical,horizontal}}  >
						<Alert onClose={hideAlert} variant="filled" severity={severityAlert} sx={{ width: '100%' }}>
							{alertMessage}
						</Alert>
					</Snackbar>
				</Stack>

    </>
  );

});

export default CustomizedDialogs;