import React from 'react';
import { withStyles } from '@material-ui/core/styles';
import {Grid, Box, Button} from '@material-ui/core';
import TextField from '@mui/material/TextField';
import Select from '@mui/material/Select';
import MenuItem from '@mui/material/MenuItem';
import { makeStyles } from "@material-ui/core/styles";
import Stack from '@mui/material/Stack';
import Snackbar from '@mui/material/Snackbar';
import Alert from '@mui/material/Alert';
import Dialog from '@material-ui/core/Dialog';
import MuiDialogTitle from '@material-ui/core/DialogTitle';
import MuiDialogContent from '@material-ui/core/DialogContent';
import IconButton from '@material-ui/core/IconButton';
import CloseIcon from '@material-ui/icons/Close';
import Typography from '@material-ui/core/Typography';
import axios from 'axios';
import { useSelector } from 'react-redux';
import {API_URL} from '../utils/EnvVars';

const styles = (theme) => ({
  root: {
    margin: 0,
    padding: theme.spacing(2),
  },
  closeButton: {
    position: 'absolute',
    right: theme.spacing(1),
    top: theme.spacing(1),
    color: theme.palette.grey[500],
  },
});

const useStyles = makeStyles({
  paper: {
    fontSize: '12px !important',    
  }
});

var vertical='top',horizontal='center';

const DialogTitle = withStyles(styles)((props) => {
  const { children, classes, onClose, ...other } = props;
  return (
    <MuiDialogTitle disableTypography className={classes.root} {...other}>
      <Typography variant="h6">{children}</Typography>
      {onClose ? (
        <IconButton aria-label="close" className={classes.closeButton} onClick={onClose}>
          <CloseIcon />
        </IconButton>
      ) : null}
    </MuiDialogTitle>
  );
});

const DialogContent = withStyles((theme) => ({
  root: {
    padding: theme.spacing(2),
  },
}))(MuiDialogContent);

const CustomizedDialogs = React.forwardRef((props, ref) => {  
  const classes = useStyles();
  const userObj = useSelector(state => state.userDetails);
  const [open, setOpen] = React.useState(false); 
  const [severityAlert, setSeverityAlert] = React.useState("error");
  const [showAlert, setShowAlert] = React.useState(false);
  const [alertMessage, setAlertMessage] = React.useState("");
  
  const [categoryName, setCategoryName] = React.useState("");
  const [websiteId, setWebsiteId] = React.useState("noselect");
  const [webUrl, setWebUrl] = React.useState("");
  const [shortDescription, setShortDescription] = React.useState("");
  const [orderBy, setOrderBy] = React.useState("");
  const [status, setStatus] = React.useState(1);
  
  var myCurrentDate=new Date();
	var myPastFromDate=new Date(myCurrentDate);
  myPastFromDate.setDate(myPastFromDate.getDate() + 365);

  React.useImperativeHandle(ref, () => ({
    handleClickOpen(){
      setOpen(true);
    }
  }));
  
  const handleClose = () => {
    setOpen(false);
  };

  function hideAlert(){
		setShowAlert(false);
	}

  function handleWebsite(webId){    
    if(webId>0 && props.websites.length>0){
      for(let i=0; i<props.websites.length; i++){
        if(props.websites[i].autoId===webId){
          setWebsiteId(props.websites[i].autoId);
          setWebUrl(props.websites[i].webUrl);
        }
      }
    }
  }

  React.useEffect(() => {	
    if(props.dataObj!=null && props.dataObj.autoId){	
          setCategoryName(props.dataObj.categoryName);
          setWebsiteId(props.dataObj.websiteId);
          setWebUrl(props.dataObj.webUrl);
          setOrderBy(props.dataObj.orderBy);
          if(props.dataObj.status=='Active'){
            setStatus(1);
          }else{
            setStatus(0);
          }
          setShortDescription(props.dataObj.shortDescription);
    }
	}, [props.dataObj]);

	function saveData(){    
    if(!webUrl){
      setSeverityAlert("error");
      setShowAlert(true);
      setAlertMessage("Enter web url");			
      return false;
    }  
    if(!categoryName){
      setSeverityAlert("error");
      setShowAlert(true);
      setAlertMessage("Enter category name");			
      return false;
    }  

		if(webUrl && webUrl.length>1){ 
			let axiosHeader = {
				headers: {
					'Content-Type': 'multipart/mixed',
          'token': userObj.token,
          'loginEmailId': userObj.emailId,
				}
			}; 
			const data = new FormData();
      if(props.dataObj && props.dataObj.autoId){
        data.append('id', props.dataObj.autoId);
      }
      data.append('categoryName', categoryName);
      data.append('websiteId', websiteId);
      data.append('webUrl', webUrl);
      data.append('orderBy', orderBy);
      data.append('status', status);
      data.append('shortDescription', shortDescription);

      let apiURL='/admin-new-subscription-courses-category';
      let myMessage="Category has been created.";
      if(props.dataObj!=null && props.dataObj.autoId){
          apiURL='/admin-update-subscription-courses-category';
          myMessage="Category has been updated.";
      }
             
			axios.post(API_URL+apiURL, data, axiosHeader)
			.then((response) => {
				console.log("RESPONSE RECEIVED: ", response.data.responseTxt);
				if(response.data.responseTxt==="success"){

          setCategoryName("");
          setWebsiteId("noselect");
          setWebUrl("");
          setOrderBy("");
          setStatus(1);
          setShortDescription("");

          setSeverityAlert("success");
          setOpen(false);
					setShowAlert(true);
					setAlertMessage(myMessage);
          ///window.location.reload();	
					return false;
        }else if(response.data.responseTxt==="AlreadyExistsError"){
            setSeverityAlert("error");
            setOpen(true);
            setShowAlert(true);
            setAlertMessage("This category was created earlier. Kindly enter another category");
            return false;  					
				}else{
          setSeverityAlert("error");
					setShowAlert(true);
					setAlertMessage("This category could not be saved.");			
					return false;
				}
			})
			.catch((error) => {
				console.log("AXIOS ERROR: ", error);
			})	
		}		
	}
  
  return (
    <>
      <Dialog fullWidth maxWidth="md" onClose={handleClose} aria-labelledby="customized-dialog-title" open={open}>
        <DialogTitle style={{marginBottom:'-30px'}} onClose={handleClose}></DialogTitle>
          <DialogContent style={{height:'88vh'}}>
            <Grid item   md={12} xs={12} className="test-instructions" >
                  <div className="btmbdrgry"><h3>{props.dataObj!=null?<>Edit</>:<>New</>} Category</h3></div>
                  <p>
                      <table style={{backgroundColor:'#000000',width:'100%' }} cellSpacing="1" cellPadding="3" >
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Website</td>
                            <td style={{textAlign:'center'}} >
                            <Select 
                                style={{width:'100%'}}
                                classes={{ paper: classes.paper }}
                                labelId="select-class-label"
                                id="select-class"
                                value={websiteId}									
                                onChange={event => handleWebsite(event.target.value)}
                                variant="standard"
                              >
                                  <MenuItem value="noselect">Select Website</MenuItem>
                                  {props.websites?props.websites.map((myRow,mykey)=>(
                                    <MenuItem key={'tchr'+mykey} value={myRow.autoId}>{myRow.webUrl}</MenuItem>
                                  )):null}
                              </Select>
                            </td>                            
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Category Name</td>
                            <td style={{textAlign:'center'}} >
                            <TextField onChange={event => setCategoryName(event.target.value)} value={categoryName} placeholder={'Enter category name'} sx={{width:'99%',fontSize: 10}} variant="standard" />
                            </td>                            
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Short Description</td>
                            <td style={{textAlign:'center'}} >
                            <TextField onChange={event => setShortDescription(event.target.value)} value={shortDescription} placeholder={'Enter shortDescription'} sx={{width:'99%',fontSize: 10}} variant="standard" />
                            </td>                            
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Order By</td>
                            <td style={{textAlign:'center'}} >
                            <TextField onChange={event => setOrderBy(event.target.value)} value={orderBy} placeholder={'Enter order by'} sx={{width:'99%',fontSize: 10}} variant="standard" />
                            </td>                            
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Status</td>
                            <td style={{textAlign:'center'}} >
                            <Select 
                                style={{width:'100%'}}
                                classes={{ paper: classes.paper }}
                                labelId="select-class-label"
                                id="select-class"
                                value={status}									
                                onChange={event => setStatus(event.target.value)}
                                variant="standard"
                              >
                                  <MenuItem value="1">Active</MenuItem>
                                  <MenuItem value="0">Not Active</MenuItem>
                              </Select>
                            </td>                            
                        </tr>
                        

                      </table>

                      <Box mt={2}>
                          <Button onClick={() => {handleClose()}} style={{marginRight:12}} size="small" variant="outlined" >Cancel</Button>
					    	          <Button onClick={() => {saveData()}} style={{marginRight:12}} size="small" variant="contained" style={{backgroundColor:'#008000',color:'#FFF',marginRight:10}} >Save</Button>
								      </Box>

                  </p>
            </Grid>
          </DialogContent>
      </Dialog>
      
        <Stack spacing={2} sx={{ width: '100%' }}>
					<Snackbar open={showAlert} autoHideDuration={6000} onClose={hideAlert} anchorOrigin={{vertical,horizontal}}  >
						<Alert onClose={hideAlert} variant="filled" severity={severityAlert} sx={{ width: '100%' }}>
							{alertMessage}
						</Alert>
					</Snackbar>
				</Stack>

    </>
  );

});

export default CustomizedDialogs;