import React from 'react';
import { withStyles } from '@material-ui/core/styles';
import {Grid, Box, Button} from '@material-ui/core';
import { LoadingButton } from '@mui/lab';
import TextField from '@mui/material/TextField';
import Select from '@mui/material/Select';
import MenuItem from '@mui/material/MenuItem';
import { makeStyles } from "@material-ui/core/styles";
import Stack from '@mui/material/Stack';
import Snackbar from '@mui/material/Snackbar';
import Alert from '@mui/material/Alert';
import Dialog from '@material-ui/core/Dialog';
import MuiDialogTitle from '@material-ui/core/DialogTitle';
import MuiDialogContent from '@material-ui/core/DialogContent';
import IconButton from '@material-ui/core/IconButton';
import CloseIcon from '@material-ui/icons/Close';
import Typography from '@material-ui/core/Typography';
import Cookies from 'js-cookie';
import moment from 'moment';
import axios from 'axios';
import { useSelector } from 'react-redux';
import {API_URL} from '../utils/EnvVars';

const styles = (theme) => ({
  root: {
    margin: 0,
    padding: theme.spacing(2),
  },
  closeButton: {
    position: 'absolute',
    right: theme.spacing(1),
    top: theme.spacing(1),
    color: theme.palette.grey[500],
  },
});

const useStyles = makeStyles({
  paper: {
    fontSize: '12px !important',    
  }
});

var vertical='top',horizontal='center';

const DialogTitle = withStyles(styles)((props) => {
  const { children, classes, onClose, ...other } = props;
  return (
    <MuiDialogTitle disableTypography className={classes.root} {...other}>
      <Typography variant="h6">{children}</Typography>
      {onClose ? (
        <IconButton aria-label="close" className={classes.closeButton} onClick={onClose}>
          <CloseIcon />
        </IconButton>
      ) : null}
    </MuiDialogTitle>
  );
});

const DialogContent = withStyles((theme) => ({
  root: {
    padding: theme.spacing(2),
  },
}))(MuiDialogContent);

const CustomizedDialogs = React.forwardRef((props, ref) => {  
  const classes = useStyles();
  const userObj = useSelector(state => state.userDetails);
  const [open, setOpen] = React.useState(false); 
  const [severityAlert, setSeverityAlert] = React.useState("error");
  const [showAlert, setShowAlert] = React.useState(false);
  const [alertMessage, setAlertMessage] = React.useState("");
  const [saveLoading, setSaveLoading] = React.useState(false);

  const [websiteId, setWebsiteId] = React.useState("noselect");
  const [webUrl, setWebUrl] = React.useState("");

  const [webCategories, setWebCategories] = React.useState([]);
  const [categoryName, setCategoryName] = React.useState("");
  const [categoryId, setCategoryId] = React.useState("noselect");
  const [categoryLoadingMsg, setCategoryLoadingMsg] = React.useState("Select Website for categories");
  
  const [freeOrganisationId, setFreeOrganisationId] = React.useState("noselect");
  const [freeOrganisationName, setFreeOrganisationName] = React.useState("");

  const [paidOrganisationId, setPaidOrganisationId] = React.useState("noselect");
  const [paidOrganisationName, setPaidOrganisationName] = React.useState("");
  
  const [courseTitle, setCourseTitle] = React.useState(""); 
  const [courseSubTitle, setCourseSubTitle] = React.useState("");
  const [headingDescription, setHeadingDescription] = React.useState("");
  const [courseDetailMobile, setCourseDetailMobile] = React.useState("");
  const [retailPrice, setRetailPrice] = React.useState("");
  const [salePrice, setSalePrice] = React.useState("");

  const [validityNumber, setValidityNumber] = React.useState(2);
  ///const [validityUnit, setValidityUnit] = React.useState("year");
  const [status, setStatus] = React.useState(1);

  var myCurrentDate=new Date();
	var myPastFromDate=new Date(myCurrentDate);
  myPastFromDate.setDate(myPastFromDate.getDate() + 185);
	const [validityDate, setValidityDate] = React.useState(moment(myPastFromDate).format('YYYY-MM-DD'));

  
  var myCurrentDate=new Date();
	var myPastFromDate=new Date(myCurrentDate);
  myPastFromDate.setDate(myPastFromDate.getDate() + 365);

  React.useImperativeHandle(ref, () => ({
    handleClickOpen(){
      setOpen(true);
    }
  }));
  
  const handleClose = () => {
    setOpen(false);
  };

  function hideAlert(){
		setShowAlert(false);
	}

  function handleWebsite(webId){    
    if(webId>0 && props.websites.length>0){
      for(let i=0; i<props.websites.length; i++){
        if(props.websites[i].autoId===webId){
          setWebsiteId(props.websites[i].autoId);
          setWebUrl(props.websites[i].webUrl);
        }
      }
      getApiCategories(userObj.emailId,userObj.token,webId);
    }
  }

  async function getApiCategories(emailId,token,websiteId){
    axios.get(API_URL+'/admin-subscription-courses-categories?loginEmailId='+emailId+'&token='+token+"&websiteId="+websiteId)
       .then(response => {
       if(response.data && response.data.responseTxt==="InvalidToken"){ 
					Cookies.remove('isadminloggedin');
					window.location.href='login';
			 }else if(response && response.data && response.data.responseTxt==="success" && response.data.list && response.data.list.length>0){
          setCategoryLoadingMsg("Found");
          setWebCategories(response.data.list);
       }else{
          setCategoryLoadingMsg("Category not found");
       }	 				
    })
  }
  
  function handleFreeOrganisation(id){    
    if(id>0 && props.organisations.length>0){
      for(let i=0; i<props.organisations.length; i++){
        if(props.organisations[i].organisationId===id){
          setFreeOrganisationId(props.organisations[i].organisationId);
          setFreeOrganisationName(props.organisations[i].organisationName);
          if(!courseTitle){
            setCourseTitle(props.organisations[i].organisationName);
          }
        }
      }
    }
  }

  function handlePaidOrganisation(id){    
    if(id>0 && props.organisations.length>0){
      for(let i=0; i<props.organisations.length; i++){
        if(props.organisations[i].organisationId===id){
          setPaidOrganisationId(props.organisations[i].organisationId);
          setPaidOrganisationName(props.organisations[i].organisationName);
        }
      }
    }
  }

  function handleCategory(id){
    if(webCategories && id>0 && webCategories.length>0){
      for(let i=0; i<webCategories.length; i++){
        if(webCategories[i].autoId===id){
          setCategoryId(webCategories[i].autoId);
          setCategoryName(webCategories[i].categoryName);
        }
      }
    }
  }


  React.useEffect(() => {	
    if(props.dataObj!=null && props.dataObj.autoId){	
      setWebsiteId(props.dataObj.websiteId);
      setWebUrl(props.dataObj.webUrl);
      setFreeOrganisationId(props.dataObj.freeOrganisationId);
      setFreeOrganisationName(props.dataObj.freeOrganisationName);
      setPaidOrganisationId(props.dataObj.paidOrganisationId);
      setPaidOrganisationName(props.dataObj.paidOrganisationName);
      setCategoryId(props.dataObj.categoryId);
      setCategoryName(props.dataObj.categoryName);      
      setCourseTitle(props.dataObj.courseTitle);
      setCourseSubTitle(props.dataObj.courseSubTitle);
      setHeadingDescription(props.dataObj.headingDescription);
      setCourseDetailMobile(props.dataObj.courseDetailMobile);
      setRetailPrice(props.dataObj.retailPrice);
      setSalePrice(props.dataObj.salePrice);
      setValidityNumber(props.dataObj.validityNumber);
      ///setValidityUnit(props.dataObj.validityUnit);
      // Populate categories
      getApiCategories(userObj.emailId,userObj.token,props.dataObj.websiteId);
      setValidityDate(props.dataObj.validityDate);
      if(props.dataObj.validityDate){
        let dateArr = props.dataObj.validityDate.split("-");
        setValidityDate(moment(new Date(dateArr[2]+"-"+dateArr[1]+"-"+dateArr[0])).format('YYYY-MM-DD'))
      }

    }else{
      setWebsiteId("noselect");
      setWebUrl("");
      setFreeOrganisationId("noselect");
      setFreeOrganisationName("");
      setPaidOrganisationId("noselect");
      setPaidOrganisationName("");
      setCategoryId("noselect");
      setCategoryName("");      
      setCourseTitle("");
      setCourseSubTitle("");
      setHeadingDescription("");
      setCourseDetailMobile("");
      setRetailPrice("");
      setSalePrice("");
      setValidityNumber(2);
      ///setValidityUnit("year");
    }
	}, [props.dataObj]);

	function saveData(){    
    if(!webUrl){
      setSeverityAlert("error");
      setShowAlert(true);
      setAlertMessage("Select website");			
      return false;
    }  
    if(!categoryName){
      setSeverityAlert("error");
      setShowAlert(true);
      setAlertMessage("Select category");			
      return false;
    }
    if(!freeOrganisationName){
      setSeverityAlert("error");
      setShowAlert(true);
      setAlertMessage("Select free organisation");			
      return false;
    }
    if(!paidOrganisationName){
      setSeverityAlert("error");
      setShowAlert(true);
      setAlertMessage("Select paid organisation");			
      return false;
    }
    if(freeOrganisationName && paidOrganisationName && freeOrganisationName.substring(0,3)!==paidOrganisationName.substring(0,3)){
      setSeverityAlert("error");
      setShowAlert(true);
      setAlertMessage("Free and Paid organisation does not match");			
      return false;
    }
    if(!courseTitle){
      setSeverityAlert("error");
      setShowAlert(true);
      setAlertMessage("Enter course title");			
      return false;
    }  

    
		if(webUrl && webUrl.length>1){ 
      setSaveLoading(true);

			let axiosHeader = {
				headers: {
					'Content-Type': 'multipart/mixed',
          'token': userObj.token,
          'loginEmailId': userObj.emailId,
				}
			}; 
			const data = new FormData();
      if(props.dataObj && props.dataObj.autoId){
        data.append('id', props.dataObj.autoId);
      }
      data.append('websiteId', websiteId);
      data.append('webUrl', webUrl);
      data.append('freeOrganisationId', freeOrganisationId);
      data.append('freeOrganisationName', freeOrganisationName);
      data.append('paidOrganisationId', paidOrganisationId);
      data.append('paidOrganisationName', paidOrganisationName);
      data.append('categoryId', categoryId);
      data.append('categoryName', categoryName);      
      data.append('courseTitle', courseTitle);
      data.append('courseSubTitle', courseSubTitle);
      data.append('headingDescription', headingDescription);
      data.append('courseDetailMobile', courseDetailMobile);
      
      if(retailPrice && salePrice){
        data.append('retailPrice', retailPrice);
        data.append('salePrice', salePrice);
      }

      data.append('validityNumber', validityNumber);
      ///data.append('validityUnit', validityUnit);
      data.append('validityDate', validityDate);
      data.append('status', status);

      let apiURL='/admin-new-subscription-courses';
      let myMessage="Course has been created.";
      if(props.dataObj!=null && props.dataObj.autoId){
          apiURL='/admin-update-subscription-courses';
          myMessage="Course has been updated.";
      }
             
			axios.post(API_URL+apiURL, data, axiosHeader)
			.then((response) => {
        setSaveLoading(false);
				console.log("RESPONSE RECEIVED: ", response.data.responseTxt);
				if(response.data.responseTxt==="success"){
          setSeverityAlert("success");
          setOpen(false);
					setShowAlert(true);
					setAlertMessage(myMessage);
          ///window.location.reload();	
					return false;
        }else if(response.data.responseTxt==="AlreadyExistsError"){
            setSeverityAlert("error");
            setOpen(true);
            setShowAlert(true);
            setAlertMessage("This course was created earlier. Kindly enter another course");
            return false;  					
				}else{
          setSeverityAlert("error");
					setShowAlert(true);
					setAlertMessage("This course could not be saved.");			
					return false;
				}
			})
			.catch((error) => {
				console.log("AXIOS ERROR: ", error);
			})	
		}		
	}
  
  return (
    <>
      <Dialog fullWidth maxWidth="md" onClose={handleClose} aria-labelledby="customized-dialog-title" open={open}>
        <DialogTitle style={{marginBottom:'-30px'}} onClose={handleClose}></DialogTitle>
          <DialogContent style={{height:'88vh'}}>
            <Grid item   md={12} xs={12} className="test-instructions" >
                  <div className="btmbdrgry"><h3>{props.dataObj!=null?<>Edit</>:<>New</>} Course</h3></div>
                  <p>
                      <table style={{backgroundColor:'#000000',width:'100%' }} cellSpacing="1" cellPadding="3" >
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Website</td>
                            <td style={{textAlign:'center'}} >
                            <Select 
                                style={{width:'100%'}}
                                classes={{ paper: classes.paper }}
                                labelId="select-class-label"
                                id="select-class"
                                value={websiteId}									
                                onChange={event => handleWebsite(event.target.value)}
                                variant="standard"
                              >
                                  <MenuItem value="noselect">Select Website</MenuItem>
                                  {props.websites?props.websites.map((myRow,mykey)=>(
                                    <MenuItem key={'tchr'+mykey} value={myRow.autoId}>{myRow.webUrl}</MenuItem>
                                  )):null}
                              </Select>
                            </td>                            
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Category Name</td>
                            <td style={{textAlign:'center'}} >
                            {(categoryLoadingMsg && categoryLoadingMsg=='Found' && webCategories && webCategories.length>0)?
                            <Select 
                                style={{width:'100%'}}
                                classes={{ paper: classes.paper }}
                                labelId="select-class-label"
                                id="select-class"
                                value={categoryId}									
                                onChange={event => handleCategory(event.target.value)}
                                variant="standard"
                              >
                                  <MenuItem value="noselect">Select Category</MenuItem>
                                  {webCategories?webCategories.map((myRow,mykey)=>(
                                    <MenuItem key={'tchr'+mykey} value={myRow.autoId}>{myRow.categoryName}</MenuItem>
                                  )):null}
                              </Select>
                              :categoryLoadingMsg}
                            </td>                            
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Organisation(Free/Paid)</td>
                            <td style={{textAlign:'center'}} >
                            <Select 
                                style={{width:'48%'}}
                                classes={{ paper: classes.paper }}
                                labelId="select-class-label"
                                id="select-class"
                                value={freeOrganisationId}									
                                onChange={event => handleFreeOrganisation(event.target.value)}
                                variant="standard"
                              >
                                  <MenuItem value="noselect">Free</MenuItem>
                                  {props.organisations?props.organisations.map((myRow,mykey)=>(
                                    <MenuItem key={'tchr'+mykey} value={myRow.organisationId}>{myRow.organisationName}</MenuItem>
                                  )):null}
                              </Select>
                              <Select 
                                style={{width:'48%', marginLeft: 15}}
                                classes={{ paper: classes.paper }}
                                labelId="select-class-label"
                                id="select-class"
                                value={paidOrganisationId}									
                                onChange={event => handlePaidOrganisation(event.target.value)}
                                variant="standard"
                              >
                                  <MenuItem value="noselect">Paid</MenuItem>
                                  {props.organisations?props.organisations.map((myRow,mykey)=>(
                                    <MenuItem key={'tchr'+mykey} value={myRow.organisationId}>{myRow.organisationName}</MenuItem>
                                  )):null}
                              </Select>

                            </td>                            
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Course Title</td>
                            <td style={{textAlign:'center'}} >
                            <TextField onChange={event => setCourseTitle(event.target.value)} value={courseTitle} placeholder={'Title'} sx={{width:'48%',fontSize: 10}} variant="standard" />
                            <TextField onChange={event => setCourseSubTitle(event.target.value)} value={courseSubTitle} placeholder={'Sub Title'} sx={{width:'48%',fontSize: 10, marginLeft: 2}} variant="standard" />
                            </td>                            
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Description for Desktop</td>
                            <td style={{textAlign:'center'}} >
                            <TextField onChange={event => setHeadingDescription(event.target.value)} value={headingDescription} placeholder={'Description for Desktop'} sx={{width:'99%',fontSize: 10}} variant="standard" multiline={true}  />
                            </td>                            
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Description for Mobile</td>
                            <td style={{textAlign:'center'}} >
                            <TextField onChange={event => setCourseDetailMobile(event.target.value)} value={courseDetailMobile} placeholder={'Description for Mobile'} sx={{width:'99%',fontSize: 10}} variant="standard" multiline={true}  />
                            </td>                            
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Price</td>
                            <td style={{textAlign:'center'}} >
                            <TextField onChange={event => setRetailPrice(event.target.value)} value={retailPrice} placeholder={'Retail Price'} sx={{width:'48%',fontSize: 10}} variant="standard" />
                            <TextField onChange={event => setSalePrice(event.target.value)} value={salePrice} placeholder={'Sale Price'} sx={{width:'48%',fontSize: 10, marginLeft: 2}} variant="standard" />
                            </td>                            
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Validity (Date for paid / Days for free)</td>
                            <td style={{textAlign:'center'}} >
                               <TextField
                                id="date"                                
                                type="date"
                                defaultValue={validityDate}
                                sx={{ width: '48%' }}
                                InputLabelProps={{
                                shrink: true,
                                }}
                                onChange={event => setValidityDate(event.target.value)}
                                variant="standard"
                                />    
                                <TextField 
                                   onChange={event => setValidityNumber(event.target.value)}
                                   value={validityNumber} 
                                   placeholder={'Days'} 
                                   sx={{width:'48%',fontSize: 10, marginLeft:2}} 
                                   variant="standard"
                                    />                           

                            </td>                            
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Status</td>
                            <td style={{textAlign:'center'}} >
                            <Select 
                                style={{width:'100%'}}
                                classes={{ paper: classes.paper }}
                                labelId="select-class-label"
                                id="select-class"
                                value={status}									
                                onChange={event => setStatus(event.target.value)}
                                variant="standard"
                              >
                                  <MenuItem value="1">Active</MenuItem>
                                  <MenuItem value="0">Inactive</MenuItem>
                              </Select>
                            </td>                            
                        </tr>
                        

                      </table>

                      <Box mt={2}>
                          <Button onClick={() => {handleClose()}} style={{marginRight:12}} size="small" variant="outlined" >Cancel</Button>
					    	          {saveLoading?
                          <LoadingButton loading={saveLoading} style={{backgroundColor:'#f49b6b',color:'#FFF',marginRight:10}} size="small" variant="contained"  >Wait</LoadingButton>
					    	          :
                          <Button onClick={() => {saveData()}} style={{backgroundColor:'#008000',color:'#FFF',marginRight:10}} size="small" variant="contained"  >Save</Button>
                          }
                      </Box>

                  </p>
            </Grid>
          </DialogContent>
      </Dialog>
      
        <Stack spacing={2} sx={{ width: '100%' }}>
					<Snackbar open={showAlert} autoHideDuration={6000} onClose={hideAlert} anchorOrigin={{vertical,horizontal}}  >
						<Alert onClose={hideAlert} variant="filled" severity={severityAlert} sx={{ width: '100%' }}>
							{alertMessage}
						</Alert>
					</Snackbar>
				</Stack>

    </>
  );

});

export default CustomizedDialogs;