import React from 'react';
import { withStyles } from '@material-ui/core/styles';
import Dialog from '@material-ui/core/Dialog';
import MuiDialogTitle from '@material-ui/core/DialogTitle';
import MuiDialogContent from '@material-ui/core/DialogContent';
import IconButton from '@material-ui/core/IconButton';
import axios from 'axios';
import LoadingButton from '@mui/lab/LoadingButton';
import {API_URL} from '../utils/EnvVars';
import TextField from '@mui/material/TextField';
import Alert from '@mui/material/Alert';
import Stack from '@mui/material/Stack';
import Snackbar from '@mui/material/Snackbar';
import Button from '@material-ui/core/Button';
import CloseIcon from '@material-ui/icons/Close';
import Typography from '@material-ui/core/Typography';
import { useSelector } from 'react-redux';

const styles = (theme) => ({
  root: {
    margin: 0,
    padding: theme.spacing(2),
  },
  closeButton: {
    position: 'absolute',
    right: theme.spacing(1),
    top: theme.spacing(1),
    color: theme.palette.grey[500],
  },
});

const DialogTitle = withStyles(styles)((props) => {
  const { children, classes, onClose, ...other } = props;
  return (
    <MuiDialogTitle disableTypography className={classes.root} {...other}>
      <Typography variant="h6">{children}</Typography>
      {onClose ? (
        <IconButton aria-label="close" className={classes.closeButton} onClick={onClose}>
          <CloseIcon />
        </IconButton>
      ) : null}
    </MuiDialogTitle>
  );
});

const DialogContent = withStyles((theme) => ({
  root: {
    padding: theme.spacing(2),
  },
}))(MuiDialogContent);

export default function CustomizedDialogs(props) {
  const userObj = useSelector(state => state.userDetails);
  const [open, setOpen] = React.useState(false);
  const [feedbackInput, setFeedbackInput] = React.useState("");
	const [showAlert, setShowAlert] = React.useState(false);
	const [submitResponse, setSubmitResponse] = React.useState(false);
	const [alertMessage, setAlertMessage] = React.useState("");
	
	var vertical='top',horizontal='center';
  
  function hideAlert(){
		setShowAlert(false);
	}

  const handleClickOpen = () => {
    setOpen(true);
  };
  
  const handleClose = () => {
    setOpen(false);
  };

  function submitTest(){  
    setOpen(false);  
      props.toCallParentMethod();      
  }

  React.useEffect(() => {
		setSubmitResponse(false);
	}, [open]);

  function submit(){
		
		if(!feedbackInput){
			setShowAlert(true);
			setAlertMessage("Enter your feedback details.");
			document.getElementById("feedbackinputid").focus();			
			return false;
		}else{
			document.getElementById('waitsubmitbtnid').style.display='';
			document.getElementById('submitbtnid').style.display='none';
			let axiosHeader = {
				headers: {
					'Content-Type': 'multipart/mixed',
				}
			};		  
			const data = new FormData();
			data.append('studentId', userObj.studentId);
      data.append('questionId', props.currentQuestionObj.questionDisplayId);
      data.append('feedback', feedbackInput);
			axios.post(API_URL+'/sendfeedback', data, axiosHeader)
			.then((response) => {
				///console.log("RESPONSE RECEIVED: ", response);
				if(response && response.data && response.data.responseTxt=="OK"){					
					document.getElementById('waitsubmitbtnid').style.display='none';
					document.getElementById('submitbtnid').style.display='';
					setSubmitResponse(true);
				}else{
					document.getElementById('waitsubmitbtnid').style.display='none';
					document.getElementById('submitbtnid').style.display='';
					setShowAlert(true);
					setAlertMessage("Error somewhere, Try after sometime.");			
					return false;
				}
			})
			.catch((error) => {
				console.log("AXIOS ERROR: ", error);
			})
		}  
	}
	

  return (
    <>
			<Button title="Send feedback about this question" variant="contained" onClick={handleClickOpen} color="secondary" >Feedback</Button>
      <Dialog onClose={handleClose} aria-labelledby="customized-dialog-title" open={open}>
        <DialogTitle onClose={handleClose}>
          Feedback For Question Id: {props.currentQuestionObj.questionDisplayId}  
        </DialogTitle>

        <DialogContent dividers>
            <div className="dialogSubmitTestBox">
              <div style={{width: 350, marginBottom:20}}>
              {submitResponse?<span style={{color:'#dea338',fontSize:16,fontWeight:'bold',lineHeight:2}}>Your feedback has been submitted successfully.</span>:
                <TextField
                    onChange={event => setFeedbackInput(event.target.value)}
                    id="feedbackinputid"
                    label="Feedback"
                    multiline                  
                    rows={4}
                    fullWidth
                />   
              }               
              </div>
                  {!submitResponse?<>
										<Button id="submitbtnid" onClick={()=>{submit()}} style={{backgroundColor:'#008000',color:'#FFFFFF'}} variant="contained">SUBMIT</Button>
										<LoadingButton 											
											loading
											loadingPosition="start"											
											variant="outlined"
											color="secondary"
											id="waitsubmitbtnid" 
											style={{textTransform: 'none',display:'none'}}
										>
											Wait...
										</LoadingButton></>
									:null}
             
             
              <Button onClick={() => { handleClose() }} style={{marginRight:20}} size="small" variant="outlined" >Close</Button>
            </div>
        </DialogContent>

        <Stack spacing={2} sx={{ width: '100%' }}>
					<Snackbar open={showAlert} autoHideDuration={6000} onClose={hideAlert} anchorOrigin={{vertical,horizontal}}  >
						<Alert onClose={hideAlert} variant="filled" severity="error" sx={{ width: '100%' }}>
							{alertMessage}
						</Alert>
					</Snackbar>
				</Stack>

      </Dialog>

    </>
  );
}
