import React from 'react';
import { withStyles } from '@material-ui/core/styles';
import {Grid, Box, Button} from '@material-ui/core';
import { LoadingButton } from '@mui/lab';
import TextField from '@mui/material/TextField';
import Select from '@mui/material/Select';
import MenuItem from '@mui/material/MenuItem';
import { makeStyles } from "@material-ui/core/styles";
import Stack from '@mui/material/Stack';
import Snackbar from '@mui/material/Snackbar';
import Alert from '@mui/material/Alert';
import Dialog from '@material-ui/core/Dialog';
import MuiDialogTitle from '@material-ui/core/DialogTitle';
import MuiDialogContent from '@material-ui/core/DialogContent';
import IconButton from '@material-ui/core/IconButton';
import CloseIcon from '@material-ui/icons/Close';
import Typography from '@material-ui/core/Typography';
import Cookies from 'js-cookie';
import moment from 'moment';
import axios from 'axios';
import { useSelector } from 'react-redux';
import {API_URL} from '../utils/EnvVars';

const styles = (theme) => ({
  root: {
    margin: 0,
    padding: theme.spacing(2),
  },
  closeButton: {
    position: 'absolute',
    right: theme.spacing(1),
    top: theme.spacing(1),
    color: theme.palette.grey[500],
  },
});

const useStyles = makeStyles({
  paper: {
    fontSize: '12px !important',    
  }
});

var vertical='top',horizontal='center';

const DialogTitle = withStyles(styles)((props) => {
  const { children, classes, onClose, ...other } = props;
  return (
    <MuiDialogTitle disableTypography className={classes.root} {...other}>
      <Typography variant="h6">{children}</Typography>
      {onClose ? (
        <IconButton aria-label="close" className={classes.closeButton} onClick={onClose}>
          <CloseIcon />
        </IconButton>
      ) : null}
    </MuiDialogTitle>
  );
});

const DialogContent = withStyles((theme) => ({
  root: {
    padding: theme.spacing(2),
  },
}))(MuiDialogContent);

const CustomizedDialogs = React.forwardRef((props, ref) => {  
  const classes = useStyles();
  const userObj = useSelector(state => state.userDetails);
  const [open, setOpen] = React.useState(false); 
  const [severityAlert, setSeverityAlert] = React.useState("error");
  const [showAlert, setShowAlert] = React.useState(false);
  const [alertMessage, setAlertMessage] = React.useState("");
  const [saveLoading, setSaveLoading] = React.useState(false);

  const [websiteId, setWebsiteId] = React.useState("noselect");
  const [webUrl, setWebUrl] = React.useState("");

  const [webCourses, setWebCourses] = React.useState([]);
  const [courseTitle, setCourseTitle] = React.useState("");
  const [courseId, setCourseId] = React.useState("noselect");
  const [courseLoadingMsg, setCourseLoadingMsg] = React.useState("Select Website for courses");
  
  const [code, setCode] = React.useState("");
  const [discountType, setDiscountType] = React.useState("Percent"); 
  const [discount, setDiscount] = React.useState(0);
  const [description, setDescription] = React.useState("");
  const [status, setStatus] = React.useState("Active");
  const [displayPublic, setDisplayPublic] = React.useState("Public");

  var currentDate=new Date();
	var myCurrentDate=new Date(currentDate);
  myCurrentDate.setDate(myCurrentDate.getDate());
	const [startDate, setStartDate] = React.useState(moment(myCurrentDate).format('YYYY-MM-DD'));

  var currentDate2=new Date();
	var myCurrentDate2=new Date(currentDate2);
  myCurrentDate2.setDate(myCurrentDate2.getDate() + 31);
	const [endDate, setEndDate] = React.useState(moment(myCurrentDate2).format('YYYY-MM-DD'));
  

  
  var myCurrentDate=new Date();
	var myPastFromDate=new Date(myCurrentDate);
  myPastFromDate.setDate(myPastFromDate.getDate() + 365);

  React.useImperativeHandle(ref, () => ({
    handleClickOpen(){
      setOpen(true);
    }
  }));
  
  const handleClose = () => {
    setOpen(false);
  };

  function hideAlert(){
		setShowAlert(false);
	}

  function handleWebsite(webId){    
    if(webId>0 && props.websites.length>0){
      for(let i=0; i<props.websites.length; i++){
        if(props.websites[i].autoId===webId){
          setWebsiteId(props.websites[i].autoId);
          setWebUrl(props.websites[i].webUrl);
        }
      }
      getApiCourses(userObj.emailId,userObj.token,webId);
    }
  }

  async function getApiCourses(emailId,token,websiteId){
    axios.get(API_URL+'/admin-subscription-courses?loginEmailId='+emailId+'&token='+token+"&websiteId="+websiteId)
       .then(response => {
       if(response && response.data && response.data.responseTxt==="success" && response.data.list && response.data.list.length>0){
          setCourseLoadingMsg("Found");
          setWebCourses(response.data.list);
       }else{
        setCourseLoadingMsg("Course not found");
       }	 				
    })
  }

  function handleCourse(id){
    if(webCourses && id>0 && webCourses.length>0){
      for(let i=0; i<webCourses.length; i++){
        if(webCourses[i].autoId===id){
          setCourseId(webCourses[i].autoId);
          setCourseTitle(webCourses[i].courseTitle);
        }
      }
    }
  }


  React.useEffect(() => {	
    if(props.dataObj && props.dataObj.autoId>0){	
      // Populate courses
      getApiCourses(userObj.emailId,userObj.token,props.dataObj.websiteId);
      setWebsiteId(props.dataObj.websiteId);
      setWebUrl(props.dataObj.webUrl);
      setCourseId(props.dataObj.courseId);
      setCourseTitle(props.dataObj.courseTitle);
      setCode(props.dataObj.code);
      setDiscountType(props.dataObj.discountType)
      setDiscount(props.dataObj.discount);
      setDescription(props.dataObj.description);
      setStatus(props.dataObj.status);
      setDisplayPublic(props.dataObj.displayPublic);
      
      if(props.dataObj.startDate){
        let dateArr = props.dataObj.startDate.split("-");
        setStartDate(moment(new Date(dateArr[2]+"-"+dateArr[1]+"-"+dateArr[0])).format('YYYY-MM-DD'))
      }
      if(props.dataObj.endDate){
        let dateArr = props.dataObj.endDate.split("-");
        setEndDate(moment(new Date(dateArr[2]+"-"+dateArr[1]+"-"+dateArr[0])).format('YYYY-MM-DD'))
      }

    }else{
      setWebsiteId("noselect");
      setWebUrl("");
      setCourseId("noselect");
      setCourseTitle("");
      setCode("");
      setDiscountType("Percent")
      setDiscount(0);
      setDescription("");
      setStatus("Active");
      setDisplayPublic("Public");
    }
	}, [props.dataObj]);

	function saveData(){    
    if(!webUrl){
      setSeverityAlert("error");
      setShowAlert(true);
      setAlertMessage("Select website");			
      return false;
    }  
    // if(!courseTitle){
    //   setSeverityAlert("error");
    //   setShowAlert(true);
    //   setAlertMessage("Select course");			
    //   return false;
    // }
    if(!code){
      setSeverityAlert("error");
      setShowAlert(true);
      setAlertMessage("Enter promo code");			
      return false;
    }
    if(code && /\s/.test(code.trim())){
      setSeverityAlert("error");
      setShowAlert(true);
      setAlertMessage("Promo code must not be contained space.");			
      return false;
    }
    if(!discount){
      setSeverityAlert("error");
      setShowAlert(true);
      setAlertMessage("Enter discount");			
      return false;
    }
    if(!description){
      setSeverityAlert("error");
      setShowAlert(true);
      setAlertMessage("Enter description");			
      return false;
    }

    
		if(webUrl && webUrl.length>1){ 
      setSaveLoading(true);

			let axiosHeader = {
				headers: {
					'Content-Type': 'multipart/mixed',
          'token': userObj.token,
          'loginEmailId': userObj.emailId,
				}
			}; 
			const data = new FormData();
      if(props.dataObj && props.dataObj.autoId>0){
        data.append('id', props.dataObj.autoId);
      }
      data.append('websiteId', websiteId);
      data.append('webUrl', webUrl);

      if(courseId && courseTitle){
        data.append('courseId', courseId);
        data.append('courseTitle', courseTitle);
      }

      data.append('code', code.trim());
      data.append('discountType', discountType);
      data.append('discount', discount);
      data.append('startDate', startDate);
      data.append('endDate', endDate);
      data.append('description', description);

      if(status && status==='Active'){
        data.append('status', 1);
      }else{
        data.append('status', 0);
      }

      if(displayPublic && displayPublic==='Public'){
        data.append('displayPublic', 1);
      }else{
        data.append('displayPublic', 0);
      }
      
      let apiURL='/admin-new-promo-code';
      let myMessage="Promo code has been created.";
      if(props.dataObj && props.dataObj.autoId>0){
          apiURL='/admin-update-promo-code';
          myMessage="Promo code has been updated.";
      }
             
			axios.post(API_URL+apiURL, data, axiosHeader)
			.then((response) => {
        setSaveLoading(false);
				console.log("RESPONSE RECEIVED: ", response.data.responseTxt);
				if(response.data.responseTxt==="success"){
          setSeverityAlert("success");
          setOpen(false);
					setShowAlert(true);
					setAlertMessage(myMessage);
          ///window.location.reload();	
					return false;
        }else if(response.data.responseTxt==="AlreadyExistsError"){
            setSeverityAlert("error");
            setOpen(true);
            setShowAlert(true);
            setAlertMessage("This promo code was created earlier. Kindly enter another promo code");
            return false;  					
        }else if(response.data.responseTxt==="InvalidToken"){ 
              Cookies.remove('isadminloggedin');
              window.location.href='login';                              
				}else{
          setSeverityAlert("error");
					setShowAlert(true);
					setAlertMessage("This promo code could not be saved.");			
					return false;
				}
			})
			.catch((error) => {
				console.log("AXIOS ERROR: ", error);
			})	
		}		
	}
  
  return (
    <>
      <Dialog fullWidth maxWidth="md" onClose={handleClose} aria-labelledby="customized-dialog-title" open={open}>
        <DialogTitle style={{marginBottom:'-30px'}} onClose={handleClose}></DialogTitle>
          <DialogContent style={{height:'88vh'}}>
            <Grid item   md={12} xs={12} className="test-instructions" >
                  <div className="btmbdrgry"><h3>{props.dataObj!=null?<>Edit</>:<>New</>} Promo Code</h3></div>
                  <p>
                      <table style={{backgroundColor:'#000000',width:'100%' }} cellSpacing="1" cellPadding="3" >
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Website</td>
                            <td style={{textAlign:'center'}} >
                            <Select 
                                style={{width:'100%'}}
                                classes={{ paper: classes.paper }}
                                labelId="select-class-label"
                                id="select-class"
                                value={websiteId}									
                                onChange={event => handleWebsite(event.target.value)}
                                variant="standard"
                              >
                                  <MenuItem value="noselect">Select Website</MenuItem>
                                  {props.websites?props.websites.map((myRow,mykey)=>(
                                    <MenuItem key={'tchr'+mykey} value={myRow.autoId}>{myRow.webUrl}</MenuItem>
                                  )):null}
                              </Select>
                            </td>                            
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Course</td>
                            <td style={{textAlign:'center'}} >
                            {(courseLoadingMsg && courseLoadingMsg=='Found' && webCourses && webCourses.length>0)?
                            <Select 
                                style={{width:'100%'}}
                                classes={{ paper: classes.paper }}
                                labelId="select-class-label"
                                id="select-class"
                                value={courseId}									
                                onChange={event => handleCourse(event.target.value)}
                                variant="standard"
                              >
                                  <MenuItem value="noselect">Select Course</MenuItem>
                                  {webCourses?webCourses.map((myRow,mykey)=>(
                                    <MenuItem key={'tchr'+mykey} value={myRow.autoId}>{myRow.courseTitle}</MenuItem>
                                  )):null}
                              </Select>
                              :courseLoadingMsg}
                            </td>                            
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Code</td>
                            <td style={{textAlign:'center'}} >
                            <TextField onChange={event => setCode(event.target.value)} value={code} placeholder={'Code'} sx={{width:'99%',fontSize: 10}} variant="standard" />
                            </td>                            
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Discount</td>
                            <td style={{textAlign:'center'}} >
                            <Select 
                                style={{width:'50%'}}
                                classes={{ paper: classes.paper }}
                                labelId="select-class-label"
                                id="select-class"
                                value={discountType}									
                                onChange={event => setDiscountType(event.target.value)}
                                variant="standard"
                              >
                                  <MenuItem value="Percent">Percent</MenuItem>
                                  <MenuItem value="Fixed">Fixed</MenuItem>
                            </Select>
                            <TextField onChange={event => setDiscount(event.target.value)} value={discount} placeholder={'Number'} sx={{width:'49%',fontSize: 10}} variant="standard" />
                            </td>                            
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Description</td>
                            <td style={{textAlign:'center'}} >
                            <TextField onChange={event => setDescription(event.target.value)} value={description} placeholder={'Description'} sx={{width:'99%',fontSize: 10}} variant="standard" multiline={true}  />
                            </td>                            
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Status / Display</td>
                            <td style={{textAlign:'center'}} >
                            <Select 
                                style={{width:'50%'}}
                                classes={{ paper: classes.paper }}
                                labelId="select-class-label"
                                id="select-class"
                                value={status}									
                                onChange={event => setStatus(event.target.value)}
                                variant="standard"
                              >
                                  <MenuItem value="Active">Active</MenuItem>
                                  <MenuItem value="Not Active">Not Active</MenuItem>
                            </Select>
                            <Select 
                                style={{width:'49%'}}
                                classes={{ paper: classes.paper }}
                                labelId="select-class-label"
                                id="select-class"
                                value={displayPublic}									
                                onChange={event => setDisplayPublic(event.target.value)}
                                variant="standard"
                              >
                                  <MenuItem value="Public">Public</MenuItem>
                                  <MenuItem value="Private">Private</MenuItem>
                            </Select>

                            </td>                            
                        </tr>

                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Start Date / Expire Date</td>
                            <td style={{textAlign:'center'}} >
                               <TextField
                                id="date"                                
                                type="date"
                                defaultValue={startDate}
                                sx={{ width: '50%' }}
                                InputLabelProps={{
                                shrink: true,
                                }}
                                onChange={event => setStartDate(event.target.value)}
                                variant="standard"
                                />    
                               <TextField
                                id="date"                                
                                type="date"
                                defaultValue={endDate}
                                sx={{ width: '49%' }}
                                InputLabelProps={{
                                shrink: true,
                                }}
                                onChange={event => setEndDate(event.target.value)}
                                variant="standard"
                                />    

                            </td>                            
                        </tr>
                        
                        

                      </table>

                      <Box mt={2}>
                          <Button onClick={() => {handleClose()}} style={{marginRight:12}} size="small" variant="outlined" >Cancel</Button>
					    	          {saveLoading?
                          <LoadingButton loading={saveLoading} style={{backgroundColor:'#008000',color:'#FFF',marginRight:10}} size="small" variant="contained"  >Save</LoadingButton>
					    	          :
                          <Button onClick={() => {saveData()}} style={{backgroundColor:'#008000',color:'#FFF',marginRight:10}} size="small" variant="contained"  >Save</Button>
                          }
                      </Box>

                  </p>
            </Grid>
          </DialogContent>
      </Dialog>
      
        <Stack spacing={2} sx={{ width: '100%' }}>
					<Snackbar open={showAlert} autoHideDuration={6000} onClose={hideAlert} anchorOrigin={{vertical,horizontal}}  >
						<Alert onClose={hideAlert} variant="filled" severity={severityAlert} sx={{ width: '100%' }}>
							{alertMessage}
						</Alert>
					</Snackbar>
				</Stack>

    </>
  );

});

export default CustomizedDialogs;