import React from 'react';
import { withStyles } from '@material-ui/core/styles';
import {Grid, Box, Button} from '@material-ui/core';
import { makeStyles } from "@material-ui/core/styles";
import Stack from '@mui/material/Stack';
import Snackbar from '@mui/material/Snackbar';
import Alert from '@mui/material/Alert';
import Dialog from '@material-ui/core/Dialog';
import MuiDialogTitle from '@material-ui/core/DialogTitle';
import MuiDialogContent from '@material-ui/core/DialogContent';
import IconButton from '@material-ui/core/IconButton';
import CloseIcon from '@material-ui/icons/Close';
import Typography from '@material-ui/core/Typography';
import TextField from '@mui/material/TextField';
import axios from 'axios';
import { useSelector } from 'react-redux';
import {API_URL} from '../utils/EnvVars';

const styles = (theme) => ({
  root: {
    margin: 0,
    padding: theme.spacing(2),
  },
  closeButton: {
    position: 'absolute',
    right: theme.spacing(1),
    top: theme.spacing(1),
    color: theme.palette.grey[500],
  },
});

var vertical='top',horizontal='center';

const DialogTitle = withStyles(styles)((props) => {
  const { children, classes, onClose, ...other } = props;
  return (
    <MuiDialogTitle disableTypography className={classes.root} {...other}>
      <Typography variant="h6">{children}</Typography>
      {onClose ? (
        <IconButton aria-label="close" className={classes.closeButton} onClick={onClose}>
          <CloseIcon />
        </IconButton>
      ) : null}
    </MuiDialogTitle>
  );
});

const DialogContent = withStyles((theme) => ({
  root: {
    padding: theme.spacing(2),
  },
}))(MuiDialogContent);

const CustomizedDialogs = React.forwardRef((props, ref) => {  
  const userObj = useSelector(state => state.userDetails);
  const [open, setOpen] = React.useState(false); 
  const [severityAlert, setSeverityAlert] = React.useState("error");
  const [showAlert, setShowAlert] = React.useState(false);
  const [alertMessage, setAlertMessage] = React.useState("");
  const [studentName, setStudentName] = React.useState("");
  const [phone, setPhone] = React.useState("");
  const [email, setEmail] = React.useState("");
  const [newPassword, setNewPassword] = React.useState("");
  const [retypeNewPassword, setRetypeNewPassword] = React.useState("");

  React.useImperativeHandle(ref, () => ({
    handleClickOpen(){
      setOpen(true);
    }
  }));
  
  const handleClose = () => {
    setOpen(false);
  };

  function hideAlert(){
		setShowAlert(false);
	}

  React.useEffect(() => {
    if(props.studentObj){		
      setStudentName(props.studentObj.sname);
      setPhone(props.studentObj.phoneNo);
      setEmail(props.studentObj.emailId);
      setNewPassword("");
      setRetypeNewPassword("");
    }
	}, [props.studentObj]);

	function saveData(){

    if(!studentName){
      setSeverityAlert("error");
      setShowAlert(true);
      setAlertMessage("Enter student name");			
      return false;
    }

    if(newPassword && retypeNewPassword && newPassword!==retypeNewPassword){
      setSeverityAlert("error");
      setShowAlert(true);
      setAlertMessage("New password and retype new password does not match");			
      return false;
    }

		if(studentName){ 
			let axiosHeader = {
				headers: {
					'Content-Type': 'multipart/mixed',
          'token': userObj.token,
          'loginEmailId': userObj.emailId,
				}
			}; 
			const data = new FormData();
      data.append('id', props.studentObj.autoId);
      data.append('studentName', studentName);
      data.append('phone', phone);
      data.append('emailId', email);
      data.append('newPassword', newPassword);
             
			axios.post(API_URL+'/admin-updatestudentdetail', data, axiosHeader)
			.then((response) => {
				console.log("RESPONSE RECEIVED: ", response);
				if(response.data.responseTxt==="OK"){
          setSeverityAlert("success");
          setOpen(false);
					setShowAlert(true);
					setAlertMessage("Student details has been updated.");
					return false;
				}else{
          setSeverityAlert("error");
					setShowAlert(true);
					setAlertMessage("Student details could not be saved.");			
					return false;
				}
			})
			.catch((error) => {
				console.log("AXIOS ERROR: ", error);
			})	
		}		
	}

  
  
  return (
    <>
      <Dialog fullWidth maxWidth="md" onClose={handleClose} aria-labelledby="customized-dialog-title" open={open}>
        <DialogTitle style={{marginBottom:'-30px'}} onClose={handleClose}></DialogTitle>
          <DialogContent style={{height:'88vh'}}>
            <Grid item   md={12} xs={12} className="test-instructions" >
                  <div className="btmbdrgry"><h3>Edit Student</h3></div>
                  <p>
                      <table style={{backgroundColor:'#000000',width:'100%' }} cellSpacing="1" cellPadding="3" >
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Student Name</td>
                            <td style={{textAlign:'center'}} >
                            <TextField onChange={event => setStudentName(event.target.value)} value={studentName} sx={{width:'99%',fontSize: 10}} variant="standard" />
                            </td>                            
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Phone</td>
                            <td style={{textAlign:'center'}} >
                            <TextField onChange={event => setPhone(event.target.value)} value={phone} style={{width:'99%'}} variant="standard" />
                            </td>
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                          <td>Email</td>
                          <td style={{textAlign:'center'}} >
                          <TextField onChange={event => setEmail(event.target.value)} value={email} style={{width:'99%'}} variant="standard" />
                          </td>                            
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                          <td>New Password</td>
                          <td style={{textAlign:'center'}} >
                          <TextField onChange={event => setNewPassword(event.target.value)} value={newPassword} type="password" style={{width:'99%'}} variant="standard" />
                          </td>
                        </tr>                     
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                          <td>Re-type New Password</td>
                          <td style={{textAlign:'center'}} >
                          <TextField onChange={event => setRetypeNewPassword(event.target.value)} value={retypeNewPassword} type="password" style={{width:'99%'}} variant="standard" />
                          </td>
                        </tr>                     
                                              
                      </table>

                      <Box mt={2}>
                          <Button onClick={() => {handleClose()}} style={{marginRight:12}} size="small" variant="outlined" >Cancel</Button>
					    	          <Button onClick={() => {saveData()}} size="small" variant="contained" style={{backgroundColor:'#008000',color:'#FFF',marginRight:10}} >Save</Button>
								      </Box>

                  </p>
            </Grid>
          </DialogContent>
      </Dialog>
      
        <Stack spacing={2} sx={{ width: '100%' }}>
					<Snackbar open={showAlert} autoHideDuration={6000} onClose={hideAlert} anchorOrigin={{vertical,horizontal}}  >
						<Alert onClose={hideAlert} variant="filled" severity={severityAlert} sx={{ width: '100%' }}>
							{alertMessage}
						</Alert>
					</Snackbar>
				</Stack>

    </>
  );

});

export default CustomizedDialogs;