import React from 'react';
import { withStyles } from '@material-ui/core/styles';
import {Grid, Box, Button} from '@material-ui/core';
import Select from '@mui/material/Select';
import MenuItem from '@mui/material/MenuItem';
import { makeStyles } from "@material-ui/core/styles";
import Stack from '@mui/material/Stack';
import Snackbar from '@mui/material/Snackbar';
import Alert from '@mui/material/Alert';
import Dialog from '@material-ui/core/Dialog';
import MuiDialogTitle from '@material-ui/core/DialogTitle';
import MuiDialogContent from '@material-ui/core/DialogContent';
import IconButton from '@material-ui/core/IconButton';
import CloseIcon from '@material-ui/icons/Close';
import Typography from '@material-ui/core/Typography';
import TextField from '@mui/material/TextField';
import moment from 'moment';
import axios from 'axios';
import { useSelector } from 'react-redux';
import {API_URL} from '../utils/EnvVars';

const styles = (theme) => ({
  root: {
    margin: 0,
    padding: theme.spacing(2),
  },
  closeButton: {
    position: 'absolute',
    right: theme.spacing(1),
    top: theme.spacing(1),
    color: theme.palette.grey[500],
  },
});

const useStyles = makeStyles({
  paper: {
    fontSize: '12px !important',    
  }
});

var vertical='top',horizontal='center';

const DialogTitle = withStyles(styles)((props) => {
  const { children, classes, onClose, ...other } = props;
  return (
    <MuiDialogTitle disableTypography className={classes.root} {...other}>
      <Typography variant="h6">{children}</Typography>
      {onClose ? (
        <IconButton aria-label="close" className={classes.closeButton} onClick={onClose}>
          <CloseIcon />
        </IconButton>
      ) : null}
    </MuiDialogTitle>
  );
});

const DialogContent = withStyles((theme) => ({
  root: {
    padding: theme.spacing(2),
  },
}))(MuiDialogContent);

const CustomizedDialogs = React.forwardRef((props, ref) => {  
  const classes = useStyles();
  const userObj = useSelector(state => state.userDetails);
  const [open, setOpen] = React.useState(false); 
  const [severityAlert, setSeverityAlert] = React.useState("error");
  const [showAlert, setShowAlert] = React.useState(false);
  const [alertMessage, setAlertMessage] = React.useState("");
  const [studentId, setStudentId] = React.useState("");
  const [studentName, setStudentName] = React.useState("");
  const [phone, setPhone] = React.useState("");
  const [email, setEmail] = React.useState("");
  const [newPassword, setNewPassword] = React.useState("");

  
  const [webCourses, setWebCourses] = React.useState([]);
  const [courseLoadingMsg, setCourseLoadingMsg] = React.useState("Select a website for courses");
  const [websiteId, setWebsiteId] = React.useState("noselect");
  const [webUrl, setWebUrl] = React.useState("");
  const [courseId, setCourseId] = React.useState("noselect");
  const [courseTitle, setCourseTitle] = React.useState("");
  const [organisationId, setOrganisationId] = React.useState(0);
  const [subscriptionType, setSubscriptionType] = React.useState("FREE");

  const [schoolId, setSchoolId] = React.useState("noselect");
  const [schoolName, setSchoolName] = React.useState("");
  const [className, setClassName] = React.useState("noselect");
  ////const [classCourseId, setClassCourseId] = React.useState(0);
  const [classLoadingMsg, setClassLoadingMsg] = React.useState("Select an academy for batches");
  const [classList, setClassList] = React.useState([]);

  var myCurrentDate=new Date();
	var myPastFromDate=new Date(myCurrentDate);
  myPastFromDate.setDate(myPastFromDate.getDate() + 30);
	const [validityDate, setValidityDate] = React.useState(moment(myPastFromDate).format('YYYY-MM-DD'));

  React.useImperativeHandle(ref, () => ({
    handleClickOpen(){
      setOpen(true);
    }
  }));
  
  const handleClose = () => {
    setOpen(false);
  };

  function hideAlert(){
		setShowAlert(false);
	}

  function handleWebsite(webId){    
    if(webId>0 && props.websites.length>0){
      for(let i=0; i<props.websites.length; i++){
        if(props.websites[i].autoId===webId){
          setWebsiteId(props.websites[i].autoId);
          setWebUrl(props.websites[i].webUrl);
        }
      }
      getApiCourses(userObj.emailId,userObj.token,webId);
    }
  }

  async function getApiCourses(emailId,token,websiteId){
    axios.get(API_URL+'/admin-subscription-courses?loginEmailId='+emailId+'&token='+token+"&websiteId="+websiteId)
       .then(response => {
       if(response && response.data && response.data.responseTxt==="success" && response.data.list && response.data.list.length>0){
          setCourseLoadingMsg("Found");
          setWebCourses(response.data.list);
       }else{
          setCourseLoadingMsg("Course not found");
       }	 				
    })
  }

  function handleCourse(id){
    if(webCourses && id>0 && webCourses.length>0){
      for(let i=0; i<webCourses.length; i++){
        if(webCourses[i].autoId===id){
          setCourseId(webCourses[i].autoId);
          setCourseTitle(webCourses[i].courseTitle);
          if(subscriptionType==='PAID'){
            setOrganisationId(webCourses[i].paidOrganisationId);
          }else{
            setOrganisationId(webCourses[i].freeOrganisationId);
          }
        }
      }
    }
  }

  function handleSubscriptionType(stype){
    if(webCourses && courseTitle && courseId && webCourses.length>0){
      for(let i=0; i<webCourses.length; i++){
        if(webCourses[i].autoId===courseId){
          setSubscriptionType(stype);
          if(stype==='PAID'){
            setOrganisationId(webCourses[i].paidOrganisationId);
          }else{
            setOrganisationId(webCourses[i].freeOrganisationId);
          }
        }
      }
    }
  }

  React.useEffect(() => {    
    setSubscriptionType("FREE");
    setCourseId("noselect");
    setCourseTitle("");
    setOrganisationId(0);
    setStudentId("");
    setStudentName("");
    setPhone("");
    setEmail("");
    setNewPassword("");
  
	}, [open]);

  const validateEmail = (email) => {
    return String(email)
      .toLowerCase()
      .match(
        /^(([^<>()[\]\\.,;:\s@"]+(\.[^<>()[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/
      );
  };

	function saveData(){
    if(!webUrl){
      setSeverityAlert("error");
      setShowAlert(true);
      setAlertMessage("Select website");			
      return false;
    }
    if(!courseTitle){
      setSeverityAlert("error");
      setShowAlert(true);
      setAlertMessage("Select course");			
      return false;
    }
    if(!studentId){        
        setSeverityAlert("error");
				setShowAlert(true);
				setAlertMessage("Student Login Id can not be empty.");	
				return false;
    }
    if(!newPassword){
      setSeverityAlert("error");
      setShowAlert(true);
      setAlertMessage("Password can not be empty.");			
      return false;
    }
    if(!studentName){
      setSeverityAlert("error");
      setShowAlert(true);
      setAlertMessage("Enter student name");			
      return false;
    } 
    if(!phone){
      setSeverityAlert("error");
      setShowAlert(true);
      setAlertMessage("Enter phone.");			
      return false;
    }    
    if(email && email.length>0 && !validateEmail(email) ){
      setSeverityAlert("error");
      setShowAlert(true);
      setAlertMessage("Email is not valid.");			
      return false;
    }

		if(studentName && courseTitle){ 
			let axiosHeader = {
				headers: {
					'Content-Type': 'multipart/mixed',
          'token': userObj.token,
          'loginEmailId': userObj.emailId,
				}
			}; 

      const data = new FormData();
      data.append('subscriptionType', subscriptionType);
      data.append('courseId', courseId);
      data.append('courseTitle', courseTitle);
      data.append('organisationId', organisationId);
      data.append('studentId', studentId);
      data.append('studentName', studentName);
      data.append('phone', phone);
      data.append('emailId', email);
      data.append('newPassword', newPassword);
      data.append('validityDate', moment(validityDate).format('YYYY-MM-DD'));
      
      if(schoolId && schoolId>0){
        data.append('schoolId', schoolId);
        data.append('schoolName', schoolName);
      }else{
        data.append('schoolId', 0);
        data.append('schoolName', '');
      }

      if(className && className!=='noselect' && courseId && courseId>0){ 
        data.append('className', className);
        data.append('classCourseId', courseId);
      }else{
        data.append('className', '');
        data.append('courseId', 0);
        data.append('classCourseId', 0);
      }

			axios.post(API_URL+'/newstudentcreationadmin', data, axiosHeader)
			.then((response) => {
				console.log("RESPONSE RECEIVED: ", response.data.responseTxt);
				if(response.data.responseTxt==="OK"){
          setSeverityAlert("success");
          setOpen(false);
					setShowAlert(true);
					setAlertMessage("Student details has been saved.");
          window.location.reload();	
					return false;
        }else if(response.data.responseTxt==="AlreadyExistsError"){
            setSeverityAlert("error");
            setOpen(true);
            setShowAlert(true);
            setAlertMessage("Student Login Id must be unique. It is associated with another student.");
            return false;  					
				}else{
          setSeverityAlert("error");
					setShowAlert(true);
					setAlertMessage("Student details could not be saved.");			
					return false;
				}
			})
			.catch((error) => {
          setSeverityAlert("error");
					setShowAlert(true);
					setAlertMessage(""+error);			
					return false;
			})	
		}		
	}
  
  const handleSchool = (sid) => {
    if(sid>0 && props.schools && props.schools.length>0){
      setClassLoadingMsg("Batch not found");
      for(let i=0; i<props.schools.length; i++){
        if(props.schools[i].autoId===sid && props.schools[i].list && props.schools[i].list.length>0){
          setClassLoadingMsg("Found");
          setSchoolId(props.schools[i].autoId);
          setSchoolName(props.schools[i].schoolName);
          setClassList(props.schools[i].list);
          break;
        }
      }      
    }else{
      setSchoolId("noselect");
      setSchoolName("");
      setClassList([]);
      setClassLoadingMsg("Select an academy for batches");
    }

  }

  const handleClassName = (clsName) => {
    if(clsName!=='noselect' && clsName.length>0){
        setClassName(clsName);
        if(clsName && classList && classList.length>0){
          for(let i=0; i<classList.length; i++){
            if(classList[i].className===clsName){
              setCourseId(classList[i].courseId);
              break;
            }
          }      
        }
    }else{
      setClassName(("noselect"));
      setCourseId(0);
    }
}


  return (
    <>
      <Dialog fullWidth maxWidth="md" onClose={handleClose} aria-labelledby="customized-dialog-title" open={open}>
        <DialogTitle style={{marginBottom:'-30px'}} onClose={handleClose}></DialogTitle>
          <DialogContent style={{height:'80vh'}}>
            <Grid item   md={12} xs={12} className="test-instructions" >
                  <div className="btmbdrgry"><h3>New Student</h3></div>
                  <p>
                      <table style={{backgroundColor:'#000000',width:'100%' }} cellSpacing="1" cellPadding="3" >
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Subscription Type</td>
                            <td style={{textAlign:'center'}} >
                            <Select 
                                style={{width:'100%'}}
                                classes={{ paper: classes.paper }}
                                labelId="select-class-label"
                                id="select-class"
                                value={subscriptionType}									
                                onChange={event => handleSubscriptionType(event.target.value)}
                                variant="standard"
                              >
                                  <MenuItem value="FREE">FREE</MenuItem>
                                  <MenuItem value="PAID">PAID</MenuItem>
                              </Select>
                            </td>                            
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Website</td>
                            <td style={{textAlign:'center'}} >
                                <Select 
                                style={{width:'100%'}}
                                classes={{ paper: classes.paper }}
                                labelId="select-class-label"
                                id="select-class"
                                value={websiteId}									
                                onChange={event => handleWebsite(event.target.value)}
                                variant="standard"
                              >
                                  <MenuItem value="noselect">Select Website</MenuItem>
                                  {(props.websites && props.websites.length>0)?
                                    props.websites.map((myRow,key)=>(
                                      <MenuItem key={'mtk'+key} value={myRow.autoId} >{myRow.webUrl}</MenuItem> 
                                    )):null}
                              </Select>
                            </td>                            
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Course</td>
                            <td style={{textAlign:'center'}} >
                            {(courseLoadingMsg && courseLoadingMsg==='Found' && webCourses && webCourses.length>0)?
                            <Select 
                                style={{width:'100%'}}
                                classes={{ paper: classes.paper }}
                                labelId="select-class-label"
                                id="select-class"
                                value={courseId}									
                                onChange={event => handleCourse(event.target.value)}
                                variant="standard"
                              >
                                  <MenuItem value="noselect">Select Course</MenuItem>
                                  {webCourses?webCourses.map((myRow,mykey)=>(
                                    <MenuItem key={'tchr'+mykey} value={myRow.autoId}>{myRow.courseTitle}</MenuItem>
                                  )):null}
                              </Select>
                              :courseLoadingMsg}
                            </td>                            
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Student Login Id</td>
                            <td style={{textAlign:'center'}} >
                            <TextField onChange={event => setStudentId(event.target.value)} value={studentId} sx={{width:'99%',fontSize: 10}} variant="standard" />
                            </td>                            
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                          <td>Password</td>
                          <td style={{textAlign:'center'}} >
                          <TextField type='password' onChange={event => setNewPassword(event.target.value)} value={newPassword} style={{width:'99%'}} variant="standard" />
                          </td>
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Student Name</td>
                            <td style={{textAlign:'center'}} >
                            <TextField onChange={event => setStudentName(event.target.value)} value={studentName} sx={{width:'99%',fontSize: 10}} variant="standard" />
                            </td>                            
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Phone</td>
                            <td style={{textAlign:'center'}} >
                            <TextField onChange={event => setPhone(event.target.value)} value={phone} style={{width:'99%'}} variant="standard" />
                            </td>
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                          <td>Email</td>
                          <td style={{textAlign:'center'}} >
                          <TextField onChange={event => setEmail(event.target.value)} value={email} style={{width:'99%'}} variant="standard" />
                          </td>                            
                        </tr>                        
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Validity</td>
                            <td style={{textAlign:'center'}} >
                                <TextField
                                id="date"                                
                                type="date"
                                defaultValue={validityDate}
                                sx={{ width: '100%' }}
                                InputLabelProps={{
                                shrink: true,
                                }}
                                onChange={event => setValidityDate(event.target.value)}
                                variant="standard"
                                />
                            </td>                            
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td style={{width:'40%'}} >Academy</td>
                            <td style={{textAlign:'center'}} >
                                <Select 
                                    style={{width:'100%'}}
                                    labelId="select-class-label"
                                    id="select-class"
                                    value={schoolId}									
                                    onChange={event => handleSchool(event.target.value)}
                                    variant="standard"
                                  >
                                      <MenuItem value="noselect">Select Academy</MenuItem>
                                      {props.schools?props.schools.map((myRow,index)=>(
                                        <MenuItem id={'a'+index} value={myRow.autoId} >{myRow.schoolName}</MenuItem>
                                      )):null}
                                  </Select>
                            </td>                            
                        </tr>           
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Batch</td>
                            <td style={{textAlign:'center'}} >
                              {(classLoadingMsg && classLoadingMsg==='Found' && classList && classList.length>0)?
                                  <Select 
                                    style={{width:'100%'}}
                                    labelId="select-class-label"
                                    id="select-class"
                                    value={className}									
                                    onChange={event => handleClassName(event.target.value)}
                                    variant="standard"
                                  >
                                      <MenuItem value="noselect">Select Batch</MenuItem>
                                      {classList?classList.map((myRow,index)=>(
                                        <MenuItem id={'b'+index} value={myRow.className} >{myRow.className}</MenuItem>
                                      )):null}
                                  </Select>
                              :classLoadingMsg}    
                            </td>
                        </tr>

                      </table>

                      <Box mt={2}>
                          <Button onClick={() => {handleClose()}} style={{marginRight:12}} size="small" variant="outlined" >Cancel</Button>
					    	          <Button onClick={() => {saveData()}} size="small" variant="contained" style={{backgroundColor:'#008000',color:'#FFF',marginRight:10}} >Save</Button>
								      </Box>

                  </p>
            </Grid>
          </DialogContent>
      </Dialog>
      
        <Stack spacing={2} sx={{ width: '100%' }}>
					<Snackbar open={showAlert} autoHideDuration={6000} onClose={hideAlert} anchorOrigin={{vertical,horizontal}}  >
						<Alert onClose={hideAlert} variant="filled" severity={severityAlert} sx={{ width: '100%' }}>
							{alertMessage}
						</Alert>
					</Snackbar>
				</Stack>

    </>
  );

});

export default CustomizedDialogs;