import React from 'react';
import { withStyles } from '@material-ui/core/styles';
import {DialogActions, DialogContentText} from '@mui/material';
import {Grid, Button} from '@material-ui/core';
import Dialog from '@material-ui/core/Dialog';
import MuiDialogTitle from '@material-ui/core/DialogTitle';
import MuiDialogContent from '@material-ui/core/DialogContent';
import IconButton from '@material-ui/core/IconButton';
import CloseIcon from '@material-ui/icons/Close';
import Typography from '@material-ui/core/Typography';
import 'font-awesome/css/font-awesome.min.css';

const styles = (theme) => ({
  root: {
    margin: 0,
    padding: theme.spacing(2),
  },
  closeButton: {
    position: 'absolute',
    right: theme.spacing(1),
    top: theme.spacing(1),
    color: theme.palette.grey[500],
  },
});

const DialogTitle = withStyles(styles)((props) => {
  const { children, classes, onClose, ...other } = props;
  return (
    <MuiDialogTitle disableTypography className={classes.root} {...other}>
      <Typography variant="h6">{children}</Typography>
      {onClose ? (
        <IconButton aria-label="close" className={classes.closeButton} onClick={onClose}>
          <CloseIcon />
        </IconButton>
      ) : null}
    </MuiDialogTitle>
  );
});

const DialogContent = withStyles((theme) => ({
  root: {
    padding: theme.spacing(2),
  },
}))(MuiDialogContent);

const CustomizedDialogs = React.forwardRef((props, ref) => {  
  const [open, setOpen] = React.useState(false); 

  const [deleteDialogShow, setDeleteDialogShow] = React.useState(false);
  const [webCourses, setWebCourses] = React.useState([]);
  const [delId, setDelId] = React.useState(0);

  React.useImperativeHandle(ref, () => ({
    handleClickOpen(){
      setOpen(true);
    }
  }));
  
  const handleClose = () => {
    setOpen(false);
  };

  const handleEdit = (index) => {
    props.editValidity(index);
  };

  const deleteValidityData = (id) => {
    setDeleteDialogShow(true);
    setDelId(id);
  };

  const deleteNow = () => {
    document.getElementById('validityRowId'+delId).style.display='none';
    props.deleteValidityData(delId);
    setDeleteDialogShow(false);
  };

  function deleteDialogHide(){
		setDeleteDialogShow(false);
	}


  React.useEffect(() => {
    if(props.studentObj && props.studentObj.courses){		
      setWebCourses(props.studentObj.courses);
    }
	}, [props.studentObj]);

  
  return (
    <>
      <Dialog fullWidth maxWidth="md" onClose={handleClose} aria-labelledby="customized-dialog-title" open={open}>
        <DialogTitle style={{marginBottom:'-30px'}} onClose={handleClose}></DialogTitle>
          <DialogContent style={{height:'88vh'}}>
            <Grid item   md={12} xs={12} className="test-instructions" >
                  <div className="btmbdrgry"><h3>{props.studentObj?props.studentObj.sname:null}</h3></div>
                  <p>
                      <table style={{backgroundColor:'#000000',width:'100%' }} cellSpacing="1" cellPadding="3" >
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td style={{fontWeight:'bold'}}>Course</td>
                            <td style={{fontWeight:'bold'}}>Subscription Type</td>
                            <td style={{fontWeight:'bold'}}>Validity</td>
                            <td style={{width:100}} ></td>                            
                        </tr>
                        {webCourses?webCourses.map((myRow,index)=>(
                              <tr id={'validityRowId'+myRow.id} key={'tra'+index} style={{backgroundColor:'#FFFFFF'}} >
                                    <td>{myRow.courseTitle}</td>
                                    <td>{myRow.subscriptionType}</td>
                                    <td>{myRow.validTillDate}</td>
                                    <td style={{textAlign:'center'}}>
                                        <i onClick={()=>{handleEdit(index)}} title="Edit" className="fa fa-pencil-square-o" style={{fontSize:15, color:'#333',marginLeft:15, cursor:'pointer'}} />
											                  <i onClick={()=>{deleteValidityData(myRow.id)}} title="Delete" className="fa fa-trash" style={{fontSize:15, color:'#333',marginLeft:15, cursor:'pointer'}} />
                                    </td>                            
                              </tr>  
                        )):null}
                        
                                              
                      </table>

                  </p>
            </Grid>
          </DialogContent>
      </Dialog>


        <Dialog
					open={deleteDialogShow}
					onClose={deleteDialogHide}
					aria-labelledby="alert-dialog-section-title"
					aria-describedby="alert-dialog-section-description"
				>
					<DialogTitle id="alert-dialog-section-title">
						Alert
					</DialogTitle>
					<DialogContent>
					<DialogContentText id="alert-dialog-section-description">
						Are you sure, You want to delete student course.
					</DialogContentText>
					</DialogContent>
					<DialogActions>
					<Button variant="outlined" size="small" onClick={()=>{deleteDialogHide()}}>Don't Delete</Button>
					<Button variant="contained" size="small" color="secondary" onClick={()=>{deleteNow()}} autoFocus>Yes, Delete</Button>
					</DialogActions>
				</Dialog>


    </>
  );

});

export default CustomizedDialogs;