import React from 'react';
import { withStyles } from '@material-ui/core/styles';
import {Grid, Box, Button} from '@material-ui/core';
import Select from '@mui/material/Select';
import MenuItem from '@mui/material/MenuItem';
import Checkbox from '@mui/material/Checkbox';
import { makeStyles } from "@material-ui/core/styles";
import Stack from '@mui/material/Stack';
import Snackbar from '@mui/material/Snackbar';
import Alert from '@mui/material/Alert';
import Dialog from '@material-ui/core/Dialog';
import MuiDialogTitle from '@material-ui/core/DialogTitle';
import MuiDialogContent from '@material-ui/core/DialogContent';
import IconButton from '@material-ui/core/IconButton';
import CloseIcon from '@material-ui/icons/Close';
import Typography from '@material-ui/core/Typography';
import TextField from '@mui/material/TextField';
import moment from 'moment';
import axios from 'axios';
import { useSelector } from 'react-redux';
import {API_URL} from '../utils/EnvVars';

const styles = (theme) => ({
  root: {
    margin: 0,
    padding: theme.spacing(2),
  },
  closeButton: {
    position: 'absolute',
    right: theme.spacing(1),
    top: theme.spacing(1),
    color: theme.palette.grey[500],
  },
});

const useStyles = makeStyles({
  paper: {
    fontSize: '12px !important',    
  }
});

var vertical='top',horizontal='center';

const DialogTitle = withStyles(styles)((props) => {
  const { children, classes, onClose, ...other } = props;
  return (
    <MuiDialogTitle disableTypography className={classes.root} {...other}>
      <Typography variant="h6">{children}</Typography>
      {onClose ? (
        <IconButton aria-label="close" className={classes.closeButton} onClick={onClose}>
          <CloseIcon />
        </IconButton>
      ) : null}
    </MuiDialogTitle>
  );
});

const DialogContent = withStyles((theme) => ({
  root: {
    padding: theme.spacing(2),
  },
}))(MuiDialogContent);

const CustomizedDialogs = React.forwardRef((props, ref) => {  
  const classes = useStyles();
  const userObj = useSelector(state => state.userDetails);
  const [open, setOpen] = React.useState(false); 
  const [severityAlert, setSeverityAlert] = React.useState("error");
  const [showAlert, setShowAlert] = React.useState(false);
  const [alertMessage, setAlertMessage] = React.useState("");
	const [validityDate, setValidityDate] = React.useState(moment(new Date()).format('YYYY-MM-DD'));

  const [autoId, setAutoId] = React.useState(0);
  const [courseId, setCourseId] = React.useState(0);
  const [courseTitle, setCourseTitle] = React.useState("");
  const [subscriptionType, setSubscriptionType] = React.useState("FREE");
  const [updateDate, setUpdateDate] = React.useState(false);
  const [studentId, setStudentId] = React.useState("");
  const [organisationId, setOrganisationId] = React.useState(0);

  React.useImperativeHandle(ref, () => ({
    handleClickOpen(){
      setOpen(true);
    }
  }));
  
  const handleClose = () => {
    setOpen(false);
  };

  function hideAlert(){
		setShowAlert(false);
	}

  React.useEffect(() => {    
    if(props.studentObj && props.studentObj.courses && props.studentObj.courses.length>0 && props.validityIndex>-1 ){      
      setAutoId(props.studentObj.courses[props.validityIndex].id);
      setCourseId(props.studentObj.courses[props.validityIndex].courseId);
      setCourseTitle(props.studentObj.courses[props.validityIndex].courseTitle);
      setStudentId(props.studentObj.studentId);
      setOrganisationId(props.studentObj.courses[props.validityIndex].organisationId);
      if(!props.studentObj.courses[props.validityIndex].subscriptionType){
        setSubscriptionType("FREE");
      }else{
        setSubscriptionType(props.studentObj.courses[props.validityIndex].subscriptionType);
      } 
      if(props.studentObj.courses[props.validityIndex].validTillDate){
        let dateArr = props.studentObj.courses[props.validityIndex].validTillDate.split("-");
        setValidityDate(moment(new Date(dateArr[2]+"-"+dateArr[1]+"-"+dateArr[0])).format('YYYY-MM-DD'))
      }
    }
	}, [props.studentObj, props.validityIndex]);

	function saveData(){
		if(validityDate && autoId){ 
			let axiosHeader = {
				headers: {
					'Content-Type': 'multipart/mixed',
          'token': userObj.token,
          'loginEmailId': userObj.emailId,
				}
			};  
			const data = new FormData();
      data.append('id', autoId);
      if(updateDate===true){
        data.append('updateDate', 1);
      }else{
        data.append('updateDate', 0);
      }
      if(courseId){
        data.append('courseId', courseId);
      }
      if(studentId){
        data.append('studentId', studentId);
      }
      if(organisationId){
        data.append('organisationId', organisationId);
      }
      if(subscriptionType){
        data.append('subscriptionType', subscriptionType);
      }
      if(validityDate){
        data.append('validityDate', moment(validityDate).format('YYYY-MM-DD'));
      }  
      
      props.studentObj.courses[props.validityIndex].subscriptionType = subscriptionType;
      props.studentObj.courses[props.validityIndex].validTillDate=validityDate;
             
			axios.post(API_URL+'/admin-validity-studentdetail', data, axiosHeader)
			.then((response) => {
				console.log("RESPONSE RECEIVED: ", response);
				if(response.data.responseTxt==="OK"){
          setSeverityAlert("success");
          setOpen(false);
					setShowAlert(true);
					setAlertMessage("Student details has been saved.");          
					return false;
				}else{
          setSeverityAlert("error");
					setShowAlert(true);
					setAlertMessage("Student details could not be saved.");			
					return false;
				}
			})
			.catch((error) => {
				console.log("AXIOS ERROR: ", error);
			})	
		}		
	}

  
  
  return (
    <>
      <Dialog fullWidth maxWidth="md" onClose={handleClose} aria-labelledby="customized-dialog-title" open={open}>
        <DialogTitle style={{marginBottom:'-30px'}} onClose={handleClose}></DialogTitle>
          <DialogContent style={{height:'88vh'}}>
            <Grid item   md={12} xs={12} className="test-instructions" >
                  <div className="btmbdrgry"><h3>{props.studentObj?props.studentObj.sname:null}</h3></div>
                  <p>
                      <table style={{backgroundColor:'#000000',width:'100%' }} cellSpacing="1" cellPadding="3" >
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Course</td>
                            <td>{courseTitle}</td>                            
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Subscription Type</td>
                            <td >
                            <Select 
                                style={{width:'100%'}}
                                classes={{ paper: classes.paper }}
                                labelId="select-class-label"
                                id="select-class"
                                value={subscriptionType}									
                                onChange={event => setSubscriptionType(event.target.value)}
                                variant="standard"
                              >
                                  <MenuItem value="FREE">FREE</MenuItem>
                                  <MenuItem value="PAID">PAID</MenuItem>
                              </Select>
                            </td>                            
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Validity</td>
                            <td style={{textAlign:'center'}} >
                                <TextField
                                id="date"                                
                                type="date"
                                defaultValue={validityDate}
                                sx={{ width: '100%' }}
                                InputLabelProps={{
                                shrink: true,
                                }}
                                onChange={event => setValidityDate(event.target.value)}
                                variant="standard"
                                />
                                <Checkbox defaultChecked={updateDate} onChange={()=>{setUpdateDate(!updateDate)}} /> Update Validity Date Only
                                
                            </td>                            
                        </tr>
                                              
                      </table>

                      <Box mt={2}>
                          <Button onClick={() => {handleClose()}} style={{marginRight:12}} size="small" variant="outlined" >Cancel</Button>
					    	          <Button onClick={() => {saveData()}} style={{marginRight:12}} size="small" variant="contained" style={{backgroundColor:'#008000',color:'#FFF',marginRight:10}} >Save</Button>
								      </Box>

                  </p>
            </Grid>
          </DialogContent>
      </Dialog>
      
        <Stack spacing={2} sx={{ width: '100%' }}>
					<Snackbar open={showAlert} autoHideDuration={6000} onClose={hideAlert} anchorOrigin={{vertical,horizontal}}  >
						<Alert onClose={hideAlert} variant="filled" severity={severityAlert} sx={{ width: '100%' }}>
							{alertMessage}
						</Alert>
					</Snackbar>
				</Stack>

    </>
  );

});

export default CustomizedDialogs;