import React from 'react';
import { withStyles } from '@material-ui/core/styles';
import Dialog from '@material-ui/core/Dialog';
import MuiDialogTitle from '@material-ui/core/DialogTitle';
import MuiDialogContent from '@material-ui/core/DialogContent';
import IconButton from '@material-ui/core/IconButton';
import Button from '@material-ui/core/Button';
import CloseIcon from '@material-ui/icons/Close';
import Typography from '@material-ui/core/Typography';

const styles = (theme) => ({
  root: {
    margin: 0,
    padding: theme.spacing(2),
  },
  closeButton: {
    position: 'absolute',
    right: theme.spacing(1),
    top: theme.spacing(1),
    color: theme.palette.grey[500],
  },
});

const DialogTitle = withStyles(styles)((props) => {
  const { children, classes, onClose, ...other } = props;
  return (
    <MuiDialogTitle disableTypography className={classes.root} {...other}>
      <Typography variant="h6">{children}</Typography>
      {onClose ? (
        <IconButton aria-label="close" className={classes.closeButton} onClick={onClose}>
          <CloseIcon />
        </IconButton>
      ) : null}
    </MuiDialogTitle>
  );
});

const DialogContent = withStyles((theme) => ({
  root: {
    padding: theme.spacing(2),
  },
}))(MuiDialogContent);

export default function CustomizedDialogs(props) {
  const [open, setOpen] = React.useState(false);

  const handleClickOpen = () => {
    setOpen(true);
  };
  
  const handleClose = () => {
    setOpen(false);
  };

  function submitTest(){  
    setOpen(false);  
      props.toCallParentMethod();      
  }

  function stopTestNow(){  
    setOpen(false);  
      props.toCallParentStopTestNow();      
  }
  function backToSelectTest(){
    if(props.testType==1){
		  window.location.href='selfassessor';
    }else if(props.testType==2){
		  window.location.href='selecttopictest';
    }else if(props.testType==4){
		  window.location.href='selectclasstest';    
    }else{
      window.location.href='selectmocktest';
    }  
	}
  return (
    <>
      <Button title="Save Test & Exit" onClick={handleClickOpen} variant="contained" color="primary" >Save Test & Exit</Button>
      <Dialog onClose={handleClose} aria-labelledby="customized-dialog-title" open={open}>
        <DialogTitle onClose={handleClose}>
          Save & Exit 
        </DialogTitle>

        <DialogContent dividers>
            <div className="dialogSubmitTestBox">
              <p>
                Click on 'Submit Test Now' for submitting your test for result.<br/> 
                Click on 'Stop Test & Continue Later', In case you want to stop your test, You can continue it later.  
                <br/><br/>               
              </p>
              <Button onClick={() => { submitTest() }} variant="contained" style={{backgroundColor:'#008000',color:'#FFFFFF'}} >Submit Test Now</Button>
              <Button onClick={() => { stopTestNow() }} variant="contained" color="secondary" >Stop Test & Continue... Later</Button>
              <Button onClick={() => { backToSelectTest() }} style={{marginRight:20}} size="small" variant="outlined" >Cancel Test</Button>
            </div>
        </DialogContent>

      </Dialog>
    </>
  );
}
