import React from 'react';
import { withStyles } from '@material-ui/core/styles';
import {Grid, Box, Button} from '@material-ui/core';
import Dialog from '@material-ui/core/Dialog';
import MuiDialogTitle from '@material-ui/core/DialogTitle';
import MuiDialogContent from '@material-ui/core/DialogContent';
import IconButton from '@material-ui/core/IconButton';
import CloseIcon from '@material-ui/icons/Close';
import Typography from '@material-ui/core/Typography';

const styles = (theme) => ({
  root: {
    margin: 0,
    padding: theme.spacing(2),
  },
  closeButton: {
    position: 'absolute',
    right: theme.spacing(1),
    top: theme.spacing(1),
    color: theme.palette.grey[500],
  },
});

const DialogTitle = withStyles(styles)((props) => {
  const { children, classes, onClose, ...other } = props;
  return (
    <MuiDialogTitle disableTypography className={classes.root} {...other}>
      <Typography variant="h6">{children}</Typography>
      {onClose ? (
        <IconButton aria-label="close" className={classes.closeButton} onClick={onClose}>
          <CloseIcon />
        </IconButton>
      ) : null}
    </MuiDialogTitle>
  );
});

const DialogContent = withStyles((theme) => ({
  root: {
    padding: theme.spacing(2),
  },
}))(MuiDialogContent);

const CustomizedDialogs = React.forwardRef((props, ref) => {  
  const [open, setOpen] = React.useState(false);

  React.useImperativeHandle(ref, () => ({
    handleClickOpen(){
      setOpen(true);
    }
  }));
  
  const handleClose = () => {
    setOpen(false);
  };

  function goToLocation(){ 
    setOpen(false);
    props.toCallStartTest();
	}
  
  return (
    <>
      <Dialog fullWidth maxWidth="md" onClose={handleClose} aria-labelledby="customized-dialog-title" open={open}>
        <DialogTitle style={{marginBottom:'-30px'}} onClose={handleClose}></DialogTitle>
          <DialogContent style={{height:'88vh'}}>
            <Grid item   md={12} xs={12} className="test-instructions" >
                  <div className="btmbdrgry"><h3>{props.testDetail.testName}</h3></div>
                  <p>
                      <table style={{backgroundColor:'#000000',width:'100%' }} cellSpacing="1" cellPadding="5" >
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Total Questions</td>
                            <td style={{textAlign:'center'}} >{props.testDetail.totalQuestions}</td>                            
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Total time for Test(minute)</td>
                            <td style={{textAlign:'center'}} >{props.testDetail.testTotalTime}</td>
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Total Marks</td>
                            <td style={{textAlign:'center'}} >{props.testDetail.totalMarks}</td>
                        </tr>
                        {(props.testDetail && props.testDetail.sectionSet && !props.testDetail.sectionSet[0])?
                        <>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                          <td>Correct Marks</td>
                          <td style={{textAlign:'center'}} >{props.testDetail.correctAnsMark}</td>                            
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                          <td>Wrong Marks</td>
                          <td style={{textAlign:'center'}} >{props.testDetail.wrongAnsMark}</td>
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                          <td>Not Answered Marks</td>
                          <td style={{textAlign:'center'}} >{props.testDetail.noAnsMark}</td>
                        </tr></>
                        :null}
                      </table>

                      {(props.testDetail && props.testDetail.sectionSet && props.testDetail.sectionSet[0])?
                      <table style={{backgroundColor:'#000000',width:'100%',marginTop:20 }} cellSpacing="1" cellPadding="5" >
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                          <th>Section</th>
                          <th>Question Range</th>
                          <th>Correct Marks</th>
                          <th>Incorrect Marks</th>
                          <th>Not Answered Marks</th>
                          {(props.testDetail && props.testDetail.sectionSet && props.testDetail.sectionSet[0] && props.testDetail.sectionSet[0].totalTime)?<th>Total Time</th>:null}                          
                        </tr>                        
                        {props.testDetail.sectionSet?props.testDetail.sectionSet.map((myRow,index)=>(
                          <tr key={'mttr'+index} style={{backgroundColor:'#FFF'}} >
                            <td>{myRow.sectionName}</td>
                            <td style={{textAlign:'center'}} >{myRow.questionRange}</td>
                            <td style={{textAlign:'center'}} >{myRow.correctMarks}</td>
                            <td style={{textAlign:'center'}} >{myRow.incorrectMarks}</td>
                            <td style={{textAlign:'center'}} >{myRow.notAnswerMarks}</td>
                            {myRow.totalTime?<td style={{textAlign:'center'}} >{myRow.totalTime}</td>:null}
                          </tr>
                        )):<span>Records Not Available</span>}
                      </table>
                      :null}

                      <Box mt={2}>
                          <Button onClick={() => {handleClose()}} style={{marginRight:20}} size="small" variant="outlined" >Cancel</Button>
					    	          <Button onClick={() => {goToLocation()}} size="small" variant="contained" color="secondary" >Start Test</Button>
								      </Box>

                  </p>
            </Grid>
          </DialogContent>
      </Dialog>
    </>
  );

});

export default CustomizedDialogs;