import React from 'react';
import { withStyles } from '@material-ui/core/styles';
import {Grid, Box, Button} from '@material-ui/core';
import Dialog from '@material-ui/core/Dialog';
import MuiDialogTitle from '@material-ui/core/DialogTitle';
import MuiDialogContent from '@material-ui/core/DialogContent';
import IconButton from '@material-ui/core/IconButton';
import CloseIcon from '@material-ui/icons/Close';
import Typography from '@material-ui/core/Typography';

const styles = (theme) => ({
  root: {
    margin: 0,
    padding: theme.spacing(2),
  },
  closeButton: {
    position: 'absolute',
    right: theme.spacing(1),
    top: theme.spacing(1),
    color: theme.palette.grey[500],
  },
});

const DialogTitle = withStyles(styles)((props) => {
  const { children, classes, onClose, ...other } = props;
  return (
    <MuiDialogTitle disableTypography className={classes.root} {...other}>
      <Typography variant="h6">{children}</Typography>
      {onClose ? (
        <IconButton aria-label="close" className={classes.closeButton} onClick={onClose}>
          <CloseIcon />
        </IconButton>
      ) : null}
    </MuiDialogTitle>
  );
});

const DialogContent = withStyles((theme) => ({
  root: {
    padding: theme.spacing(2),
  },
}))(MuiDialogContent);

const CustomizedDialogs = React.forwardRef((props, ref) => {  
  const [open, setOpen] = React.useState(false);

  React.useImperativeHandle(ref, () => ({
    handleClickOpen(){
      setOpen(true);
    }
  }));
  
  const handleClose = () => {
    setOpen(false);
  };

  function goToLocation(){ 
    setOpen(false);
    props.toCallStartTest();
	}
  
  return (
    <>
      <Dialog fullWidth maxWidth="md" onClose={handleClose} aria-labelledby="customized-dialog-title" open={open}>
        <DialogTitle style={{marginBottom:'-30px'}} onClose={handleClose}></DialogTitle>
          <DialogContent style={{height:'88vh'}}>
          {(props.testDetail!=null && props.testDetail.patternDetails!=null)?
            <Grid item   md={12} xs={12} className="test-instructions" >
                  <div className="btmbdrgry"><h3>{props.testDetail.mockTestTitle}</h3></div>
                  <p>
                      <table style={{backgroundColor:'#000000',width:'100%' }} cellSpacing="1" cellPadding="5" >
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Total Questions</td>
                            <td style={{textAlign:'center'}} >{props.testDetail.patternDetails.totalQuestion}</td>                            
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Total time for Test(minutes)</td>
                            <td style={{textAlign:'center'}} >{props.testDetail.patternDetails.totalTime}</td>
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Question Type</td>
                            <td style={{textAlign:'center'}} >{props.testDetail.patternDetails.questionType}</td>
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Marks for correct answer</td>
                            <td style={{textAlign:'center'}} >{props.testDetail.patternDetails.markCorrectAns}</td>
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Marks for incorrect answer</td>
                            <td style={{textAlign:'center'}} >{props.testDetail.patternDetails.markIncorrectAns}</td>
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Marks for questions not attempted</td>
                            <td style={{textAlign:'center'}} >{props.testDetail.patternDetails.markNotAttempt}</td>
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Total Marks</td>
                            <td style={{textAlign:'center'}} >{props.testDetail.patternDetails.totalMark}</td>
                        </tr>
                      </table>

                      <Box mt={2}>
                          <Button onClick={() => {handleClose()}} style={{marginRight:20}} size="small" variant="outlined" >Cancel</Button>
					    	          <Button onClick={() => {goToLocation()}} size="small" variant="contained" color="secondary" >Start Test</Button>
								      </Box>

                  </p>
            </Grid>
          :null}  
          </DialogContent>
      </Dialog>
    </>
  );

});

export default CustomizedDialogs;