import React from 'react';
import { withStyles } from '@material-ui/core/styles';
import {DialogActions, DialogContentText, Stack, Snackbar, Alert} from '@mui/material';
import {Grid, Button} from '@material-ui/core';
import Dialog from '@material-ui/core/Dialog';
import MuiDialogTitle from '@material-ui/core/DialogTitle';
import MuiDialogContent from '@material-ui/core/DialogContent';
import IconButton from '@material-ui/core/IconButton';
import CloseIcon from '@material-ui/icons/Close';
import Typography from '@material-ui/core/Typography';
import Cookies from 'js-cookie';
import axios from 'axios';
import LinearProgress from '@mui/material/LinearProgress';
import 'font-awesome/css/font-awesome.min.css';
import ParentsChildSave from './ParentsChildSave';
import { useSelector } from 'react-redux';
import {API_URL} from '../utils/EnvVars';

var vertical='top',horizontal='center';

const styles = (theme) => ({
  root: {
    margin: 0,
    padding: theme.spacing(2),
  },
  closeButton: {
    position: 'absolute',
    right: theme.spacing(1),
    top: theme.spacing(1),
    color: theme.palette.grey[500],
  },
});

const DialogTitle = withStyles(styles)((props) => {
  const { children, classes, onClose, ...other } = props;
  return (
    <MuiDialogTitle disableTypography className={classes.root} {...other}>
      <Typography variant="h6">{children}</Typography>
      {onClose ? (
        <IconButton aria-label="close" className={classes.closeButton} onClick={onClose}>
          <CloseIcon />
        </IconButton>
      ) : null}
    </MuiDialogTitle>
  );
});

const DialogContent = withStyles((theme) => ({
  root: {
    padding: theme.spacing(2),
  },
}))(MuiDialogContent);

const CustomizedDialogs = React.forwardRef((props, ref) => {
  const userObj = useSelector(state => state.userDetails);  
  const [open, setOpen] = React.useState(false); 

  const childRefChildSave = React.useRef();
  const [dataLoading, setDataLoading] = React.useState(true);
  const [deleteDialogShow, setDeleteDialogShow] = React.useState(false);
  const [rows, setRows] = React.useState([]);
  const [severityAlert, setSeverityAlert] = React.useState("error");
	const [showAlert, setShowAlert] = React.useState(false);
  const [alertMessage, setAlertMessage] = React.useState("");
  const [delId, setDelId] = React.useState(0);

  React.useImperativeHandle(ref, () => ({
    handleClickOpen(){
      setOpen(true);
    }
  }));

  function hideAlert(){
		setShowAlert(false);
	}
  
  const handleClose = () => {
    setOpen(false);
  };

  const deleteData = (id) => {
    setDeleteDialogShow(true);
    setDelId(id);
  };

  function deleteDialogHide(){
		setDeleteDialogShow(false);
	}

	React.useEffect(() => {		
		if(open && userObj.emailId && userObj.token){
			getApiData(userObj.emailId,userObj.token);
		}
	}, [userObj,open]);

	async function getApiData(emailId,token){
			axios.get(API_URL+'/admin-parents-children?emailId='+emailId+'&token='+token+"&parentId="+props.dataObj.autoId)
			   .then(response => {	
				setDataLoading(false);	
				if(response.data && response.data.responseTxt==="success"){
					setRows(response.data.list);
				} 				
			})
	}

  function deleteNow(){
    deleteDialogHide();
		if(delId && userObj.emailId && userObj.token){

			let axiosHeader = {
					headers: {
					'Content-Type': 'multipart/mixed',
			  		'token': userObj.token,
			  		'loginEmailId': userObj.emailId,
				}
			}; 

		  const data = new FormData();
		  data.append('id', delId);
			data.append('parentId', props.dataObj.autoId);

		  axios.post(API_URL+'/admin-delete-parents-children', data, axiosHeader)
				.then((response) => {
					//console.log("RESPONSE RECEIVED: ", response.data.responseTxt);
				if(response.data && response.data.responseTxt==="InvalidToken"){ 
					Cookies.remove('isadminloggedin');
					window.location.href='login';
				}else if(response.data.responseTxt==="success"){
          setRows(response.data.list);
					setSeverityAlert("success");
					///setOpen(false);
					setShowAlert(true);
					setAlertMessage("Student has been deleted.");			  		
					return false;
				}else{
			  	setSeverityAlert("error");
					setShowAlert(true);
					setAlertMessage("This student could not be deleted.");			
					return false;
				}
			}).catch((error) => {
					setSeverityAlert("error");
					setShowAlert(true);
					setAlertMessage(""+error);			
					return false;
				})	
		}		
		
	}

  function updatedList(list) {
    setRows(list);
  }

  function saveData(){
    childRefChildSave.current.handleClickOpen();
  }

  return (
    <>
      <Dialog fullWidth maxWidth="md" onClose={handleClose} aria-labelledby="customized-dialog-title" open={open}>
        <DialogTitle style={{marginBottom:'-30px'}} onClose={handleClose}></DialogTitle>
          <DialogContent style={{height:'88vh'}}>
            <Grid item   md={12} xs={12} className="test-instructions" >
                  <div className="btmbdrgry"><h3>{props.dataObj?props.dataObj.fullName:null} <i onClick={()=>{saveData()}} title="Create" className="fa fa-plus-circle" style={{fontSize:30, color:'#0158dc',marginLeft:15, cursor:'pointer'}} /></h3>
                  
                  </div>
                  <p>
                      {dataLoading?<LinearProgress />:null}
                      <table style={{backgroundColor:'#000000',width:'100%' }} cellSpacing="1" cellPadding="3" >
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td style={{fontWeight:'bold'}}>Student Name</td>
                            <td style={{fontWeight:'bold'}}>Student Id</td>
                            <td style={{width:100,textAlign:'center'}} >Action</td>                            
                        </tr>
                        {rows?rows.map((myRow,index)=>(
                              <tr id={'validityRowId'+myRow.id} key={'tra'+index} style={{backgroundColor:'#FFFFFF'}} >
                                    <td>{myRow.fullName}</td>
                                    <td>{myRow.studentId}</td>
                                    <td style={{textAlign:'center'}}>
											                  <i onClick={()=>{deleteData(myRow.autoId)}} title="Delete" className="fa fa-trash" style={{fontSize:15, color:'#333',cursor:'pointer'}} />
                                    </td>                            
                              </tr>  
                        )):null}
                                              
                      </table>

                      {(!rows || rows.length<1)?<>No Student Found</>:null}

                  </p>
            </Grid>
          </DialogContent>
      </Dialog>

        <Stack spacing={2} sx={{ width: '100%' }}>
					<Snackbar open={showAlert} autoHideDuration={6000} onClose={hideAlert} anchorOrigin={{vertical,horizontal}}  >
						<Alert onClose={hideAlert} variant="filled" severity={severityAlert} sx={{ width: '100%' }}>
							{alertMessage}
						</Alert>
					</Snackbar>
				</Stack>

        <Dialog
					open={deleteDialogShow}
					onClose={deleteDialogHide}
					aria-labelledby="alert-dialog-section-title"
					aria-describedby="alert-dialog-section-description"
				>
					<DialogTitle id="alert-dialog-section-title">
						Alert
					</DialogTitle>
					<DialogContent>
					<DialogContentText id="alert-dialog-section-description">
						Are you sure, You want to delete student.
					</DialogContentText>
					</DialogContent>
					<DialogActions>
					<Button variant="outlined" size="small" onClick={()=>{deleteDialogHide()}}>Don't Delete</Button>
					<Button variant="contained" size="small" color="secondary" onClick={()=>{deleteNow()}} autoFocus>Yes, Delete</Button>
					</DialogActions>
				</Dialog>

        <ParentsChildSave dataObj={props.dataObj} ref={childRefChildSave} updatedList={updatedList} />                  

    </>
  );

});

export default CustomizedDialogs;