import React from 'react';
import { withStyles } from '@material-ui/core/styles';
import {Grid, Box, Button} from '@material-ui/core';
import Select from '@mui/material/Select';
import MenuItem from '@mui/material/MenuItem';
import { makeStyles } from "@material-ui/core/styles";
import Stack from '@mui/material/Stack';
import Snackbar from '@mui/material/Snackbar';
import Alert from '@mui/material/Alert';
import Dialog from '@material-ui/core/Dialog';
import MuiDialogTitle from '@material-ui/core/DialogTitle';
import MuiDialogContent from '@material-ui/core/DialogContent';
import IconButton from '@material-ui/core/IconButton';
import CloseIcon from '@material-ui/icons/Close';
import Typography from '@material-ui/core/Typography';
import TextField from '@mui/material/TextField';
import axios from 'axios';
import { useSelector } from 'react-redux';
import {API_URL} from '../utils/EnvVars';

const styles = (theme) => ({
  root: {
    margin: 0,
    padding: theme.spacing(2),
  },
  closeButton: {
    position: 'absolute',
    right: theme.spacing(1),
    top: theme.spacing(1),
    color: theme.palette.grey[500],
  },
});

const useStyles = makeStyles({
  paper: {
    fontSize: '12px !important',    
  }
});

var vertical='top',horizontal='center';

const DialogTitle = withStyles(styles)((props) => {
  const { children, classes, onClose, ...other } = props;
  return (
    <MuiDialogTitle disableTypography className={classes.root} {...other}>
      <Typography variant="h6">{children}</Typography>
      {onClose ? (
        <IconButton aria-label="close" className={classes.closeButton} onClick={onClose}>
          <CloseIcon />
        </IconButton>
      ) : null}
    </MuiDialogTitle>
  );
});

const DialogContent = withStyles((theme) => ({
  root: {
    padding: theme.spacing(2),
  },
}))(MuiDialogContent);

const CustomizedDialogs = React.forwardRef((props, ref) => {  
  const classes = useStyles();
  const userObj = useSelector(state => state.userDetails);
  const [open, setOpen] = React.useState(false); 
  const [severityAlert, setSeverityAlert] = React.useState("error");
  const [showAlert, setShowAlert] = React.useState(false);
  const [alertMessage, setAlertMessage] = React.useState("");
  
  const [parentName, setParentName] = React.useState("");
  const [email, setEmail] = React.useState("");
  const [mobile, setMobile] = React.useState("");
  const [newPassword, setNewPassword] = React.useState("");
  const [accountStatus, setAccountStatus] = React.useState("Active");

  const [teacherName, setTeacherName] = React.useState("");
  const [loginId, setLoginId] = React.useState("");


  const [schoolId, setSchoolId] = React.useState("noselect");
  const [schoolName, setSchoolName] = React.useState("");


  React.useImperativeHandle(ref, () => ({
    handleClickOpen(){
      setOpen(true);
    }
  }));
  
  const handleClose = () => {
    setOpen(false);
  };

  function hideAlert(){
		setShowAlert(false);
	}


  React.useEffect(() => {   
    if(props.dataObj!=null && props.dataObj.autoId){	
      setParentName(props.dataObj.fullName);
      setMobile(props.dataObj.mobile);
      setEmail(props.dataObj.emailId);
      setNewPassword("");
      setAccountStatus(props.dataObj.accountStatus);

    }else{
      setParentName("");
      setMobile("");
      setEmail("");
      setNewPassword("");
      setAccountStatus("Active");

  } 
  
	}, [open]);

  const validateEmail = (email) => {
    return String(email)
      .toLowerCase()
      .match(
        /^(([^<>()[\]\\.,;:\s@"]+(\.[^<>()[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/
      );
  };

	function saveData(){
    if(!parentName){
      setSeverityAlert("error");
      setShowAlert(true);
      setAlertMessage("Enter parent name");			
      return false;
    } 
    if(!mobile){
      setSeverityAlert("error");
      setShowAlert(true);
      setAlertMessage("Enter mobile.");			
      return false;
    }
    if(email && email.length>0 && !validateEmail(email) ){
      setSeverityAlert("error");
      setShowAlert(true);
      setAlertMessage("Email is not valid.");			
      return false;
    }  
    
    if(!newPassword && !props.dataObj.autoId){
      setSeverityAlert("error");
      setShowAlert(true);
      setAlertMessage("Password can not be empty.");			
      return false;
    }

		if(parentName){ 
			let axiosHeader = {
				headers: {
					'Content-Type': 'multipart/mixed',
          'token': userObj.token,
          'loginEmailId': userObj.emailId,
				}
			}; 

      const data = new FormData();
      if(props.dataObj && props.dataObj.autoId){
        data.append('id', props.dataObj.autoId);
      }
      data.append('fullName', parentName);
      data.append('emailId', email);
      data.append('mobile', mobile);

      if(newPassword){
        data.append('newPassword', newPassword);
      }else{
        data.append('newPassword', '');
      }

      if(accountStatus==='Active'){
        data.append('accountStatus', 1);
      }else{
        data.append('accountStatus', 0);
      }

      let apiURL='/admin-create-parents';
      if(props.dataObj!=null && props.dataObj.autoId){
          apiURL='/admin-update-parents';
      }

			axios.post(API_URL+apiURL, data, axiosHeader)
			.then((response) => {
				////console.log("RESPONSE RECEIVED: ", response.data.responseTxt);
				if(response.data.responseTxt==="success"){
          setSeverityAlert("success");
          setOpen(false);
					setShowAlert(true);
					setAlertMessage("Parent has been saved.");
          window.location.reload();	
					return false;

        }else if(response.data.responseTxt==="AlreadyExistsErrorMobile"){
          setSeverityAlert("error");
          setOpen(true);
          setShowAlert(true);
          setAlertMessage("Mobile must be unique. It is associated with another parent.");
          return false;  					

        }else if(response.data.responseTxt==="AlreadyExistsErrorEmailId"){
            setSeverityAlert("error");
            setOpen(true);
            setShowAlert(true);
            setAlertMessage("Email must be unique. It is associated with another parent.");
            return false;  	

				}else{
          setSeverityAlert("error");
					setShowAlert(true);
					setAlertMessage("Parent could not be saved.");			
					return false;
				}
			})
			.catch((error) => {
          setSeverityAlert("error");
					setShowAlert(true);
					setAlertMessage(""+error);			
					return false;
			})	
		}		
	}
  
  function numberOnly(event){
    if (!/[0-9]/.test(event.key)) {
      event.preventDefault();
    } 
  }


  return (
    <>
      <Dialog fullWidth maxWidth="md" onClose={handleClose} aria-labelledby="customized-dialog-title" open={open}>
        <DialogTitle style={{marginBottom:'-30px'}} onClose={handleClose}></DialogTitle>
          <DialogContent style={{height:'80vh'}}>
            <Grid item   md={12} xs={12} className="test-instructions" >
                  <div className="btmbdrgry"><h3>{(props.dataObj && props.dataObj.autoId)?<>Edit</>:<>New</>} Parent</h3></div>
                  <p>
                      <table style={{backgroundColor:'#000000',width:'100%' }} cellSpacing="1" cellPadding="3" >
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Parent Name</td>
                            <td style={{textAlign:'center'}} >
                            <TextField onChange={event => setParentName(event.target.value)} value={parentName} sx={{width:'99%',fontSize: 10}} variant="standard" />
                            </td>                            
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                          <td>Mobile</td>
                          <td style={{textAlign:'center'}} >
                          <TextField onChange={event => setMobile(event.target.value)} value={mobile} style={{width:'99%'}} inputProps={{maxlength:10}} onKeyPress={(event)=>{numberOnly(event)}} variant="standard" />
                          </td>                            
                        </tr>                        
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                          <td>Email</td>
                          <td style={{textAlign:'center'}} >
                          <TextField onChange={event => setEmail(event.target.value)} value={email} style={{width:'99%'}} variant="standard" />
                          </td>                            
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                          <td>Password</td>
                          <td style={{textAlign:'center'}} >
                          <TextField type='password' onChange={event => setNewPassword(event.target.value)} value={newPassword} style={{width:'99%'}} variant="standard" />
                          </td>
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Status</td>
                            <td  >
                            <Select 
                                style={{width:'100%'}}
                                classes={{ paper: classes.paper }}
                                labelId="select-class-label"
                                id="select-class"
                                value={accountStatus}									
                                onChange={event => setAccountStatus(event.target.value)}
                                variant="standard"
                              >
                                  <MenuItem value="Active">Active</MenuItem>
                                  <MenuItem value="Inactive">Inactive</MenuItem>
                              </Select>
                            </td>                            
                        </tr>

                      </table>

                      <Box mt={2}>
                          <Button onClick={() => {handleClose()}} style={{marginRight:12}} size="small" variant="outlined" >Cancel</Button>
					    	          <Button onClick={() => {saveData()}} size="small" variant="contained" style={{backgroundColor:'#008000',color:'#FFF',marginRight:10}} >Save</Button>
								      </Box>

                  </p>
            </Grid>
          </DialogContent>
      </Dialog>
      
        <Stack spacing={2} sx={{ width: '100%' }}>
					<Snackbar open={showAlert} autoHideDuration={6000} onClose={hideAlert} anchorOrigin={{vertical,horizontal}}  >
						<Alert onClose={hideAlert} variant="filled" severity={severityAlert} sx={{ width: '100%' }}>
							{alertMessage}
						</Alert>
					</Snackbar>
				</Stack>

    </>
  );

});

export default CustomizedDialogs;