import React from 'react';
import { withStyles } from '@material-ui/core/styles';
import {Grid, Box, Button} from '@material-ui/core';
import { LoadingButton } from '@mui/lab';
import TextField from '@mui/material/TextField';
import InputLabel from '@mui/material/InputLabel';
import FormControl from '@mui/material/FormControl';
import Select from '@mui/material/Select';
import MenuItem from '@mui/material/MenuItem';
import { makeStyles } from "@material-ui/core/styles";
import Stack from '@mui/material/Stack';
import Snackbar from '@mui/material/Snackbar';
import Alert from '@mui/material/Alert';
import Dialog from '@material-ui/core/Dialog';
import MuiDialogTitle from '@material-ui/core/DialogTitle';
import MuiDialogContent from '@material-ui/core/DialogContent';
import IconButton from '@material-ui/core/IconButton';
import CloseIcon from '@material-ui/icons/Close';
import Typography from '@material-ui/core/Typography';
import TreeView from './TreeView';
import { Editor } from '@tinymce/tinymce-react';
import axios from 'axios';
import { useSelector } from 'react-redux';
import {API_URL} from '../utils/EnvVars';

const styles = (theme) => ({
  root: {
    margin: 0,
    padding: theme.spacing(2),
  },
  closeButton: {
    position: 'absolute',
    right: theme.spacing(1),
    top: theme.spacing(1),
    color: theme.palette.grey[500],
  },
});

const useStyles = makeStyles({
  paper: {
    fontSize: '12px !important',    
  }
});

var vertical='top',horizontal='center';

const DialogTitle = withStyles(styles)((props) => {
  const { children, classes, onClose, ...other } = props;
  return (
    <MuiDialogTitle disableTypography className={classes.root} {...other}>
      <Typography variant="h6">{children}</Typography>
      {onClose ? (
        <IconButton aria-label="close" className={classes.closeButton} onClick={onClose}>
          <CloseIcon />
        </IconButton>
      ) : null}
    </MuiDialogTitle>
  );
});

const DialogContent = withStyles((theme) => ({
  root: {
    padding: theme.spacing(2),
  },
}))(MuiDialogContent);

const CustomizedDialogs = React.forwardRef((props, ref) => { 
  const editorRef = React.useRef(null);
  const classes = useStyles();
  const userObj = useSelector(state => state.userDetails);
  const [open, setOpen] = React.useState(false); 
  const [severityAlert, setSeverityAlert] = React.useState("error");
  const [showAlert, setShowAlert] = React.useState(false);
  const [alertMessage, setAlertMessage] = React.useState("");
  const [saveLoading, setSaveLoading] = React.useState(false);

  const [topicId, setTopicId] = React.useState(0);
  const [topicName, setTopicName] = React.useState("");

  const [contentName, setContentName] = React.useState("");
  const [contentUrl, setContentUrl] = React.useState("");
  const [description, setDescription] = React.useState("");
  const [contentType, setContentType] = React.useState("noselect");
  const [contentSource, setContentSource] = React.useState("noselect");
  const [contentSourceArr, setContentSourceArr] = React.useState([]);
  const [contOrder, setContOrder] = React.useState(1);
  const [standard, setStandard] = React.useState("noselect");
  const [country, setCountry] = React.useState("noselect");

  const [contentFilePath, setContentFilePath] = React.useState("");

  const [currentSource, setCurrentSource] = React.useState(0);
  const [currentFile, setCurrentFile] = React.useState("");


  React.useImperativeHandle(ref, () => ({
    handleClickOpen(){
      setOpen(true);
    }
  }));
  
  const handleClose = () => {
    setOpen(false);
  };

  function hideAlert(){
		setShowAlert(false);
	}

  React.useEffect(() => {	
    if(props.dataObj && props.dataObj.autoId>0){	
      setTopicId(props.dataObj.topicId);
      setTopicName(props.dataObj.topicName);
      setContentName(props.dataObj.contentName);
      setContentUrl(props.dataObj.contentUrl);
      setDescription(props.dataObj.description);
      setContentType(props.dataObj.contentType);
      handleContentType(props.dataObj.contentType);
      setContentSource(props.dataObj.contentSource);
      setContOrder(props.dataObj.contOrder);
      setStandard(props.dataObj.standard);
      setCountry(props.dataObj.country);
      setContentFilePath("");
      setCurrentSource(props.dataObj.currentSource);
      setCurrentFile(props.dataObj.currentFile);

    }else{
      ///alert(props.topicId);
      if(props.topicId && props.topicId>0){
        setTopicId(props.topicId);
      }else{
        setTopicId(0);
      }
      
      if(props.topicName && props.topicName.length>0){
        setTopicName(props.topicName);
      }else{
        setTopicName("");
      }

      setContentName("");
      setContentUrl("");
      setDescription("");
      setContentType("noselect");
      setContentSource("noselect");
      setContOrder(1);
      setStandard("1");
      setCountry("");
      setContentFilePath("");
      setCurrentSource(0);
      setCurrentFile("");

    }
	}, [props.dataObj, props.topicName]);

	function saveData(){    
    if(!topicId){
      setSeverityAlert("error");
      setShowAlert(true);
      setAlertMessage("Select topic from left side");			
      return false;
    }
    if(!contentName){
      setSeverityAlert("error");
      setShowAlert(true);
      setAlertMessage("Enter title");			
      return false;
    }  
    if(contentType==='noselect'){
      setSeverityAlert("error");
      setShowAlert(true);
      setAlertMessage("Select content type");			
      return false;
    }
    if(contentSource==='noselect'){
      setSeverityAlert("error");
      setShowAlert(true);
      setAlertMessage("Select source");			
      return false;
    }
    if(contentSource==='URL' && !contentUrl){
      setSeverityAlert("error");
      setShowAlert(true);
      setAlertMessage("Enter content URL");			
      return false;
    }else if(contentSource==='URL' && contentUrl && contentUrl.indexOf("youtube.com")===-1){
        setSeverityAlert("error");
        setShowAlert(true);
        setAlertMessage("You can enter youtube video URL only.");			
        return false;        
    }else if(contentSource==='Text' && !description){
      setSeverityAlert("error");
      setShowAlert(true);
      setAlertMessage("Enter text content");			
      return false;
    }else if(contentSource==='File' && !contentFilePath){
      setSeverityAlert("error");
      setShowAlert(true);
      setAlertMessage("Browse file from your local folder");			
      return false;
    }
    if(standard==='noselect'){
      setSeverityAlert("error");
      setShowAlert(true);
      setAlertMessage("Select standard");			
      return false;
    }

    
		if(topicId && topicId>0 && contentName && contentName.length>1){ 
      setSaveLoading(true);

			let axiosHeader = {
				headers: {
					'Content-Type': 'multipart/form-data',
          'token': userObj.token,
          'loginEmailId': userObj.emailId,
				}
			}; 
			const data = new FormData();
      if(props.dataObj && props.dataObj.autoId>0){
        data.append('id', props.dataObj.autoId);
      }
      data.append('contentName', contentName);
      data.append('topicId', topicId);
      data.append('topicName', topicName);
      data.append('contOrder', contOrder);

      if(standard){
        data.append('standard', standard);
      }else{
        data.append('standard', 1);
      } 
      
      if(country){
        data.append('country', country);
      }
    
      if(contentType==='Video'){
        data.append('contentType', 1);
      }else if(contentType==='PDF'){
        data.append('contentType', 2);
      }else if(contentType==='PPT'){
        data.append('contentType', 3);
      }else if(contentType==='Text'){
        data.append('contentType', 4);
      }

      if(contentSource==='URL'){
        data.append('contentSource', 1);
        data.append('contentUrl', contentUrl);
      }else if(contentSource==='Text'){
        data.append('contentSource', 2);
        data.append('description', description);
      }else if(contentSource==='File'){
        data.append('contentSource', 3);
        var myContentFile = document.querySelector('#contentfile');
        data.append("contentFile", myContentFile.files[0]);
      }

      data.append('currentSource', currentSource);
      data.append('currentFile', currentFile);

      let apiURL='/admin-new-studycontent';
      let myMessage="Content code has been created.";
      if(props.dataObj && props.dataObj.autoId>0){
          apiURL='/admin-update-studycontent';
          myMessage="Content has been updated.";
      }
             
			axios.post(API_URL+apiURL, data, axiosHeader)
			.then((response) => {
        setSaveLoading(false);
				///console.log("RESPONSE RECEIVED: ", response.data.responseTxt);
				if(response.data.responseTxt==="success"){
          setSeverityAlert("success");
          setOpen(false);
					setShowAlert(true);
					setAlertMessage(myMessage);
          ///window.location.reload();	
					return false;
        }else if(response.data.responseTxt==="AlreadyExistsError"){
            setSeverityAlert("error");
            setOpen(true);
            setShowAlert(true);
            setAlertMessage("This content title was created earlier. Kindly enter another title");
            return false;  					
				}else{
          setSeverityAlert("error");
					setShowAlert(true);
					setAlertMessage("This content could not be saved.");			
					return false;
				}
			})
			.catch((error) => {
				console.log("AXIOS ERROR: ", error);
			})	
		}		
	}
  
  const selectTopic = (obj) => {
		setTopicName(obj.topicName);
		setTopicId(obj.topicId);
	}

  const handleContentType = (val) => {
    setContentType(val);
    setContentSource("noselect");
    if(val && val==='Video'){
      setContentSourceArr(["URL"]); 
    }else if(val && val==='Text'){
      setContentSourceArr(["Text", "URL"]); 
    }else{
      setContentSourceArr(["File", "URL"]);
    }    
  }

  return (
    <>
      <Dialog fullWidth maxWidth="lg" onClose={handleClose} aria-labelledby="customized-dialog-title" open={open}>
        <DialogTitle style={{marginBottom:'-30px'}} onClose={handleClose}></DialogTitle>
          <DialogContent style={{height:'88vh'}}>
            <Grid item   md={12} xs={12} className="test-instructions" >
                  <div className="btmbdrgry"><h3>{props.dataObj!=null?<>Edit</>:<>New</>} Content</h3></div>
                  <p>
                  <table style={{backgroundColor:'#000000',width:'100%' }} cellSpacing="1" cellPadding="3" >
                    <tr style={{backgroundColor:'#FFFFFF'}} >
                      <td style={{width:'40%',verticalAlign:'top'}}>
                              <TreeView toCallParentMethod={selectTopic} />
                      </td>
                    <td style={{verticalAlign:'top'}}>
                      <table style={{width:'100%'}} cellSpacing="1" cellPadding="3" >
                        {topicName?
                        <tr style={{fontWeight:'bold'}} >
                            <td>Topic: <span style={{color:'#07449f'}}>{topicName}</span></td>                            
                        </tr>
                        :null}
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td style={{textAlign:'center'}} >
                            <TextField onChange={event => setContentName(event.target.value)} value={contentName} label={'Title'} sx={{width:'99%',fontSize: 10}} variant="outlined" />
                            </td>                            
                        </tr> 
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>
                            <FormControl fullWidth style={{marginTop:5}} >
                              <InputLabel id="type-select-label">Type</InputLabel>
                              <Select 
                                  label="Type"
                                  style={{width:'99%'}}
                                  classes={{ paper: classes.paper }}
                                  labelId="type-select-label"
                                  id="select-class"
                                  value={contentType}									
                                  onChange={event => handleContentType(event.target.value)}
                                >
                                    <MenuItem value="noselect">Select Content Type</MenuItem>
                                    <MenuItem value="Video">Video</MenuItem>
                                    <MenuItem value="PDF">PDF</MenuItem>
                                    <MenuItem value="PPT">PPT</MenuItem>
                                    <MenuItem value="Text">Text</MenuItem>
                              </Select>
                            </FormControl>
                              
                            </td>                            
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>
                            <FormControl fullWidth style={{marginTop:5}} >
                              <InputLabel id="source-select-label">Source</InputLabel>
                              <Select 
                                  label="Source"
                                  style={{width:'99%'}}
                                  classes={{ paper: classes.paper }}
                                  labelId="source-select-label"
                                  id="select-class"
                                  value={contentSource}									
                                  onChange={event => setContentSource(event.target.value)}                                  
                                >
                                    <MenuItem value="noselect">Select Source</MenuItem>
                                    {contentSourceArr?contentSourceArr.map((myRow,mykey)=>(
                                    <MenuItem key={'cntyp'+mykey} value={myRow}>{myRow}</MenuItem>
                                    )):null}
                              </Select>
                            </FormControl>  
                            </td>                            
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>
                            {contentSource==='URL'?
                            <TextField onChange={event => setContentUrl(event.target.value)} value={contentUrl} label={'URL'} sx={{width:'99%',fontSize: 10}} variant="outlined" />
                            :contentSource==='Text'?
                            <>
                                <Editor 
                                onEditorChange={(newText) => setDescription(newText)}
                                onInit={(evt, editor) => editorRef.current = editor}
                                value={description}
                                tinymceScriptSrc={process.env.PUBLIC_URL + '/tinymce/tinymce.min.js'}
                                init={{
                                  height: 400,
                                  menubar: false,
                                  plugins: [
                                    'advlist autolink lists link image charmap print preview anchor',
                                    'searchreplace visualblocks code fullscreen',
                                    'insertdatetime media table paste code help wordcount'
                                  ],
                                  toolbar: 'undo redo | formatselect | ' +
                                  'bold italic backcolor | alignleft aligncenter ' +
                                  'alignright alignjustify | bullist numlist outdent indent | ' +
                                  'removeformat | help',
                                  content_style: 'body { font-family:Helvetica,Arial,sans-serif; font-size:14px }'
                                }}
                              />
                            </>
                            :contentSource==='File'?<><input                             
                            className={classes.input}
                            style={{ display: 'none' }}
                            id="contentfile"
                            type="file" 
                            onChange={event => setContentFilePath(event.target.value)}
                          />
                          <label htmlFor="contentfile">
                            <Button component="span" style={{backgroundColor:'#f9c07a',color:'#000', margin: 2}} size="small" variant="contained" >
                              Browse File
                            </Button>   
                            {
                              contentFilePath?
                              <span style={{marginLeft:5}}>{contentFilePath}</span>
                              :contentUrl?<><br/><a href={contentUrl} target="_blank" >{contentUrl}</a></>:null
                            }                         
                          </label></>:null 
                            }                            
                            </td>                            
                        </tr> 
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td style={{textAlign:'center'}} >
                            <TextField onChange={event => setContOrder(event.target.value)} value={contOrder} label={'Order'} sx={{width:'99%',fontSize: 10}} variant="outlined" />
                            </td>                            
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>
                            <FormControl fullWidth style={{marginTop:5}} >
                              <InputLabel id="standard-select-label">Standard</InputLabel>
                              <Select 
                                  label="Standard"
                                  style={{width:'99%'}}
                                  classes={{ paper: classes.paper }}
                                  labelId="standard-select-label"
                                  id="select-class"
                                  value={standard}									
                                  onChange={event => setStandard(event.target.value)}
                                >
                                    <MenuItem value="noselect">Select Standard</MenuItem>
                                    <MenuItem value="1">L 1</MenuItem>
                                    <MenuItem value="2">L 2</MenuItem>
                                    <MenuItem value="3">L 3</MenuItem>
                                    <MenuItem value="4">L 4</MenuItem>
                                    <MenuItem value="5">L 5</MenuItem>
                                    <MenuItem value="6">L 6</MenuItem>
                                    <MenuItem value="7">L 7</MenuItem>
                                    <MenuItem value="8">L 8</MenuItem>
                                    <MenuItem value="9">L 9</MenuItem>
                                    <MenuItem value="10">L 10</MenuItem>
                                    <MenuItem value="11">L 11</MenuItem>
                                    <MenuItem value="12">L 12</MenuItem>
                                    <MenuItem value="13">L 13</MenuItem>
                                    <MenuItem value="14">L 14</MenuItem>
                                    <MenuItem value="15">L 15</MenuItem>
                              </Select>
                            </FormControl> 
                            </td>                            
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>
                            <FormControl fullWidth style={{marginTop:5}} >
                              <InputLabel id="country-select-label">Country</InputLabel>
                              <Select 
                                  label="Country"
                                  style={{width:'99%'}}
                                  classes={{ paper: classes.paper }}
                                  labelId="country-class-label"
                                  id="select-class"
                                  value={country}									
                                  onChange={event => setCountry(event.target.value)}
                                >
                                  <MenuItem value="noselect">Select Country</MenuItem>
                                  {props.countryList?props.countryList.map((myRow,mykey)=>(
                                    <MenuItem key={'cntry'+mykey} value={myRow.country}>{myRow.country}</MenuItem>
                                  )):null}
                              </Select>
                            </FormControl> 
                            </td>                            
                        </tr>
                        
                        
                      </table>

                          </td>                            
                        </tr>
                      </table>

                      <Box mt={2}>
                          <Button onClick={() => {handleClose()}} style={{marginRight:12}} size="small" variant="outlined" >Cancel</Button>
					    	          {saveLoading?
                          <LoadingButton loading={saveLoading} style={{backgroundColor:'#008000',color:'#FFF',marginRight:10}} size="small" variant="contained"  >Save</LoadingButton>
					    	          :
                          <Button onClick={() => {saveData()}} style={{backgroundColor:'#008000',color:'#FFF',marginRight:10}} size="small" variant="contained"  >Save</Button>
                          }
                      </Box>

                  </p>
            </Grid>
          </DialogContent>
      </Dialog>
      
        <Stack spacing={2} sx={{ width: '100%' }}>
					<Snackbar open={showAlert} autoHideDuration={6000} onClose={hideAlert} anchorOrigin={{vertical,horizontal}}  >
						<Alert onClose={hideAlert} variant="filled" severity={severityAlert} sx={{ width: '100%' }}>
							{alertMessage}
						</Alert>
					</Snackbar>
				</Stack>

    </>
  );

});

export default CustomizedDialogs;