import React from 'react';
import { withStyles } from '@material-ui/core/styles';
import {Grid, Box, Button} from '@material-ui/core';
import Select from '@mui/material/Select';
import MenuItem from '@mui/material/MenuItem';
import Stack from '@mui/material/Stack';
import Snackbar from '@mui/material/Snackbar';
import Alert from '@mui/material/Alert';
import Dialog from '@material-ui/core/Dialog';
import MuiDialogTitle from '@material-ui/core/DialogTitle';
import MuiDialogContent from '@material-ui/core/DialogContent';
import IconButton from '@material-ui/core/IconButton';
import CloseIcon from '@material-ui/icons/Close';
import Typography from '@material-ui/core/Typography';
import TextField from '@mui/material/TextField';
import axios from 'axios';
import { useSelector } from 'react-redux';
import {API_URL} from '../utils/EnvVars';

const styles = (theme) => ({
  root: {
    margin: 0,
    padding: theme.spacing(2),
  },
  closeButton: {
    position: 'absolute',
    right: theme.spacing(1),
    top: theme.spacing(1),
    color: theme.palette.grey[500],
  },
});

var vertical='top',horizontal='center';

const DialogTitle = withStyles(styles)((props) => {
  const { children, classes, onClose, ...other } = props;
  return (
    <MuiDialogTitle disableTypography className={classes.root} {...other}>
      <Typography variant="h6">{children}</Typography>
      {onClose ? (
        <IconButton aria-label="close" className={classes.closeButton} onClick={onClose}>
          <CloseIcon />
        </IconButton>
      ) : null}
    </MuiDialogTitle>
  );
});

const DialogContent = withStyles((theme) => ({
  root: {
    padding: theme.spacing(2),
  },
}))(MuiDialogContent);

const CustomizedDialogs = React.forwardRef((props, ref) => {  
  const userObj = useSelector(state => state.userDetails);
  const [open, setOpen] = React.useState(false); 
  const [severityAlert, setSeverityAlert] = React.useState("error");
  const [showAlert, setShowAlert] = React.useState(false);
  const [alertMessage, setAlertMessage] = React.useState("");
  
  const [schoolId, setSchoolId] = React.useState("noselect");
  const [schoolName, setSchoolName] = React.useState("");
  const [className, setClassName] = React.useState("noselect");
  const [courseId, setCourseId] = React.useState(0);
  const [oldCourseId, setOldCourseId] = React.useState(0);

  
  const [classLoadingMsg, setClassLoadingMsg] = React.useState("Select an academy for batches");
  const [classList, setClassList] = React.useState([]);

  React.useImperativeHandle(ref, () => ({
    handleClickOpen(){
      setOpen(true);
    }
  }));
  
  const handleClose = () => {
    setOpen(false);
  };

  function hideAlert(){
		setShowAlert(false);
	}

  
  const handleSchool = (sid) => {
    if(sid>0 && props.schools && props.schools.length>0){
      setClassLoadingMsg("Batch not found");
      for(let i=0; i<props.schools.length; i++){
        if(props.schools[i].autoId===sid){
          setSchoolId(props.schools[i].autoId);
          setSchoolName(props.schools[i].schoolName);
          if(props.schools[i].list && props.schools[i].list.length>0){
            setClassLoadingMsg("Found");
            setClassName("noselect");          
            setClassList(props.schools[i].list);
          }
          break;
        }
      } 
    }else{
      setSchoolId("noselect");
      setClassName("noselect");
      setCourseId(0);
      setClassLoadingMsg("Select an academy for batches");
    }
  }

  const handleClassName = (clsName) => {
      if(clsName!=='noselect' && clsName.length>0){
          setClassName(clsName);
          if(clsName && classList && classList.length>0){
            for(let i=0; i<classList.length; i++){
              if(classList[i].className===clsName){
                setCourseId(classList[i].courseId);
                break;
              }
            }      
          }
      }else{
        setClassName(("noselect"));
        setCourseId(0);
      }
  }


  React.useEffect(() => {
    if(props.studentObj){	
      if(props.studentObj.schoolId && props.studentObj.schoolId>0){
        setSchoolId(props.studentObj.schoolId);
        setSchoolName(props.studentObj.schoolName);
        handleSchool(props.studentObj.schoolId);
      }else{
        setSchoolId("noselect");
        setSchoolName("");
        setClassLoadingMsg("Select an academy for batches");
        setClassList([]);      
      }
      if(props.studentObj.className && props.studentObj.className.length>0 ){
        setClassName(props.studentObj.className);
        setCourseId(props.studentObj.classCourseId);
        setOldCourseId(props.studentObj.classCourseId);
      }else{
        setClassName("noselect");
        setCourseId(0);
        setOldCourseId(0);
      }
    }
	}, [props.studentObj]);

	function saveData(){

    // if(schoolId==="noselect"){
    //   setSeverityAlert("error");
    //   setShowAlert(true);
    //   setAlertMessage("Select academy");			
    //   return false;
    // }

		if(schoolId){ 
			let axiosHeader = {
				headers: {
					'Content-Type': 'multipart/mixed',
          'token': userObj.token,
          'loginEmailId': userObj.emailId,
				}
			}; 
			const data = new FormData(); 
      data.append('id', props.studentObj.autoId); 
      data.append('studentId', props.studentObj.studentId);
      
      if(schoolId && schoolId>0){
        data.append('schoolId', schoolId);
        data.append('schoolName', schoolName);
      }else{
        data.append('schoolId', 0);
        data.append('schoolName', '');
      }

      if(className && className!=='noselect' && courseId && courseId>0){ 
        data.append('className', className);
        data.append('courseId', courseId);
        data.append('classCourseId', oldCourseId);
      }else{
        data.append('className', '');
        data.append('courseId', 0);
        data.append('classCourseId', 0);
      }

			axios.post(API_URL+'/admin-update-student-batch', data, axiosHeader)
			.then((response) => {
				console.log("RESPONSE RECEIVED: ", response);
				if(response.data.responseTxt==="OK"){
          setSeverityAlert("success");
          setOpen(false);
					setShowAlert(true);
					setAlertMessage("Student details has been saved.");
					return false;
				}else{
          setSeverityAlert("error");
					setShowAlert(true);
					setAlertMessage("Student details could not be saved.");			
					return false;
				}
			})
			.catch((error) => {
          setSeverityAlert("error");
					setShowAlert(true);
					setAlertMessage(""+error);			
					return false;
			})	
		}		
	}

  
  
  return (
    <>
      <Dialog fullWidth maxWidth="md" onClose={handleClose} aria-labelledby="customized-dialog-title" open={open}>
        <DialogTitle style={{marginBottom:'-30px'}} onClose={handleClose}></DialogTitle>
          <DialogContent style={{height:'88vh'}}>
            <Grid item   md={12} xs={12} className="test-instructions" >
                  <div className="btmbdrgry"><h3>Academy</h3></div>
                  <p>
                      <table style={{backgroundColor:'#000000',width:'100%' }} cellSpacing="1" cellPadding="3" >
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td style={{width:'40%'}} >Academy</td>
                            <td style={{textAlign:'center'}} >
                                <Select 
                                    style={{width:'100%'}}
                                    labelId="select-class-label"
                                    id="select-class"
                                    value={schoolId}									
                                    onChange={event => handleSchool(event.target.value)}
                                    variant="standard"
                                  >
                                      <MenuItem value="noselect">Select Academy</MenuItem>
                                      {props.schools?props.schools.map((myRow,index)=>(
                                        <MenuItem id={'a'+index} value={myRow.autoId} >{myRow.schoolName}</MenuItem>
                                      )):null}
                                  </Select>
                            </td>                            
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Batch</td>
                            <td style={{textAlign:'center'}} >
                              {(classLoadingMsg && classLoadingMsg==='Found' && classList && classList.length>0)?
                                  <Select 
                                    style={{width:'100%'}}
                                    labelId="select-class-label"
                                    id="select-class"
                                    value={className}									
                                    onChange={event => handleClassName(event.target.value)}
                                    variant="standard"
                                  >
                                      <MenuItem value="noselect">Select Batch</MenuItem>
                                      {classList?classList.map((myRow,index)=>(
                                        <MenuItem id={'b'+index} value={myRow.className} >{myRow.className}</MenuItem>
                                      )):null}
                                  </Select>
                              :classLoadingMsg}    
                            </td>
                        </tr>
                                            
                                              
                      </table>

                      <Box mt={2}>
                          <Button onClick={() => {handleClose()}} style={{marginRight:12}} size="small" variant="outlined" >Cancel</Button>
					    	          <Button onClick={() => {saveData()}} size="small" variant="contained" style={{backgroundColor:'#008000',color:'#FFF',marginRight:10}} >Save</Button>
								      </Box>

                  </p>
            </Grid>
          </DialogContent>
      </Dialog>
      
        <Stack spacing={2} sx={{ width: '100%' }}>
					<Snackbar open={showAlert} autoHideDuration={6000} onClose={hideAlert} anchorOrigin={{vertical,horizontal}}  >
						<Alert onClose={hideAlert} variant="filled" severity={severityAlert} sx={{ width: '100%' }}>
							{alertMessage}
						</Alert>
					</Snackbar>
				</Stack>

    </>
  );

});

export default CustomizedDialogs;