import React from 'react';
import {Box, Grid, Button} from '@material-ui/core';
import {TextField, FormControl, Stack, Snackbar, Alert, LinearProgress, Radio, Dialog, DialogActions, DialogContent, DialogContentText, DialogTitle} from '@mui/material';
import {MetaTags} from 'react-meta-tags';
import axios from 'axios';
import Cookies from 'js-cookie';
import CircularProgress from '@mui/material/CircularProgress';
import SmartLearningKeywordSave from '../components/SmartLearningKeywordSave';
import DialogAuthorization from '../components/DialogAuthorization';
import DialogStudyContent from '../components/DialogStudyContent';
import KeywordSearch from '../components/KeywordSearch';
import { useSelector } from 'react-redux';
import {API_URL} from '../utils/EnvVars';
import Header from "./HeaderMy";
///import moment from 'moment';
import '../styles/bizofficer-a.css';
import 'font-awesome/css/font-awesome.min.css';

  
  var vertical='top',horizontal='center';
  
  export default function Execute() {
	const userObj = useSelector(state => state.userDetails);	
	const isloggedin = Cookies.get('isadminloggedin');
	const childRefSave = React.useRef();
	const childRefAuthorization = React.useRef();
	const childRef = React.useRef(); 
	const [showProgress, setShowProgress] = React.useState(false);
	const [pageLoading, setPageLoading] = React.useState(true);
	const [deleteDialogShow, setDeleteDialogShow] = React.useState(false);
	const [filter, setFilter] = React.useState(false);
	const [keyword, setKeyword] = React.useState("");
	const [dataObj, setDataObj] = React.useState({});
	const [rows, setRows] = React.useState([]);
	const [countryList, setCountryList] = React.useState([]);
	const [contentObj, setContentObj] = React.useState("");

	const [keywordId, setKeywordId] = React.useState("");
	const [keywordName, setKeywordName] = React.useState(""); 

	// const [topicName, setTopicName] = React.useState("");
	// const [topicId, setTopicId] = React.useState(""); 
	const [severityAlert, setSeverityAlert] = React.useState("error");
	const [showAlert, setShowAlert] = React.useState(false);
	const [alertMessage, setAlertMessage] = React.useState("");
	const [authPrivileges, setAuthPrivileges] = React.useState({});
  

	var myCurrentDate=new Date();
	var myPastFromDate=new Date(myCurrentDate);
    myPastFromDate.setDate(myPastFromDate.getDate() - 366);

	function hideAlert(){
		setShowAlert(false);
	}

	// check if logged in
	React.useEffect(() => {
		if(!isloggedin){
			window.location.href='login';
		}
	}, [isloggedin]);

	React.useEffect(() => {		
		if(userObj.emailId && userObj.token){
			getApiData(userObj.emailId,userObj.token,keyword);
			getApiCountry();
		}
	}, [userObj,filter]);

	async function getApiData(emailId,token,keyword){
			axios.get(API_URL+'/admin-keywordcontents?loginEmailId='+emailId+'&token='+token+"&keyword="+keyword+"&keywordName="+keywordName) 
			   .then(response => {
			 	///console.log("Just Checking >> "+response.data); 
				 setPageLoading(false); 
				if(response.data && response.data.responseTxt==="InvalidToken"){ 
					Cookies.remove('isadminloggedin');
					window.location.href='login';
				}else if(response.data && response.data.responseTxt==="NoAuthorization"){ 
					childRefAuthorization.current.handleClickOpen();
				}else if(response.data && response.data.responseTxt==="success"){
					setRows(response.data.list);
					setAuthPrivileges(response.data.privileges);
				}	 				
			})
	}

	async function getApiCountry(){
		axios.get(API_URL+'/admin-country')
		   .then(response => {
			 if(response.data){					 
				 setCountryList(response.data);
			 }	 				
		})
	}


	function deleteData(){
		if(dataObj && userObj.emailId && userObj.token){
			let axiosHeader = {
					headers: {
					'Content-Type': 'multipart/mixed',
			  		'token': userObj.token,
			  		'loginEmailId': userObj.emailId,
				}
			}; 

		  const data = new FormData();
		  data.append('id', dataObj.autoId);
				 
		  axios.post(API_URL+'/admin-delete-keywordcontent', data, axiosHeader)
				.then((response) => {
					//console.log("RESPONSE RECEIVED: ", response.data.responseTxt);
				if(response.data.responseTxt==="success"){
					setSeverityAlert("success");
					//setOpen(false);
					setShowAlert(true);
					setAlertMessage("Content has been deleted.");
			  		window.location.reload();	
					return false;
				}else{
			  		setSeverityAlert("error");
					setShowAlert(true);
					setAlertMessage("This content could not be deleted.");			
					return false;
				}
			})
				.catch((error) => {
					console.log("AXIOS ERROR: ", error);
				})	
		}		
	
		
	}

	function newData(){
		setDataObj(null);
		childRefSave.current.handleClickOpen();
	}

	function editData(myObj){
		setDataObj(myObj);
		childRefSave.current.handleClickOpen();
	}

	function confirmDelete(myObj){
		setDataObj(myObj);
		setDeleteDialogShow(true);
	}

	function search(){
		setFilter(!filter);
	}

	function onEnter(event){
		if(event.key === 'Enter'){
			search();
		}
	}
	
	function deleteDialogHide(){
		setDeleteDialogShow(false);
	}

	function exeContent(obj){ 
		if(obj && obj.contentType===1){
			setContentObj(obj);
			childRef.current.handleClickOpen();	
		}else{
			if(window.screen.width<480){
				window.open(obj.contentUrl, "_blank");
			}else{
				setContentObj(obj);
				childRef.current.handleClickOpen();
			}
		}	
	}

	const selectKeyword = (obj) => {
		setKeywordName(obj.title);
		setKeywordId(obj.id);
		setFilter(!filter);
	}


	return (
		<div> 
				<MetaTags>
            		<title>Smart Learning: Keyword</title>
          		</MetaTags>
				
				<Header title="Smart Learning: Keyword" />
				{pageLoading?<LinearProgress />:null}

				<Box className='mainBox'>	

					<Box mt={1}>
							<Grid container spacing={2}>
								<Grid item md={12} xs={12} style={{marginBottom:15}} className='btmbdrgry' >
								
									<div style={{float:'left', width:300, marginTop: 7 }}>
										<KeywordSearch toCallParentMethod={selectKeyword} title={keywordName} />
									</div>

									<FormControl style={{float:'left',width:150,marginRight:60,marginTop:8}}>
										<TextField
										id="keywordtxt"
										label="Search"
										defaultValue={keyword}
										sx={{ width: 200 }}
										size="small"
										onChange={event => setKeyword(event.target.value)}
										onKeyPress={(event)=>{onEnter(event)}}
										/>
									</FormControl>

									<Button onClick={() => {search()}} style={{marginTop:-5}} size="small" variant="contained" color="secondary" >Search</Button>

									<span style={{marginTop:30}}>
										{(authPrivileges && authPrivileges.create===1)?	
											<i onClick={()=>{newData()}} title="Add New" className="fa fa-plus-circle" style={{fontSize:40, color:'#0158dc',marginLeft:15, cursor:'pointer'}} />
										:null}												
									</span>	
								</Grid>
							</Grid>
							<Grid container spacing={2}>

								<Grid item md={12} xs={12}>
									{keywordName?<div style={{fontWeight:'bold',marginBottom:10}}>Selected Keyword: {keywordName}</div>:null}
									<Grid container spacing={2} className="materialBox" >
										{rows.length?rows.map((myRow,index)=>(
											<Grid key={'mtldd'+index} item  >
												
												<div className="smitem" onClick={()=>{exeContent(myRow)}} >													
												<p>
													{myRow.contentType==='Video'?<i className="fa fa-play-circle"></i>:myRow.contentType==='PDF'?<i className="fa fa-file-pdf-o"></i>:myRow.contentType==='PPT'?<i className="fa fa-file-powerpoint-o"></i>:<i className="fa fa-globe"></i>}												
												</p>
												<p className="text-line-2">
													{myRow.contentName}
												</p>	
												</div>
												<div className='actionBtnBox'>
													{(authPrivileges && authPrivileges.delete===1)?
														<i onClick={()=>{confirmDelete(myRow)}} title="Delete" className="fa fa-trash" style={{fontSize:20, color:'#888888',marginRight:10, cursor:'pointer'}} />
													:null}													
													{(authPrivileges && authPrivileges.update===1)?
														<i onClick={()=>{editData(myRow)}} title="Edit" className="fa fa-pencil-square-o" style={{fontSize:20, color:'#888888',marginRight:10, cursor:'pointer'}} />
													:null}													
												</div>
											</Grid>
										)):showProgress?<><CircularProgress style={{width:20,height:20}} />Loading...</>:<div style={{color:'#FF0000',fontSize:14,fontWeight:'bold',textAlign:'center',width:'100%'}}>Data not found</div>}	
									</Grid>
								</Grid>
							</Grid>
					</Box>


				</Box>

			<SmartLearningKeywordSave dataObj={dataObj} keywordId={keywordId} keywordName={keywordName} countryList={countryList} ref={childRefSave} />						
			
			<Stack spacing={2} sx={{ width: '100%' }}>
					<Snackbar open={showAlert} autoHideDuration={6000} onClose={hideAlert} anchorOrigin={{vertical,horizontal}}  >
						<Alert onClose={hideAlert} variant="filled" severity={severityAlert} sx={{ width: '100%' }}>
							{alertMessage}
						</Alert>
					</Snackbar>
			</Stack>

				<Dialog
					open={deleteDialogShow}
					onClose={deleteDialogHide}
					aria-labelledby="alert-dialog-section-title"
					aria-describedby="alert-dialog-section-description"
				>
					<DialogTitle id="alert-dialog-section-title">
						Alert
					</DialogTitle>
					<DialogContent>
					<DialogContentText id="alert-dialog-section-description">
						Are you sure, You want to delete content.
					</DialogContentText>
					</DialogContent>
					<DialogActions>
					<Button variant="outlined" size="small" onClick={()=>{deleteDialogHide()}}>Don't Delete</Button>
					<Button variant="contained" size="small" color="secondary" onClick={()=>{deleteData()}} autoFocus>Yes, Delete</Button>
					</DialogActions>
				</Dialog>


				<DialogAuthorization ref={childRefAuthorization} />			

				<DialogStudyContent contentObj={contentObj} ref={childRef} />

		</div>	
	);
  }