import React from 'react';
import { DataGrid } from '@mui/x-data-grid';
import {Box, Grid, Button} from '@material-ui/core';
import {TextField, Stack, Snackbar, Alert, Dialog, DialogActions, DialogContent, DialogContentText, DialogTitle} from '@mui/material';
import FormControl from '@mui/material/FormControl';
import Radio from '@mui/material/Radio';
import {MetaTags} from 'react-meta-tags';
import axios from 'axios';
import Cookies from 'js-cookie';
import LinearProgress from '@mui/material/LinearProgress';
import CircularProgress from '@mui/material/CircularProgress';
import Tooltip from '@mui/material/Tooltip'; 
import StudentAcademyEdit from '../components/StudentAcademyEdit';
import DialogStudentValidity from '../components/DialogStudentValidity';
import DialogStudentValidityEdit from '../components/DialogStudentValidityEdit';
import DialogStudentEdit from '../components/DialogStudentEdit';
import DialogStudentSave from '../components/DialogStudentSave';
import StudentNewCourseSave from '../components/StudentNewCourseSave';
import DialogAuthorization from '../components/DialogAuthorization';
import { useSelector } from 'react-redux';
import {API_URL} from '../utils/EnvVars';
import Header from "./HeaderMy";
import moment from 'moment';
import '../styles/bizofficer-a.css';
import 'font-awesome/css/font-awesome.min.css';

	var vertical='top',horizontal='center';
  
  export default function Execute() {
	const userObj = useSelector(state => state.userDetails);	
	const isloggedin = Cookies.get('isadminloggedin'); 
	const childRef = React.useRef();
	const childRefAcademy = React.useRef(); 
	const childRefAddStudent = React.useRef();
	const childRefValidity = React.useRef();
	const childRefValidityEdit = React.useRef();
	const childRefAuthorization = React.useRef();
	const childRefNewCorsSave = React.useRef();
	
	const [filter, setFilter] = React.useState(false);
	const [keyword, setKeyword] = React.useState(""); 
	const [deleteDialogShow, setDeleteDialogShow] = React.useState(false);
	const [dataLoading, setDataLoading] = React.useState(true);
	const [recordsFound, setRecordsFound] = React.useState(0);
	const [downloadShow, setDownloadShow] = React.useState(false);
	const [downloadReady, setDownloadReady] = React.useState(false);
	const [downloadUrl, setDownloadUrl] = React.useState("");
	const [selectedRow, setSelectedRow] = React.useState(0);
	const [studentObj, setStudentObj] = React.useState({});
	const [rows, setRows] = React.useState([]);
	const [websites, setWebsites] = React.useState([]);
	const [schools, setSchools] = React.useState([]);
	
	const [validityIndex, setValidityIndex] = React.useState(0);

	const [open, setOpen] = React.useState(false);
	const [severityAlert, setSeverityAlert] = React.useState("error");
	const [showAlert, setShowAlert] = React.useState(false);
	const [alertMessage, setAlertMessage] = React.useState("");
	const [authPrivileges, setAuthPrivileges] = React.useState({});
	
	var myCurrentDate=new Date();
	var myPastFromDate=new Date(myCurrentDate);
    myPastFromDate.setDate(myPastFromDate.getDate() - 1827);
	const [fromDate, setFromDate] = React.useState(moment(myPastFromDate).format('YYYY-MM-DD'));
	const [toDate, setToDate] = React.useState(moment(new Date()).format('YYYY-MM-DD'));

	// check if logged in
	React.useEffect(() => {
		if(!isloggedin){
			window.location.href='login';
		}
	}, [isloggedin]);


	const columns = [
		{
			field: "Select",
			headerName: "",
			width: 90,
			sortable: false,
				renderCell: (cellValues) => {
				return (
				  <Radio 
					checked={cellValues.id === selectedRow}
					value={cellValues.id}
					name="radio-buttons"
					inputProps={{ 'aria-label': {cellValues} }}
				  />
				 )
			  }
		  },
		{ field: 'id', headerName: '#', width: 40 },
		{ field: 'studentId', headerName: 'User Id', flex: 1, renderCell: (params) =>  (
			<Tooltip title={params.value} ><span>{params.value}</span></Tooltip>
		   ), },
		{ field: 'sname', headerName: 'Name', flex: 1, renderCell: (params) =>  (
			<Tooltip title={params.value} ><span>{params.value}</span></Tooltip>
		   ), },
		{ field: 'phoneNo', headerName: 'Phone', flex: 1 },
		{ field: 'emailId', headerName: 'Email', flex: 1 },   
		{ field: 'schoolName', headerName: 'Academy', flex: 1 },
		{ field: 'className', headerName: 'Batch', flex: 1 },
		{ field: 'registrationDate', headerName: 'Reg Date',type: 'date', width: 130 }
		/*
		{
		  field: 'age',
		  headerName: 'Age',
		  type: 'number',
		  width: 130,
		},
		{
		  field: 'fullName',
		  headerName: 'Full name',
		  description: 'This column has a value getter and is not sortable.',
		  sortable: false,
		  width: 160,
		  valueGetter: (params) =>
			`${params.getValue(params.id, 'firstName') || ''} ${
			  params.getValue(params.id, 'lastName') || ''
			}`,
		},
		*/
	  ];
	

	React.useEffect(() => {		
		if(userObj.emailId && userObj.token){
			getApiData(userObj.emailId,userObj.token,keyword,fromDate,toDate);
		}
	}, [userObj,filter]);

	async function getApiData(emailId,token,keyword,fromDate,toDate){
			axios.get(API_URL+'/studentslist?emailId='+emailId+'&token='+token+"&keyword="+keyword+"&fromDate="+fromDate+"&toDate="+toDate)
			   .then(response => {	
				setDataLoading(false);	
				if(response.data && response.data.responseTxt==="InvalidToken"){ 
					Cookies.remove('isadminloggedin');
					window.location.href='login';
				}else if(response.data && response.data.responseTxt==="NoAuthorization"){ 
					childRefAuthorization.current.handleClickOpen();
				}else if(response.data && response.data.responseTxt==="success"){
					setRows(response.data.list);
					setAuthPrivileges(response.data.privileges);
					if(response.data.list){	
						setRecordsFound(response.data.list.length);	
					}		 
				} 				
			})
	}

	React.useEffect(() => {		
		if(userObj.emailId && userObj.token){
			getApiWebsites(userObj.emailId,userObj.token);
			getApiSchools(userObj.emailId,userObj.token);
		}
	}, [userObj]);

	async function getApiWebsites(emailId,token){
		axios.get(API_URL+'/admin-websites?loginEmailId='+emailId+'&token='+token)
		   .then(response => {
			if(response.data && response.data.responseTxt==="InvalidToken"){ 
				Cookies.remove('isadminloggedin');
				window.location.href='login';
			}else if(response.data.responseTxt==="success"){					 
				 setWebsites(response.data.list);
			}	 				
		})
	}

	async function getApiSchools(emailId,token){
		let axiosHeader = {
			headers: {
			'Content-Type': 'multipart/mixed',
			  'token': token,
			  'loginEmailId': emailId,
			}
		}; 
		axios.get(API_URL+'/admin-school-classes',axiosHeader)
		   .then(response => {
			 if(response.data.responseTxt==="success"){					 
				 setSchools(response.data.list);
			 }	 				
		})
	}
	
	function saveData(opt){
		if(opt===1){
			childRefAddStudent.current.handleClickOpen();
		}else if(opt===2){
			childRef.current.handleClickOpen();
		}else if(opt===3){
			if(studentObj && studentObj.courses && studentObj.courses.length>0){
				childRefValidity.current.handleClickOpen();
			}
		}else if(opt===4){
			childRefAcademy.current.handleClickOpen();
		}else if(opt===5){
			childRefNewCorsSave.current.handleClickOpen();
		}	
	}
	
	function editMyValidity(index){
		if(studentObj && studentObj.courses && studentObj.courses.length>0){
			setValidityIndex(index);
			childRefValidityEdit.current.handleClickOpen();
		}
	}

	function deleteData(){
		if(studentObj && userObj.emailId && userObj.token){
			let axiosHeader = {
					headers: {
					'Content-Type': 'multipart/mixed',
			  		'token': userObj.token,
			  		'loginEmailId': userObj.emailId,
				}
			}; 

		  const data = new FormData();
		  data.append('id', studentObj.autoId);
		  data.append('studentId', studentObj.studentId);
				 
		  axios.post(API_URL+'/admin-delete-student', data, axiosHeader)
				.then((response) => {
					//console.log("RESPONSE RECEIVED: ", response.data.responseTxt);
				if(response.data && response.data.responseTxt==="InvalidToken"){ 
					Cookies.remove('isadminloggedin');
					window.location.href='login';
				}else if(response.data.responseTxt==="success"){
					setSeverityAlert("success");
					setOpen(false);
					setShowAlert(true);
					setAlertMessage("Student has been deleted.");
			  		window.location.reload();	
					return false;
				}else{
			  		setSeverityAlert("error");
					setShowAlert(true);
					setAlertMessage("This student could not be deleted.");			
					return false;
				}
			})
				.catch((error) => {
					console.log("AXIOS ERROR: ", error);
				})	
		}		
		
	}

	function deleteValidityData(validityId){
		if(studentObj && userObj.emailId && userObj.token){
			let axiosHeader = {
					headers: {
					'Content-Type': 'multipart/mixed',
			  		'token': userObj.token,
			  		'loginEmailId': userObj.emailId,
				}
			}; 

		  const data = new FormData();
		  data.append('id', validityId);
				 
		  axios.post(API_URL+'/admin-delete-validity-studentdetail', data, axiosHeader)
				.then((response) => {
				//	console.log("RESPONSE RECEIVED: ", response.data.responseTxt);
				if(response.data && response.data.responseTxt==="InvalidToken"){ 
					Cookies.remove('isadminloggedin');
					window.location.href='login';
				}else if(response.data.responseTxt==="success"){
					setSeverityAlert("success");
					setOpen(false);
					setShowAlert(true);
					setAlertMessage("Student Course has been deleted.");
			  		///window.location.reload();	
					return false;
				}else{
			  		setSeverityAlert("error");
					setShowAlert(true);
					setAlertMessage("Student course could not be deleted.");			
					return false;
				}
			})
				.catch((error) => {
					console.log("AXIOS ERROR: ", error);
				})	
		}		
		
	}


	function selectRow(obj){
		if(obj && rows[obj.id-1]){			
			setSelectedRow(rows[obj.id-1].id);
			setStudentObj(rows[obj.id-1]);
		}
	}

	function search(){
		setFilter(!filter);
	}

	function onEnter(event){
		if(event.key === 'Enter'){
			search();
		}
	}
	
	function downloadFile(opt){
		if(opt===1){ //START DOWNLOAD			
			setDownloadReady(true);
			setDownloadShow(true);
			if(userObj.emailId && userObj.token){
				downloadApiCall(userObj.emailId,userObj.token,keyword,fromDate,toDate);
			}
		}else if(opt===2){ //HIDE DOWNLOAD ALERT
			setDownloadShow(false);
		}else if(opt===3){ //DOWNLOAD NOW
			window.open(downloadUrl,"_blank");
		}
	}

	async function downloadApiCall(emailId,token,keyword,fromDate,toDate){
		axios.get(API_URL+'/admin-download-students?emailId='+emailId+'&token='+token+"&keyword="+keyword+"&fromDate="+fromDate+"&toDate="+toDate)
		.then(response => {
			 if(response.data.responseTxt==="InvalidToken"){ 
				Cookies.remove('isadminloggedin');
				window.location.href='login';
			 }else if(response.data.responseTxt==="success"){	
				 setDownloadReady(false);
				 setDownloadUrl(response.data.downloadUrl);
			 }else{
				setSeverityAlert("error");
			    setShowAlert(true);
			    setAlertMessage("It could not download data.");			
			    return false;
		  	 }	 				
		})
	}

	function deleteDialogHide(){
		setDeleteDialogShow(false);
	}

	function hideAlert(){
		setShowAlert(false);
	}
	
	return (
		<div> 
				<MetaTags>
            		<title>Students</title>
          		</MetaTags>
				
				<Header title="Students" />
				{dataLoading?<LinearProgress />:null}

				<Box className='mainBox'>	

					<Box mt={1}>
							<Grid container spacing={2}>
								<Grid item md={12} xs={12}>

									<FormControl style={{width:150,marginRight:60,marginTop:8}}>
										<TextField
										id="keywordtxt"
										label="Search"
										defaultValue={keyword}
										sx={{ width: 200 }}
										size="small"
										onChange={event => setKeyword(event.target.value)}
										onKeyPress={(event)=>{onEnter(event)}}
										/>
									</FormControl>

										<TextField
										id="date"
										label="From Date"
										type="date"
										defaultValue={fromDate}
										sx={{ width: 200, marginRight:1, marginTop:1 }}
										size="small"
										onChange={event => setFromDate(event.target.value)}
										inputFormat="dd-MM-yyyy"
										/>

										<TextField
										id="date"
										label="To Date"
										type="date"
										defaultValue={toDate}
										sx={{ width: 200, marginRight:1, marginTop:1 }}
										size="small"
										onChange={event => setToDate(event.target.value)}
										/>		

									<Button onClick={() => {search()}} style={{marginTop:8}} size="small" variant="contained" color="secondary" >Search</Button>

									<span style={{marginTop:30}}>	
										{(authPrivileges && authPrivileges.create===1)?<>
											<i onClick={()=>{saveData(1)}} title="Create New Student" className="fa fa-plus-circle" style={{fontSize:30, color:'#0158dc',marginLeft:15, cursor:'pointer'}} />
											{(recordsFound>0)?<i onClick={()=>{downloadFile(1)}} title="Download" className="fa fa-download" style={{fontSize:20, color:'#0158dc',marginLeft:15, cursor:'pointer'}} />:null}
										</>:null}
										{selectedRow>0?<>
											{(authPrivileges && authPrivileges.update===1)?
											<>
												<i onClick={()=>{saveData(2)}} title="Edit" className="fa fa-pencil-square-o" style={{fontSize:20, color:'#0158dc',marginLeft:15, cursor:'pointer'}} />
												<i onClick={()=>{saveData(5)}} title="Add new course to student" className='fa fa-book' style={{fontSize:20, color:'#0158dc',marginLeft:15, cursor:'pointer'}} />
												{(studentObj && studentObj.courses && studentObj.courses.length>0)?
												<i onClick={()=>{saveData(3)}} title="Student's courses & validity" className="fa fa-calendar" style={{fontSize:20, color:'#0158dc',marginLeft:15, cursor:'pointer'}} />
												:null}
												<i onClick={()=>{saveData(4)}} title="Student's academy" className='fa fa-university' style={{fontSize:20, color:'#0158dc',marginLeft:15, cursor:'pointer'}} />
											</>
  											:null}
											{(authPrivileges && authPrivileges.delete===1)?
												<i onClick={()=>{setDeleteDialogShow(true)}} title="Delete Student" className="fa fa-trash" style={{fontSize:20, color:'#0158dc',marginLeft:15, cursor:'pointer'}} />
											:null}	
										</>:null}
										
									</span>	
								</Grid>
							</Grid>
					</Box>

					<div className="tblReport" style={{height: 2150, width: '100%' }}>
						<DataGrid
							rows={rows}
							columns={columns}
							pageSize={50}
							rowHeight={40}
							rowsPerPageOptions={[50]}
							ActionsComponent={()=>{alert('Hello')}}		
							style={{fontSize:12}}	
							onRowClick={itm => selectRow(itm)}
							components={{
								NoRowsOverlay: () => (
								  <Stack height="100%" alignItems="center" justifyContent="center">
									<span style={{color:'#FF0000',fontWeight:'bold'}}>No student found!</span>
								  </Stack>
								)}}	
						/>
					</div>

				</Box>
				
			<DialogStudentValidityEdit studentObj={studentObj} validityIndex={validityIndex} ref={childRefValidityEdit} />	
			<DialogStudentValidity studentObj={studentObj} editValidity={editMyValidity} deleteValidityData={deleteValidityData} ref={childRefValidity} />						
			<DialogStudentEdit studentObj={studentObj} ref={childRef} />
			<StudentAcademyEdit studentObj={studentObj} schools={schools} ref={childRefAcademy} />								
			<DialogStudentSave websites={websites} schools={schools} ref={childRefAddStudent} />
			<StudentNewCourseSave websites={websites} studentObj={studentObj} ref={childRefNewCorsSave} />	
			
				<Stack spacing={2} sx={{ width: '100%' }}>
					<Snackbar open={showAlert} autoHideDuration={6000} onClose={hideAlert} anchorOrigin={{vertical,horizontal}}  >
						<Alert onClose={hideAlert} variant="filled" severity={severityAlert} sx={{ width: '100%' }}>
							{alertMessage}
						</Alert>
					</Snackbar>
				</Stack>

				<Dialog
					open={deleteDialogShow}
					onClose={deleteDialogHide}
					aria-labelledby="alert-dialog-section-title"
					aria-describedby="alert-dialog-section-description"
				>
					<DialogTitle id="alert-dialog-section-title">
						Alert
					</DialogTitle>
					<DialogContent>
					<DialogContentText id="alert-dialog-section-description">
						Are you sure, You want to delete student.
					</DialogContentText>
					</DialogContent>
					<DialogActions>
					<Button variant="outlined" size="small" onClick={()=>{deleteDialogHide()}}>Don't Delete</Button>
					<Button variant="contained" size="small" color="secondary" onClick={()=>{deleteData()}} autoFocus>Yes, Delete</Button>
					</DialogActions>
				</Dialog>
					

				<Dialog
					open={downloadShow}
					aria-labelledby="alert-dialog-section-title-a"
					aria-describedby="alert-dialog-section-description-a"
				>
					<DialogTitle id="alert-dialog-section-title-a">
						Alert
					</DialogTitle>
					<DialogContent>
					<DialogContentText id="alert-dialog-section-description-a">
						<div style={{width:360}}>
						{downloadReady?<><div style={{textAlign:'center'}}><CircularProgress size={28} /></div>
						<br/>Wait..., It is creating CSV file to download</>:<>CSV file is ready to download</>}
						</div>
					</DialogContentText>
					</DialogContent>
					<DialogActions>
					{!downloadReady?<><Button variant="outlined" size="small" onClick={()=>{downloadFile(2)}}>Cancel</Button><Button variant="contained" size="small" style={{backgroundColor:'#8d04e8',color:'#FFF'}} onClick={()=>{downloadFile(3)}}>Download Now</Button></>:null}
					</DialogActions>
				</Dialog>

				<DialogAuthorization ref={childRefAuthorization} />

		</div>	
	);
  }