import React from 'react';
import CircularProgress from '@mui/material/CircularProgress';
import {Box, Grid, Button} from '@material-ui/core';
import {TextField, FormControl, Stack, Snackbar, Alert, LinearProgress, Radio, Dialog, DialogActions, DialogContent, DialogContentText, DialogTitle} from '@mui/material';
import {MetaTags} from 'react-meta-tags';
import axios from 'axios';
import Cookies from 'js-cookie';
import DialogAuthorization from '../components/DialogAuthorization';
import { useSelector } from 'react-redux';
import {API_URL} from '../utils/EnvVars';
import Header from "./HeaderMy";
///import moment from 'moment';
import '../styles/bizofficer-a.css';
import 'font-awesome/css/font-awesome.min.css';

  
  export default function Execute() {
	const userObj = useSelector(state => state.userDetails);	
	const isloggedin = Cookies.get('isadminloggedin');
	const childRefAuthorization = React.useRef();
	const [pageLoading, setPageLoading] = React.useState(true);
	const [startTreeSync, setStartTreeSync] = React.useState(false);
	const [treeSyncDone, setTreeSyncDone] = React.useState(false);
	const [authPrivileges, setAuthPrivileges] = React.useState({});

	// check if logged in
	React.useEffect(() => {
		if(!isloggedin){
			window.location.href='login';
		}
	}, [isloggedin]);

	React.useEffect(() => {		
		if(userObj.emailId && userObj.token){
			getApiOrganisationList(userObj.emailId,userObj.token);
		}
	}, [userObj]);

	async function getApiOrganisationList(emailId,token){
      let axiosHeader = {
        headers: {
          'Content-Type': 'multipart/mixed',
          'token': token,
          'loginEmailId': emailId,
        }
      }; 
	  axios.get(API_URL+'/treeviewsynccheckauth',axiosHeader)
			   .then(response => {			 	 
				setPageLoading(false); 		
				if(response.data && response.data.responseTxt==="InvalidToken"){ 
					Cookies.remove('isadminloggedin');
					window.location.href='login';
				}else if(response.data && response.data.responseTxt==="NoAuthorization"){ 
					childRefAuthorization.current.handleClickOpen();
				}else if(response.data && response.data.responseTxt==="success"){					
					setAuthPrivileges(response.data.privileges);
				}			 				
	  })
	}


	function startSync(){
		if(userObj.emailId && userObj.token){
			setTreeSyncDone(false);
			setStartTreeSync(true);
			syncData();
		}
	}

	async function syncData(){
			axios.get(API_URL+'/topicquestioncount')
			   .then(response => {
			 	///console.log("Just Checking >> "+response.data);
				 if(response.data.responseTxt==="DONE"){	
					setTreeSyncDone(true);				 
					setStartTreeSync(false);
				 }	 				
			})
	}

	

	return (
		<div> 
				<MetaTags>
            		<title>Treeview Sync</title>
          		</MetaTags>
				
				<Header title="Treeview Sync" />
				{pageLoading?<LinearProgress />:null}

				<Box className='mainBox'>	

					<Box mt={1}>
							<Grid container spacing={2}>
								<Grid item md={12} xs={12} style={{textAlign:'center'}} >
								{treeSyncDone?<span style={{fontSize:30,color:'#0000FF'}} >Synchronization has been completed successfully.</span>:null}
								{startTreeSync?<>	
									<CircularProgress /><br/>
									<span style={{fontSize:30,color:'#FF0000'}} >Wait...</span><br/>
									<span style={{fontSize:14,color:'#0000FF',fontWeight:'bold'}} >You have initiated for synchronization and cache tree-view. It will take approx 1 hour to finish it.</span>
									<br/><span style={{fontWeight:'bold'}} >You can close this window.</span>
									</>
								:	
								(authPrivileges && authPrivileges.create===1)?
									<Button onClick={() => {startSync()}} style={{marginTop:50}} size="large" variant="contained" color="secondary" >Initiate Sync</Button>
  								:null
								}	
								</Grid>
							</Grid>
					</Box>

					

				</Box>

			
				
				<DialogAuthorization ref={childRefAuthorization} />				

		</div>	
	);
  }