package com.bizofficer.admin.subscription;



import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;
import javax.persistence.TypedQuery;

import org.apache.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.crossstore.ChangeSetPersister.NotFoundException;
import org.springframework.stereotype.Service;

import com.bizofficer.hibernate.entity.PgprepAdministrator;
import com.bizofficer.hibernate.entity.SubscriptionCourses;
import com.bizofficer.hibernate.repository.PgprepAdministratorRepository;
import com.bizofficer.module.util.PrivilegesBeans;
import com.bizofficer.module.util.PrivilegesUtil;
import com.bizofficer.module.util.RoleModules;
import com.bizofficer.system.util.MakeDate;


@Service
public class CoursesAdminService{
	
	private static final Logger logger = Logger.getLogger(CoursesAdminService.class);
	
	@Autowired
	EntityManagerFactory entityManagerFactory;
	
	@Autowired
	PgprepAdministratorRepository adminRepo;
	
	public Object execute(Object obj) throws NotFoundException{
		AdminSubscriptionBean objBean = (AdminSubscriptionBean) obj;
		SubscriptionResponseBean responseObj = new SubscriptionResponseBean();
		
		try {
			
			responseObj.setResponseTxt("failed");
			
			logger.info("LoginEmailId >> " + objBean.getLoginEmailId() );
			logger.info("Token >> " + objBean.getToken() );
			logger.info("Keyword >> " + objBean.getKeyword() );
			logger.info("WebsiteId >> " + objBean.getWebsiteId() );
			
			if(objBean.getLoginEmailId()==null || objBean.getToken()==null) {
				return responseObj;
			}
			
			PgprepAdministrator adminObj = (PgprepAdministrator) adminRepo.findByEmailIdAndLoginToken(objBean.getLoginEmailId(), objBean.getToken());
			if(adminObj==null) {
				return responseObj;
			}			

			logger.info("Verify >> " + adminObj.getId() );
			
			if(adminObj.getUserType()==0 && adminObj.getRoleId()!=null && adminObj.getPrivileges()!=null){				
				PrivilegesUtil	myPgUtil = new PrivilegesUtil();
				PrivilegesBeans prvgbnObj = myPgUtil.authPrivileges(adminObj.getPrivileges(), RoleModules.getCourses() );
				logger.info(prvgbnObj.toString());
				if(prvgbnObj!=null && prvgbnObj.getView()!=null && prvgbnObj.getView()==1) {					
					responseObj.setPrivileges(prvgbnObj);
				}else {
					logger.info("NoAuthorization");
					responseObj.setResponseTxt("NoAuthorization");
					return responseObj;
				}
			}else {
				PrivilegesUtil	myPgUtil = new PrivilegesUtil();
				PrivilegesBeans prvgbnObj = myPgUtil.fullPrivileges();
				responseObj.setPrivileges(prvgbnObj);
			}
			
			MakeDate mkdateObj = new MakeDate();
			EntityManager entityManager = entityManagerFactory.createEntityManager();
			entityManager.getTransaction().begin();
			
			List<SubscriptionCoursesBean> mylist = new ArrayList<SubscriptionCoursesBean>();
			
			String whereQry =" WHERE 1=1 ";			
			if(objBean.getKeyword()!=null && objBean.getKeyword().length()>0 ) {
				whereQry +=" AND (webUrl LIKE :keyword OR freeOrganisationName LIKE :keyword OR paidOrganisationName LIKE :keyword OR categoryName LIKE :keyword OR courseTitle LIKE :keyword ) ";
			}
			if(objBean.getWebsiteId()!=null && objBean.getWebsiteId()>0 ) {
				whereQry +=" AND websiteId=:websiteId ";
			}
			
			TypedQuery<SubscriptionCourses> query = (TypedQuery<SubscriptionCourses>) entityManager.createQuery("from "+SubscriptionCourses.class.getName()+whereQry+" order by courseId desc ", SubscriptionCourses.class);
			if(objBean.getKeyword()!=null && objBean.getKeyword().length()>0 ) {
				query.setParameter("keyword", "%"+objBean.getKeyword()+"%");
			}
			if(objBean.getWebsiteId()!=null && objBean.getWebsiteId()>0 ) {
				query.setParameter("websiteId", objBean.getWebsiteId());
			}
			query.setFirstResult(0);
			query.setMaxResults(500);
			List<?> resultListCat = query.getResultList();
			Iterator<?> iteratorCat=resultListCat.iterator();	
			SubscriptionCoursesBean clsObj;
			int i=1;
			while(iteratorCat.hasNext()){
				SubscriptionCourses myObj = (SubscriptionCourses)iteratorCat.next();		
				
				clsObj = new SubscriptionCoursesBean();
				
				clsObj.setId(i);
				clsObj.setAutoId(myObj.getCourseId());
				///websiteId webUrl freeOrganisationId freeOrganisationName paidOrganisationId paidOrganisationName
				// categoryId categoryName courseUrl courseTitle retailPrice salePrice discount validityNumber validityUnit
				// status
				
				clsObj.setWebsiteId(myObj.getWebsiteId());
				clsObj.setWebUrl(myObj.getWebUrl());
				clsObj.setFreeOrganisationId(myObj.getFreeOrganisationId());
				clsObj.setFreeOrganisationName(myObj.getFreeOrganisationName());
				clsObj.setPaidOrganisationId(myObj.getPaidOrganisationId());
				clsObj.setPaidOrganisationName(myObj.getPaidOrganisationName());
				clsObj.setCategoryId(myObj.getCategoryId());
				clsObj.setCategoryName(myObj.getCategoryName());
				
				clsObj.setCourseUrl(myObj.getCourseUrl());
				clsObj.setCourseTitle(myObj.getCourseTitle());
				clsObj.setCourseSubTitle(myObj.getCourseSubTitle());
				clsObj.setHeadingDescription(myObj.getHeadingDescription());
				clsObj.setCourseDetailMobile(myObj.getCourseDetailMobile());
				clsObj.setRetailPrice(myObj.getRetailPrice());
				clsObj.setSalePrice(myObj.getSalePrice());				
				clsObj.setDiscount(myObj.getDiscount());
				clsObj.setValidityNumber(myObj.getValidityNumber());
				clsObj.setValidityUnit(myObj.getValidityUnit());
				
				if(myObj.getValidityDate()!=null) {
					clsObj.setValidityDate(mkdateObj.dateToString(myObj.getValidityDate(), "dd-MM-yyyy") );
				}
				
				if(myObj.getStatus()==1) {
					clsObj.setStatus("Active");
				}else {
					clsObj.setStatus("Inactive");
				}
				
				mylist.add(clsObj);
				i++;
			}

			responseObj.setList(mylist);
			responseObj.setResponseTxt("success");
			entityManager.getTransaction().commit();
			entityManager.close();
		        
		}catch(Exception e) {
			e.getStackTrace();
		}
		
		
		return responseObj;
	}
	

	
	

	
	
}
