package com.bizofficer.admin.payments;



import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;
import javax.persistence.TypedQuery;

import org.apache.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.crossstore.ChangeSetPersister.NotFoundException;
import org.springframework.stereotype.Service;

import com.bizofficer.hibernate.entity.PgprepAdministrator;
import com.bizofficer.hibernate.entity.PgprepStudentDetails;
import com.bizofficer.hibernate.entity.SubscriptionPaymentTransaction;
import com.bizofficer.hibernate.repository.PgprepAdministratorRepository;
import com.bizofficer.util.module.PrivilegesBeans;
import com.bizofficer.util.module.PrivilegesUtil;
import com.bizofficer.util.module.RoleModules;
import com.bizofficer.util.system.MakeDate;


@Service
public class PaymentAdminService{
	
	private static final Logger logger = Logger.getLogger(PaymentAdminService.class);
	
	@Autowired
	EntityManagerFactory entityManagerFactory;
	
	@Autowired
	PgprepAdministratorRepository adminRepo;
	
	public Object execute(Object obj) throws NotFoundException{
		AdminPaymentBean objBean = (AdminPaymentBean) obj;
		PaymentResponseBean responseObj = new PaymentResponseBean();
		
		try {
			
			responseObj.setResponseTxt("failed");
			logger.info("LoginEmailId >> " + objBean.getLoginEmailId() );
			logger.info("Token >> " + objBean.getToken() );
			logger.info("Keyword >> " + objBean.getKeyword() );
			
			if(objBean.getLoginEmailId()==null || objBean.getToken()==null) {
				return responseObj;
			}
			
			PgprepAdministrator adminObj = (PgprepAdministrator) adminRepo.findByEmailIdAndLoginToken(objBean.getLoginEmailId(), objBean.getToken());
			if(adminObj==null) {
				logger.info("InvalidToken");
				responseObj.setResponseTxt("InvalidToken");
				return responseObj;
			}			

			logger.info("Verify >> " + adminObj.getId() );
			
			if(adminObj.getUserType()==0 && adminObj.getRoleId()!=null && adminObj.getPrivileges()!=null){				
				PrivilegesUtil	myPgUtil = new PrivilegesUtil();
				PrivilegesBeans prvgbnObj = myPgUtil.authPrivileges(adminObj.getPrivileges(), RoleModules.getPayments() );
				logger.info(prvgbnObj.toString());
				if(prvgbnObj!=null && prvgbnObj.getView()!=null && prvgbnObj.getView()==1) {					
					responseObj.setPrivileges(prvgbnObj);
				}else {
					logger.info("NoAuthorization");
					responseObj.setResponseTxt("NoAuthorization");
					return responseObj;
				}
			}else {
				PrivilegesUtil	myPgUtil = new PrivilegesUtil();
				PrivilegesBeans prvgbnObj = myPgUtil.fullPrivileges();
				responseObj.setPrivileges(prvgbnObj);
			}
			
			EntityManager entityManager = entityManagerFactory.createEntityManager();
			entityManager.getTransaction().begin();
			
			List<PaymentTransResBean> mylist = new ArrayList<PaymentTransResBean>();
			MakeDate mkdateObj = new MakeDate();
			
			String whereQry =" WHERE 1=1 ";			
			if(objBean.getKeyword()!=null && objBean.getKeyword().length()>0 ) {
				whereQry +=" AND (domainName LIKE :keyword OR studentName LIKE :keyword OR courseName LIKE :keyword OR referenceNumber LIKE :keyword ) ";
			}
			
			TypedQuery<SubscriptionPaymentTransaction> query = (TypedQuery<SubscriptionPaymentTransaction>) entityManager.createQuery("from "+SubscriptionPaymentTransaction.class.getName()+whereQry+" order by paymentId desc ", SubscriptionPaymentTransaction.class);
			if(objBean.getKeyword()!=null && objBean.getKeyword().length()>0 ) {
				query.setParameter("keyword", "%"+objBean.getKeyword()+"%");
			}
			query.setFirstResult(0);
			query.setMaxResults(500);
			List<?> resultListCat = query.getResultList();
			Iterator<?> iteratorCat=resultListCat.iterator();	
			PaymentTransResBean resObj;
			int i=1;
			while(iteratorCat.hasNext()){
				SubscriptionPaymentTransaction myObj = (SubscriptionPaymentTransaction)iteratorCat.next();
				
				resObj = new PaymentTransResBean();
				
				resObj.setId(i);
				resObj.setAutoId(myObj.getPaymentId());
				resObj.setDomainName(myObj.getDomainName());
				resObj.setWebsiteId(myObj.getWebsiteId());
				resObj.setStudentName(myObj.getStudentName());
				resObj.setCourseId(myObj.getCourseId());	
				resObj.setCourseName(myObj.getCourseName());
				resObj.setAmount(myObj.getAmount());
				resObj.setReferenceNumber(myObj.getReferenceNumber());
				resObj.setPromoCode(myObj.getPromoCode());
				resObj.setCreatedDateTime(mkdateObj.changeDateTimeFormat(myObj.getCreatedDateTime(), "dd-MM-yyyy HH:mm"));
				
				if(myObj.getStudentId()!=null) {
					TypedQuery<PgprepStudentDetails> queryST = (TypedQuery<PgprepStudentDetails>) entityManager.createQuery("from "+PgprepStudentDetails.class.getName()+" WHERE studentId=:studentId ", PgprepStudentDetails.class);
					queryST.setParameter("studentId", myObj.getStudentId());
					queryST.setFirstResult(0);
					queryST.setMaxResults(1);
					List<?> resultST = queryST.getResultList();
					Iterator<?> iteratorST=resultST.iterator();	
					if(iteratorST.hasNext()){
						PgprepStudentDetails myObjST = (PgprepStudentDetails)iteratorST.next();
						resObj.setPhone(myObjST.getPhoneNo());
						resObj.setEmailId(myObjST.getEmailId());
					}	
				}
					
				mylist.add(resObj);
				i++;
			}

			responseObj.setList(mylist);
			responseObj.setResponseTxt("success");
			entityManager.getTransaction().commit();
			entityManager.close();
		        
		}catch(Exception e) {
			e.getStackTrace();
		}
		
		
		return responseObj;
	}
	

	
	

	
	
}
