package com.bizofficer.admin.promocode;



import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;
import javax.persistence.TypedQuery;

import org.apache.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.crossstore.ChangeSetPersister.NotFoundException;
import org.springframework.stereotype.Service;

import com.bizofficer.hibernate.entity.PgprepAdministrator;
import com.bizofficer.hibernate.entity.SubscriptionPromocode;
import com.bizofficer.hibernate.repository.PgprepAdministratorRepository;
import com.bizofficer.util.module.PrivilegesBeans;
import com.bizofficer.util.module.PrivilegesUtil;
import com.bizofficer.util.module.RoleModules;
import com.bizofficer.util.system.MakeDate;


@Service
public class PromoAdminService{
	
	private static final Logger logger = Logger.getLogger(PromoAdminService.class);
	
	@Autowired
	EntityManagerFactory entityManagerFactory;
	
	@Autowired
	PgprepAdministratorRepository adminRepo;
	
	public Object execute(PromoAdminBean objBean) throws NotFoundException{
		PromoAdminResponseBean responseObj = new PromoAdminResponseBean();
		
		try {
			
			responseObj.setResponseTxt("failed");
			logger.info("LoginEmailId >> " + objBean.getLoginEmailId() );
			logger.info("Token >> " + objBean.getToken() );
			logger.info("Keyword >> " + objBean.getKeyword() );
			
			if(objBean.getLoginEmailId()==null || objBean.getToken()==null) {
				return responseObj;
			}
			
			PgprepAdministrator adminObj = (PgprepAdministrator) adminRepo.findByEmailIdAndLoginToken(objBean.getLoginEmailId(), objBean.getToken());
			if(adminObj==null) {
				logger.info("InvalidToken");
				responseObj.setResponseTxt("InvalidToken");
				return responseObj;
			}			

			logger.info("Verify >> " + adminObj.getId() );
			
			if(adminObj.getUserType()==0 && adminObj.getRoleId()!=null && adminObj.getPrivileges()!=null){				
				PrivilegesUtil	myPgUtil = new PrivilegesUtil();
				PrivilegesBeans prvgbnObj = myPgUtil.authPrivileges(adminObj.getPrivileges(), RoleModules.getPromoCodes() );
				logger.info(prvgbnObj.toString());
				if(prvgbnObj!=null && prvgbnObj.getView()!=null && prvgbnObj.getView()==1) {					
					responseObj.setPrivileges(prvgbnObj);
				}else {
					logger.info("NoAuthorization");
					responseObj.setResponseTxt("NoAuthorization");
					return responseObj;
				}
			}else {
				PrivilegesUtil	myPgUtil = new PrivilegesUtil();
				PrivilegesBeans prvgbnObj = myPgUtil.fullPrivileges();
				responseObj.setPrivileges(prvgbnObj);
			}
			
			MakeDate mkdateObj = new MakeDate();
			EntityManager entityManager = entityManagerFactory.createEntityManager();
			entityManager.getTransaction().begin();
			
			List<SubscriptionPromoBean> mylist = new ArrayList<SubscriptionPromoBean>();
			
			String whereQry =" WHERE 1=1 ";			
			if(objBean.getKeyword()!=null && objBean.getKeyword().length()>0 ) {
				whereQry +=" AND (code LIKE :keyword OR discountType LIKE :keyword OR description LIKE :keyword OR webUrl LIKE :keyword OR courseTitle LIKE :keyword ) ";
			}
						
			TypedQuery<SubscriptionPromocode> query = (TypedQuery<SubscriptionPromocode>) entityManager.createQuery("from "+SubscriptionPromocode.class.getName()+whereQry+" order by id desc ", SubscriptionPromocode.class);
			if(objBean.getKeyword()!=null && objBean.getKeyword().length()>0 ) {
				query.setParameter("keyword", "%"+objBean.getKeyword()+"%");
			}

			query.setFirstResult(0);
			query.setMaxResults(500);
			List<?> resultListCat = query.getResultList();
			Iterator<?> iteratorCat=resultListCat.iterator();	
			SubscriptionPromoBean clsObj;
			int i=1;
			while(iteratorCat.hasNext()){
				SubscriptionPromocode myObj = (SubscriptionPromocode)iteratorCat.next();		
				
				clsObj = new SubscriptionPromoBean();
				
				clsObj.setId(i);
				clsObj.setAutoId(myObj.getId());
				
				clsObj.setDiscount(myObj.getDiscount());
				clsObj.setCode(myObj.getCode());
				clsObj.setDiscountType(myObj.getDiscountType());
				
				if(myObj.getStartDate()!=null) {
					clsObj.setStartDate(mkdateObj.dateToString(myObj.getStartDate(), "dd-MM-yyyy") );
				}
				if(myObj.getEndDate()!=null) {
					clsObj.setEndDate(mkdateObj.dateToString(myObj.getEndDate(), "dd-MM-yyyy") );
				}
				
				if(myObj.getStatus()!=null && myObj.getStatus()==1) {
					clsObj.setStatus("Active");
				}else {
					clsObj.setStatus("Not Active");
				}
				
				if(myObj.getDisplayPublic()!=null && myObj.getDisplayPublic()==1) {
					clsObj.setDisplayPublic("Public");
				}else {
					clsObj.setDisplayPublic("Private");
				}
				
				clsObj.setDescription(myObj.getDescription());

				clsObj.setWebsiteId(myObj.getWebsiteId());
				clsObj.setWebUrl(myObj.getWebUrl());
				clsObj.setCourseId(myObj.getCourseId());
				clsObj.setCourseTitle(myObj.getCourseTitle());
				
				mylist.add(clsObj);
				i++;
			}

			responseObj.setList(mylist);
			
			responseObj.setResponseTxt("success");
			
			entityManager.getTransaction().commit();
			entityManager.close();
		        
		}catch(Exception e) {
			e.getStackTrace();
		}
		
		
		return responseObj;
	}
	

	
	

	
	
}
