package com.bizofficer.admin.school;



import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;

import org.apache.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.bizofficer.hibernate.entity.PgprepAdministrator;
import com.bizofficer.hibernate.entity.PgprepSchoolUsers;
import com.bizofficer.hibernate.entity.PgprepSchools;
import com.bizofficer.hibernate.repository.PgprepAdministratorRepository;
import com.bizofficer.hibernate.repository.PgprepSchoolUsersRepository;
import com.bizofficer.hibernate.repository.PgprepSchoolsRepository;
import com.bizofficer.util.module.PrivilegesBeans;
import com.bizofficer.util.module.PrivilegesUtil;
import com.bizofficer.util.module.RoleModules;
import com.bizofficer.util.system.General;
import com.bizofficer.util.system.MakeDate;


@Service
public class SchoolCreationAdminService{
	
	private static final Logger logger = Logger.getLogger(SchoolCreationAdminService.class);
	
	@Autowired
	EntityManagerFactory entityManagerFactory;
	
	@Autowired
	PgprepAdministratorRepository adminRepo;
	
	@Autowired
	PgprepSchoolsRepository stRepo;
	
	@Autowired
	PgprepSchoolUsersRepository usrRepo;
	
	public Object execute(AdminSchoolBean objBean){		
		SchoolAdminResponseBean responseObj = new SchoolAdminResponseBean();
		
		try {
			
			responseObj.setResponseTxt("failed");
			
			logger.info("LoginEmailId >> " + objBean.getLoginEmailId() );
			logger.info("Token >> " + objBean.getToken() );
			
			logger.info("School Name >> " + objBean.getSchoolName() );
			logger.info("Website Id >> " + objBean.getWebsiteId() );
			logger.info("Web Url >> " + objBean.getWebUrl() );
			logger.info("Address >> " + objBean.getAddress() );
			
			logger.info("Email Id >> " + objBean.getEmailId() );
			logger.info("FullName >> " + objBean.getFullName() );

			
			if(objBean.getLoginEmailId()==null || objBean.getToken()==null || objBean.getSchoolName()==null) {
				return responseObj;
			}
			
			PgprepAdministrator adminObj = (PgprepAdministrator) adminRepo.findByEmailIdAndLoginToken(objBean.getLoginEmailId(), objBean.getToken());
			if(adminObj==null) {
				logger.info("InvalidToken");
				responseObj.setResponseTxt("InvalidToken");
				return responseObj;
			}
			logger.info("Verify >> " + adminObj.getId() );
			if(adminObj.getUserType()==0 && adminObj.getRoleId()!=null && adminObj.getPrivileges()!=null){				
				PrivilegesUtil	myPgUtil = new PrivilegesUtil();
				PrivilegesBeans prvgbnObj = myPgUtil.authPrivileges(adminObj.getPrivileges(), RoleModules.getAcademy() );
				logger.info(prvgbnObj.toString());
				if(prvgbnObj==null || (prvgbnObj!=null && (prvgbnObj.getCreate()==null || prvgbnObj.getCreate()==0))) {
					logger.info("NoAuthorization");
					responseObj.setResponseTxt("NoAuthorization");
					return responseObj;
				}
			}
			
			PgprepSchools schObj = stRepo.findIdBySchoolName(objBean.getSchoolName());
			logger.info("Existing >> " + schObj );
			if(schObj!=null && schObj.getSchoolId()>0) {
				responseObj.setResponseTxt("AlreadyExistsError");
				return responseObj;
			}
			
			PgprepSchoolUsers schusrObj = usrRepo.findIdByEmailId(objBean.getEmailId());
			logger.info("Existing >> " + schusrObj );
			if(schusrObj!=null && schusrObj.getId()>0) {
				responseObj.setResponseTxt("AlreadyExistsError");
				return responseObj;
			}
			
			General gen = new General();
			MakeDate dateObj = new MakeDate();
			
			EntityManager entityManager = entityManagerFactory.createEntityManager();
			entityManager.getTransaction().begin();
			
			PgprepSchools saveObj = new PgprepSchools();
			saveObj.setSchoolName(objBean.getSchoolName());
			saveObj.setWebsiteId(objBean.getWebsiteId());
			saveObj.setWebUrl(objBean.getWebUrl());
			saveObj.setAddress(objBean.getAddress());
			saveObj.setStatus(1);
			saveObj.setCreatedDate(dateObj.getCurrentTimeStamp());
			PgprepSchools mySchoolObj = stRepo.save(saveObj);

			
			PgprepSchoolUsers usrObj = new PgprepSchoolUsers();
			usrObj.setSchoolId(mySchoolObj.getSchoolId());
			usrObj.setSchoolName(objBean.getSchoolName());
			usrObj.setSchoolName(objBean.getSchoolName());
			usrObj.setSchoolName(objBean.getSchoolName());
			usrObj.setFullName(objBean.getFullName());
			usrObj.setEmailId(objBean.getEmailId());
			usrObj.setPassword(gen.getMD5Hashing(objBean.getNewPassword()));
			usrObj.setRole("admin");
			usrObj.setStatus(1);
			usrObj.setCreatedDateTime(dateObj.getCurrentTimeStamp());
			usrRepo.save(usrObj);
			
			responseObj.setResponseTxt("success");
			
			entityManager.getTransaction().commit();
			entityManager.close();
		        
		}catch(Exception e) {
			e.getStackTrace();
		}
		
		
		return responseObj;
	}
	

	
	

	
	
}
