package com.bizofficer.admin.school;



import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;

import org.apache.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.bizofficer.hibernate.entity.PgprepAdministrator;
import com.bizofficer.hibernate.entity.PgprepSchools;
import com.bizofficer.hibernate.repository.PgprepAdministratorRepository;
import com.bizofficer.hibernate.repository.PgprepSchoolUsersRepository;
import com.bizofficer.hibernate.repository.PgprepSchoolsRepository;
import com.bizofficer.util.module.PrivilegesBeans;
import com.bizofficer.util.module.PrivilegesUtil;
import com.bizofficer.util.module.RoleModules;


@Service
public class SchoolUpdateAdminService{
	
	private static final Logger logger = Logger.getLogger(SchoolUpdateAdminService.class);
	
	@Autowired
	EntityManagerFactory entityManagerFactory;
	
	@Autowired
	PgprepAdministratorRepository adminRepo;
	
	@Autowired
	PgprepSchoolsRepository stRepo;
	
	@Autowired
	PgprepSchoolUsersRepository usrRepo;
	
	public Object execute(AdminSchoolBean objBean){
		SchoolAdminResponseBean responseObj = new SchoolAdminResponseBean();
		
		try {
			
			logger.info("LoginEmailId >> " + objBean.getLoginEmailId() );
			logger.info("Token >> " + objBean.getToken() );
			
			logger.info("Id >> " + objBean.getId() );
			logger.info("SchoolName >> " + objBean.getSchoolName() );
			logger.info("Address >> " + objBean.getAddress() );
			
			if(objBean.getLoginEmailId()==null || objBean.getToken()==null) {
				return responseObj;
			}
			
			PgprepAdministrator adminObj = (PgprepAdministrator) adminRepo.findByEmailIdAndLoginToken(objBean.getLoginEmailId(), objBean.getToken());
			if(adminObj==null) {
				logger.info("InvalidToken");
				responseObj.setResponseTxt("InvalidToken");
				return responseObj;
			}
			logger.info("Verify >> " + adminObj.getId() );
			if(adminObj.getUserType()==0 && adminObj.getRoleId()!=null && adminObj.getPrivileges()!=null){				
				PrivilegesUtil	myPgUtil = new PrivilegesUtil();
				PrivilegesBeans prvgbnObj = myPgUtil.authPrivileges(adminObj.getPrivileges(), RoleModules.getAcademy() );
				logger.info(prvgbnObj.toString());
				if(prvgbnObj==null || (prvgbnObj!=null && (prvgbnObj.getUpdate()==null || prvgbnObj.getUpdate()==0))) {
					logger.info("NoAuthorization");
					responseObj.setResponseTxt("NoAuthorization");
					return responseObj;
				}
			}
			
			PgprepSchools scObj = stRepo.findIdBySchoolNameAndSchoolIdNot(objBean.getSchoolName(),objBean.getId());
			logger.info("Existing >> " + scObj );
			if(scObj!=null && scObj.getSchoolId()>0) {
				responseObj.setResponseTxt("AlreadyExistsError");
				return responseObj;
			}			
			
			EntityManager entityManager = entityManagerFactory.createEntityManager();
			entityManager.getTransaction().begin();
			
			PgprepSchools findObj = (PgprepSchools)entityManager.find(PgprepSchools.class ,objBean.getId());
			findObj.setSchoolName(objBean.getSchoolName());
			findObj.setWebsiteId(objBean.getWebsiteId());
			findObj.setWebUrl(objBean.getWebUrl());
			findObj.setAddress(objBean.getAddress());
			
			entityManager.getTransaction().commit();
			entityManager.close();

			//UPDATE SCHOOL NAME
			usrRepo.updateSchoolName(objBean.getSchoolName(), objBean.getId());
			
			responseObj.setResponseTxt("success");
				
		        
		}catch(Exception e) {
			e.getStackTrace();
		}
		
		
		return responseObj;
	}
	

	
	

	
	
}
