package com.bizofficer.admin.school;



import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;

import org.apache.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.bizofficer.hibernate.entity.PgprepAdministrator;
import com.bizofficer.hibernate.entity.PgprepSchoolUsers;
import com.bizofficer.hibernate.repository.PgprepAdministratorRepository;
import com.bizofficer.hibernate.repository.PgprepSchoolUsersRepository;
import com.bizofficer.util.module.PrivilegesBeans;
import com.bizofficer.util.module.PrivilegesUtil;
import com.bizofficer.util.module.RoleModules;
import com.bizofficer.util.system.General;
import com.bizofficer.util.system.MakeDate;


@Service
public class UserSchoolCreationAdminService{
	
	private static final Logger logger = Logger.getLogger(UserSchoolCreationAdminService.class);
	
	@Autowired
	EntityManagerFactory entityManagerFactory;
	
	@Autowired
	PgprepAdministratorRepository adminRepo;
	
	@Autowired
	PgprepSchoolUsersRepository stRepo;
	
	public Object execute(AdminSchoolBean objBean){		
		SchoolAdminResponseBean responseObj = new SchoolAdminResponseBean();
		
		try {
			
			responseObj.setResponseTxt("failed");
			
			logger.info("LoginEmailId >> " + objBean.getLoginEmailId() );
			logger.info("Token >> " + objBean.getToken() );

			logger.info("School Id >> " + objBean.getSchoolId() );
			logger.info("School Name >> " + objBean.getSchoolName() );
			logger.info("Email Id >> " + objBean.getEmailId() );
			logger.info("FullName >> " + objBean.getFullName() );
			
			if(objBean.getLoginEmailId()==null || objBean.getToken()==null || objBean.getEmailId()==null) {
				return responseObj;
			}
			
			PgprepAdministrator adminObj = (PgprepAdministrator) adminRepo.findByEmailIdAndLoginToken(objBean.getLoginEmailId(), objBean.getToken());
			if(adminObj==null) {
				logger.info("InvalidToken");
				responseObj.setResponseTxt("InvalidToken");
				return responseObj;
			}
			logger.info("Verify >> " + adminObj.getId() );
			if(adminObj.getUserType()==0 && adminObj.getRoleId()!=null && adminObj.getPrivileges()!=null){				
				PrivilegesUtil	myPgUtil = new PrivilegesUtil();
				PrivilegesBeans prvgbnObj = myPgUtil.authPrivileges(adminObj.getPrivileges(), RoleModules.getAcademy() );
				logger.info(prvgbnObj.toString());
				if(prvgbnObj==null || (prvgbnObj!=null && (prvgbnObj.getUpdate()==null || prvgbnObj.getUpdate()==0))) {
					logger.info("NoAuthorization");
					responseObj.setResponseTxt("NoAuthorization");
					return responseObj;
				}
			}
			
			PgprepSchoolUsers schObj = stRepo.findIdByEmailId(objBean.getEmailId());
			logger.info("Existing >> " + schObj );
			if(schObj!=null && schObj.getId()>0) {
				responseObj.setResponseTxt("AlreadyExistsError");
				return responseObj;
			}
			
			General gen = new General();
			MakeDate dateObj = new MakeDate();
			
			EntityManager entityManager = entityManagerFactory.createEntityManager();
			entityManager.getTransaction().begin();
			
			PgprepSchoolUsers saveObj = new PgprepSchoolUsers();
			saveObj.setSchoolId(objBean.getSchoolId());
			saveObj.setSchoolName(objBean.getSchoolName());
			saveObj.setFullName(objBean.getFullName());
			saveObj.setEmailId(objBean.getEmailId());
			saveObj.setPassword(gen.getMD5Hashing(objBean.getNewPassword()));
			saveObj.setRole("admin");
			saveObj.setStatus(1);
			saveObj.setCreatedDateTime(dateObj.getCurrentTimeStamp());
			stRepo.save(saveObj);

			responseObj.setResponseTxt("success");
			
			entityManager.getTransaction().commit();
			entityManager.close();
		        
		}catch(Exception e) {
			e.getStackTrace();
		}
		
		
		return responseObj;
	}
	

	
	

	
	
}
