package com.bizofficer.admin.students;



import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;

import org.apache.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.crossstore.ChangeSetPersister.NotFoundException;
import org.springframework.stereotype.Service;

import com.bizofficer.hibernate.entity.PgprepAdministrator;
import com.bizofficer.hibernate.entity.PgprepStudentCourses;
import com.bizofficer.hibernate.repository.PgprepAdministratorRepository;
import com.bizofficer.hibernate.repository.PgprepStudentCoursesRepository;
import com.bizofficer.util.module.PrivilegesBeans;
import com.bizofficer.util.module.PrivilegesUtil;
import com.bizofficer.util.module.RoleModules;
import com.bizofficer.util.system.MakeDate;


@Service
public class StudentNewCourseAdminService{
	
	private static final Logger logger = Logger.getLogger(StudentNewCourseAdminService.class);
	
	@Autowired
	EntityManagerFactory entityManagerFactory;
	
	@Autowired
	PgprepAdministratorRepository adminRepo;
	
	@Autowired
	PgprepStudentCoursesRepository corsRepo;
	
	public Object execute(Object obj) throws NotFoundException{
		StudentAdminBean objBean = (StudentAdminBean) obj;
		StudentAdmResponsePojo responseObj = new StudentAdmResponsePojo();
		
		try {
			
			responseObj.setResponseTxt("failed");
			
			logger.info("getLoginEmailId >> " + objBean.getLoginEmailId() );
			logger.info("Token >> " + objBean.getToken() );

			logger.info("Auto Id >> " + objBean.getId() );
			logger.info("subscriptionType >> " + objBean.getSubscriptionType() );
			logger.info("courseId >> " + objBean.getCourseId() );
			logger.info("courseTitle >> " + objBean.getCourseTitle() );
			logger.info("organisationId >> " + objBean.getOrganisationId() );
			logger.info("studentId >> " + objBean.getStudentId() );
			logger.info("validityDate >> " + objBean.getValidityDate() );
			
			if(objBean.getLoginEmailId()==null || objBean.getToken()==null || objBean.getId()==null || objBean.getCourseId()==null || objBean.getOrganisationId()==null) {
				return responseObj;
			}
			
			PgprepAdministrator adminObj = (PgprepAdministrator) adminRepo.findByEmailIdAndLoginToken(objBean.getLoginEmailId(), objBean.getToken());
			if(adminObj==null) {
				logger.info("InvalidToken");
				responseObj.setResponseTxt("InvalidToken");
				return responseObj;
			}
			logger.info("Verify >> " + adminObj.getId() );
			
			if(adminObj.getUserType()==0 && adminObj.getRoleId()!=null && adminObj.getPrivileges()!=null){				
				PrivilegesUtil	myPgUtil = new PrivilegesUtil();
				PrivilegesBeans prvgbnObj = myPgUtil.authPrivileges(adminObj.getPrivileges(), RoleModules.getStudents() );
				logger.info(prvgbnObj.toString());
				if(prvgbnObj==null || (prvgbnObj!=null && (prvgbnObj.getUpdate()==null || prvgbnObj.getUpdate()==0))) {
					logger.info("NoAuthorization");
					responseObj.setResponseTxt("NoAuthorization");
					return responseObj;
				}
			}
			
			EntityManager entityManager = entityManagerFactory.createEntityManager();
			entityManager.getTransaction().begin();
			
			PgprepStudentCourses checkExistingObj = corsRepo.findIdBySidAndCourseId(objBean.getId(), objBean.getCourseId());
			if(checkExistingObj!=null) {
				responseObj.setResponseTxt("AlreadyExistsError");
				return responseObj;
			}
			
			
			PgprepStudentCourses saveObj = new PgprepStudentCourses();
			saveObj.setSid(objBean.getId());
			saveObj.setStudentId(objBean.getStudentId());
			saveObj.setSubscriptionType(objBean.getSubscriptionType());			
			saveObj.setCourseId(objBean.getCourseId());
			saveObj.setCourseTitle(objBean.getCourseTitle());
			saveObj.setOrganisationId(objBean.getOrganisationId());			
			if(objBean.getValidityDate()!=null) {
				MakeDate dateObj = new MakeDate();
				saveObj.setValidTillDate(dateObj.getStringToDate(objBean.getValidityDate().toString(), "yyyy-MM-dd"));
			}			
			corsRepo.save(saveObj);
				
			responseObj.setResponseTxt("success");
			
			entityManager.getTransaction().commit();
			entityManager.close();
		        
		}catch(Exception e) {
			e.getStackTrace();
		}
		
		
		return responseObj;
	}
	

	
	

	
	
}
