package com.bizofficer.admin.subscription;



import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;
import javax.persistence.TypedQuery;

import org.apache.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.crossstore.ChangeSetPersister.NotFoundException;
import org.springframework.stereotype.Service;

import com.bizofficer.hibernate.entity.PgprepAdministrator;
import com.bizofficer.hibernate.entity.SubscriptionCoursesCategory;
import com.bizofficer.hibernate.repository.PgprepAdministratorRepository;
import com.bizofficer.util.module.PrivilegesBeans;
import com.bizofficer.util.module.PrivilegesUtil;
import com.bizofficer.util.module.RoleModules;


@Service
public class CategoryAdminService{
	
	private static final Logger logger = Logger.getLogger(CategoryAdminService.class);
	
	@Autowired
	EntityManagerFactory entityManagerFactory;
	
	@Autowired
	PgprepAdministratorRepository adminRepo;
	
	public Object execute(Object obj) throws NotFoundException{
		AdminSubscriptionBean objBean = (AdminSubscriptionBean) obj;
		SubscriptionResponseBean responseObj = new SubscriptionResponseBean();
		
		try {
			
			responseObj.setResponseTxt("failed");
			logger.info("LoginEmailId >> " + objBean.getLoginEmailId() );
			logger.info("Token >> " + objBean.getToken() );
			logger.info("Keyword >> " + objBean.getKeyword() );
			
			if(objBean.getLoginEmailId()==null || objBean.getToken()==null) {
				return responseObj;
			}
			
			PgprepAdministrator adminObj = (PgprepAdministrator) adminRepo.findByEmailIdAndLoginToken(objBean.getLoginEmailId(), objBean.getToken());
			if(adminObj==null) {
				logger.info("InvalidToken");
				responseObj.setResponseTxt("InvalidToken");
				return responseObj;
			}			

			logger.info("Verify >> " + adminObj.getId() );
			
			if(adminObj.getUserType()==0 && adminObj.getRoleId()!=null && adminObj.getPrivileges()!=null){				
				PrivilegesUtil	myPgUtil = new PrivilegesUtil();
				PrivilegesBeans prvgbnObj = myPgUtil.authPrivileges(adminObj.getPrivileges(), RoleModules.getCoursesCategories() );
				logger.info(prvgbnObj.toString());
				if(prvgbnObj!=null && prvgbnObj.getView()!=null && prvgbnObj.getView()==1) {					
					responseObj.setPrivileges(prvgbnObj);
				}else {
					logger.info("NoAuthorization");
					responseObj.setResponseTxt("NoAuthorization");
					return responseObj;
				}
			}else {
				PrivilegesUtil	myPgUtil = new PrivilegesUtil();
				PrivilegesBeans prvgbnObj = myPgUtil.fullPrivileges();
				responseObj.setPrivileges(prvgbnObj);
			}
			
			EntityManager entityManager = entityManagerFactory.createEntityManager();
			entityManager.getTransaction().begin();
			
			List<SubscriptionCoursesCategoryBean> mylist = new ArrayList<SubscriptionCoursesCategoryBean>();
			
			String whereQry =" WHERE 1=1 ";			
			if(objBean.getKeyword()!=null && objBean.getKeyword().length()>0 ) {
				whereQry +=" AND (categoryName LIKE :keyword OR categoryUrl LIKE :keyword OR shortDescription LIKE :keyword OR webUrl LIKE :keyword ) ";
			}
			if(objBean.getWebsiteId()!=null && objBean.getWebsiteId()>0) {
				whereQry +=" AND websiteId=:websiteId ";
			}
			
			TypedQuery<SubscriptionCoursesCategory> query = (TypedQuery<SubscriptionCoursesCategory>) entityManager.createQuery("from "+SubscriptionCoursesCategory.class.getName()+whereQry+" order by categoryName ", SubscriptionCoursesCategory.class);
			if(objBean.getKeyword()!=null && objBean.getKeyword().length()>0 ) {
				query.setParameter("keyword", "%"+objBean.getKeyword()+"%");
			}
			if(objBean.getWebsiteId()!=null && objBean.getWebsiteId()>0) {
				query.setParameter("websiteId", objBean.getWebsiteId());
			}
			query.setFirstResult(0);
			query.setMaxResults(500);
			List<?> resultListCat = query.getResultList();
			Iterator<?> iteratorCat=resultListCat.iterator();	
			SubscriptionCoursesCategoryBean clsObj;
			int i=1;
			while(iteratorCat.hasNext()){
				SubscriptionCoursesCategory myObj = (SubscriptionCoursesCategory)iteratorCat.next();		
				
				clsObj = new SubscriptionCoursesCategoryBean();
				
				clsObj.setId(i);
				clsObj.setAutoId(myObj.getCategoryId());
				
				clsObj.setCategoryName(myObj.getCategoryName());
				clsObj.setCategoryUrl(myObj.getCategoryUrl());
				clsObj.setShortDescription(myObj.getShortDescription());				
				clsObj.setOrderBy(myObj.getOrderBy());				
				clsObj.setWebsiteId(myObj.getWebsiteId());
				clsObj.setWebUrl(myObj.getWebUrl());
				
				if(myObj.getStatus()==1) {
					clsObj.setStatus("Active");
				}else {
					clsObj.setStatus("Not Active");
				}
				
				mylist.add(clsObj);
				i++;
			}

			responseObj.setList(mylist);
			responseObj.setResponseTxt("success");
			entityManager.getTransaction().commit();
			entityManager.close();
		        
		}catch(Exception e) {
			e.getStackTrace();
		}
		
		
		return responseObj;
	}
	

	
	

	
	
}
