package com.bizofficer.admin.subscription;



import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;

import org.apache.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.crossstore.ChangeSetPersister.NotFoundException;
import org.springframework.stereotype.Service;

import com.bizofficer.hibernate.entity.PgprepAdministrator;
import com.bizofficer.hibernate.entity.SubscriptionCoursesCategory;
import com.bizofficer.hibernate.repository.PgprepAdministratorRepository;
import com.bizofficer.hibernate.repository.SubscriptionCoursesCategoryRepository;
import com.bizofficer.util.module.PrivilegesBeans;
import com.bizofficer.util.module.PrivilegesUtil;
import com.bizofficer.util.module.RoleModules;


@Service
public class CategoryUpdateAdminService{
	
	private static final Logger logger = Logger.getLogger(CategoryUpdateAdminService.class);
	
	@Autowired
	EntityManagerFactory entityManagerFactory;
	
	@Autowired
	PgprepAdministratorRepository adminRepo;
	
	@Autowired
	SubscriptionCoursesCategoryRepository stRepo;
	
	public Object execute(AdminSubscriptionBean objBean) throws NotFoundException{
		SubscriptionResponseBean responseObj = new SubscriptionResponseBean();
		
		try {
			
			responseObj.setResponseTxt("failed");
			
			logger.info("LoginEmailId >> " + objBean.getLoginEmailId() );
			logger.info("Token >> " + objBean.getToken() );
			
			logger.info("CategoryName >> " + objBean.getCategoryName() );
			logger.info("shortDescription >> " + objBean.getShortDescription() );
			logger.info("OrderBy >> " + objBean.getOrderBy() );
			logger.info("WebsiteId >> " + objBean.getWebsiteId() );
			logger.info("WebUrl >> " + objBean.getWebUrl() );
			logger.info("Status >> " + objBean.getStatus() );
			
			if(objBean.getLoginEmailId()==null || objBean.getToken()==null) {
				return responseObj;
			}
			
			PgprepAdministrator adminObj = (PgprepAdministrator) adminRepo.findByEmailIdAndLoginToken(objBean.getLoginEmailId(), objBean.getToken());
			if(adminObj==null) {
				logger.info("InvalidToken");
				responseObj.setResponseTxt("InvalidToken");
				return responseObj;
			}			

			logger.info("Verify >> " + adminObj.getId() );
			
			if(adminObj.getUserType()==0 && adminObj.getRoleId()!=null && adminObj.getPrivileges()!=null){				
				PrivilegesUtil	myPgUtil = new PrivilegesUtil();
				PrivilegesBeans prvgbnObj = myPgUtil.authPrivileges(adminObj.getPrivileges(), RoleModules.getCoursesCategories() );
				logger.info(prvgbnObj.toString());
				if(prvgbnObj==null || (prvgbnObj!=null && (prvgbnObj.getUpdate()==null || prvgbnObj.getUpdate()==0))) {
					logger.info("NoAuthorization");
					responseObj.setResponseTxt("NoAuthorization");
					return responseObj;
				}
			}
			
			SubscriptionCoursesCategory webObj = stRepo.findIdByCategoryNameAndWebsiteIdAndCategoryIdNot(objBean.getCategoryName(), objBean.getWebsiteId(), objBean.getId() );
			logger.info("Existing >> " + webObj );
			if(webObj!=null && webObj.getCategoryId()>0) {
				responseObj.setResponseTxt("AlreadyExistsError");
				return responseObj;
			}			
			
			EntityManager entityManager = entityManagerFactory.createEntityManager();
			entityManager.getTransaction().begin();
			
			SubscriptionCoursesCategory findObj = (SubscriptionCoursesCategory)entityManager.find(SubscriptionCoursesCategory.class ,objBean.getId());
			findObj.setCategoryName(objBean.getCategoryName());
			findObj.setCategoryUrl(objBean.getCategoryName().trim().replaceAll(" ", "-"));
			findObj.setShortDescription(objBean.getShortDescription());
			findObj.setOrderBy(objBean.getOrderBy());
			findObj.setWebsiteId(objBean.getWebsiteId());
			findObj.setWebUrl(objBean.getWebUrl());
			findObj.setStatus(objBean.getStatus());
			
			entityManager.getTransaction().commit();
			entityManager.close();

			
			responseObj.setResponseTxt("success");
				
		        
		}catch(Exception e) {
			e.getStackTrace();
		}
		
		
		return responseObj;
	}
	

	
	

	
	
}
