package com.bizofficer.admin.teachers;



import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;
import javax.persistence.TypedQuery;

import org.apache.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.crossstore.ChangeSetPersister.NotFoundException;
import org.springframework.stereotype.Service;

import com.bizofficer.hibernate.entity.PgprepAdministrator;
import com.bizofficer.hibernate.entity.PgprepTeachers;
import com.bizofficer.hibernate.repository.PgprepAdministratorRepository;
import com.bizofficer.util.module.PrivilegesBeans;
import com.bizofficer.util.module.PrivilegesUtil;
import com.bizofficer.util.module.RoleModules;


@Service
public class TeachersAdmService{
	
	private static final Logger logger = Logger.getLogger(TeachersAdmService.class);
	
	@Autowired
	EntityManagerFactory entityManagerFactory;
	
	@Autowired
	PgprepAdministratorRepository adminRepo;
	
	public Object execute(Object obj) throws NotFoundException{
		TeachersAdmRequest objBean = (TeachersAdmRequest) obj;
		TeachersAdmResponse responseObj = new TeachersAdmResponse();
		
		try {
			
			responseObj.setResponseTxt("failed");
			
			logger.info("EmailId >> " + objBean.getEmailId() );
			logger.info("Token >> " + objBean.getToken() );
			logger.info("Keyword >> " + objBean.getKeyword() );
			
			if(objBean.getEmailId()==null || objBean.getToken()==null) {
				return responseObj;
			}
			
			PgprepAdministrator adminObj = (PgprepAdministrator) adminRepo.findByEmailIdAndLoginToken(objBean.getEmailId(), objBean.getToken());
			if(adminObj==null) {
				logger.info("InvalidToken");
				responseObj.setResponseTxt("InvalidToken");
				return responseObj;
			}			

			logger.info("Verify >> " + adminObj.getId() );
			
			if(adminObj.getUserType()==0 && adminObj.getRoleId()!=null && adminObj.getPrivileges()!=null){				
				PrivilegesUtil	myPgUtil = new PrivilegesUtil();
				PrivilegesBeans prvgbnObj = myPgUtil.authPrivileges(adminObj.getPrivileges(), RoleModules.getTeachers() );
				logger.info(prvgbnObj.toString());
				if(prvgbnObj!=null && prvgbnObj.getView()!=null && prvgbnObj.getView()==1) {					
					responseObj.setPrivileges(prvgbnObj);
				}else {
					logger.info("NoAuthorization");
					responseObj.setResponseTxt("NoAuthorization");
					return responseObj;
				}
			}else {
				PrivilegesUtil	myPgUtil = new PrivilegesUtil();
				PrivilegesBeans prvgbnObj = myPgUtil.fullPrivileges();
				responseObj.setPrivileges(prvgbnObj);
			}
			
			List<TeachersAdmResponseBean> listObj = new ArrayList<TeachersAdmResponseBean>();
			
			EntityManager entityManager = entityManagerFactory.createEntityManager();
			entityManager.getTransaction().begin();
			
			String whereQry =" WHERE 1=1 ";			
			if(objBean.getKeyword()!=null && objBean.getKeyword().length()>0 ) {
				whereQry +=" AND (schoolName LIKE :keyword OR loginId LIKE :keyword OR emailId LIKE :keyword OR teacherName LIKE :keyword ) "; 
			}
			
			TypedQuery<PgprepTeachers> query = (TypedQuery<PgprepTeachers>) entityManager.createQuery("from "+PgprepTeachers.class.getName()+whereQry+" order by id desc ", PgprepTeachers.class);
			if(objBean.getKeyword()!=null && objBean.getKeyword().length()>0 ) {
				query.setParameter("keyword", "%"+objBean.getKeyword()+"%");
			}
			query.setFirstResult(0);
			query.setMaxResults(500);
			List<?> resultListCat = query.getResultList();
			Iterator<?> iteratorCat=resultListCat.iterator();	
			TeachersAdmResponseBean responseBeanObj;
			int i=1;
			while(iteratorCat.hasNext()){
				PgprepTeachers myObj = (PgprepTeachers)iteratorCat.next();		
				
				responseBeanObj = new TeachersAdmResponseBean();
				
				responseBeanObj.setId(i);
				responseBeanObj.setAutoId(myObj.getId());
				
				if(myObj.getAccountStatus()==1) {
					responseBeanObj.setAccountStatus("Active");
				}else {
					responseBeanObj.setAccountStatus("Inactive");
				}
				
				responseBeanObj.setLoginId(myObj.getLoginId());
				responseBeanObj.setEmailId(myObj.getEmailId());
				responseBeanObj.setTeacherName(myObj.getTeacherName());
				
				responseBeanObj.setSchoolId(myObj.getSchoolId());
				responseBeanObj.setSchoolName(myObj.getSchoolName());
				
				listObj.add(responseBeanObj);
				i++;
			}
			
			responseObj.setList(listObj);

			responseObj.setResponseTxt("success");
				
			entityManager.getTransaction().commit();
			entityManager.close();
		        
		}catch(Exception e) {
			e.getStackTrace();
		}
		
		
		return responseObj;
	}
	

	
	

	
	
}
