package com.bizofficer.apiweb.reports;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;
import javax.persistence.TypedQuery;

import org.apache.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.crossstore.ChangeSetPersister.NotFoundException;
import org.springframework.stereotype.Service;

import com.bizofficer.hibernate.entity.PgprepTestSummary;
import com.bizofficer.pojo.response.ListResponsePojo;
import com.bizofficer.util.system.MakeDate;


@Service
public class ReportsService{
	
	private static final Logger logger = Logger.getLogger(ReportsService.class);
	
	@Autowired
	EntityManagerFactory entityManagerFactory;
	
	@SuppressWarnings("deprecation")
	public Object doExecute(Object obj) throws NotFoundException{
		BeanReport objBean = (BeanReport) obj; 	
		ListResponsePojo responseObj = new ListResponsePojo();
		
		try {

			responseObj.setResponseTxt("failed");
			
			logger.info("StudentId >>> " +  objBean.getStudentId() );
			logger.info("OrganisationId >>> " +  objBean.getOrganisationId() );
			
			if(objBean.getStudentId()==null || objBean.getOrganisationId()==null) {
				return responseObj;
			}
			
			EntityManager entityManager = entityManagerFactory.createEntityManager();
			entityManager.getTransaction().begin();
			
			MakeDate mkdateObj = new MakeDate();
			
			List<ReportsBean> dataList = new ArrayList<ReportsBean>();
			
			ReportsBean serviceObj;
			
			TypedQuery<PgprepTestSummary> query = (TypedQuery<PgprepTestSummary>) entityManager.createQuery("from "+PgprepTestSummary.class.getName()+" where testStatus=1 AND studentId=:studentId AND organisationId=:organisationId order by id desc ", PgprepTestSummary.class);
			query.setParameter("studentId", objBean.getStudentId());
			query.setParameter("organisationId", objBean.getOrganisationId());
			query.setFirstResult(0);
			query.setMaxResults(500);
			List<?> resultListCat = query.getResultList();
			Iterator<?> iteratorCat=resultListCat.iterator();
			int i = 1;
			while(iteratorCat.hasNext()){
				PgprepTestSummary myObj = (PgprepTestSummary)iteratorCat.next();
				
				serviceObj = new ReportsBean();
				serviceObj.setId(i);
				serviceObj.setTotalQuestions(myObj.getTotalQuestion());
				
				if(myObj.getFullMarks()!=null) {
					BigDecimal fullMarks = new BigDecimal(myObj.getFullMarks().toString());
					fullMarks = fullMarks.setScale(2, BigDecimal.ROUND_HALF_EVEN);
					serviceObj.setFullMarks(fullMarks);
				}
				
				serviceObj.setMarksObtain(myObj.getMarksObtain());
				serviceObj.setTimeSpent(this.convertSecondsToTimeLabel(myObj.getTimeSpent()));
				serviceObj.setTestSession(myObj.getTestSession());
				serviceObj.setMockTestName(myObj.getTestTitle());
				serviceObj.setTestTypeId(myObj.getTestType());
				
				if (myObj.getTestType()!=null && myObj.getTestType() == 1) {
					serviceObj.setTestType("Self Test");
                } else if (myObj.getTestType()!=null && myObj.getTestType() == 2) {
                	serviceObj.setTestType("Topic Test");
                } else if (myObj.getTestType()!=null && myObj.getTestType() == 3) {
                	serviceObj.setTestType("Mock Test");
                } else if (myObj.getTestType()!=null && myObj.getTestType() == 4) {
                	serviceObj.setTestType("Class Test");
                }
				
				serviceObj.setSubmitDateTime(mkdateObj.changeDateTimeFormat(myObj.getStartDate(), "dd-MM-yyyy"));
				
				dataList.add(serviceObj);
				
				i++;	
			}
			entityManager.getTransaction().commit();
			entityManager.close();
			
			responseObj.setList(dataList);
			
			responseObj.setResponseTxt("success");
			
		}catch(Exception e) {
			e.getStackTrace();
		}
		
		///System.out.println( "dataList >>> " +  dataList );
			
		return responseObj;
	}
	
	
	private String convertSecondsToTimeLabel(Integer time) {
		String hourStr="00", minsStr="00", secsStr="00";
		
		if(time>0) {
			Integer hours = time/3600; 
			if(hours<10){
				hourStr="0"+hours;
			}else {
				hourStr= String.valueOf(hours);
			}
			
			Integer mins = time % 3600 / 60; 
			if(mins<10){
				minsStr="0"+mins;
			}else {
				minsStr= String.valueOf(mins);
			} 
			
			Integer secs = time % 3600 % 60; 
			if(secs<10){
				secsStr="0"+secs;
			}else {
				secsStr= String.valueOf(secs);
			} 
		}
		return hourStr+':'+minsStr+':'+secsStr; 
	}

	

	
}
