package com.bizofficer.teacher.students;

import org.apache.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpHeaders;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Service;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.RequestHeader;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.bizofficer.teacher.classes.ClassesRequest;
import com.bizofficer.teacher.classes.ClassesTeacherResponse;
import com.bizofficer.teacher.classes.ClassesTeacherService;
import com.bizofficer.teacher.login.LoginTeachBean;
import com.bizofficer.teacher.login.TokenVerifyTeacherResponsePojo;
import com.bizofficer.teacher.login.TokenVerifyTeacherService;

@RestController
@Service
public class TeacherStudentsController {
	
	private static final Logger logger = Logger.getLogger(TeacherStudentsController.class);
	
	@Autowired
	private TeacherStudentsService cclsObj;
	
	@Autowired
	private ClassesTeacherService classesServiceObj;
	
	@Autowired
	private TokenVerifyTeacherService objTokenVerifyTeacherService;

	@RequestMapping(value = {"/teacher-list-students"}, method = RequestMethod.GET)
	public ResponseEntity<Object> execute(@ModelAttribute("SpringWeb")BeanReqTeachStudents objBean, @RequestHeader("schoolId") Integer schoolId, @RequestHeader("userId") String userId, @RequestHeader("token") String token) {
		
		try {
			
			LoginTeachBean loginBean = new LoginTeachBean();
			loginBean.setSchoolId(schoolId);
			loginBean.setUserId(userId);
			loginBean.setToken(token);
			TokenVerifyTeacherResponsePojo objTokenVerifyResponse = (TokenVerifyTeacherResponsePojo) (Object) objTokenVerifyTeacherService.execute(loginBean);
			
			if(objTokenVerifyResponse.getResponseTxt().equals("success")) {
				objBean.setSchoolId(objTokenVerifyResponse.getSchoolId());
				TeacherStudentsResponseBean responseObj = (TeacherStudentsResponseBean) (Object) cclsObj.execute(objBean);
				
				logger.info("Service ResponseTxt: "+responseObj.getResponseTxt());
				
				ClassesRequest clsBean = new ClassesRequest();
				clsBean.setSchoolId(objTokenVerifyResponse.getSchoolId());
				ClassesTeacherResponse classesObj = (ClassesTeacherResponse) (Object) classesServiceObj.execute(clsBean);
				if(classesObj.getResponseTxt().equals("success")) {
					responseObj.setClasses(classesObj.getList());
				}
				
				HttpHeaders headers = new HttpHeaders();
		        return ResponseEntity.ok().headers(headers).body(responseObj);
			}
			
			logger.info("Token Verify ResponseTxt: "+objTokenVerifyResponse.getResponseTxt());
			
			HttpHeaders headers = new HttpHeaders();
	        return ResponseEntity.ok().headers(headers).body(objTokenVerifyResponse);
			
		} catch (Exception e) {
			e.printStackTrace();
		}
		
		return new ResponseEntity<>(HttpStatus.BAD_REQUEST);
	}
	

	
	
}
