import * as React from 'react';
import { styled, alpha } from '@mui/material/styles';
import Button from '@mui/material/Button';
import Menu from '@mui/material/Menu';
import MenuItem from '@mui/material/MenuItem';
import ListItemIcon from '@material-ui/core/ListItemIcon';
import ListItemText from '@material-ui/core/ListItemText';
import RadioButtonUncheckedIcon from '@mui/icons-material/RadioButtonUnchecked';
import RadioButtonCheckedIcon from '@mui/icons-material/RadioButtonChecked';
import KeyboardArrowDownIcon from '@mui/icons-material/KeyboardArrowDown';
import AutoAwesomeIcon from '@mui/icons-material/AutoAwesome';
import CircularProgress from '@mui/material/CircularProgress';
import { useDispatch, useSelector } from 'react-redux';
import axios from 'axios';
import {API_URL} from '../utils/EnvVars';
import { selectCourse } from '../store/course.actions';
import { setTopicTree, setTopicList, setKeywordList, setTopicTreeLearning, setTopicListLearning, setKeywordListLearning, setTopicTreeTest, setTopicListTest, setSmartLearning, setMockTest } from '../store/data.actions';


const StyledMenu = styled((props) => (
  <Menu
    elevation={0}
    anchorOrigin={{
      vertical: 'bottom',
      horizontal: 'right',
    }}
    transformOrigin={{
      vertical: 'top',
      horizontal: 'right',
    }}
    {...props}
  />
))(({ theme }) => ({
  '& .MuiPaper-root': {
    borderRadius: 6,
    marginTop: theme.spacing(1),
    minWidth: 180,
    color:
      theme.palette.mode === 'light' ? 'rgb(55, 65, 81)' : theme.palette.grey[300],
    boxShadow:
      'rgb(255, 255, 255) 0px 0px 0px 0px, rgba(0, 0, 0, 0.05) 0px 0px 0px 1px, rgba(0, 0, 0, 0.1) 0px 10px 15px -3px, rgba(0, 0, 0, 0.05) 0px 4px 6px -2px',
    '& .MuiMenu-list': {
      padding: '4px 0',
    },
    '& .MuiMenuItem-root': {
      '& .MuiSvgIcon-root': {
        fontSize: 16,
        color: theme.palette.text.secondary,
        marginRight: theme.spacing(1.5),
      },
      '&:active': {
        backgroundColor: alpha(
          theme.palette.primary.main,
          theme.palette.action.selectedOpacity,
        ),
      },
    },
  },
}));

export default function CustomizedMenus(props) {
    const dispatch = useDispatch();
    const userObj = useSelector(state => state.userDetails);
    const mySelectedCourses = useSelector(state => state.mySelectedCourses);
    const selectedCourse = useSelector(state => state.selectedCourse);
  
    const [anchorEl, setAnchorEl] = React.useState(null);
    const open = Boolean(anchorEl);
    const [organisationList, setOrganisationList] = React.useState([]);
    const [selectedIndex, setSelectedIndex] = React.useState(0);
    const [loader, setLoader] = React.useState(false);
    const [newIndex, setNewIndex] = React.useState(0);
  
    const handleClick = (event) => {
        setAnchorEl(event.currentTarget);
    };
    const handleClose = () => {
        setAnchorEl(null);
    };

    function switchCourse(index){
        if(selectedIndex!==index){
          if(loader===false){    
            dispatch(selectCourse(index));
            setNewIndex(index);
          }
          setLoader(true);
          
          let axiosHeader = {
                    headers: {
                        'Content-Type': 'multipart/mixed',
                    }
                };
          const data = new FormData();
                data.append('id', userObj.sid);
                data.append('openedCourseIndex', index);
                axios.post(API_URL+'/lastopenedcourse', data, axiosHeader)
                .then((response) => { 
            if(response.data.responseTxt==="success"){ 
                if(mySelectedCourses[index].templateId && mySelectedCourses[index].templateId>0){
                  getApiDataLastOpenedCourseUpdate(mySelectedCourses[index].templateId);
                }
            }  
          })
          .catch((error) => {
            console.log("AXIOS ERROR: ", error);
          })
    
        }
      }
    
      async function getApiDataLastOpenedCourseUpdate(templateId){
        axios.get(API_URL+'/templatecache?templateId='+templateId)
           .then(response => {
           ///console.log("Just Checking >> "+response.data);  
          if(response && response.data && response.data.responseTxt==="success"){
                    if(response.data.topicList && response.data.topicList.length>0){
                  dispatch(setTopicList(JSON.parse(response.data.topicList)));
              }else{
                  dispatch(setTopicList([]));
              }
              if(response.data.keywordList && response.data.keywordList.length>0){
                  dispatch(setKeywordList(JSON.parse(response.data.keywordList)));
              }else{
                  dispatch(setKeywordList([]));
              }
              if(response.data.topicTree && response.data.topicTree.length>0){
                  dispatch(setTopicTree(JSON.parse(response.data.topicTree)));
              }else{
                  dispatch(setTopicTree([]));
              }
              if(response.data.topicTreeLearning && response.data.topicTreeLearning.length>0){
                  dispatch(setTopicTreeLearning(JSON.parse(response.data.topicTreeLearning)));
              }else{
                  dispatch(setTopicTreeLearning([]));
              }
              if(response.data.topicListLearning && response.data.topicListLearning.length>0){
                  dispatch(setTopicListLearning(JSON.parse(response.data.topicListLearning)));
              }else{
                  dispatch(setTopicListLearning([]));
              }
              if(response.data.keywordListLearning && response.data.keywordListLearning.length>0){
                  dispatch(setKeywordListLearning(JSON.parse(response.data.keywordListLearning)));
              }else{
                  dispatch(setKeywordListLearning([]));
              }
              if(response.data.topicTreeTest && response.data.topicTreeTest.length>0){
                  dispatch(setTopicTreeTest(JSON.parse(response.data.topicTreeTest)));
              }else{
                  dispatch(setTopicTreeTest([]));
              }
              if(response.data.topicListTest && response.data.topicListTest.length>0){
                  dispatch(setTopicListTest(JSON.parse(response.data.topicListTest)));
              }else{
                  dispatch(setTopicListTest([]));
              }
              if(response.data.smartLearningJson && response.data.smartLearningJson.length>0){
                  dispatch(setSmartLearning(JSON.parse(response.data.smartLearningJson)));
              }else{
                  dispatch(setSmartLearning([]));
              }
              if(response.data.mockTestJson && response.data.mockTestJson.length>0){
                  dispatch(setMockTest(JSON.parse(response.data.mockTestJson)));
              }else{
                  dispatch(setMockTest([]));
              }
      
              const mydtmout = setTimeout(
                function () {
                  setLoader(false);
                  clearTimeout(mydtmout);
                  window.location.href='dashboard';							
                }
              , 6000);
    
          } 
    
        })
     }
    
    React.useEffect(() => {
        if(selectedCourse!==null && selectedCourse>=0 && mySelectedCourses!==null && mySelectedCourses[0]!==null){
            setOrganisationList(mySelectedCourses);
            setSelectedIndex(selectedCourse);
        }
    }, [mySelectedCourses, selectedCourse]); 

    function goToLocation(url){
       window.location=url;
    }

    function validTillDateFormat(val,stype,corseTitle){    
        let rtrn = '';
        if(val && stype==='PAID'){
          let valArr = val.split("-");
          let myDate = valArr[2]+'-'+valArr[1]+'-'+valArr[0];
          rtrn = 'PRIME, '+myDate;
        }else if(stype==='FREE' && corseTitle.indexOf("FREE FOREVER")>-1){
          rtrn = 'FREE';  
        }else{
          rtrn = 'FREE TRIAL';
        }
        return rtrn;
    }
    
    function upgrade(corseDate,stype,corseTitle){    
        let rtrn = 1;
        if(stype==='PAID'){
          let d1 = new Date();
          let d2 = new Date(corseDate);
          d2.setDate(d2.getDate() + 1);
          if(d1>d2){
            rtrn = 2;
          }else{
            rtrn = 0;
          }  
        }else if(stype==='FREE' && corseTitle.indexOf("FREE FOREVER")>-1){
          rtrn = 0;
        }
      return rtrn;
    }

    function goToCourseBuy(cid){
        window.location='selectcourse?cid='+cid;
    }
        

  return (
    <div>
      <Button
        id="demo-customized-button"
        aria-controls={open ? 'demo-customized-menu' : undefined}
        aria-haspopup="true"
        aria-expanded={open ? 'true' : undefined}        
        disableElevation
        onClick={handleClick}
        endIcon={<KeyboardArrowDownIcon />}
        color="inherit"
      >
        {props.title}
      </Button>
      <StyledMenu
        id="demo-customized-menu"
        MenuListProps={{
          'aria-labelledby': 'demo-customized-button',
        }}
        anchorEl={anchorEl}
        open={open}
        onClose={handleClose}
      >

        {(organisationList && organisationList.length>0)?organisationList.map((myRow,index)=>(          
          (index===selectedIndex)?
          <MenuItem disableRipple key={'lib'+index} onClick={()=>{switchCourse(index)}} sx={{backgroundColor:'#c2e4fc',color:'#1f407a'}}>
            <ListItemIcon>{(loader && newIndex===index)?<CircularProgress size={25} />:<RadioButtonCheckedIcon />}</ListItemIcon>
            <ListItemText primary={<div onClick={()=>{switchCourse(index)}} className="corstitle" >{myRow.organisationName}</div>} secondary={<div><div>{validTillDateFormat(myRow.validTillDate,myRow.subscriptionType,myRow.organisationName)}</div><div>{(upgrade(myRow.validTillDate,myRow.subscriptionType,myRow.organisationName)>0)?<Button onClick={()=>{goToCourseBuy(myRow.courseId)}} style={{textTransform:'none',height:20,backgroundColor:'#008140',color:'#FFF'}} size='small' variant='contained' >{(upgrade(myRow.validTillDate,myRow.subscriptionType,myRow.organisationName)===2)?<>Renew</>:<>Upgrade</>}</Button>:null}</div></div>}  />
          </MenuItem>
          :
          <MenuItem disableRipple key={'lib'+index} onClick={()=>{switchCourse(index)}} >
            <ListItemIcon>{(loader && newIndex===index)?<CircularProgress size={25} />:<RadioButtonUncheckedIcon />}</ListItemIcon>
            <ListItemText primary={<div onClick={()=>{switchCourse(index)}} className="corstitle" >{myRow.organisationName}</div>} secondary={<div><div>{validTillDateFormat(myRow.validTillDate,myRow.subscriptionType,myRow.organisationName)}</div><div>{(upgrade(myRow.validTillDate,myRow.subscriptionType,myRow.organisationName)>0)?<Button onClick={()=>{goToCourseBuy(myRow.courseId)}} style={{textTransform:'none',height:20,backgroundColor:'#008140',color:'#FFF'}} size='small' variant='contained' >{(upgrade(myRow.validTillDate,myRow.subscriptionType,myRow.organisationName)===2)?<>Renew</>:<>Upgrade</>}</Button>:null}</div></div>} />
          </MenuItem>
        )):null}

        <MenuItem onClick={()=>{goToLocation('selectcourse')}} style={{width:275}} disableRipple>
          <AutoAwesomeIcon />
          All Courses
        </MenuItem>
      </StyledMenu>
    </div>
  );
}
