import React from 'react';
import { withStyles } from '@material-ui/core/styles';
import {Grid, Box, Button} from '@material-ui/core';
import { LoadingButton } from '@mui/lab';
import SaveIcon from '@mui/icons-material/Save';
import Dialog from '@material-ui/core/Dialog';
import Alert from '@mui/material/Alert';
import Stack from '@mui/material/Stack';
import Snackbar from '@mui/material/Snackbar';
import MuiDialogTitle from '@material-ui/core/DialogTitle';
import MuiDialogContent from '@material-ui/core/DialogContent';
import IconButton from '@material-ui/core/IconButton';
import CloseIcon from '@material-ui/icons/Close';
import Typography from '@material-ui/core/Typography';
import 'font-awesome/css/font-awesome.min.css';
import '../styles/bizofficer-a.css';
import axios from 'axios';
import Cookies from 'js-cookie';
import {API_URL} from '../utils/EnvVars';

var vertical='top',horizontal='center';

const styles = (theme) => ({
  root: {
    margin: 0,
    padding: theme.spacing(2),
  },
  closeButton: {
    position: 'absolute',
    right: theme.spacing(1),
    top: theme.spacing(1),
    color: theme.palette.grey[500],
  },
});

const DialogTitle = withStyles(styles)((props) => {
  const { children, classes, onClose, ...other } = props;
  return (
    <MuiDialogTitle disableTypography className={classes.root} {...other}>
      <Typography variant="h6">{children}</Typography>
      {onClose ? (
        <IconButton aria-label="close" className={classes.closeButton} onClick={onClose}>
          <CloseIcon />
        </IconButton>
      ) : null}
    </MuiDialogTitle>
  );
});

const DialogContent = withStyles((theme) => ({
  root: {
    padding: theme.spacing(2),
  },
}))(MuiDialogContent);

const CustomizedDialogs = React.forwardRef((props, ref) => { 
  const [open, setOpen] = React.useState(false);
  const [waitLoading, setWaitLoading] = React.useState(false);
  const [payNowWaitLoading, setPayNowWaitLoading] = React.useState(false);
  const [severityAlert, setSeverityAlert] = React.useState("error");
  const [showAlert, setShowAlert] = React.useState(false);
	const [alertMessage, setAlertMessage] = React.useState("");
  const [payableAmount, setPayableAmount] = React.useState(0);
  const [discount, setDiscount] = React.useState(0);
  const [studentId, setStudentId] = React.useState("");
  const [token, setToken] = React.useState("");
  const [webUrl, setWebUrl] = React.useState("");  
  const [code, setCode] = React.useState("");
  const [applyPromoCodeLoading, setApplyPromoCodeLoading] = React.useState(false);
  const [applyPromoCodeDone, setApplyPromoCodeDone] = React.useState(false);

  
  React.useImperativeHandle(ref, () => ({
    handleClickOpen(){
      setOpen(true);
    }
  }));
  
  const handleClose = () => {
    setOpen(false);
  };

  function hideAlert(){
		setShowAlert(false);
	}

  React.useEffect(() => {
    setWaitLoading(false);
    setPayNowWaitLoading(false);
    setApplyPromoCodeDone(false);
    if(props.dataDetail && props.dataDetail.salePrice){	
		  setPayableAmount(props.dataDetail.salePrice);
      setDiscount(props.dataDetail.discount);
      setToken(props.token);
      setStudentId(props.studentId);
      setWebUrl(window.location.host);
      setCode("");
    }
	}, [props.dataDetail]); 

  function addCourse(opt){
    if(opt===2){
      setPayNowWaitLoading(true);
      props.toCallSelectCourse(opt,code);
    }else{
      setWaitLoading(true);
      props.toCallSelectCourse(opt,code);
    }
	}

  function applyPromoCode(){
    if(code){
      setApplyPromoCodeLoading(true);
      getApiPromoCode(code);      
    }
  }

  async function getApiPromoCode(code){
    let axiosHeader = {
			headers:{
				'Content-Type': 'multipart/mixed',
				'studentId': studentId,
				'token': token,
			}
		};
    let apiURL = API_URL+'/verifypromocodes?webUrl='+webUrl+'&promoCode='+code+'&courseId='+props.dataDetail.courseId;
    ///alert(apiURL);
    axios.get(apiURL, axiosHeader)
       .then(response => {
        setApplyPromoCodeLoading(false);
       ///console.log("Just Checking >> "+response.data);  
       if(response && response.data && response.data.responseTxt==='success'){
          setApplyPromoCodeDone(true);
          setPayableAmount(response.data.amount);
          setSeverityAlert("success");
          setShowAlert(true);
          setAlertMessage("Promotional code has been applied successfully.");			
          return false;
       }else if(response && response.data && response.data.responseTxt==='invalid'){
          setSeverityAlert("error");
          setShowAlert(true);
          setAlertMessage("Promotional code is invalid.");			
          return false;

       }else if(response && response.data && response.data.responseTxt==="unauthorized"){
            Cookies.remove('isloggedin');
            window.location.href='logout';
                   
       }else{
          setSeverityAlert("error");
          setShowAlert(true);
          setAlertMessage("Something wrong with promotional code to apply.");			
          return false;
       }				 				
    })
  }
  
  return (
    <>
      <Dialog fullWidth maxWidth="md" onClose={handleClose} aria-labelledby="customized-dialog-title" open={open}>
        <DialogTitle style={{marginBottom:'-30px'}} onClose={handleClose}></DialogTitle>
          <DialogContent style={{height:'88vh'}}>
            <Grid item   md={12} xs={12} className="test-instructions" >
                  <div style={{textAlign:'center'}} className="btmbdrgry"><h3>{props.dataDetail.courseTitle}</h3></div>
                  <div style={{textAlign:'center'}}>{props.dataDetail.courseSubTitle}</div>
                  <div style={{textAlign:'center',fontWeight:'bold',color:'#0f3cff'}}>Validity up to {props.dataDetail.validityDate}</div>

                    <Box mt={2}>
                      <Grid container spacing={2} >
                      <Grid item md={6} sm={6} xs={12} >
                          <div style={{textAlign:'center',fontWeight:'bold',fontSize:18,color:'#FF0000' }} >
                              MRP<br/>
                              <strike><span className='fa fa-inr' />{props.dataDetail.retailPrice}</strike>
                          </div>
                      </Grid>
                      <Grid item md={6} sm={6} xs={12}  >
                          <div style={{textAlign:'center',fontWeight:'bold',fontSize:18,color:'#008000' }} >
                            {applyPromoCodeDone?
                              <>  
                              Promo Code Applied<br/>
                              <span className='fa fa-inr' />{payableAmount}<br/>
                              </>:
                              <>  
                              DISCOUNTED PRICE<br/>
                              <span className='fa fa-inr' />{payableAmount} ({discount}%)<br/>
                              </>
                            }
                          </div>
                      </Grid>                      
                      </Grid>
                    </Box>

                  {!applyPromoCodeDone?      
                    <Box mt={1} mb={1}>
                      <Grid container spacing={2} >
                      <Grid item md={12} sm={12} xs={12} >
                          <div style={{textAlign:'center'}} >
                        {(props.dataDetail.promoList && props.dataDetail.promoList.length>0)?props.dataDetail.promoList.map((myPC,pcKey)=>(  
                          <span key={'pca'+pcKey} style={{marginLeft:5}}><i class="fa fa-tags" style={{color:'#7b7b7b'}}></i> {myPC.description}</span>
                        )):<span style={{marginLeft:5}}>Apply promotional code</span>}  
                          <input type="text" onChange={event => setCode(event.target.value)} value={code} placeholder={'Enter promotional code'} style={{marginLeft:5}} />
                          {applyPromoCodeLoading?
                            <LoadingButton loading={applyPromoCodeLoading} loadingPosition="start" startIcon={<SaveIcon />} size="small" variant="contained" style={{backgroundColor:'#cccef9',color:'#000',marginLeft:5, height:23, marginTop:-5}} >Wait</LoadingButton>
                            : <Button onClick={() => {applyPromoCode()}} size="small" variant="contained" style={{backgroundColor:'#dddbdb',color:'#000',marginLeft:5, height:23, marginTop:-5}} >Apply</Button>
                            }
                          </div>
                      </Grid>
                      </Grid>
                    </Box>
                  :null}  

                      <Box mb={2} style={{textAlign:'center'}} >
                          {!props.selectedFlag?
                          <>
                            {waitLoading?
                            <LoadingButton loading={waitLoading} loadingPosition="start" startIcon={<SaveIcon />} style={{marginRight:20, backgroundColor:'#ea1072',color:'#FFF'}}  size="small" variant="contained" >Wait</LoadingButton>
                            :(payableAmount>0)?<Button onClick={() => {addCourse(1)}} style={{marginRight:20}} size="small" variant="contained" color="secondary" >FREE TRIAL</Button>:null
                            }
                            {payNowWaitLoading?
                            <LoadingButton loading={payNowWaitLoading} loadingPosition="start" startIcon={<SaveIcon />} style={{marginRight:20, backgroundColor:'#008000',color:'#FFF'}}  size="small" variant="contained" >Wait</LoadingButton>
                            : <Button onClick={() => {addCourse(2)}} size="small" variant="contained" style={{backgroundColor:'#008000',color:'#FFF'}} >{(payableAmount<1 && applyPromoCodeDone)?<>Get it free</>:applyPromoCodeDone?<>JUST PAY&nbsp;&nbsp;<span className='fa fa-inr' />{payableAmount}</>:<>PAY NOW</>}</Button>
                            }
                          </>:
                            payNowWaitLoading?
                              <LoadingButton loading={payNowWaitLoading} loadingPosition="start" startIcon={<SaveIcon />} style={{marginRight:20, backgroundColor:'#008000',color:'#FFF'}}  size="small" variant="contained" >Wait</LoadingButton>
                              : <Button onClick={() => {addCourse(2)}} size="small" variant="contained" style={{backgroundColor:'#008000',color:'#FFF'}} >{(applyPromoCodeDone && payableAmount>0)?<>JUST PAY&nbsp;&nbsp;<span className='fa fa-inr' />{payableAmount}</>:(applyPromoCodeDone && payableAmount<=0)?<>GET IT FREE</>:<>PAY NOW</>}</Button>
                          }
								      </Box>

                      <>{(props.dataDetail.headingDescription && props.dataDetail.headingDescription.indexOf("==")>-1)?
                        <div style={{fontSize:18,fontWeight:'bold'}}>Key Features</div>
                      :null}
                      </>
                      <Box mt={2}>
                            {
                            props.dataDetail.headingDescription?props.dataDetail.headingDescription.split("\n").map((myRow,index)=>(
                                <>{myRow.indexOf("==")>-1?<Grid container spacing={2} className='btmbrdrtbl' >
                                    <Grid item md={4} sm={4} xs={12} >
                                        <div><b>{myRow.split("==")[0]}</b></div>
                                    </Grid>
                                    <Grid item md={8} sm={8} xs={12} >
                                        <div>{myRow.split("==")[1].indexOf("##")>-1?<ul>
                                          {myRow.split("==")[1].split("##").map((myPoint,indexLi)=>(
                                            <li key={'pt'+indexLi} style={{marginLeft:-23}}>- {myPoint}</li>
                                          ))}
                                        </ul>:<>{myRow.split("==")[1]}</>}</div>
                                    </Grid>
                                    </Grid>:<Grid container spacing={2}><Grid item xs={12} >{myRow}</Grid></Grid>}</>
                              )):null
                            }
                      </Box>

                      <Box mt={2}>
                          <Button onClick={() => {handleClose()}} style={{marginRight:20}} size="small" variant="outlined" >Cancel</Button>
                      </Box>  
            </Grid>
          </DialogContent>
      </Dialog>

        <Stack spacing={2} sx={{ width: '100%' }}>
					<Snackbar open={showAlert} autoHideDuration={6000} onClose={hideAlert} anchorOrigin={{vertical,horizontal}}  >
						<Alert onClose={hideAlert} variant="filled" severity={severityAlert} sx={{ width: '100%' }}>
							{alertMessage}
						</Alert>
					</Snackbar>
				</Stack>

    </>
  );

});

export default CustomizedDialogs;