import React from 'react';
import {Box, Grid} from '@material-ui/core';
import axios from 'axios';
import Button from '@mui/material/Button';
import Dialog from '@mui/material/Dialog';
import DialogActions from '@mui/material/DialogActions';
import DialogContent from '@mui/material/DialogContent';
import DialogContentText from '@mui/material/DialogContentText';
import DialogTitle from '@mui/material/DialogTitle';
import DialogStudyContent from './DialogStudyContent';
import CircularProgress from '@mui/material/CircularProgress';
import { useSelector } from 'react-redux';
import {API_URL} from '../utils/EnvVars';
import '../styles/bizofficer-a.css';

function DialogHelp(props, ref) {  
  const selectedCourse = useSelector(state => state.selectedCourse);
	const mySelectedCourses = useSelector(state => state.mySelectedCourses);
  ///const userObj = useSelector(state => state.userDetails);
  const openHelpContentRef = React.useRef();
  const [open, setOpen] = React.useState(false);
  const [showProgress, setShowProgress] = React.useState(false);
	const [materialsDisplayList, setMaterialsDisplayList] = React.useState([]);
	const [contentObj, setContentObj] = React.useState("");

  React.useImperativeHandle(ref, () => ({
    handleClickOpen(){
      setOpen(true);
    }
  }));
  
  const handleClose = () => {
    setOpen(false);
    props.toCallStartTimer();
  };

  function googleSearch(){
		setContentObj(null);
    openHelpContentRef.current.handleClickOpen();		
	}

  function exeContent(obj){ 
		if(obj && obj.contentType===1){
			setContentObj(obj);
			openHelpContentRef.current.handleClickOpen();	
		}else{
			if(window.screen.width<480){
				window.open(obj.contentUrl, "_blank");
			}else{
				setContentObj(obj);
				openHelpContentRef.current.handleClickOpen();
			}
		}	
	}

  const descriptionElementRef = React.useRef(null);
  React.useEffect(() => {
    if (open) {
      const { current: descriptionElement } = descriptionElementRef;
      if (descriptionElement !== null) {
        descriptionElement.focus();
      }
    }
  }, [open]);

  React.useEffect(() => {
    setShowProgress(true);
    if(mySelectedCourses!==null && selectedCourse>=0 && mySelectedCourses[selectedCourse].templateId && props.searchQuery){
				getApiData(mySelectedCourses[selectedCourse].templateId,props.searchFlag,props.searchQuery,props.topicId); 
		}else if(mySelectedCourses!==null && selectedCourse>=0 && mySelectedCourses[selectedCourse].templateId && props.currentQuestionObj){
      getApiData(mySelectedCourses[selectedCourse].templateId,'Topic','testview',props.currentQuestionObj.topicId); 
    }
	}, [mySelectedCourses,selectedCourse,props.searchQuery,props.currentQuestionObj]); 

	async function getApiData(templateId,searchFlag,searchQuery,topicId){
			axios.get(API_URL+'/helpcontent?templateId='+templateId+'&searchFlag='+searchFlag+'&searchQuery='+searchQuery+'&topicId='+topicId)
			   .then(response => {
				if(response.data!=null){ 
				 	setMaterialsDisplayList(response.data);	
          setShowProgress(false); 
				}		 				
			})
	}


  return (
    <>      
      <Dialog
        open={open}
        onClose={handleClose}
        scroll={'paper'}
        key={'help123'}
        aria-labelledby="scroll-dialog-title"
        aria-describedby="scroll-dialog-description"
        fullWidth 
        maxWidth="md"
      >
        <DialogTitle id="scroll-dialog-title">
          {props.searchQuery} {showProgress?<><CircularProgress style={{width:20,height:20}} />Loading...</>:null}
        </DialogTitle>
        <DialogContent dividers={'paper'}>
          <DialogContentText
            id="scroll-dialog-description"
            ref={descriptionElementRef}
            tabIndex={-1}
          >
								<Box component="form" noValidate mt={2} >
									<Grid container spacing={2} className="materialBox" style={{minHeight:'63vh'}} >
                    {materialsDisplayList.length?materialsDisplayList.map((myRow,index)=>(				
                      <Grid onClick={()=>{exeContent(myRow)}} key={'mtldd'+index} item className="smitem" >
                        <p>
                          {myRow.contentType==1?<i className="fa fa-play-circle"></i>:myRow.contentType==2?<i className="fa fa-file-pdf-o"></i>:myRow.contentType==3?<i className="fa fa-file-powerpoint-o"></i>:<i className="fa fa-globe"></i>}												
                        </p>
                        <p className="text-line-2">
                          {myRow.contentTitle}
                        </p>	
                      </Grid>
                    )):showProgress?<><CircularProgress style={{width:20,height:20}} />Loading...</>:<iframe width="100%" height="370" src="https://www.google.com/search?igu=1" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>}	
                </Grid>	
							</Box>
          </DialogContentText>
        </DialogContent>
        <DialogActions> 
        {(materialsDisplayList!=null && materialsDisplayList.length>0)?
        <Button onClick={()=>{googleSearch()}}><i class="fa fa-google" aria-hidden="true"></i>oogle</Button>
        :null}  
        <Button onClick={handleClose}>Cancel</Button>
        </DialogActions>
      </Dialog>
      <DialogStudyContent contentObj={contentObj} ref={openHelpContentRef} />
    </>
  );
}

export default React.forwardRef(DialogHelp);