import React from 'react';
import { makeStyles } from '@material-ui/core/styles';
import {Box, Container, Grid, Link, Button} from '@material-ui/core';
import Header from "./Header";
import Footer from "./Footer";
import Breadcrumbs from "../components/Breadcrumbs";
import '../styles/bizofficer.css';
import 'font-awesome/css/font-awesome.min.css';
import Moment from 'moment';

const useStyles = makeStyles((theme) => ({
	root: {
		background: 'linear-gradient(45deg, #33ccff 30%, #0000ff 90%)',
		border: 0,
		borderRadius: 22,
		boxShadow: '0 3px 5px 2px rgba(255, 105, 135, .3)',
		color: 'white',
		height: 48,
		padding: '0 30px',
		marginTop: '30px',
	  },
	  sectionDesktop: {
	  display: 'none',
	  [theme.breakpoints.up('md')]: {
		display: 'flex',
	  },
	},
	sectionMobile: {
	  display: 'flex',
	  [theme.breakpoints.up('md')]: {
		display: 'none',
	  },
	},
  }));

  export default function Execute() {

	const classes = useStyles();

		return (
			<div>
				<Header />
				<Container>

					<div className="article-detail-box">
								<Box mt={4} >
									<Grid container spacing={2} >
										<Grid xs={12} style={{textAlign:'center'}} >
											<img src={process.env.PUBLIC_URL + '/article-detail.jpg'} alt="image" />
										</Grid>	
										<Grid xs={12}> 
											<h1>How the brain solves problems during sleep</h1>
											<p>
												<span style={{marginRight:'10px'}}>By Dr. Rajiv Chopra</span>
												<span>
												{Moment('2021-02-02').format('DD-MMM-YYYY')}
												</span>
											</p>	
											<p>
											When you’re awake and trying to work through a sticky problem, the go-to approach is often taking a piece of paper and listing the pluses and minuses. But there are usually too many items, and you don’t know how to sufficiently rate the importance of each one, so "it doesn’t help you," Stickgold says.
											<br/><br/>
But when you get into bed, the brain does a triage and "rifles through the events of the day and sees what’s left unfinished," he says. It’s picking out what has some "affective buzz," the emotions that happened during or shortly after something took place. The brain uses these memory "tags" as indicators that the event was important and that there’s more to figure out. Essentially, the brain is saying, "I think I can help you."
<br/><br/>
Two elements make this happen. The prefrontal cortex gets shut down. This part of the brain handles executive decision-making (which includes rational thinking and impulse control), but now there’s no critical edge or categories to put ideas in. The brain can freely associate and, as Stickgold says, "process in the background."
<br/><br/>
And when you get into the REM stage of sleep, the neuromodulators norepinephrine and serotonin are turned off. Norepinephrine enhances focus on immediate, concrete problems. "It’s the reason you don’t want to hear about someone’s ‘brilliant idea’ when you’re approaching a deadline," he says.
<br/><br/>
There’s little known about what happens when serotonin is shut off, but Stickgold suggests it biases the brain into identifying looser connections as valuable. With both neurochemicals at bay, fragments of ideas can come together. "You have enhanced discovery of weak associations, ones you’d never notice," Stickgold says.
<br/><br/>
The result is that you wake up the next day suddenly thinking, "I don’t want to take a job in Iowa," or "yeah, Iowa." It can feel like a gut decision, one you can’t necessarily explain. It also may not be the final one, but something has shifted. "You’re not in the same place as when you went to sleep," says Stickgold, adding that it can’t all be explained, and science can’t calculate whether what you decide is right. "It’s a nonrational process."	
											</p>
											
										</Grid>
									</Grid>
								</Box>	
					</div>


					<div className="article-box">
						<Box mt={3}  >

							<Grid container spacing={2} >
								<Grid item md={12} xs={12} >
									<Link title="Click to view all" href="articles"><h1>Related Articles</h1></Link>
									<h3>Trending tips from doctors &amp; health experts</h3>
									<Link title="Click to view all" href="articles"><h5>Click to view all</h5></Link>
								</Grid>
							</Grid>

							<Grid container spacing={2} >
								<Grid item md={2} xs={6} >
									<div className="article-content-box" >
										<Link href="articles">
											<img src={process.env.PUBLIC_URL + '/covid.jpg'}  />
											<p className="text-line-4">We are together in the fight We are together in the fight against COVID-19. We are together in the fight against COVID-19. We are together in the fight against COVID-19</p>
										</Link>
									</div>	
								</Grid>
								<Grid item md={2} xs={6} >
									<div className="article-content-box" >
										<Link href="articles">
											<p><img src={process.env.PUBLIC_URL + '/covid.jpg'}  /></p>
											<p className="text-line-4">We are together in the fight We are together in the fight against COVID-19. We are together in the fight against COVID-19. We are together in the fight against COVID-19</p>
										</Link>
									</div>	
								</Grid>
								<Grid item md={2} xs={6} >
									<div className="article-content-box" >
										<Link href="articles">
											<p><img src={process.env.PUBLIC_URL + '/covid.jpg'}  /></p>
											<p className="text-line-4">We are together in the fight We are together in the fight against COVID-19. We are together in the fight against COVID-19. We are together in the fight against COVID-19</p>
										</Link>
									</div>	
								</Grid>
								<Grid item md={2} xs={6} >
									<div className="article-content-box" >
										<Link href="articles">
											<p><img src={process.env.PUBLIC_URL + '/covid.jpg'}  /></p>
											<p className="text-line-4">We are together in the fight We are together in the fight against COVID-19. We are together in the fight against COVID-19. We are together in the fight against COVID-19</p>
										</Link>	
									</div>
								</Grid>
								<Grid item md={2} xs={6} className={classes.sectionDesktop} >
									<div className="article-content-box" >
										<Link href="articles">
											<p><img src={process.env.PUBLIC_URL + '/covid.jpg'}  /></p>
											<p className="text-line-4">We are together in the fight We are together in the fight against COVID-19. We are together in the fight against COVID-19. We are together in the fight against COVID-19</p>
										</Link>	
									</div>
								</Grid>

								<Grid item md={2} xs={6} className={classes.sectionDesktop} >
									<div className="article-content-box" >
										<Link href="articles">
											<p><img src={process.env.PUBLIC_URL + '/covid.jpg'}  /></p>
											<p className="text-line-4">We are together in the fight We are together in the fight against COVID-19. We are together in the fight against COVID-19. We are together in the fight against COVID-19</p>
										</Link>	
									</div>
								</Grid>

							</Grid>
						</Box>	
					</div>


				</Container>
				<Footer />
			</div>
		);
 
}