import React from 'react';
import {Box, IconButton, Menu, Tooltip } from '@material-ui/core';
import { fade, makeStyles } from '@material-ui/core/styles';
import AppBar from '@material-ui/core/AppBar';
import Toolbar from '@material-ui/core/Toolbar';
import AccountCircleIcon from '@mui/icons-material/AccountCircle';
import ErrorOutlineIcon from '@mui/icons-material/ErrorOutline';
import Divider from '@mui/material/Divider';
import MenuItem from '@mui/material/MenuItem';
import ListItemText from '@mui/material/ListItemText';
import ListItemIcon from '@mui/material/ListItemIcon';
import LogoutIcon from '@mui/icons-material/Logout';
import Avatar from '@mui/material/Avatar';
import SwipeableTopDrawer from "../components/SwipeableTopDrawer";
import CourseMenu from "../components/CourseMenu";
import Cookies from 'js-cookie';
import { useSelector, useDispatch } from 'react-redux';
import { addUser } from '../store/user.actions';
import { selectCourse } from '../store/course.actions';
import { setMyCourses } from '../store/mycourses.actions';
import { setTopicTree, setTopicList, setKeywordList, setTopicTreeLearning, setTopicListLearning, setKeywordListLearning, setTopicTreeTest, setTopicListTest, setSmartLearning, setMockTest } from '../store/data.actions';

const useStyles = makeStyles((theme) => ({
  grow: {
    flexGrow: 1,    
  },
  menuButton: {
    marginRight: theme.spacing(2),
  },
  
  search: {
    position: 'relative',
    borderRadius: theme.shape.borderRadius,
    backgroundColor: fade(theme.palette.common.white, 0.15),
    '&:hover': {
      backgroundColor: fade(theme.palette.common.white, 0.25),
    },
    marginRight: theme.spacing(2),
    marginLeft: 0,
    width: '100%',
    [theme.breakpoints.up('sm')]: {
      marginLeft: theme.spacing(3),
      width: 'auto',
    },
  },
  searchIcon: {
    padding: theme.spacing(0, 2),
    height: '100%',
    position: 'absolute',
    pointerEvents: 'none',
    display: 'flex',
    alignItems: 'center',
    justifyContent: 'center',
  },
  inputRoot: {
    color: 'inherit',
  },
  inputInput: {
    padding: theme.spacing(1, 1, 1, 0),
    // vertical padding + font size from searchIcon
    paddingLeft: `calc(1em + ${theme.spacing(4)}px)`,
    transition: theme.transitions.create('width'),
    width: '100%',
    [theme.breakpoints.up('md')]: {
      width: '20ch',
    },
  },
  sectionDesktop: {
    display: 'none',
    [theme.breakpoints.up('md')]: {
      display: 'flex',
    },
  },
  sectionMobile: {
    display: 'flex',
    [theme.breakpoints.up('md')]: {
      display: 'none',
    },
  },
}));

export default function Header() {
  const dispatch = useDispatch();
  const userObj = useSelector(state => state.userDetails);
  const selectedCourse = useSelector(state => state.selectedCourse); 
  const mySelectedCourses = useSelector(state => state.mySelectedCourses);
  const [organisationName, setOrganisationName] = React.useState("");
  
  const [anchorElUser, setAnchorElUser] = React.useState(null);
  const classes = useStyles();
 
  const handleOpenUserMenu = (event) => {
    setAnchorElUser(event.currentTarget);
  };
  const handleCloseUserMenu = () => {
    setAnchorElUser(null);
  };


  function goToLocation(url){
    window.location=url;
  }
  function logout(){
    // dispatch(addUser(null));
    // dispatch(setMyCourses(null));
    // dispatch(selectCourse(null));
    // dispatch(setTopicList(null));
    // dispatch(setKeywordList(null));
    // dispatch(setTopicTree(null));
    // dispatch(setTopicTreeLearning(null));
    // dispatch(setTopicListLearning(null));
    // dispatch(setKeywordListLearning(null));
    // dispatch(setTopicTreeTest(null));
    // dispatch(setTopicListTest(null));
    // dispatch(setSmartLearning(null));
    // dispatch(setMockTest(null));
    Cookies.remove('isloggedin');    
    window.location.href='logout';
  }

	React.useEffect(() => {
    if(mySelectedCourses && selectedCourse>=0){
		  setOrganisationName(mySelectedCourses[selectedCourse].organisationName);
      var d1 = new Date();
      var d2 = new Date(mySelectedCourses[selectedCourse].validTillDate);
      d2.setDate(d2.getDate() + 1);
      ////alert("Date>> "+d1.getFullYear()+"-"+d1.getMonth()+"-"+d1.getDate());  
      if(d1>d2 && (window.location.pathname.indexOf("selectmocktest")>-1 || window.location.pathname.indexOf("selecttopictest")>-1)){
          window.location.href='validity';
      }
    }
	}, [mySelectedCourses, selectedCourse]);

  return (<>
    {!window.navigator.onLine?
    <div className='netBar' >Alert: It seems, you are not connected to the internet.</div>
    :null}
    <div className={classes.grow}>
      <AppBar position="static">
        <Toolbar>

          <SwipeableTopDrawer/>  
      
          <CourseMenu title={(organisationName && organisationName.length>0)?<>{organisationName}</>:'ETL'} />


          <div className={classes.grow} />

          <Box sx={{ flexGrow: 0 }}>
            <Tooltip title={userObj.studentName+" "+userObj.phoneNo} >
              <IconButton onClick={handleOpenUserMenu} sx={{ p: 0 }}>
                <Avatar alt={userObj.studentName} src="/static/images/avatar/2.jpg" sx={{ width: 33, height: 33 }} />
              </IconButton>
            </Tooltip>
            <Menu
              sx={{ mt: '45px'}}
              id="menu-appbar"
              anchorEl={anchorElUser}
              anchorOrigin={{
                vertical: 'top',
                horizontal: 'right',
              }}
              keepMounted
              transformOrigin={{
                vertical: 'top',
                horizontal: 'right',
              }}
              open={Boolean(anchorElUser)}
              onClose={handleCloseUserMenu}
            >
                <MenuItem style={{justifyContent:'center', width: 230, cursor:'none'}}>                  
                    <IconButton sx={{ p: 0, cursor:'none' }}>
                      <Avatar alt={userObj.studentName} src="/static/images/avatar/2.jpg" sx={{ width: 50, height: 50, cursor:'none' }} />
                    </IconButton>
                </MenuItem>
                <MenuItem>                  
                  <ListItemText style={{textAlign:'center',cursor:'none'}}>
                    {userObj.studentName}
                  </ListItemText>
                </MenuItem>
                <MenuItem> 
                  <ListItemText style={{textAlign:'center',cursor:'none'}}>
                    {userObj.phoneNo}
                  </ListItemText>
                </MenuItem>
                <Divider />

                <MenuItem onClick={()=>{goToLocation('profile')}} >
                  <ListItemIcon>
                  <AccountCircleIcon fontSize="small" />
                  </ListItemIcon>
                  <ListItemText>Profile</ListItemText>
                </MenuItem>
                
                <MenuItem onClick={()=>{goToLocation('feedback')}} >
                  <ListItemIcon>
                  <ErrorOutlineIcon fontSize="small" />
                  </ListItemIcon>
                  <ListItemText>Feedback</ListItemText>
                </MenuItem>

                <MenuItem onClick={()=>{logout()}} >
                  <ListItemIcon>
                  <LogoutIcon fontSize="small" />
                  </ListItemIcon>
                  <ListItemText>Logout</ListItemText>
                </MenuItem>
              
            </Menu>
          </Box>

        </Toolbar>
      </AppBar>
          
    </div>
  </>);
}