import React from 'react';
import { DataGrid } from '@mui/x-data-grid';
import {Box, Container, Grid} from '@material-ui/core';
import {MetaTags} from 'react-meta-tags';
import axios from 'axios';
import Cookies from 'js-cookie';
import {Tooltip, Stack, LinearProgress} from '@mui/material';
import { useSelector } from 'react-redux';
import {API_URL,LIVE_CLASS_URL} from '../utils/EnvVars';
import Header from "./HeaderMy";
import '../styles/bizofficer-a.css';
///import 'font-awesome/css/font-awesome.min.css';

function dateFormat(datetime){
	if(datetime && datetime!=null){
		let datetimeArr = datetime.split(" ");
		let dtArr = datetimeArr[0].split("-");
		let tmArr = datetimeArr[1].split(":");
		datetime = dtArr[2]+"-"+dtArr[1]+"-"+dtArr[0]+" "+tmArr[0]+":"+tmArr[1];
	}
	return datetime;
}  
  
  
const columns = [
	{ field: 'id', headerName: '#', width: 40 },
	{ field: 'subject', headerName: 'Subject', width: 290, renderCell: (params) =>  (
		<Tooltip title={params.value} ><span>{params.value}</span></Tooltip>
	   ), },
	{ field: 'startTime', headerName: 'Date/Time', type: 'date', width: 180, 
	   valueGetter: (params) => {
	   return dateFormat(params.value);
		 }},
	{ field: 'duration', headerName: 'Duration(Min)', flex: 1 },
	{ field: 'note', headerName: 'Note', flex: 1 }
  ];
  
  export default function Execute() {
	const userObj = useSelector(state => state.userDetails);
	const isloggedin = Cookies.get('isloggedin');
	const [rows, setRows] = React.useState([]);
	const [pageLoading, setPageLoading] = React.useState(true);

	// check if logged in
	React.useEffect(() => {
		if(!isloggedin){
			window.location.href='login';
		}
	}, [isloggedin]);

	React.useEffect(() => {		
		if(userObj.studentId && userObj.token){
			getApiData(userObj.studentId,userObj.token);
		}
	}, [userObj]);

	async function getApiData(studentId,token){
			let axiosHeader = {
				headers:{
					'Content-Type': 'multipart/mixed',
					'studentId': studentId,
					'token': token,
				}
			};
			axios.get(API_URL+'/myliveclasses', axiosHeader)
			   .then(response => {
				setPageLoading(false);
			 	///console.log("Just Checking >> "+response.data); 
				if(response.data && response.data.responseTxt==='success' && response.data.list){ 
					setRows(response.data.list);	
				}else if(response && response.data && response.data.responseTxt==="unauthorized"){
					Cookies.remove('isloggedin');
					window.location.href='logout';
 
				} 			 				
			})
	}

	function goToDetail(obj){
		if(obj && rows[obj.id-1]){
			window.location.href=LIVE_CLASS_URL+"/?userName="+rows[obj.id-1].subject+"&meetingNumber="+rows[obj.id-1].meetingNumber+"&passWord="+rows[obj.id-1].meetingPassword;
		}
	}

	return (
		<div> 
				<MetaTags>
            		<title>My Teacher Help</title>
          		</MetaTags>
				
				<Header />
				{pageLoading?<LinearProgress />:null}
				<Box style={{marginBottom:100, marginLeft:20, marginRight:20}}>	
					<Box mt={1}>
							<Grid container spacing={2}>
								<Grid item md={12} xs={12}>
									<h3 className="heading" >My Teacher Help</h3>
									<h4 style={{color:'#f50057'}}>Click on any row to join class</h4>
								</Grid>
							</Grid>
					</Box>

					<div className="tblReport" style={{height: '70vh', width: '100%' }}>
						<DataGrid
							rows={rows}
							columns={columns}
							pageSize={50}
							rowHeight={40}
							rowsPerPageOptions={[50]}
							ActionsComponent={()=>{alert('Hello')}}		
							style={{fontSize:12}}	
							components={{
								NoRowsOverlay: () => (
								  <Stack height="100%" alignItems="center" justifyContent="center">
									<span style={{color:'#FF0000',fontWeight:'bold'}}>No live classes found!</span>
								  </Stack>
								)}}
							onRowClick={itm => goToDetail(itm)}			
						/>
					</div>

				</Box>

		</div>	
	);
  }