import React from 'react';
import {Box, Grid, Button, Link} from '@material-ui/core';
import axios from 'axios';
import LoadingButton from '@mui/lab/LoadingButton';
import Alert from '@mui/material/Alert';
import Stack from '@mui/material/Stack';
import Snackbar from '@mui/material/Snackbar';
import TextField from '@mui/material/TextField';
import {MetaTags} from 'react-meta-tags';
import {API_URL} from '../utils/EnvVars';
import Cookies from 'js-cookie';
import '../styles/bizofficer-a.css';
import 'font-awesome/css/font-awesome.min.css';
import { useDispatch } from 'react-redux';
import { addUser } from '../store/user.actions';
import { selectCourse } from '../store/course.actions';
import { setMyCourses } from '../store/mycourses.actions';
import { setTopicTree, setTopicList, setKeywordList, setTopicTreeLearning, setTopicListLearning, setKeywordListLearning, setTopicTreeTest, setTopicListTest, setSmartLearning, setMockTest } from '../store/data.actions';




  export default function Execute() {
	const isloggedin = Cookies.get('isloggedin');
	const dispatch = useDispatch();
	const [userId, setUserId] = React.useState("");
	const [password, setPassword] = React.useState("");
	const [showAlert, setShowAlert] = React.useState(false);
	const [alertMessage, setAlertMessage] = React.useState("");

	var vertical='top',horizontal='center';

	if(isloggedin){
		window.location.href='dashboard';
	}

	function hideAlert(){
		setShowAlert(false);
	}

	function login(){
		///alert('Login Now');
		if(!userId){
			setShowAlert(true);
			setAlertMessage("Enter your user-id.");			
			return false;
		}else if(!password){
			setShowAlert(true);
			setAlertMessage("Enter your password.");			
			return false;	
		}else{
			document.getElementById('waitloginbtnid').style.display='';
			document.getElementById('loginbtnid').style.display='none';
			let axiosHeader = {
				headers: {
					'Content-Type': 'multipart/mixed',
				}
			};		  
			const data = new FormData();
			data.append('userId', userId);
			data.append('password', password);
			axios.post(API_URL+'/loginmultiorg', data, axiosHeader)
			.then((response) => {
				console.log("RESPONSE RECEIVED: ", response);
				if(response && response.data && response.data.responseTxt==="OK"){	
					if(response.data.organisations && response.data.organisations.length>0){				
						dispatch(addUser(response.data));
						dispatch(setMyCourses(response.data.organisations));
						
						if(response.data.openedCourse!=null && response.data.openedCourse>0){
							dispatch(selectCourse(response.data.openedCourse));
						}else{
							dispatch(selectCourse(0));
						}

						if(response.data.topicList && response.data.topicList.length>0){
							dispatch(setTopicList(JSON.parse(response.data.topicList)));
						}else{
							dispatch(setTopicList([]));
						}
						if(response.data.keywordList && response.data.keywordList.length>0){
							dispatch(setKeywordList(JSON.parse(response.data.keywordList)));
						}else{
							dispatch(setKeywordList([]));
						}
						if(response.data.topicTree && response.data.topicTree.length>0){
							dispatch(setTopicTree(JSON.parse(response.data.topicTree)));
						}else{
							dispatch(setTopicTree([]));
						}
						if(response.data.topicTreeLearning && response.data.topicTreeLearning.length>0){
							dispatch(setTopicTreeLearning(JSON.parse(response.data.topicTreeLearning)));
						}else{
							dispatch(setTopicTreeLearning([]));
						}
						if(response.data.topicListLearning && response.data.topicListLearning.length>0){
							dispatch(setTopicListLearning(JSON.parse(response.data.topicListLearning)));
						}else{
							dispatch(setTopicListLearning([]));
						}
						if(response.data.keywordListLearning && response.data.keywordListLearning.length>0){
							dispatch(setKeywordListLearning(JSON.parse(response.data.keywordListLearning)));
						}else{
							dispatch(setKeywordListLearning([]));
						}
						if(response.data.topicTreeTest && response.data.topicTreeTest.length>0){
							dispatch(setTopicTreeTest(JSON.parse(response.data.topicTreeTest)));
						}else{
							dispatch(setTopicTreeTest([]));
						}
						if(response.data.topicListTest && response.data.topicListTest.length>0){
							dispatch(setTopicListTest(JSON.parse(response.data.topicListTest)));
						}else{
							dispatch(setTopicListTest([]));
						}
						if(response.data.smartLearningJson && response.data.smartLearningJson.length>0){
							dispatch(setSmartLearning(JSON.parse(response.data.smartLearningJson)));
						}else{
							dispatch(setSmartLearning([]));
						}
						if(response.data.mockTestJson && response.data.mockTestJson.length>0){
							dispatch(setMockTest(JSON.parse(response.data.mockTestJson)));
						}else{
							dispatch(setMockTest([]));
						}

						Cookies.set('isloggedin', 1, { expires: new Date(new Date().getTime() + 3600000*24*400) });
						document.getElementById('waitloginbtnid').style.display='none';
						document.getElementById('loginbtnid').style.display='';
						window.location.href="dashboard";
					}else{
						document.getElementById('waitloginbtnid').style.display='none';
						document.getElementById('loginbtnid').style.display='';
						setShowAlert(true);
						setAlertMessage("Something wrong, Please contact to admin");			
						return false;
					}
				}else if(response.data.responseTxt=="ValidityFinished"){
					document.getElementById('waitloginbtnid').style.display='none';
					document.getElementById('loginbtnid').style.display='';
					setShowAlert(true);
					setAlertMessage("Validity Finished! Contact to customer care to Re-Activate your account.");			
					return false;	
				}else{
					document.getElementById('waitloginbtnid').style.display='none';
					document.getElementById('loginbtnid').style.display='';
					setShowAlert(true);
					setAlertMessage("Your user-id or password is invalid.");			
					return false;
				}
			})
			.catch((error) => {
				console.log("AXIOS ERROR: ", error);
			})
		}  
	}
	
	function onEnter(event){
		if(event.key === 'Enter'){
			login();
		}
	}

		return (
			<div> 
				<MetaTags>
            		<title>Student Login - Smart E-Learning Platform </title>
            		<meta name="description" content="Test Simulator" />
          		</MetaTags>
				
				<Box className="loginBGImg" style={{backgroundImage:"url('"+process.env.PUBLIC_URL+"/student_login_bg.jpg')", backgroundPosition: 'center', height: '100vh', overflow: 'hidden'}}>					
						<Stack spacing={2} sx={{ width: '100%' }}>
							<Snackbar open={showAlert} autoHideDuration={6000} onClose={hideAlert} anchorOrigin={{vertical,horizontal}}  >
								<Alert onClose={hideAlert} variant="filled" severity="error" sx={{ width: '100%' }}>
									{alertMessage}
								</Alert>
							</Snackbar>
						</Stack>

					<Box>
						<Grid container style={{justifyContent: 'center'}} spacing={2}>
							<Grid item className="dhslogin" md={6} xs={12}>

							
								<Grid className="flex-container loginbox">								
									<Grid md={12} xs={12}>
										<img src={process.env.PUBLIC_URL+"/ease_to_learn_logo.png"} style={{height:80,marginTop:20,marginBottom:20}}  />
									</Grid>
									<Grid md={12} xs={12}>
										<div className='loginLabel' >Email or Mobile</div>
										<TextField 
											onKeyPress={(event)=>{onEnter(event)}}
											onChange={event => setUserId(event.target.value)}
											style={{backgroundColor:'#FFF', borderRadius: 5}}
											color="warning"
											size="small"
											fullWidth	
											variant="outlined"
										/>
									</Grid>
									<Grid md={12} xs={12}>
										<div className='loginLabel' >Password</div>
										<TextField
											onKeyPress={(event)=>{onEnter(event)}}
											onChange={event => setPassword(event.target.value)}
											style={{backgroundColor:'#FFF', borderRadius: 5}}
											color="warning"
											size="small"
											type="password"											
											fullWidth	
											variant="outlined"							
										/>
									</Grid>
									<Grid md={12} xs={12}>
										<Link href="forgotpassword" className="loginfrgot" >Forgot Password?</Link>
									</Grid>
									<Grid md={12} xs={12} style={{marginTop: -25}} >
										<Button id="loginbtnid" onClick={()=>{login()}} className="loginbtn" variant="contained">LOGIN</Button>
										<LoadingButton 
											className="loginbtn"
											loading
											loadingPosition="start"											
											variant="outlined"
											color="secondary"
											id="waitloginbtnid" 
											style={{textTransform: 'none',display:'none'}}
										>
											Wait...
										</LoadingButton>
									</Grid>

								
								</Grid>
							

							</Grid>
											

						</Grid>
					</Box>




				</Box>
				
			</div>
		);
 
}