import React from 'react';
import {Box, Container, Grid } from '@material-ui/core';
import CircularProgress from '@mui/material/CircularProgress';
import CheckCircleOutlineIcon from '@mui/icons-material/CheckCircleOutline';
import {MetaTags} from 'react-meta-tags';
import axios from 'axios';
import Header from "./HeaderMy";
import '../styles/bizofficer-a.css';
import {API_URL} from '../utils/EnvVars';
import { useDispatch } from 'react-redux';
import { selectCourse } from '../store/course.actions';
import { setMyCourses } from '../store/mycourses.actions';
import { setTopicTree, setTopicList, setKeywordList, setTopicTreeLearning, setTopicListLearning, setKeywordListLearning, setTopicTreeTest, setTopicListTest, setSmartLearning, setMockTest } from '../store/data.actions';


  export default function Execute() {
	const dispatch = useDispatch();
	const authResult = new URLSearchParams(window.location.search); 
	const studentId = authResult.get('studentId');
	const courseId = authResult.get('courseId');

	React.useEffect(() => {		
		if(studentId,courseId){
			getApiData(studentId,courseId);	
		}
	}, [courseId]); 

	async function getApiData(studentId,courseId){
		axios.get(API_URL+'/selectmycourse?studentId='+studentId+'&courseId='+courseId)
		.then(response => {				
				if(response.data.responseTxt==="success"){
					let index = response.data.organisations.length-1;
					dispatch(setMyCourses(response.data.organisations));
					dispatch(selectCourse(index));
					getApiDataLastOpenedCourseUpdate(response.data.organisations[index].templateId);
				}
		 })
	}

	async function getApiDataLastOpenedCourseUpdate(templateId){
		axios.get(API_URL+'/templatecache?templateId='+templateId)
		   .then(response => {
		   ///console.log("Just Checking >> "+response.data);  
		  if(response && response.data && response.data.responseTxt==="success"){
			  if(response.data.topicList && response.data.topicList.length>0){
				dispatch(setTopicList(JSON.parse(response.data.topicList)));
			  }else{
				dispatch(setTopicList([]));
			  }
			  if(response.data.keywordList && response.data.keywordList.length>0){
				dispatch(setKeywordList(JSON.parse(response.data.keywordList)));
			  }else{
				dispatch(setKeywordList([]));
			  }
			  if(response.data.topicTree && response.data.topicTree.length>0){
				dispatch(setTopicTree(JSON.parse(response.data.topicTree)));
			  }else{
				dispatch(setTopicTree([]));
			  }
			  if(response.data.topicTreeLearning && response.data.topicTreeLearning.length>0){
				dispatch(setTopicTreeLearning(JSON.parse(response.data.topicTreeLearning)));
			  }else{
				dispatch(setTopicTreeLearning([]));
			  }
			  if(response.data.topicListLearning && response.data.topicListLearning.length>0){
				dispatch(setTopicListLearning(JSON.parse(response.data.topicListLearning)));
			  }else{
				dispatch(setTopicListLearning([]));
			  }
			  if(response.data.keywordListLearning && response.data.keywordListLearning.length>0){
				dispatch(setKeywordListLearning(JSON.parse(response.data.keywordListLearning)));
			  }else{
				dispatch(setKeywordListLearning([]));
			  }
			  if(response.data.topicTreeTest && response.data.topicTreeTest.length>0){
				dispatch(setTopicTreeTest(JSON.parse(response.data.topicTreeTest)));
			  }else{
				dispatch(setTopicTreeTest([]));
			  }
			  if(response.data.topicListTest && response.data.topicListTest.length>0){
				dispatch(setTopicListTest(JSON.parse(response.data.topicListTest)));
			  }else{
				dispatch(setTopicListTest([]));
			  }
			  if(response.data.smartLearningJson && response.data.smartLearningJson.length>0){
				dispatch(setSmartLearning(JSON.parse(response.data.smartLearningJson)));
			  }else{
				dispatch(setSmartLearning([]));
			  }
			  if(response.data.mockTestJson && response.data.mockTestJson.length>0){
				dispatch(setMockTest(JSON.parse(response.data.mockTestJson)));
			  }else{
				dispatch(setMockTest([]));
			  }
	
			  const mydtmout = setTimeout(
				function () {
				  clearTimeout(mydtmout);
				  window.location.href='dashboard';							
				}
			  , 8000);
	
		  } 
	
		})
	 }

	
		return (
			<div> 
				<MetaTags>
            		<title>Payment Transaction Verifying</title>
          		</MetaTags>
				
				<Header />
				<Container style={{marginBottom:100}}>		

				<Box mt={1}>
						<Grid container spacing={2}>
							<Grid item   md={12} xs={12} style={{textAlign:'center'}}>
								<div><CheckCircleOutlineIcon style={{fontSize:60,color:'#32cd32'}} /></div>
								<h3 className="heading" style={{color:'#32cd32'}} >Payment transaction has been completed successfully.</h3>
								<h3>Just Updating</h3>
							</Grid>
						</Grid>
				</Box>				

				<Box mt={1}>
							<Grid container spacing={2}>
								<Grid item md={12} xs={12} style={{textAlign:'center'}} >
									<CircularProgress /><br/>
									<span style={{fontSize:30,color:'#c51162'}} >Wait...</span><br/>
									<span style={{fontSize:14,color:'#0000FF',fontWeight:'bold'}} >It is updating payment status and fetching your courses</span>
									<br/><span style={{fontWeight:'bold'}} >Please do not close this window.</span>
								</Grid>
							</Grid>
				</Box>				



					

				</Container>
				
				

			</div>
		);
 
}