import React from 'react';
import { DataGrid } from '@mui/x-data-grid';
import {Box, Container, Grid} from '@material-ui/core';
import {MetaTags} from 'react-meta-tags';
import axios from 'axios';
import Cookies from 'js-cookie';
import LinearProgress from '@mui/material/LinearProgress';
import Tooltip from '@mui/material/Tooltip';
import { useSelector } from 'react-redux';
import {API_URL} from '../utils/EnvVars';
import Header from "./HeaderMy";
import '../styles/bizofficer-a.css';
///import 'font-awesome/css/font-awesome.min.css';

  
  
const columns = [
	{ field: 'id', headerName: '#', width: 40 },
	{ field: 'mockTestName', headerName: 'Title', width: 290, renderCell: (params) =>  (
		<Tooltip title={params.value} ><span>{params.value}</span></Tooltip>
	   ), },
	{ field: 'testType', headerName: 'Type', width: 145 },
	{ field: 'submitDateTime', headerName: 'Date', width: 145 },
	{ field: 'totalQuestions', headerName: 'Total Questions', flex: 1 },
	{ field: 'fullMarks', headerName: 'Full Marks', flex: 1 },
	{ field: 'marksObtain', headerName: 'Marks Obtain', flex: 1 },
	{ field: 'timeSpent', headerName: 'Time Spent', flex: 1 }
	/*
	{
	  field: 'age',
	  headerName: 'Age',
	  type: 'number',
	  width: 130,
	},
	{
	  field: 'fullName',
	  headerName: 'Full name',
	  description: 'This column has a value getter and is not sortable.',
	  sortable: false,
	  width: 160,
	  valueGetter: (params) =>
		`${params.getValue(params.id, 'firstName') || ''} ${
		  params.getValue(params.id, 'lastName') || ''
		}`,
	},
	*/
  ];
  
  export default function Execute() {
	const userObj = useSelector(state => state.userDetails);
	const selectedCourse = useSelector(state => state.selectedCourse);
	const mySelectedCourses = useSelector(state => state.mySelectedCourses);
	const isloggedin = Cookies.get('isloggedin');
	const [rows, setRows] = React.useState([]);
	const [linearProgress, setLinearProgress] = React.useState(true);

	
	// check if logged in
	React.useEffect(() => {
		if(!isloggedin){
			window.location.href='login';
		}
	}, [isloggedin]);

	React.useEffect(() => {		
		if(selectedCourse>=0 && mySelectedCourses[selectedCourse].organisationId && userObj.studentId){
			getApiData(mySelectedCourses[selectedCourse].organisationId,userObj.studentId,userObj.token);
		}
	}, [mySelectedCourses,selectedCourse]);

	async function getApiData(organisationId, studentId, token){
			let axiosHeader = {
				headers:{
					'Content-Type': 'multipart/mixed',
					'studentId': studentId,
					'token': token,
				}
			};
			axios.get(API_URL+'/reportanalytics?panel=student&organisationId='+organisationId+'&studentId='+studentId, axiosHeader)
			   .then(response => {
					setLinearProgress(false);
			 	///console.log("Just Checking >> "+response.data);  
				 if(response.data && response.data.responseTxt==='success'){
					setRows(response.data.list);	
			   	}else if(response && response.data && response.data.responseTxt==="unauthorized"){
				   Cookies.remove('isloggedin');
				   window.location.href='logout';

			   	}				 				 				
			})
	}

	function goToDetail(obj){
		if(obj && rows[obj.id-1]){
			if(rows[obj.id-1].testTypeId==3){
				window.location.href="analytics?testId="+rows[obj.id-1].testSession;
			}else{
				window.location.href="testanalytics?testId="+rows[obj.id-1].testSession;
			}	
		}
	}

	return (
		<div> 
				<MetaTags>
            		<title>Report & Analytics</title>
          		</MetaTags>
				
				<Header />
				{linearProgress?<LinearProgress />:null}
				<Box style={{marginBottom:100, marginLeft:20, marginRight:20}}>	
					<Box mt={1}>
							<Grid container spacing={2}>
								<Grid item md={12} xs={12}>
									<h3 className="heading" >Report & Analytics</h3>
									<h4 style={{color:'#f50057'}}>Click on any row to view analytics and details</h4>
								</Grid>
							</Grid>
					</Box>

					<div className="tblReport" style={{height: '70vh', width: '100%' }}>
						<DataGrid
							rows={rows}
							columns={columns}
							pageSize={50}
							rowHeight={40}
							rowsPerPageOptions={[50]}
							ActionsComponent={()=>{alert('Hello')}}		
							style={{fontSize:12}}	
							onRowClick={itm => goToDetail(itm)}			
						/>
					</div>

				</Box>

		</div>	
	);
  }