import React from 'react';
import { DataGrid } from '@mui/x-data-grid';
import {Box, Container, Grid} from '@material-ui/core';
import Stack from '@mui/material/Stack';
import {MetaTags} from 'react-meta-tags';
import axios from 'axios';
import Cookies from 'js-cookie';
import LinearProgress from '@mui/material/LinearProgress';
import Tooltip from '@mui/material/Tooltip';
import DialogClassTestDetails from '../components/DialogClassTestDetails';
import DialogTestStart from '../components/DialogTestStart';
import { useSelector } from 'react-redux';
import {API_URL} from '../utils/EnvVars';
import Header from "./HeaderMy";
import '../styles/bizofficer-a.css';
///import 'font-awesome/css/font-awesome.min.css';

function dateFormat(datetime){
	if(datetime && datetime!=null){
		let datetimeArr = datetime.split(" ");
		let dtArr = datetimeArr[0].split("-");
		let tmArr = datetimeArr[1].split(":");
		datetime = dtArr[2]+"-"+dtArr[1]+"-"+dtArr[0]+" "+tmArr[0]+":"+tmArr[1];
	}
	return datetime;
}    
  
const columns = [
	{ field: 'id', headerName: '#', width: 40 },
	{ field: 'testTitle', headerName: 'Test Title', minWidth: 250, renderCell: (params) =>  (
		<Tooltip title={params.value} ><span>{params.value}</span></Tooltip>
	   ), },
	{ field: 'subject', headerName: 'Subject', width: 170 },
	{ field: 'testDateTime', headerName: 'Date/Time', type: 'date', width: 170, 
		valueGetter: (params) => {
		return dateFormat(params.value);
	  	}},
	{ field: 'questionType', headerName: 'Question Type', width: 170 },
	{ field: 'totalMark', headerName: 'Total Marks', width: 170 },	  
	{ field: 'totalTime', headerName: 'Duration (Minutes)', width: 170 }
  ];
  
  export default function Execute() {
	const mySelectedCourses = useSelector(state => state.mySelectedCourses);
	const selectedCourse = useSelector(state => state.selectedCourse);

	const userObj = useSelector(state => state.userDetails);
	const isloggedin = Cookies.get('isloggedin');
	const childRef = React.useRef();
	const childRefStartTest = React.useRef();
	const [testDetail, setTestDetail] = React.useState({});
	const [rows, setRows] = React.useState([]);
	const [currentRunningTestTitle, setCurrentRunningTestTitle] = React.useState("");
	const [currentRunningTestSession, setCurrentRunningTestSession] = React.useState("");

	// check if logged in
	React.useEffect(() => {
		if(!isloggedin){
			window.location.href='login';
		}
	}, [isloggedin]);

	React.useEffect(() => {		
		if(userObj && userObj!=null && userObj.schools!=null && userObj.schools[0]!=null && userObj.schools[0].schoolId>0){
			getApiData(userObj.schools[0].schoolId,userObj.schools[0].className);	
		}
	}, [userObj]);

	async function getApiData(schoolId,className){
			let axiosHeader = {
				headers:{
					'Content-Type': 'multipart/mixed',
					'studentId': userObj.studentId,
					'token': userObj.token,
				}
			};
			axios.get(API_URL+'/classtestlist?schoolId='+schoolId+'&className='+className, axiosHeader)
			   .then(response => {
			 	///console.log("Just Checking >> "+response.data);  
				 if(response.data.responseTxt==="success"){
					setRows(response.data.list);

				}else if(response && response.data && response.data.responseTxt==="unauthorized"){
					Cookies.remove('isloggedin');
					window.location.href='logout';						

				}				 				 				
			})
	}

	function showDetails(obj){
		if(obj && rows[obj.id-1]){
			setTestDetail(rows[obj.id-1]);
			childRef.current.handleClickOpen();	
		}	
	}

	function startMyTest(){
		///alert("aaaa");
		if(selectedCourse>=0 && mySelectedCourses[selectedCourse].organisationId!=null && userObj.studentId!=null){
			let axiosHeader = {
				headers:{
					'Content-Type': 'multipart/mixed',
					'studentId': userObj.studentId,
					'token': userObj.token,
				}
			};
			axios.get(API_URL+'/testcurrentrunning?organisationId='+mySelectedCourses[selectedCourse].organisationId+'&studentId='+userObj.studentId, axiosHeader)
				.then(response => {
					///console.log("Just Checking >> "+response.data);
					if(response.data.responseTxt==="OK"){
						setCurrentRunningTestTitle(response.data.testName);
						setCurrentRunningTestSession(response.data.testSession);
						childRefStartTest.current.handleClickOpen();

					}else if(response && response.data && response.data.responseTxt==="unauthorized"){
						Cookies.remove('isloggedin');
						window.location.href='logout';						

					}else{
						window.location.href='testsimulator?classTestId='+testDetail.scheduleId+'&testType=4';
					}			 				
			}).catch((error) => {
				console.log("AXIOS ERROR: ", error);
			})
		}		
	}
	function deleteCurrentStartNew(){		
		if(selectedCourse>=0 && mySelectedCourses[selectedCourse].organisationId!=null && userObj.studentId!=null){
			let axiosHeader = {
				headers:{
					'Content-Type': 'multipart/mixed',
					'studentId': userObj.studentId,
					'token': userObj.token,
				}
			};
			axios.get(API_URL+'/testrunningdelete?organisationId='+mySelectedCourses[selectedCourse].organisationId+'&studentId='+userObj.studentId, axiosHeader)
				.then(response => {
					///console.log("Just Checking >> "+response.data);
					if(response && response.data && response.data.responseTxt==="unauthorized"){
						Cookies.remove('isloggedin');
						window.location.href='logout';						
					}			 				
			}).catch((error) => {
				console.log("AXIOS ERROR: ", error);
			})		
			window.location.href='testsimulator?classTestId='+testDetail.scheduleId+'&testType=4';
		}
	}	
	function continueCurrentTest(){	
		window.location.href='testsimulator?testSession='+currentRunningTestSession+'&testType=4';
	}

	return (
		<div> 
				<MetaTags>
            		<title>Class Test</title>
          		</MetaTags>
				
				<Header />
				{(document.readyState!="complete")?<LinearProgress />:null}
				<Box style={{marginBottom:100, marginLeft:20, marginRight:20}}>	
					<Box mt={1}>
							<Grid container spacing={2}>
								<Grid item md={12} xs={12}>
									<h3 className="heading" >Class Test</h3>
									<h4 style={{color:'#f50057'}}>Click on any row to start test</h4>
								</Grid>
							</Grid>
					</Box>

					<div className="tblReport" style={{height: '70vh', width: '100%' }}>
						<DataGrid
							rows={rows}
							columns={columns}
							pageSize={50}
							rowHeight={40}
							rowsPerPageOptions={[50]}
							ActionsComponent={()=>{alert('Hello')}}		
							style={{fontSize:12}}	
							onRowClick={itm => showDetails(itm)}	
							components={{
								NoRowsOverlay: () => (
								  <Stack height="100%" alignItems="center" justifyContent="center">
									<span style={{color:'#FF0000',fontWeight:'bold'}}>No class test available!</span>
								  </Stack>
								)}}		
						/>
					</div>

				</Box>

				<DialogClassTestDetails toCallStartTest={startMyTest} testDetail={testDetail} ref={childRef} />
				<DialogTestStart toCallDeleteCurrentStartNew={deleteCurrentStartNew} toCallContinueCurrentTest={continueCurrentTest} currentRunningTestTitle={currentRunningTestTitle} ref={childRefStartTest}  />							

		</div>	
	);
  }