import React from 'react';
///import { makeStyles } from '@material-ui/core/styles';
import { styled } from '@mui/material/styles';
import {Box, Container, Grid, Link, Button} from '@material-ui/core';
import {MetaTags} from 'react-meta-tags';
import axios from 'axios';
import Cookies from 'js-cookie';
import LinearProgress from '@mui/material/LinearProgress';
import ArrowForwardIosSharpIcon from '@mui/icons-material/ArrowForwardIosSharp';
import DoneIcon from '@mui/icons-material/Done';
import ArrowRightIcon from '@mui/icons-material/ArrowRight';
import MuiAccordion from '@mui/material/Accordion';
import MuiAccordionSummary from '@mui/material/AccordionSummary';
import MuiAccordionDetails from '@mui/material/AccordionDetails';
import Typography from '@mui/material/Typography';
import DialogCourseDetails from '../components/DialogCourseDetails';
import Header from "./HeaderMy";
import {API_URL,PAYMENT_GATEWAY_SUCCESS_URL} from '../utils/EnvVars';
import '../styles/bizofficer-a.css';
import { useDispatch, useSelector } from 'react-redux';
import { selectCourse } from '../store/course.actions';
import { setMyCourses } from '../store/mycourses.actions';
import { setTopicTree, setTopicList, setKeywordList, setTopicTreeLearning, setTopicListLearning, setKeywordListLearning, setTopicTreeTest, setTopicListTest, setSmartLearning, setMockTest } from '../store/data.actions';

const Accordion = styled((props) => (
	<MuiAccordion disableGutters elevation={0} square {...props} />
  ))(({ theme }) => ({
	border: `1px solid ${theme.palette.divider}`,
	'&:not(:last-child)': {
	  borderBottom: 0,
	},
	'&:before': {
	  display: 'none',
	},
  }));
  
  const AccordionSummary = styled((props) => (
	<MuiAccordionSummary
	  expandIcon={<ArrowForwardIosSharpIcon sx={{ fontSize: '0.9rem' , color: '#FFFFFF' }} />}
	  {...props}
	/>
  ))(({ theme }) => ({
	backgroundColor: '#dd8313',
	color: '#FFFFFF',
	flexDirection: 'row-reverse',
	'& .MuiAccordionSummary-expandIconWrapper.Mui-expanded': {
	  transform: 'rotate(90deg)',
	},
	'& .MuiAccordionSummary-content': {
	  marginLeft: theme.spacing(1),
	},
  }));
  
  const AccordionDetails = styled(MuiAccordionDetails)(({ theme }) => ({
	padding: theme.spacing(2),
	borderTop: '1px solid rgba(0, 0, 0, .125)',
  }));

  export default function Execute() {
	const dispatch = useDispatch();
	const userObj = useSelector(state => state.userDetails);
	///const mySelectedCourses = useSelector(state => state.mySelectedCourses);
	const isloggedin = Cookies.get('isloggedin');
	const childRef = React.useRef();
	const [loadingPage, setLoadingPage] = React.useState(true);
	const [dataList, setDataList] = React.useState([]);
	const [expanded, setExpanded] = React.useState('panel0');
	const [dataDetail, setDataDetail] = React.useState({});
	const [hostName, setHostName] = React.useState('');
	const [selectedCourses, setSelectedCourses] = React.useState([]);
	const [selectedFlag, setSelectedFlag] = React.useState(0);

	const authResult = new URLSearchParams(window.location.search); 
	const courseId = authResult.get('cid');

	// check if logged in
	React.useEffect(() => {
		if(!isloggedin){
			window.location.href='login';
		}
	}, [isloggedin]);

	const handleChange = (panel) => (event, newExpanded) => {
		setExpanded(newExpanded ? panel : false);
	};

	React.useEffect(() => {		
		let dname = window.location.hostname;	
		if(dname && userObj.studentId){
			getApiData(dname, userObj.studentId, userObj.token);
			setHostName(dname);
			getApiDataMySelectedCourses(userObj.studentId);
		}
	}, [userObj]); 

	React.useEffect(() => {		
			if(courseId && courseId>0 && dataList  && dataList.length>0){				
				for(let i=0; i<dataList.length; i++){
					if(dataList[i].coursesList.length>0){
						for(let j=0; j<dataList[i].coursesList.length; j++){
							if(courseId==dataList[i].coursesList[j].courseId){
								if(isAddedCourse(courseId)==1){
									setDataDetail(dataList[i].coursesList[j]);
									setSelectedFlag(1);
									childRef.current.handleClickOpen();		
								}else{
									setDataDetail(dataList[i].coursesList[j]);
									setSelectedFlag(0);
									childRef.current.handleClickOpen();		
								}
							}
						}
					}
				}
			}
	}, [courseId,dataList]); 

	async function getApiData(dname, studentId, token){
		let axiosHeader = {
			headers:{
				'Content-Type': 'multipart/mixed',
				'studentId': studentId,
				'token': token,
			}
		};
			axios.get(API_URL+'/categoryandcourses?domainName='+dname, axiosHeader)
			   .then(response => {
				setLoadingPage(false);
				if(response.data && response.data.responseTxt==='success'){
				 	setDataList(response.data.list);	
				}else if(response && response.data && response.data.responseTxt==="unauthorized"){
					Cookies.remove('isloggedin');
					window.location.href='logout';

				}			 				
			})
	}

	async function getApiDataMySelectedCourses(studentId){
		axios.get(API_URL+'/myselectedcourses?studentId='+studentId)
		   .then(response => {
			if(response.data && response.data.responseTxt==='success'){
			   setSelectedCourses(response.data.courses);	
			} 			 				
		})
	}

	function showDetails(obj,selected){
		setDataDetail(obj);
		setSelectedFlag(selected);
		childRef.current.handleClickOpen();		
	}
	function selectMyNewCourse(opt,promoCode){
	
		if(userObj!=null && userObj.studentId!=null && opt>0){
			let axiosHeader = {
				headers:{
					'Content-Type': 'multipart/mixed',
					'studentId': userObj.studentId,
					'token': userObj.token,
				}
			};
			if(opt===1){
				axios.get(API_URL+'/selectmycourse?sid='+userObj.sid+'&studentId='+userObj.studentId+'&courseId='+dataDetail.courseId, axiosHeader)
					.then(response => {
						///console.log("Just Checking >> "+response.data);
						if(response && response.data && response.data.responseTxt==="success"){
							let index = response.data.organisations.length-1;
							dispatch(setMyCourses(response.data.organisations));
							dispatch(selectCourse(index));
							getApiDataLastOpenedCourseUpdate(response.data.organisations[index].templateId);
						
						}else if(response && response.data && response.data.responseTxt==="unauthorized"){
							Cookies.remove('isloggedin');
							window.location.href='logout';
								   
					    }			 				
				}).catch((error) => {
					console.log("AXIOS ERROR: ", error);
				})
			}else if(opt===2){
				let apiQuery='&webUrl='+window.location.host;
				if(promoCode){
					apiQuery+='&promoCode='+promoCode;
				}
				axios.get(API_URL+'/paymenttokengenerate?studentName='+userObj.studentName+'&email='+userObj.emailId+'&phone='+userObj.phoneNo+'&courseId='+dataDetail.courseId+'&courseName='+dataDetail.courseTitle+apiQuery, axiosHeader)
					.then(response => {
						///console.log("Just Checking >> "+response.data);
						if(response && response.data && response.data.responseTxt==="success"){
							//REDIRECT TO PAYMENT GATEWAY	
							if(response.data.amount>0){						
								// //window.location.href='http://localhost/rough-code/payment.php?key='+response.data.key+'&txnid='+response.data.token+'&amount='+response.data.amount+'&firstname='+userObj.studentName+'&email='+userObj.emailId+'&phone='+userObj.phoneNo+'&productinfo='+response.data.productinfo+'&hash='+response.data.hashCode;
								// window.location.href='https://uat.easetolearn.com/payment.php?key='+response.data.key+'&txnid='+response.data.token+'&amount='+response.data.amount+'&firstname='+userObj.studentName+'&email='+userObj.emailId+'&phone='+userObj.phoneNo+'&productinfo='+response.data.productinfo+'&hash='+response.data.hashCode;
								// return false;
								document.pgform.key.value=response.data.key;
								document.pgform.txnid.value=response.data.token;
								document.pgform.amount.value=response.data.amount;
								document.pgform.firstname.value=userObj.studentName;
								document.pgform.email.value=userObj.emailId;
								document.pgform.phone.value=userObj.phoneNo;
								document.pgform.productinfo.value=response.data.productinfo;
								document.pgform.surl.value=PAYMENT_GATEWAY_SUCCESS_URL;
								document.pgform.furl.value='https://'+hostName+'/pgcancelled';
								document.pgform.hash.value=response.data.hashCode;
								document.pgform.submit(); 

							}else if(response.data.organisations.length>0){ 
								let index = response.data.organisations.length-1;
								for(let i=0; i<response.data.organisations.length; i++){
									if(response.data.organisations[i].courseId===dataDetail.courseId){
										index = i;
										break;
									}
								}
								dispatch(setMyCourses(response.data.organisations));
								dispatch(selectCourse(index));
								getApiDataLastOpenedCourseUpdate(response.data.organisations[index].templateId);

							}							
						}else if(response && response.data && response.data.responseTxt==="unauthorized"){
							Cookies.remove('isloggedin');
							window.location.href='logout';
								   
					    }			 				
				}).catch((error) => {
					console.log("AXIOS ERROR: ", error);
				})
			}
		}
	}


	async function getApiDataLastOpenedCourseUpdate(templateId){
		axios.get(API_URL+'/templatecache?templateId='+templateId)
		   .then(response => {
		   ///console.log("Just Checking >> "+response.data);  
		  if(response && response.data && response.data.responseTxt==="success"){
			  if(response.data.topicList && response.data.topicList.length>0){
				dispatch(setTopicList(JSON.parse(response.data.topicList)));
			  }else{
				dispatch(setTopicList([]));
			  }
			  if(response.data.keywordList && response.data.keywordList.length>0){
				dispatch(setKeywordList(JSON.parse(response.data.keywordList)));
			  }else{
				dispatch(setKeywordList([]));
			  }
			  if(response.data.topicTree && response.data.topicTree.length>0){
				dispatch(setTopicTree(JSON.parse(response.data.topicTree)));
			  }else{
				dispatch(setTopicTree([]));
			  }
			  if(response.data.topicTreeLearning && response.data.topicTreeLearning.length>0){
				dispatch(setTopicTreeLearning(JSON.parse(response.data.topicTreeLearning)));
			  }else{
				dispatch(setTopicTreeLearning([]));
			  }
			  if(response.data.topicListLearning && response.data.topicListLearning.length>0){
				dispatch(setTopicListLearning(JSON.parse(response.data.topicListLearning)));
			  }else{
				dispatch(setTopicListLearning([]));
			  }
			  if(response.data.keywordListLearning && response.data.keywordListLearning.length>0){
				dispatch(setKeywordListLearning(JSON.parse(response.data.keywordListLearning)));
			  }else{
				dispatch(setKeywordListLearning([]));
			  }
			  if(response.data.topicTreeTest && response.data.topicTreeTest.length>0){
				dispatch(setTopicTreeTest(JSON.parse(response.data.topicTreeTest)));
			  }else{
				dispatch(setTopicTreeTest([]));
			  }
			  if(response.data.topicListTest && response.data.topicListTest.length>0){
				dispatch(setTopicListTest(JSON.parse(response.data.topicListTest)));
			  }else{
				dispatch(setTopicListTest([]));
			  }
			  if(response.data.smartLearningJson && response.data.smartLearningJson.length>0){
				dispatch(setSmartLearning(JSON.parse(response.data.smartLearningJson)));
			  }else{
				dispatch(setSmartLearning([]));
			  }
			  if(response.data.mockTestJson && response.data.mockTestJson.length>0){
				dispatch(setMockTest(JSON.parse(response.data.mockTestJson)));
			  }else{
				dispatch(setMockTest([]));
			  }
	
			  const mydtmout = setTimeout(
				function () {
				  clearTimeout(mydtmout);
				  window.location.href='dashboard';							
				}
			  , 8000);
	
		  } 
	
		})
	 }
		

	function isAddedCourse(courseId) {
		for (let i = 0; i < selectedCourses.length; i++) {
		  if (selectedCourses[i] == courseId) return true;
		}
		return false;
	}
	
		return (
			<div> 
				<MetaTags>
            		<title>Select Course</title>
          		</MetaTags>
				
				<Header />
				{loadingPage?<LinearProgress />:null}
				<Container>		

				<Box mt={1}>
						<Grid container spacing={2}>
							<Grid item   md={12} xs={12}>
								<h3 className="heading" >Select Course</h3>
							</Grid>
						</Grid>
				</Box>				
				
				<Box mt={1}>
						<Grid container spacing={2}>
							<Grid item   md={12} xs={12} className="MuiAccordionRoot" >
							{dataList?dataList.map((myRow,index)=>(	
								<Accordion expanded={expanded === 'panel'+(index+1)} onChange={handleChange('panel'+(index+1))}>
									<AccordionSummary aria-controls={"panel"+(index+1)+"d-content"} id={"panel"+(index+1)+"d-header"} >
									<Typography>{myRow.categoryName}</Typography>
									</AccordionSummary>
									<AccordionDetails>
									<Typography>
										<ul style={{listStyle:'none'}} >
											{
												myRow.coursesList.map((myTRow,indextt)=>(
													<li key={'intt'+indextt}>
														{isAddedCourse(myTRow.courseId)?<>
															<span style={{color: '#008000'}}><DoneIcon /> </span>
															<Link onClick={()=>{showDetails(myTRow,1)}} style={{cursor:'pointer',color:'#605959'}} >{myTRow.courseTitle} - {myTRow.courseSubTitle}</Link>
														</>
														:<>
															<span style={{color: '#605959'}}><ArrowRightIcon /> </span>
															<Link onClick={()=>{showDetails(myTRow,0)}} style={{cursor:'pointer',color:'#605959'}} >{myTRow.courseTitle} - {myTRow.courseSubTitle}</Link>
														</>
														}
													</li>
												))
											}	
										</ul>
									</Typography>
									</AccordionDetails>
								</Accordion>
							)):null}	

							</Grid>

						</Grid>
				</Box>

				
				<form name="pgform" action="https://secure.payu.in/_payment" method='post' >
					<input type="hidden" name="key" value="" />
					<input type="hidden" name="txnid" value="" />
					<input type="hidden" name="amount" value="" />
					<input type="hidden" name="productinfo" value="" />
					<input type="hidden" name="firstname" value="" />
					<input type="hidden" name="email" value="" />
					<input type="hidden" name="phone" value="" />					
					<input type="hidden" name="surl" value="" />
					<input type="hidden" name="furl" value="" />
					<input type="hidden" name="hash" value="" />
				</form>							
					



				</Container>
				
				<DialogCourseDetails toCallSelectCourse={selectMyNewCourse} dataDetail={dataDetail} studentId={userObj.studentId} token={userObj.token} selectedFlag={selectedFlag} ref={childRef} />

			</div>
		);
 
}