import React from 'react';
///import { makeStyles } from '@material-ui/core/styles';
import { styled } from '@mui/material/styles';
import {Box, Grid, Link, Button} from '@material-ui/core';
import {MetaTags} from 'react-meta-tags';
import axios from 'axios';
import Cookies from 'js-cookie';
import { useSelector } from 'react-redux';
import ArrowForwardIosSharpIcon from '@mui/icons-material/ArrowForwardIosSharp';
import MuiAccordion from '@mui/material/Accordion';
import MuiAccordionSummary from '@mui/material/AccordionSummary';
import MuiAccordionDetails from '@mui/material/AccordionDetails';
import Typography from '@mui/material/Typography';
import DialogTestDetails from '../components/DialogTestDetails';
import DialogTestStart from '../components/DialogTestStart';
import Header from "./HeaderMy";
import {API_URL} from '../utils/EnvVars';
import '../styles/bizofficer-a.css';
///import 'font-awesome/css/font-awesome.min.css';

const Accordion = styled((props) => (
	<MuiAccordion disableGutters elevation={0} square {...props} />
  ))(({ theme }) => ({
	border: `1px solid ${theme.palette.divider}`,
	'&:not(:last-child)': {
	  borderBottom: 0,
	},
	'&:before': {
	  display: 'none',
	},
  }));
  
  const AccordionSummary = styled((props) => (
	<MuiAccordionSummary
	  expandIcon={<ArrowForwardIosSharpIcon sx={{ fontSize: '0.9rem' , color: '#FFFFFF' }} />}
	  {...props}
	/>
  ))(({ theme }) => ({
	backgroundColor: '#1f407a',
	color: '#FFFFFF',
	flexDirection: 'row-reverse',
	'& .MuiAccordionSummary-expandIconWrapper.Mui-expanded': {
	  transform: 'rotate(90deg)',
	},
	'& .MuiAccordionSummary-content': {
	  marginLeft: theme.spacing(1),
	},
  }));
  
  const AccordionDetails = styled(MuiAccordionDetails)(({ theme }) => ({
	padding: theme.spacing(2),
	borderTop: '1px solid rgba(0, 0, 0, .125)',
  }));

  export default function Execute() {
	const dataObj = useSelector(state => state.getData);
	const mySelectedCourses = useSelector(state => state.mySelectedCourses);
	const selectedCourse = useSelector(state => state.selectedCourse);

	const userObj = useSelector(state => state.userDetails);
	const isloggedin = Cookies.get('isloggedin');
	const childRef = React.useRef();
	const childRefStartTest = React.useRef();  
	const [mockTestList, setMockTestList] = React.useState([]);
	const [expanded, setExpanded] = React.useState('panel0');
	const [testDetail, setTestDetail] = React.useState({});
	const [currentRunningTestTitle, setCurrentRunningTestTitle] = React.useState("");
	const [currentRunningTestSession, setCurrentRunningTestSession] = React.useState("");

	// check if logged in
	React.useEffect(() => {
		if(!isloggedin){
			window.location.href='login';
		}
	}, [isloggedin]);

	const handleChange = (panel) => (event, newExpanded) => {
		setExpanded(newExpanded ? panel : false);
	};

	React.useEffect(() => {		
		if(dataObj && dataObj.mockTest){
			setMockTestList(dataObj.mockTest);
		}
	}, [dataObj]);

	function showDetails(obj){
		setTestDetail(obj);
		childRef.current.handleClickOpen();		
	}
	function startMyTest(){
		///alert("aaaa");
		if(selectedCourse>=0 && mySelectedCourses[selectedCourse].organisationId!=null && userObj.studentId!=null){
			let axiosHeader = {
				headers:{
					'Content-Type': 'multipart/mixed',
					'studentId': userObj.studentId,
					'token': userObj.token,
				}
			};
			axios.get(API_URL+'/testcurrentrunning?organisationId='+mySelectedCourses[selectedCourse].organisationId+'&studentId='+userObj.studentId, axiosHeader)
				.then(response => {
					///console.log("Just Checking >> "+response.data);
					if(response.data.responseTxt=="OK"){
						setCurrentRunningTestTitle(response.data.testName);
						setCurrentRunningTestSession(response.data.testSession);
						childRefStartTest.current.handleClickOpen();
					}else if(response && response.data && response.data.responseTxt==="unauthorized"){
						Cookies.remove('isloggedin');
						window.location.href='logout';						

					}else{
						window.location.href='testsimulator?testId='+testDetail.mocktestGeneratedId+'&testType=3';
					}			 				
			}).catch((error) => {
				console.log("AXIOS ERROR: ", error);
			})
		}		
	}
	function deleteCurrentStartNew(){		
		if(selectedCourse>=0 && mySelectedCourses[selectedCourse].organisationId && userObj.studentId){
			let axiosHeader = {
				headers:{
					'Content-Type': 'multipart/mixed',
					'studentId': userObj.studentId,
					'token': userObj.token,
				}
			};
			axios.get(API_URL+'/testrunningdelete?organisationId='+mySelectedCourses[selectedCourse].organisationId+'&studentId='+userObj.studentId, axiosHeader)
				.then(response => {
					///console.log("Just Checking >> "+response.data);
					if(response && response.data && response.data.responseTxt==="unauthorized"){
						Cookies.remove('isloggedin');
						window.location.href='logout';						
					}			 				
			}).catch((error) => {
				console.log("AXIOS ERROR: ", error);
			})		
			window.location.href='testsimulator?testId='+testDetail.mocktestGeneratedId+'&testType=3';
		}
	}	
	function continueCurrentTest(){	
		window.location.href='testsimulator?testSession='+currentRunningTestSession+'&testType=3';
	}

	
		return (
			<div> 
				<MetaTags>
            		<title>Select Mock Test</title>
          		</MetaTags>
				
				<Header />

				<Box style={{marginBottom:100, marginLeft:20, marginRight:20}}>		

				<Box mt={1}>
						<Grid container spacing={2}>
							<Grid item   md={12} xs={12}>
								<h3 className="heading" >Select Mock Test</h3>
							</Grid>
						</Grid>
				</Box>				
				
				<Box mt={1}>
						<Grid container spacing={2}>
							<Grid item   md={6} xs={12} className="MuiAccordionRoot" >
							{mockTestList?mockTestList.map((myRow,index)=>(	
								<Accordion expanded={expanded === 'panel'+(index+1)} onChange={handleChange('panel'+(index+1))}>
									<AccordionSummary aria-controls={"panel"+(index+1)+"d-content"} id={"panel"+(index+1)+"d-header"} >
									<Typography>{myRow.categoryName}</Typography>
									</AccordionSummary>
									<AccordionDetails>
									<Typography>
										<ul>
											{
												myRow.testList.map((myTRow,indextt)=>(
													<li key={'intt'+indextt}><Link onClick={()=>{showDetails(myTRow)}} style={{cursor:'pointer'}} >{myTRow.testName}</Link></li>
												))
											}	
										</ul>
									</Typography>
									</AccordionDetails>
								</Accordion>
							)):null}	

							</Grid>
							<Grid item   md={6} xs={12} className="test-instructions" >
								<div className="btmbdrgry"><h3>Instructions</h3></div>
								<p>
									<ol>
										<li>The clock has been set at server and count down timer at the top right corner of the screen will display left out time to closure from where you can monitor time you have to complete the exam.</li>
										<li>Click answer option buttons to select your answer.</li>
										<li>To change an answer, simply click the desired option button.</li>
										<li>Click on RESET button to deselect a chosen answer.</li>
										<li>Click on SAVE & NEXT to save the answer before moving to the next question. The next question will automatically be displayed.</li>
										<li>Click on SKIP to move to the next question without saving the current question.</li>
										<li>Click on MARK FOR REVIEW to review your answer at later stage.</li>
										<li>Make sure you click on SAVE & NEXT button everytime you want to save your answer.</li>
										<li>To go to a question, click on the question number on the right side of the screen.</li>
										<li>The color coded diagram on the right side of the screen shows the status of the questions												
												<div>
													<div><div className="qbg-not-visited-ins" style={{background:"url('/not-visited.png')"}} >2</div> you have not visited question no 2. </div>
													<div className="qbg-ins-label" ><div className="qbg-visited-ins" style={{background:"url('/not-answered.png')"}} >3</div> you have not answered question no 3.</div>
													<div className="qbg-ins-label" ><div className="qbg-visited-ins" style={{background:"url('/answered.png')"}} >4</div> you have answered question no 4.</div>
													<div className="qbg-ins-label" ><div className="qbg-visited-ins" style={{background:"url('/review.png')"}} >5</div> you have marked the question no. 5 for review.</div>
													<div className="qbg-ins-label" ><div className="qbg-visited-ins" style={{background:"url('/answered-review.png')"}}  >6</div> you have answered & marked for review of question no. 6</div>
												</div>												
										</li>								
										<li className="clr">Candidate will be allowed to Shuffle between sections and questions anytime during the examination as per their convenience.</li>
										<li>Candidate can change their response of attempted answers anytime during the examination slot time by clicking another answer which candidates wants to change.</li>
										<li>All the answered questions(saved or marked) will be considered for calculating the final score.</li>
										<li className="redboldtxt" >Do Not PRESS any keyboard key once the exam is started.This will LOCK your exam. You can connect with the exam invigilator to unlock and continue giving the exam.</li>
										<li className="redboldtxt" >Do Not CLICK on the SUBMIT Button unless you have completed the exam.In case you click SUBMIT button, you will not be permitted to continue.</li>
									</ol>
								</p>
							</Grid>

						</Grid>
				</Box>

				

					



				</Box>
				
				<DialogTestDetails toCallStartTest={startMyTest} testDetail={testDetail} ref={childRef} />
				<DialogTestStart toCallDeleteCurrentStartNew={deleteCurrentStartNew} toCallContinueCurrentTest={continueCurrentTest} currentRunningTestTitle={currentRunningTestTitle} ref={childRefStartTest}  />							
			</div>
		);
 
}