import React from 'react';
import {Box, Grid, Link} from '@material-ui/core';
import {MetaTags} from 'react-meta-tags';
import DialogTestStart from '../components/DialogTestStart';
import DialogTopicTestDetails from '../components/DialogTopicTestDetails';
import CircularProgress from '@mui/material/CircularProgress';
import axios from 'axios';
import Cookies from 'js-cookie';
import { useSelector } from 'react-redux';
import {API_URL} from '../utils/EnvVars';
import TreeViewComp from '../components/TreeViewComp';
import SearchInput from '../components/SearchInput';
import Header from "./HeaderMy";
import '../styles/bizofficer-a.css';


  
  export default function Execute() {
	const dataObj = useSelector(state => state.getData);
	const selectedCourse = useSelector(state => state.selectedCourse);
	const mySelectedCourses = useSelector(state => state.mySelectedCourses);

	const childRef = React.useRef();
	const userObj = useSelector(state => state.userDetails);
	const isloggedin = Cookies.get('isloggedin');
	const childRefStartTest = React.useRef();  
	const [topicTestList, setTopicTestList] = React.useState([]);
	const [testDetail, setTestDetail] = React.useState({});
	const [selectedTopicId, setSelectedTopicId] = React.useState(0);
	const [searchQuery, setSearchQuery] = React.useState(null);
	const [searchFlag, setSearchFlag] = React.useState(null);
	const [showProgress, setShowProgress] = React.useState(false);
	const [currentRunningTestTitle, setCurrentRunningTestTitle] = React.useState("");
	const [currentRunningTestSession, setCurrentRunningTestSession] = React.useState("");
	const [selectedTemplateId, setSelectedTemplateId] = React.useState(0);

	// check if logged in
	React.useEffect(() => {
		if(!isloggedin){
			window.location.href='login';
		}
	}, [isloggedin]);

	function showDetails(obj){
		setTestDetail(obj);
		childRef.current.handleClickOpen();		
	}

	const selectTopic = (obj) => {
		setSearchFlag('Topic');
		setSearchQuery(obj.topicName);
		setSelectedTopicId(obj.topicId);
	}

	const searchBoxQuery = (searchFlag,obj) => {
		setSearchFlag(searchFlag);
		setSearchQuery(obj.title);	
		setSelectedTopicId(0);	
	}

	function startMyTest(){
		if(selectedCourse>=0 && mySelectedCourses[selectedCourse].organisationId!=null && userObj.studentId!=null){

			let axiosHeader = {
				headers:{
					'Content-Type': 'multipart/mixed',
					'studentId': userObj.studentId,
					'token': userObj.token,
				}
			};	
			axios.get(API_URL+'/testcurrentrunning?organisationId='+mySelectedCourses[selectedCourse].organisationId+'&studentId='+userObj.studentId, axiosHeader)
				.then(response => {
					if(response.data.responseTxt=="OK"){
						setCurrentRunningTestTitle(response.data.testName);
						setCurrentRunningTestSession(response.data.testSession);
						childRefStartTest.current.handleClickOpen();
					}else if(response && response.data && response.data.responseTxt==="unauthorized"){
						Cookies.remove('isloggedin');
						window.location.href='logout';						
					}else if(searchQuery){
						window.location.href='testsimulator?testId='+testDetail.mockTestId+'&testType=2';
					}			 				
			}).catch((error) => {
				console.log("AXIOS ERROR: ", error);
			})	
		}	
	}

	function deleteCurrentStartNew(){		
		if(selectedCourse>=0 && mySelectedCourses[selectedCourse].organisationId!=null && userObj.studentId!=null){
			let axiosHeader = {
				headers:{
					'Content-Type': 'multipart/mixed',
					'studentId': userObj.studentId,
					'token': userObj.token,
				}
			};
			axios.get(API_URL+'/testrunningdelete?organisationId='+mySelectedCourses[selectedCourse].organisationId+'&studentId='+userObj.studentId, axiosHeader)
				.then(response => {
					///console.log("Just Checking >> "+response.data);
					if(response && response.data && response.data.responseTxt==="unauthorized"){
						Cookies.remove('isloggedin');
						window.location.href='logout';						
					}			 				
			}).catch((error) => {
				console.log("AXIOS ERROR: ", error);
			})		
			window.location.href='testsimulator?testId='+testDetail.mockTestId+'&testType=2';
		}	
	}	
	function continueCurrentTest(){	
		window.location.href='testsimulator?testSession='+currentRunningTestSession+'&testType=2';
	}

	React.useEffect(() => {
		if(selectedCourse>=0 && mySelectedCourses[selectedCourse].templateId!=null && searchQuery!=null && mySelectedCourses[selectedCourse].topicTest==1){
			setShowProgress(true);
			getApiData(mySelectedCourses[selectedCourse].templateId,searchQuery,selectedTopicId);
		}
	}, [searchQuery, selectedTopicId]); 

	async function getApiData(templateId,topicName,topicId){
		let axiosHeader = {
			headers:{
				'Content-Type': 'multipart/mixed',
				'studentId': userObj.studentId,
				'token': userObj.token,
			}
		};
		axios.get(API_URL+'/topictestlist?templateId='+templateId+'&topicName='+topicName+'&topicId='+topicId, axiosHeader)
			   .then(response => { 
				setShowProgress(false);
			 	///console.log("Just Checking >> "+response.data);
			   if(response.data && response.data.responseTxt==='success'){
				   setTopicTestList(response.data.list);	
			   }else if(response && response.data && response.data.responseTxt==="unauthorized"){
				   Cookies.remove('isloggedin');
				   window.location.href='logout';

			   }				 				
		})
	}

	React.useEffect(() => {		
		if(selectedCourse>=0 && mySelectedCourses[selectedCourse].templateId && mySelectedCourses[selectedCourse].organisationId && mySelectedCourses[selectedCourse].selfTest==1){
			setSelectedTemplateId(mySelectedCourses[selectedCourse].templateId);
		}
	}, [mySelectedCourses,selectedCourse]);
	
		return (
			<div> 
				<MetaTags>
            		<title>Select Topic Test</title>
          		</MetaTags>
				
				<Header />
				<Box style={{marginBottom:100, marginLeft:20, marginRight:20}}>		
				<Box mt={1}>
						<Grid container spacing={2}>
							<Grid item   md={12} xs={12}>
								<h3 className="heading" >Select Topic Test</h3>
							</Grid>
						</Grid>
				</Box>				
				
				<Box mt={1}>
						<Grid container spacing={2}>
							<Grid item   md={5} xs={12} className="selectTopicSelfTest" >
								<SearchInput options={dataObj.topicListTest} label="Search Topic" flag="Topic" toCallParentMethod={searchBoxQuery} />
								<p className="headingTwo" style={{marginTop:10}}>Topic (Browse & Select)</p>								
								<TreeViewComp treeViewData={dataObj.topicTreeTest} toCallParentMethod={selectTopic} />		
							</Grid>
							<Grid item   md={7} xs={12} className="selfTestForm animate-zoom" >

								<div className="btmbdrgry"><span className="headingTwo" >{searchQuery?<span>{searchFlag+': '+searchQuery}</span>:<span style={{fontSize:16,color:'#f50057'}}>Select topic from left side to get list</span>}</span>
								{showProgress?<CircularProgress style={{width:20,height:20}} />:null}
								</div>
								{(topicTestList!=null && topicTestList.length>0)?<span style={{fontSize:16,color:'#f50057'}}>Click below links to start topic test</span>:null}								
								<Box component="form" noValidate >
										<ul className='topictestlist'>
											{
												(topicTestList!=null && topicTestList.length>0)?topicTestList.map((myRow,indextt)=>(
													<li key={'intt'+indextt}><Link onClick={()=>{showDetails(myRow)}} style={{cursor:'pointer', fontWeight:'bold',fontSize:13}} >{myRow.mockTestTitle}</Link></li>
												)):null
											}	
										</ul>
								</Box>
									
							</Grid>

						</Grid>
				</Box>


				</Box>

				<DialogTopicTestDetails toCallStartTest={startMyTest} testDetail={testDetail} ref={childRef} />
				<DialogTestStart toCallDeleteCurrentStartNew={deleteCurrentStartNew} toCallContinueCurrentTest={continueCurrentTest} currentRunningTestTitle={currentRunningTestTitle} ref={childRefStartTest}  />							 

			</div>
		);
 
}