import React from 'react';
import {Box, Grid, Button} from '@material-ui/core';
import Alert from '@mui/material/Alert';
import Stack from '@mui/material/Stack';
import Snackbar from '@mui/material/Snackbar';
import {MetaTags} from 'react-meta-tags';
import InputLabel from '@mui/material/InputLabel';
import TextField from '@mui/material/TextField';
import NativeSelect from '@mui/material/NativeSelect';
import DialogTestStart from '../components/DialogTestStart';
import axios from 'axios';
import Cookies from 'js-cookie';
import { useSelector } from 'react-redux';
import {API_URL} from '../utils/EnvVars';
import TreeViewComp from '../components/TreeViewComp';
import SearchInput from '../components/SearchInput';
import Header from "./HeaderMy";
import '../styles/bizofficer-a.css';

  
  export default function Execute() {
	const dataObj = useSelector(state => state.getData);
	const selectedCourse = useSelector(state => state.selectedCourse);
	const mySelectedCourses = useSelector(state => state.mySelectedCourses);

	const userObj = useSelector(state => state.userDetails);
	const isloggedin = Cookies.get('isloggedin');
	const childRefStartTest = React.useRef();  
	const [questionTypeList, setQuestionTypeList] = React.useState([]);
	const [selectedTopicId, setSelectedTopicId] = React.useState(0);
	const [searchQuery, setSearchQuery] = React.useState(null);
	const [searchFlag, setSearchFlag] = React.useState(null);
	const [availableTotalQuestion, setAvailableTotalQuestion] = React.useState(0);
	const [questionType, setQuestionType] = React.useState("Any");
	const [totalQuestion, setTotalQuestion] = React.useState(30);
	const [totalTime, setTotalTime] = React.useState(30);
	const [marksCorrectAnswer, setMarksCorrectAnswer] = React.useState(1);
	const [marksIncorrectAnswer, setMarksIncorrectAnswer] = React.useState(0);
	const [marksNotAttempted, setMarksNotAttempted] = React.useState(0);
	const [showAlert, setShowAlert] = React.useState(false);
	const [alertMessage, setAlertMessage] = React.useState("");
	const [currentRunningTestTitle, setCurrentRunningTestTitle] = React.useState("");
	const [currentRunningTestSession, setCurrentRunningTestSession] = React.useState("");
	const [selectedTemplateId, setSelectedTemplateId] = React.useState(0);

	// check if logged in
	React.useEffect(() => {
		if(!isloggedin){
			window.location.href='login';
		}
	}, [isloggedin]);

	const vertical='top',horizontal='center';
	
	const selectTopic = (obj) => {
		setSearchFlag('Topic');
		setSearchQuery(obj.topicName);
		setSelectedTopicId(obj.topicId);
		setAvailableTotalQuestion(obj.questionCount);
	}

	const searchBoxQuery = (searchFlag,obj) => {
		setSearchFlag(searchFlag);
		setSearchQuery(obj.title);
		setAvailableTotalQuestion(obj.questionCount);
	}

	function startMyTest(){
		//alert("aaaa");
		if(!searchQuery){
			setShowAlert(true);
			setAlertMessage("Select your topic or keyword from left side.");
		}else{

			let axiosHeader = {
				headers:{
					'Content-Type': 'multipart/mixed',
					'studentId': userObj.studentId,
					'token': userObj.token,
				}
			};

			axios.get(API_URL+'/testcurrentrunning?organisationId='+mySelectedCourses[selectedCourse].organisationId+'&studentId='+userObj.studentId, axiosHeader)
				.then(response => {
					if(response.data.responseTxt==="OK"){
						setCurrentRunningTestTitle(response.data.testName);
						setCurrentRunningTestSession(response.data.testSession);
						childRefStartTest.current.handleClickOpen();
					}else if(response && response.data && response.data.responseTxt==="unauthorized"){
						Cookies.remove('isloggedin');
						window.location.href='logout';
						
					}else if(searchQuery){
						window.location='testsimulator?testId=0&testType=1&questionType='+questionType+'&totalQuestion='+totalQuestion+'&totalTime='+totalTime+'&marksCorrectAnswer='+marksCorrectAnswer+'&marksIncorrectAnswer='+marksIncorrectAnswer+'&marksNotAttempted='+marksNotAttempted+'&searchFlag='+searchFlag+'&searchQuery='+searchQuery+'&topicId='+selectedTopicId;
					
					}else{
						setShowAlert(true);
						setAlertMessage("Select your topic or keyword from left side.");
					}			 				
			}).catch((error) => {
				console.log("AXIOS ERROR: ", error);
			})	
		}	
	}
	function deleteCurrentStartNew(){	
		let axiosHeader = {
			headers:{
				'Content-Type': 'multipart/mixed',
				'studentId': userObj.studentId,
				'token': userObj.token,
			}
		};	
		axios.get(API_URL+'/testrunningdelete?organisationId='+mySelectedCourses[selectedCourse].organisationId+'&studentId='+userObj.studentId, axiosHeader)
			   .then(response => {
			 	///console.log("Just Checking >> "+response.data);
				if(response && response.data && response.data.responseTxt==="unauthorized"){
					Cookies.remove('isloggedin');
					window.location.href='logout';						
				}			 				
		}).catch((error) => {
			console.log("AXIOS ERROR: ", error);
		})		
		window.location='testsimulator?testId=0&testType=1&questionType='+questionType+'&totalQuestion='+totalQuestion+'&totalTime='+totalTime+'&marksCorrectAnswer='+marksCorrectAnswer+'&marksIncorrectAnswer='+marksIncorrectAnswer+'&marksNotAttempted='+marksNotAttempted+'&searchFlag='+searchFlag+'&searchQuery='+searchQuery+'&topicId='+selectedTopicId;
	}	
	function continueCurrentTest(){	
		window.location.href='testsimulator?testSession='+currentRunningTestSession+'&testType=1';
	}

	function hideAlert(){
		setShowAlert(false);
	}

	React.useEffect(() => {		
		if(selectedCourse>=0 && mySelectedCourses[selectedCourse].templateId && mySelectedCourses[selectedCourse].organisationId && mySelectedCourses[selectedCourse].selfTest==1){
			setSelectedTemplateId(mySelectedCourses[selectedCourse].templateId);
			getApiData(mySelectedCourses[selectedCourse].templateId,mySelectedCourses[selectedCourse].organisationId);
		}
	}, [mySelectedCourses,selectedCourse]); 

	async function getApiData(templateId,organisationId){
			let axiosHeader = {
				headers:{
					'Content-Type': 'multipart/mixed',
					'studentId': userObj.studentId,
					'token': userObj.token,
				}
			};
			axios.get(API_URL+'/selftestformoptions?templateId='+templateId+'&organisationId='+organisationId, axiosHeader)
			   .then(response => {
			 	///console.log("Just Checking >> "+response.data);  
				 if(response.data.responseTxt==="success"){
					setQuestionTypeList(response.data.list[0].questionTypeList);
					setTotalQuestion(response.data.list[0].totalQuestions);
					setTotalTime(response.data.list[0].duration);
					setMarksCorrectAnswer(response.data.list[0].marksCorrectAns);
					setMarksIncorrectAnswer(response.data.list[0].marksIncorrectAns);
					setMarksNotAttempted(response.data.list[0].marksNotAnswer);	
					
				}else if(response && response.data && response.data.responseTxt==="unauthorized"){
					Cookies.remove('isloggedin');
					window.location.href='logout';
					
				}

			})
	}
	
		return (
			<div> 
				<MetaTags>
            		<title>Self Assessor</title>
          		</MetaTags>
				
				<Header />
				<Box style={{marginBottom:100, marginLeft:20, marginRight:20}}>		
				<Box mt={1}>
						<Grid container spacing={2}>
							<Grid item   md={12} xs={12}>
								<h3 className="heading" >Self Assessor</h3>
							</Grid>
						</Grid>
				</Box>				
				
				<Box mt={1}>
						<Grid container spacing={2}>
							<Grid item   md={5} xs={12} className="selectTopicSelfTest" >
								<SearchInput options={dataObj.keywordList} label="Search Keyword" flag="Keyword" toCallParentMethod={searchBoxQuery} />
								<SearchInput options={dataObj.topicList} label="Search Topic" flag="Topic" toCallParentMethod={searchBoxQuery} />
								<p className="headingTwo" style={{marginTop:10}}>Topic (Browse & Select)</p>								
								<TreeViewComp treeViewData={dataObj.topicTree} toCallParentMethod={selectTopic} />		
								
							</Grid>
							<Grid item   md={7} xs={12} className="selfTestForm animate-zoom" >

								<div className="btmbdrgry"><span className="headingTwo" >{searchQuery?<span>{searchFlag+': '+searchQuery}</span>:<span>Select topic from left side</span>}</span>{searchQuery?<span className="questionCount">Total Questions: {availableTotalQuestion}</span>:null}</div>

								<Box component="form" noValidate >
											<InputLabel variant="standard" htmlFor="questionTypeId" style={{marginTop:25, marginBottom:-28,fontSize:12}} >
												Question Type
											</InputLabel>
											<NativeSelect
											defaultValue={'Any'}
											inputProps={{
												name: 'questionType',
												id: 'questionTypeId',
											}}
											style={{width:'45%',marginTop:30,marginRight:'4%',fontSize:12}}											
											 onChange={event => setQuestionType(event.target.value)}
											>
												{questionTypeList?questionTypeList.map((myRow,index)=>(
													<option key={'op'+index} value={myRow.typeTitle} >{myRow.typeTitle}</option>
												)):null}											
											</NativeSelect>
										<TextField onChange={event => setTotalQuestion(event.target.value)} value={totalQuestion} style={{width:'45%',marginTop:15,marginRight:'4%'}} type="number" min="10" max="30" label="Total number of question" variant="standard" />
										<TextField onChange={event => setTotalTime(event.target.value)} value={totalTime} style={{width:'45%',marginTop:15,marginRight:'4%'}} type="number" defaultValue="30" min="5" max="30" label="Total time for Test (minute)" variant="standard" />
										<TextField onChange={event => setMarksCorrectAnswer(event.target.value)} value={marksCorrectAnswer} style={{width:'45%',marginTop:15,marginRight:'4%'}} type="number" defaultValue="1" min="1" max="50" step="0.1" label="Marks for correct answer" variant="standard" />
										<TextField onChange={event => setMarksIncorrectAnswer(event.target.value)} value={marksIncorrectAnswer} style={{width:'45%',marginTop:15,marginRight:'4%'}} type="number" defaultValue="0" min="0" max="50" step="0.1" label="Marks for incorrect answer" variant="standard" />
										<TextField onChange={event => setMarksNotAttempted(event.target.value)} value={marksNotAttempted} style={{width:'45%',marginTop:15,marginRight:'4%'}} type="number" defaultValue="0" min="0" max="50" step="0.1" label="Marks for questions not attempted" variant="standard" />

								</Box>
								{(availableTotalQuestion!=null && availableTotalQuestion>0)?	
									<Box mt={2}>
										<Button onClick={() => {startMyTest()}} size="small" variant="contained" color="secondary" >Start Assessment</Button>
									</Box>
  								:null}	
								<Box mt={5} className="selectTopicTxt" >
									Set your fundamentals right. Create Self tests topic wise / keyword wise. Try to answer All Questions with HELP OF Smart Learning/Books/Teacher/Web. Once confident move to  Assessments.		
								</Box>	
							</Grid>

						</Grid>
				</Box>


				</Box>

				<Stack spacing={2} sx={{ width: '100%' }}>
					<Snackbar open={showAlert} autoHideDuration={6000} onClose={hideAlert} anchorOrigin={{vertical,horizontal}}  >
						<Alert onClose={hideAlert} variant="filled" severity="error" sx={{ width: '100%' }}>
							{alertMessage}
						</Alert>
					</Snackbar>
				</Stack>			

				<DialogTestStart toCallDeleteCurrentStartNew={deleteCurrentStartNew} toCallContinueCurrentTest={continueCurrentTest} currentRunningTestTitle={currentRunningTestTitle} ref={childRefStartTest}  />							

			</div>
		);
 
}