import React from 'react';
import {Box, Container, Grid, Link, Button} from '@material-ui/core';
import {MetaTags} from 'react-meta-tags';
import TextField from '@mui/material/TextField';
import TreeViewComp from '../components/TreeViewComp';
import SearchInput from '../components/SearchInput';
import DialogStudyContent from '../components/DialogStudyContent';
import axios from 'axios';
import Cookies from 'js-cookie';
import LinearProgress from '@mui/material/LinearProgress';
import CircularProgress from '@mui/material/CircularProgress';
import { useSelector } from 'react-redux';
import {API_URL} from '../utils/EnvVars';
import Header from "./HeaderMy";
import '../styles/bizofficer-a.css';


const materials = [
	{
		value: '0',
		label: 'All Materials',
	},
	{
	  value: '1',
	  label: 'Video',
	},
	{
		value: '2',
		label: 'PDF',
	},
	{
	  value: '3',
	  label: 'PPT',
	},
	{
		value: '4',
		label: 'Web Text',
	  },
  ];
  
 

  export default function Execute() {	
	const dataObj = useSelector(state => state.getData);
	const userObj = useSelector(state => state.userDetails);
	const selectedCourse = useSelector(state => state.selectedCourse);
	const mySelectedCourses = useSelector(state => state.mySelectedCourses);
 	const isloggedin = Cookies.get('isloggedin');
	const childRef = React.useRef();  
	const [showProgress, setShowProgress] = React.useState(false);
	const [selectedTopicId, setSelectedTopicId] = React.useState(0);
	const [searchQuery, setSearchQuery] = React.useState(null);
	const [searchFlag, setSearchFlag] = React.useState(null);
	const [material, setMaterial] = React.useState(0);
	const [materialsList, setMaterialsList] = React.useState([]);
	const [materialsDisplayList, setMaterialsDisplayList] = React.useState([]);
	const [contentObj, setContentObj] = React.useState("");
	const [selectedTemplateId, setSelectedTemplateId] = React.useState(0);

	// check if logged in
	React.useEffect(() => {
		if(!isloggedin){
			window.location.href='login';
		}
	}, [isloggedin]);

	const handleChangeMaterial = (event) => {
		setMaterial(event.target.value);
			if(event.target.value>0){
				var result = new Array();
				var length = materialsList.length;
				for(var j = 0; j < length; j++)
				{
					if(event.target.value==materialsList[j].contentType)
					{
						result.push(materialsList[j]);
					}
				}
				setMaterialsDisplayList(result);
			}else{
				setMaterialsDisplayList(materialsList);
			}
	  };

	const selectTopic = (obj) => {
		setSearchFlag('Topic');
		setSelectedTopicId(obj.topicId);
		setSearchQuery(obj.topicName);
		////alert("selectTopic Parent >>> " + obj.topicId + " == " + obj.topicName);
	}

	const searchBoxQuery = (searchFlag,obj) => {
		setSearchFlag(searchFlag);
		setSearchQuery(obj.title);
		setSelectedTopicId(0);
		//alert("Seach Parent >>> " + searchFlag + " == " + searchQuery);
	}

	React.useEffect(() => {
		setShowProgress(true);		
		if(searchQuery && searchFlag && searchQuery.length>0 && searchFlag.length>0 && mySelectedCourses!==null && selectedCourse>=0 && mySelectedCourses[selectedCourse].templateId && mySelectedCourses[selectedCourse].smartLearning===1){
			setMaterial(0);
			getApiData(mySelectedCourses[selectedCourse].templateId);
			setSelectedTemplateId(mySelectedCourses[selectedCourse].templateId);
		}else{
			setMaterialsList(dataObj.smartLearning);	
			setMaterialsDisplayList(dataObj.smartLearning);	
			setShowProgress(false);
		}
	}, [mySelectedCourses,selectedCourse,searchFlag,searchQuery]); 

	async function getApiData(templateId){
			let axiosHeader = {
				headers:{
					'Content-Type': 'multipart/mixed',
					'studentId': userObj.studentId,
					'token': userObj.token,
				}
			};

			axios.get(API_URL+'/syllabus?templateId='+templateId+'&searchFlag='+searchFlag+'&topicId='+selectedTopicId+'&searchQuery='+searchQuery, axiosHeader)
			   .then(response => {
				setShowProgress(false); 
				if(response.data && response.data.responseTxt==='success'){
					setMaterialsList(response.data.list);	
				 	setMaterialsDisplayList(response.data.list);
			   	}else if(response && response.data && response.data.responseTxt==="unauthorized"){
				   Cookies.remove('isloggedin');
				   window.location.href='logout';

			   	} 
			})
	}

	function exeContent(obj){ 
		if(obj && obj.contentType===1 || obj && obj.contentType===4){
			setContentObj(obj);
			childRef.current.handleClickOpen();	
		}else{
			if(window.screen.width<480){
				window.open(obj.contentUrl, "_blank");
			}else{
				setContentObj(obj);
				childRef.current.handleClickOpen();
			}
		}	
	}

		return (
			<div> 
				<MetaTags>
            		<title>Study Materials</title>
          		</MetaTags>
				
				<Header />
				{showProgress?<LinearProgress />:null}
				<Box style={{marginBottom:100, marginLeft:20, marginRight:20}}>		

				<Box mt={1}>
						<Grid container spacing={2}>
							<Grid item   md={12} xs={12}>
								<h3 className="heading" >Smart Learning</h3>
							</Grid>
						</Grid>
				</Box>				
				
				<Box mt={1}>
						<Grid container spacing={2}>
							<Grid item   md={5} xs={12} className="selectTopicSelfTest" >
								<SearchInput options={dataObj.keywordList} label="Search Keyword" flag="Keyword" toCallParentMethod={searchBoxQuery} />
								<SearchInput options={dataObj.topicListLearning} label="Search Topic" flag="Topic" toCallParentMethod={searchBoxQuery} />
								<p className="headingTwo" style={{marginTop:10}}>Topic (Browse & Select)</p>
								<TreeViewComp treeViewData={dataObj.topicTreeLearning} toCallParentMethod={selectTopic} />		
							</Grid>
							<Grid item   md={7} xs={12} className="selfTestForm animate-zoom" >
								<Grid container spacing={2} className="btmbdrgry" style={{marginLeft:3}} >
									<Grid xs={8}  >
										<span className="headingTwo" >{searchQuery?<span>{searchFlag+': '+searchQuery}</span>:<span>Select topic from left side</span>}</span>
										{showProgress?<><CircularProgress style={{width:20,height:20}} />Loading...</>:null}
									</Grid>
									<Grid xs={4} >
										<span className="filterSMBox" >
										<TextField
											id="outlined-select-native"
											select
											label="Filter"
											value={material}
											onChange={handleChangeMaterial}
											SelectProps={{
												native: true,
											}}										
										>
											{materials.map((option) => (
												<option key={option.value} value={option.value}>
												{option.label}
												</option>
											))}
										</TextField>
										</span>
									</Grid>
								</Grid>
								
								<Box component="form" noValidate mt={2} >
									<Grid container spacing={2} className="materialBox" >
									{materialsDisplayList.length?materialsDisplayList.map((myRow,index)=>(				
										<Grid onClick={()=>{exeContent(myRow)}} key={'mtldd'+index} item className="smitem" >
											<p>
												{myRow.contentType==1?<i className="fa fa-play-circle"></i>:myRow.contentType==2?<i className="fa fa-file-pdf-o"></i>:myRow.contentType==3?<i className="fa fa-file-powerpoint-o"></i>:<i className="fa fa-globe"></i>}												
											</p>
											<p className="text-line-2">
												{myRow.contentTitle}
											</p>	
										</Grid>
									)):showProgress?<><CircularProgress style={{width:20,height:20}} />Loading...</>:<div style={{color:'#FF0000',fontSize:14,fontWeight:'bold',textAlign:'center',width:'100%'}}>Data not found</div>}	
									</Grid>	
								</Box>	
								
									
							</Grid>

						</Grid>
				</Box>

				

					



				</Box>
				
				<DialogStudyContent contentObj={contentObj} ref={childRef} />

			</div>
		);
 
}