import React from 'react';
import { withStyles } from '@material-ui/core/styles';
import {Grid, Box, Button} from '@material-ui/core';
import Select from '@mui/material/Select';
import MenuItem from '@mui/material/MenuItem';
import { makeStyles } from "@material-ui/core/styles";
import Stack from '@mui/material/Stack';
import Snackbar from '@mui/material/Snackbar';
import Alert from '@mui/material/Alert';
import Dialog from '@material-ui/core/Dialog';
import MuiDialogTitle from '@material-ui/core/DialogTitle';
import MuiDialogContent from '@material-ui/core/DialogContent';
import IconButton from '@material-ui/core/IconButton';
import CloseIcon from '@material-ui/icons/Close';
import Typography from '@material-ui/core/Typography';
import TextField from '@mui/material/TextField';
import Cookies from 'js-cookie';
import axios from 'axios';
import { useSelector } from 'react-redux';
import {API_URL} from '../utils/EnvVars';

const styles = (theme) => ({
  root: {
    margin: 0,
    padding: theme.spacing(2),
  },
  closeButton: {
    position: 'absolute',
    right: theme.spacing(1),
    top: theme.spacing(1),
    color: theme.palette.grey[500],
  },
});

const useStyles = makeStyles({
  paper: {
    fontSize: '12px !important',    
  }
});

var vertical='top',horizontal='center';

const DialogTitle = withStyles(styles)((props) => {
  const { children, classes, onClose, ...other } = props;
  return (
    <MuiDialogTitle disableTypography className={classes.root} {...other}>
      <Typography variant="h6">{children}</Typography>
      {onClose ? (
        <IconButton aria-label="close" className={classes.closeButton} onClick={onClose}>
          <CloseIcon />
        </IconButton>
      ) : null}
    </MuiDialogTitle>
  );
});

const DialogContent = withStyles((theme) => ({
  root: {
    padding: theme.spacing(2),
  },
}))(MuiDialogContent);

const CustomizedDialogs = React.forwardRef((props, ref) => {  
  const classes = useStyles();
  const userObj = useSelector(state => state.teacherDetails);
  const [open, setOpen] = React.useState(false); 
  const [severityAlert, setSeverityAlert] = React.useState("error");
  const [showAlert, setShowAlert] = React.useState(false);
  const [alertMessage, setAlertMessage] = React.useState("");
  
  const [className, setClassName] = React.useState("");  
  const [courseId, setCourseId] = React.useState("noselect");
  const [courseTitle, setCourseTitle] = React.useState("");
  const [organisationId, setOrganisationId] = React.useState(0);
  
  
  React.useImperativeHandle(ref, () => ({
    handleClickOpen(){
      setOpen(true);
    }
  }));
  
  const handleClose = () => {
    setOpen(false);
  };

  function hideAlert(){
		setShowAlert(false);
	}

  function handleCourse(corsId){    
    if(corsId && props.courses.length>0){
      for(let i=0; i<props.courses.length; i++){
        if(props.courses[i].courseId===corsId){
          setCourseId(props.courses[i].courseId);
          setCourseTitle(props.courses[i].courseTitle);
          setOrganisationId(props.courses[i].organisationId);
        }
      }
    }
  }

  

	function saveData(){

    if(!className){        
      setSeverityAlert("error");
      setShowAlert(true);
      setAlertMessage("Enter batch name");	
      return false;
    }

    if(!courseTitle){        
      setSeverityAlert("error");
      setShowAlert(true);
      setAlertMessage("Select course");	
      return false;
    }

		if(className.length>1){ 
			let axiosHeader = {
				headers: {
					'Content-Type': 'multipart/mixed',
					'schoolId': userObj.schoolId,
					'userId': userObj.loginId,
					'token': userObj.token,
				}
			}; 
			const data = new FormData();
      data.append('className', className);
      data.append('courseId', courseId);
      data.append('courseTitle', courseTitle);
      data.append('organisationId', organisationId);
             
			axios.post(API_URL+'/teacher-create-classes', data, axiosHeader)
			.then((response) => {
				///console.log("RESPONSE RECEIVED: ", response.data.responseTxt);
				if(response.data.responseTxt==="success"){
          setClassName("");
          setSeverityAlert("success");
          setOpen(false);
					setShowAlert(true);
					setAlertMessage("Batch has been created.");
          window.location.reload();	
					return false;
        }else if(response.data.responseTxt==="AlreadyExistsError"){
            setSeverityAlert("error");
            setOpen(true);
            setShowAlert(true);
            setAlertMessage("Batch name must be unique. It is created earlier.");
            return false;  			

        }else if(response.data.responseTxt==="unauthorized"){
            Cookies.remove('isteachloggedin');
            window.location.href='login';
  
				}else{
          setSeverityAlert("error");
					setShowAlert(true);
					setAlertMessage("Batch could not be saved.");			
					return false;
				}
			})
			.catch((error) => {
          setSeverityAlert("error");
					setShowAlert(true);
					setAlertMessage(""+error);			
					return false;
			})	
		}		
	}
  
  return (
    <>
      <Dialog fullWidth maxWidth="md" onClose={handleClose} aria-labelledby="customized-dialog-title" open={open}>
        <DialogTitle style={{marginBottom:'-30px'}} onClose={handleClose}></DialogTitle>
          <DialogContent style={{height:'88vh'}}>
            <Grid item   md={12} xs={12} className="test-instructions" >
                  <div className="btmbdrgry"><h3>New Batch</h3></div>
                  <p>
                      <table style={{backgroundColor:'#000000',width:'100%' }} cellSpacing="1" cellPadding="3" >
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Batch Name</td>
                            <td style={{textAlign:'center'}} >
                            <TextField onChange={event => setClassName(event.target.value)} value={className} sx={{width:'99%',fontSize: 10}} variant="standard" />
                            </td>                            
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Course</td>
                            <td style={{textAlign:'center'}} >
                              <Select 
                                style={{width:'100%'}}
                                classes={{ paper: classes.paper }}
                                labelId="select-class-label"
                                id="select-class"
                                value={courseId} 								
                                onChange={event => handleCourse(event.target.value)}
                                variant="standard"
                              >
                                  <MenuItem value="noselect">Select Course</MenuItem>
                                  {props.courses?props.courses.map((myRow,mykey)=>(
                                    <MenuItem key={'tchr'+mykey} value={myRow.courseId}>{myRow.courseTitle}</MenuItem>
                                  )):null}
                              </Select>
                            </td>                            
                        </tr>

                      </table>

                      <Box mt={2}>
                          <Button onClick={() => {handleClose()}} style={{marginRight:12}} size="small" variant="outlined" >Cancel</Button>
					    	          <Button onClick={() => {saveData()}} style={{marginRight:12}} size="small" variant="contained" style={{backgroundColor:'#008000',color:'#FFF',marginRight:10}} >Save</Button>
								      </Box>

                  </p>
            </Grid>
          </DialogContent>
      </Dialog>
      
        <Stack spacing={2} sx={{ width: '100%' }}>
					<Snackbar open={showAlert} autoHideDuration={6000} onClose={hideAlert} anchorOrigin={{vertical,horizontal}}  >
						<Alert onClose={hideAlert} variant="filled" severity={severityAlert} sx={{ width: '100%' }}>
							{alertMessage}
						</Alert>
					</Snackbar>
				</Stack>

    </>
  );

});

export default CustomizedDialogs;