import React from 'react';
import {Box, Grid} from '@material-ui/core';
import axios from 'axios';
import Button from '@mui/material/Button';
import Dialog from '@mui/material/Dialog';
import DialogActions from '@mui/material/DialogActions';
import DialogContent from '@mui/material/DialogContent';
import DialogContentText from '@mui/material/DialogContentText';
import DialogTitle from '@mui/material/DialogTitle';
import DialogStudyContent from './DialogStudyContent';
import CircularProgress from '@mui/material/CircularProgress';
import { useSelector } from 'react-redux';
import {API_URL} from '../utils/EnvVars';
import '../styles/bizofficer-a.css';

function DialogHelp(props, ref) {  
  const [open, setOpen] = React.useState(false);
  const userObj = useSelector(state => state.userDetails);
  const openHelpContentRef = React.useRef();
  const [showProgress, setShowProgress] = React.useState(false);
	///const [materialsList, setMaterialsList] = React.useState([]);
	const [materialsDisplayList, setMaterialsDisplayList] = React.useState([]);
	const [contentUrl, setContentUrl] = React.useState("");

  React.useImperativeHandle(ref, () => ({
    handleClickOpen(){
      setOpen(true);
    }
  }));
  
  const handleClose = () => {
    setOpen(false);
    props.toCallStartTimer();
  };

  function googleSearch(){
		setContentUrl("https://www.google.com/search?igu=1");
		openHelpContentRef.current.handleClickOpen();		
	}

  function exeContent(contentUrl){
		setContentUrl(contentUrl);
		openHelpContentRef.current.handleClickOpen();		
	}

  const descriptionElementRef = React.useRef(null);
  React.useEffect(() => {
    if (open) {
      const { current: descriptionElement } = descriptionElementRef;
      if (descriptionElement !== null) {
        descriptionElement.focus();
      }
    }
  }, [open]);

  React.useEffect(() => {
    setShowProgress(true);
		const interval = setInterval(() => {
			if(userObj.templateId){
				getApiData(userObj.templateId,props.currentQuestionObj.topicId);
				clearInterval(interval);
			}
		 }, 3000);
		 return () => clearInterval(interval);
	}, [userObj,props.currentQuestionObj.topicId]); 

	async function getApiData(templateId,topicId){
			axios.get(API_URL+'/syllabus?templateId='+templateId+'&topicId='+topicId)
			   .then(response => {
				if(response.data!=null){ 
				 	setMaterialsDisplayList(response.data);	
          setShowProgress(false); 
				} 		 				
			})
	}


  return (
    <>      
      <Dialog
        open={open}
        onClose={handleClose}
        scroll={'paper'}
        key={'help123'}
        aria-labelledby="scroll-dialog-title"
        aria-describedby="scroll-dialog-description"
        fullWidth 
        maxWidth="md"
      >
        <DialogTitle id="scroll-dialog-title">
          Help {showProgress?<><CircularProgress style={{width:20,height:20}} />Loading...</>:null}
        </DialogTitle>
        <DialogContent dividers={'paper'}>
          <DialogContentText
            id="scroll-dialog-description"
            ref={descriptionElementRef}
            tabIndex={-1}
          >
								<Box component="form" noValidate mt={2} >
									<Grid container spacing={2} className="materialBox" style={{minHeight:250}} >
                    {materialsDisplayList.length?materialsDisplayList.map((myRow,index)=>(				
                      <Grid onClick={()=>{exeContent(myRow.contentUrl)}} key={'mtldd'+index} item className="smitem" >
                        <p>
                          {myRow.contentType==1?<i className="fa fa-play-circle"></i>:myRow.contentType==2?<i className="fa fa-file-pdf-o"></i>:myRow.contentType==3?<i className="fa fa-file-powerpoint-o"></i>:<i className="fa fa-globe"></i>}												
                        </p>
                        <p className="text-line-2">
                          {myRow.contentTitle}
                        </p>	
                      </Grid>
                    )):showProgress?<><CircularProgress style={{width:20,height:20}} />Loading...</>:<div style={{color:'#FF0000',fontSize:14,fontWeight:'bold',textAlign:'center',width:'100%',height:250}}>Data not found</div>}	
                </Grid>	
							</Box>
          </DialogContentText>
        </DialogContent>
        <DialogActions> 
        <Button onClick={()=>{googleSearch()}}><i class="fa fa-google" aria-hidden="true"></i>oogle</Button>
          <Button onClick={handleClose}>Cancel</Button>
        </DialogActions>
      </Dialog>
      <DialogStudyContent contentUrl={contentUrl} ref={openHelpContentRef} />
    </>
  );
}

export default React.forwardRef(DialogHelp);