import React from 'react';
import { withStyles } from '@material-ui/core/styles';
import {Grid, Box, Button} from '@material-ui/core';
import MenuItem from '@mui/material/MenuItem';
import Select from '@mui/material/Select';
import {FormControl, DialogContentText, DialogActions} from '@mui/material';
import Stack from '@mui/material/Stack';
import Snackbar from '@mui/material/Snackbar';
import Alert from '@mui/material/Alert';
import Dialog from '@material-ui/core/Dialog';
import MuiDialogTitle from '@material-ui/core/DialogTitle';
import MuiDialogContent from '@material-ui/core/DialogContent';
import IconButton from '@material-ui/core/IconButton';
import CloseIcon from '@material-ui/icons/Close';
import Typography from '@material-ui/core/Typography';
import TextField from '@mui/material/TextField';
import DateTimePicker from '@mui/lab/DateTimePicker';
import AdapterDateFns from '@mui/lab/AdapterDateFns';
import LocalizationProvider from '@mui/lab/LocalizationProvider';
import moment from 'moment';
import axios from 'axios';
import { useSelector } from 'react-redux';
import {API_URL} from '../utils/EnvVars';

const styles = (theme) => ({
  root: {
    margin: 0,
    padding: theme.spacing(2),
  },
  closeButton: {
    position: 'absolute',
    right: theme.spacing(1),
    top: theme.spacing(1),
    color: theme.palette.grey[500],
  },
});

var vertical='top',horizontal='center';

const DialogTitle = withStyles(styles)((props) => {
  const { children, classes, onClose, ...other } = props;
  return (
    <MuiDialogTitle disableTypography className={classes.root} {...other}>
      <Typography variant="h6">{children}</Typography>
      {onClose ? (
        <IconButton aria-label="close" className={classes.closeButton} onClick={onClose}>
          <CloseIcon />
        </IconButton>
      ) : null}
    </MuiDialogTitle>
  );
});

const DialogContent = withStyles((theme) => ({
  root: {
    padding: theme.spacing(2),
  },
}))(MuiDialogContent);

const CustomizedDialogs = React.forwardRef((props, ref) => {  
  const userObj = useSelector(state => state.teacherDetails);
  const [open, setOpen] = React.useState(false); 
  const [severityAlert, setSeverityAlert] = React.useState("error");
  const [showAlert, setShowAlert] = React.useState(false);
  const [alertMessage, setAlertMessage] = React.useState("");
  const [deleteDialogShow, setDeleteDialogShow] = React.useState(false);
  
  const [status, setStatus] = React.useState("Active");
  const [note, setNote] = React.useState("");
  const [duration, setDuration] = React.useState(60);
  const [dateTimePicker, setDateTimePicker] = React.useState(new Date());
  const [subject, setSubject] = React.useState("noselect");
  const [className, setClassName] = React.useState("noselect");

  
  React.useImperativeHandle(ref, () => ({
    handleClickOpen(){
      setOpen(true);
    }
  }));
  
  const handleClose = () => {
    setOpen(false);
  };

  const dateTimePickerChange = (dateTimePicker) => {
    setDateTimePicker(dateTimePicker);
  };

  function hideAlert(){
		setShowAlert(false);
	}

  React.useEffect(() => {		
    if(props.dataDetail && props.dataDetail!==null){
      setClassName(props.dataDetail.className);
      setSubject(props.dataDetail.subject);
      setDuration(props.dataDetail.duration);
      setNote(props.dataDetail.note);
      setStatus(props.dataDetail.status);

      if(props.dataDetail.startTime!=null){
        setDateTimePicker(new Date(props.dataDetail.startTime))
      }
    }else{
      setClassName("noselect");
      setSubject("noselect");
      setDuration(60);
      setNote("");
      setStatus("Active");
    }

	}, [props.dataDetail]);

  function deleteData(){
		axios.get(API_URL+'/teacher-delete-liveclasses?id='+props.dataDetail.autoId+'&schoolId='+userObj.schoolId+'&loginId='+userObj.loginId+'&token='+userObj.token)
			   .then(response => {
            if(response.data.responseTxt==="success"){
              setSeverityAlert("success");
              setOpen(false);
              setShowAlert(true);
              setAlertMessage("Live class has been deleted.");
              window.location.reload();	
            }else{
              setSeverityAlert("error");
              setShowAlert(true);
              setAlertMessage("Live class could not be deleted.");			
              return false;
            }			 				
		}).catch((error) => {
			console.log("ERROR: ", error);
		})		
  }

	function saveData(){

    if(!className){
      setSeverityAlert("error");
      setOpen(true);
      setShowAlert(true);
      setAlertMessage("Select class");
      return false;  					
    }
    if(!subject){
      setSeverityAlert("error");
      setOpen(true);
      setShowAlert(true);
      setAlertMessage("Select subject");
      return false;  					
    }
    if(!duration || duration===0){
      setSeverityAlert("error");
      setOpen(true);
      setShowAlert(true);
      setAlertMessage("Enter duration");
      return false;  					
    }

		if(className && subject){
			let axiosHeader = {
				headers: {
					'Content-Type': 'multipart/mixed',
				}
			}; 
			const data = new FormData();
      if(props.dataDetail && props.dataDetail.autoId){
			  data.append('id', props.dataDetail.autoId);
      }
      data.append('token', userObj.token);
			data.append('schoolId', userObj.schoolId);
      data.append('loginId', userObj.loginId);
      data.append('className', className);
      data.append('subject', subject);
      if(dateTimePicker){
        data.append('startTime', moment(dateTimePicker).format('YYYY-MM-DD HH:mm:ss'));
      }
      data.append('duration', duration);
      data.append('note', note);

      if(status==='Active'){
        data.append('status', 1);
      }else{
        data.append('status', 0);
      }

			axios.post(API_URL+'/teacher-save-liveclasses', data, axiosHeader)
			.then((response) => {
				console.log("RESPONSE RECEIVED: ", response);
				if(response.data.responseTxt==="success"){
          setSeverityAlert("success");
          setOpen(false);
					setShowAlert(true);
					setAlertMessage("Live class has been saved.");
          if(props.dataDetail.autoId!=null && props.dataDetail.autoId>0){
            window.location.reload();	
          }else{
            window.location.href='liveclasses';
          }		
					return false;
        }else if(response.data.responseTxt==="AlreadyExistsError"){
            setSeverityAlert("error");
            setOpen(true);
            setShowAlert(true);
            setAlertMessage("One live class can be scheduled at same date and time.");
            return false;  					
				}else{
          setSeverityAlert("error");
					setShowAlert(true);
					setAlertMessage("Live class could not be saved.");			
					return false;
				}
			})
			.catch((error) => {
				console.log("AXIOS ERROR: ", error);
			})	
		}		
	}

  function deleteDialogHide(){
		setDeleteDialogShow(false);
	}
  
  return (
    <>
      <Dialog fullWidth maxWidth="md" onClose={handleClose} aria-labelledby="customized-dialog-title" open={open}>
        <DialogTitle style={{marginBottom:'-30px'}} onClose={handleClose}></DialogTitle>
          <DialogContent style={{height:'88vh'}}>
            <Grid item   md={12} xs={12} className="test-instructions" >
                  <div className="btmbdrgry"><h3>{(props.dataDetail && props.dataDetail.autoId)?<>Edit</>:<>Create</>}</h3></div>
                  <p>
                      <table style={{backgroundColor:'#000000',width:'100%' }} cellSpacing="1" cellPadding="3" >
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Class</td>
                            <td>
                            <FormControl style={{width:'100%'}} >
                                <Select
                                  labelId="select-subject-label"
                                  id="select-subject"
                                  value={className}								
                                  onChange={event => setClassName(event.target.value)}
                                >
                                  <MenuItem value="noselect" >Select Class</MenuItem>
                                  {(userObj!=null && userObj.teacherAssociation)?userObj.teacherAssociation.map((myObj,index)=>(
                                    <MenuItem key={'cls'+index} value={myObj.className}>{myObj.className}</MenuItem>
                                  )):null}
                                </Select>
                            </FormControl>
                            </td>                            
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Subject</td>
                            <td>
                            <FormControl style={{width:'100%'}} >
                                <Select
                                  labelId="select-subject-label"
                                  id="select-subject"
                                  value={subject}								
                                  onChange={event => setSubject(event.target.value)}
                                >
                                  <MenuItem value="noselect" >Select Subject</MenuItem>
                                  {(userObj && userObj.subjectList)?userObj.subjectList.map((mySubject,index)=>(
                                    <MenuItem key={'cls'+index} value={mySubject}>{mySubject}</MenuItem>
                                  )):null}
                                </Select>
                            </FormControl>
                            </td>                            
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Start Date/Time</td>
                            <td style={{textAlign:'center'}} >
                              <LocalizationProvider dateAdapter={AdapterDateFns}>
                                <Stack spacing={1}>
                                    <DateTimePicker                                                                             
                                      value={dateTimePicker}
                                      onChange={dateTimePickerChange}
                                      renderInput={(params) => <TextField {...params} />}
                                      minDate={new Date()}
                                      inputFormat="dd-MM-yyyy HH:mm"
                                    />                                  
                                </Stack>
                              </LocalizationProvider>
                            </td>                            
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Duration (Minutes)</td>
                            <td style={{textAlign:'center'}} >
                            <TextField onChange={event => setDuration(event.target.value)} value={duration} style={{width:'99%'}} type="number" variant="standard" />
                            </td>
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                          <td>Note</td>
                          <td style={{textAlign:'center'}} >
                          <TextField onChange={event => setNote(event.target.value)} value={note} style={{width:'99%'}} variant="standard" />
                          </td>
                        </tr>                       
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                          <td>Status</td>
                          <td>
                          <FormControl style={{width:'100%'}} >
                                <Select
                                  labelId="select-status-label"
                                  id="select-status"
                                  value={status}								
                                  onChange={event => setStatus(event.target.value)}
                                >
                                    <MenuItem value="Active" >Active</MenuItem>
                                    <MenuItem value="Not Active" >Not Active</MenuItem>
                                </Select>
                            </FormControl>
                          </td>
                        </tr>

                      </table>

                      <Box mt={2}>
                          <Button onClick={() => {handleClose()}} style={{marginRight:12}} size="small" variant="outlined" >Cancel</Button>
					    	          <Button onClick={() => {saveData()}} size="small" variant="contained" style={{backgroundColor:'#008000',color:'#FFF',marginRight:10}} >Save</Button>
                          {(props.dataDetail && props.dataDetail.autoId>0)?<Button onClick={() => {setDeleteDialogShow(true)}} style={{marginRight:12}} size="small" variant="contained" color="secondary" >Delete</Button>:null}
								      </Box>

                  </p>
            </Grid>
          </DialogContent>
      </Dialog>
      
        <Stack spacing={2} sx={{ width: '100%' }}>
					<Snackbar open={showAlert} autoHideDuration={6000} onClose={hideAlert} anchorOrigin={{vertical,horizontal}}  >
						<Alert onClose={hideAlert} variant="filled" severity={severityAlert} sx={{ width: '100%' }}>
							{alertMessage}
						</Alert>
					</Snackbar>
				</Stack>

        <Dialog
					open={deleteDialogShow}
					onClose={deleteDialogHide}
					aria-labelledby="alert-dialog-section-title"
					aria-describedby="alert-dialog-section-description"
				>
					<DialogTitle id="alert-dialog-section-title">
						Alert
					</DialogTitle>
					<DialogContent>
					<DialogContentText id="alert-dialog-section-description">
						Are you sure, You want to delete live class.
					</DialogContentText>
					</DialogContent>
					<DialogActions>
					<Button variant="outlined" size="small" onClick={()=>{deleteDialogHide()}}>Don't Delete</Button>
					<Button variant="contained" size="small" color="secondary" onClick={()=>{deleteData()}} autoFocus>Yes, Delete</Button>
					</DialogActions>
				</Dialog>

    </>
  );

});

export default CustomizedDialogs;