import React from 'react';
import { withStyles } from '@material-ui/core/styles';
import {Grid, Box, Button} from '@material-ui/core';
// import MenuItem from '@mui/material/MenuItem';
// import Select from '@mui/material/Select';
// import InputLabel from '@mui/material/InputLabel';
// import FormControl from '@mui/material/FormControl';
import Stack from '@mui/material/Stack';
import Snackbar from '@mui/material/Snackbar';
import Alert from '@mui/material/Alert';
import Dialog from '@material-ui/core/Dialog';
import MuiDialogTitle from '@material-ui/core/DialogTitle';
import MuiDialogContent from '@material-ui/core/DialogContent';
import IconButton from '@material-ui/core/IconButton';
import CloseIcon from '@material-ui/icons/Close';
import Typography from '@material-ui/core/Typography';
import TextField from '@mui/material/TextField';
import DateTimePicker from '@mui/lab/DateTimePicker';
import AdapterDateFns from '@mui/lab/AdapterDateFns';
import LocalizationProvider from '@mui/lab/LocalizationProvider';
import moment from 'moment';
import axios from 'axios';
import { useSelector } from 'react-redux';
import {API_URL} from '../utils/EnvVars';

const styles = (theme) => ({
  root: {
    margin: 0,
    padding: theme.spacing(2),
  },
  closeButton: {
    position: 'absolute',
    right: theme.spacing(1),
    top: theme.spacing(1),
    color: theme.palette.grey[500],
  },
});

var vertical='top',horizontal='center';

const DialogTitle = withStyles(styles)((props) => {
  const { children, classes, onClose, ...other } = props;
  return (
    <MuiDialogTitle disableTypography className={classes.root} {...other}>
      <Typography variant="h6">{children}</Typography>
      {onClose ? (
        <IconButton aria-label="close" className={classes.closeButton} onClick={onClose}>
          <CloseIcon />
        </IconButton>
      ) : null}
    </MuiDialogTitle>
  );
});

const DialogContent = withStyles((theme) => ({
  root: {
    padding: theme.spacing(2),
  },
}))(MuiDialogContent);

const CustomizedDialogs = React.forwardRef((props, ref) => {  
  const userObj = useSelector(state => state.teacherDetails);
  const [open, setOpen] = React.useState(false); 
  const [severityAlert, setSeverityAlert] = React.useState("error");
  const [showAlert, setShowAlert] = React.useState(false);
  const [alertMessage, setAlertMessage] = React.useState("");
  const [testTitle, setTestTitle] = React.useState("");
  const [totalTime, setTotalTime] = React.useState(0);
  const [className, setClassName] = React.useState("");
  const [dateTimePicker, setDateTimePicker] = React.useState(new Date());
  const [markCorrectAns, setMarkCorrectAns] = React.useState(0);
  const [markIncorrectAns, setMarkIncorrectAns] = React.useState(0);
  const [markNotAttempt, setMarkNotAttempt] = React.useState(0);
  const [totalMarks, setTotalMarks] = React.useState(0);
  const [totalQuestions, setTotalQuestions] = React.useState(0);
  const [subject, setSubject] = React.useState("");
  
  
  React.useImperativeHandle(ref, () => ({
    handleClickOpen(){
      setOpen(true);
    }
  }));
  
  const handleClose = () => {
    setOpen(false);
  };

  const dateTimePickerChange = (dateTimePicker) => {
    setDateTimePicker(dateTimePicker);
  };

  function hideAlert(){
		setShowAlert(false);
	}

  React.useEffect(() => {		
		setTestTitle(props.testDetail.testTitle);
    setTotalTime(props.testDetail.totalTime);
    if(props.testDetail.className!=null){
      setClassName(props.testDetail.className);
      setSubject(props.testDetail.subject);
    }
    if(props.testDetail.testDateTime!=null){
      setDateTimePicker(new Date(props.testDetail.testDateTime))
    }
    setMarkCorrectAns(props.testDetail.markCorrectAns);
    setMarkIncorrectAns(props.testDetail.markIncorrectAns);
    setMarkNotAttempt(props.testDetail.markNotAttempt);
    setTotalMarks(props.testDetail.totalMark);
    setTotalQuestions(props.testDetail.totalQuestion);

	}, [props.testDetail]);

  function deleteData(){
		axios.get(API_URL+'/teacherscheduledtestdelete?id='+props.testDetail.autoId+'&topicTestId='+props.testDetail.topicTestId)
			   .then(response => {
            if(response.data.responseTxt==="OK"){
              setSeverityAlert("success");
              setOpen(false);
              setShowAlert(true);
              setAlertMessage("Test has been deleted.");
              window.location.reload();	
            }else{
              setSeverityAlert("error");
              setShowAlert(true);
              setAlertMessage("Test could not be deleted.");			
              return false;
            }			 				
		}).catch((error) => {
			console.log("ERROR: ", error);
		})		
  }

	function saveData(){
		if(testTitle && totalTime){
			let axiosHeader = {
				headers: {
					'Content-Type': 'multipart/mixed',
				}
			}; 
			const data = new FormData();
			data.append('id', props.testDetail.autoId);
      data.append('topicTestId', props.testDetail.topicTestId);
      data.append('topicId', props.testDetail.topicId);
      data.append('loginId', props.testDetail.loginId);
      data.append('testTitle', testTitle);
      data.append('schoolId', userObj.schoolId);
      data.append('schoolName', userObj.schoolName);			
			data.append('className', className);
      data.append('subject', subject);
      data.append('totalTime', totalTime);
      data.append('testDateTime', moment(dateTimePicker).format('YYYY-MM-DD HH:mm:ss'));
      data.append('markCorrectAns', markCorrectAns);
      data.append('markIncorrectAns', markIncorrectAns);
      data.append('markNotAttempt', markNotAttempt);
      data.append('questionType', props.testDetail.questionType);
      data.append('totalQuestion', props.testDetail.totalQuestion);
			axios.post(API_URL+'/teacherscheduledtestsave', data, axiosHeader)
			.then((response) => {
				console.log("RESPONSE RECEIVED: ", response);
				if(response.data.responseTxt==="OK"){
          setSeverityAlert("success");
          setOpen(false);
					setShowAlert(true);
					setAlertMessage("Test details has been saved.");
          if(props.testDetail.autoId!=null && props.testDetail.autoId>0){
            window.location.reload();	
          }else{
            window.location.href='scheduledtest';
          }		
					return false;
        }else if(response.data.responseTxt==="AlreadyExistsError"){
            setSeverityAlert("error");
            setOpen(true);
            setShowAlert(true);
            setAlertMessage("One test can be scheduled at same date and time.");
            return false;  					
				}else{
          setSeverityAlert("error");
					setShowAlert(true);
					setAlertMessage("Test details could not be saved.");			
					return false;
				}
			})
			.catch((error) => {
				console.log("AXIOS ERROR: ", error);
			})	
		}		
	}

  function handleMarkCorrectAns(val){ 
    setMarkCorrectAns(val);
    setTotalMarks(val*totalQuestions);
  }
  
  return (
    <>
      <Dialog fullWidth maxWidth="md" onClose={handleClose} aria-labelledby="customized-dialog-title" open={open}>
        <DialogTitle style={{marginBottom:'-30px'}} onClose={handleClose}></DialogTitle>
          <DialogContent style={{height:'88vh'}}>
            <Grid item   md={12} xs={12} className="test-instructions" >
                  <div className="btmbdrgry"><h3>{props.testDetail.testTitle}</h3></div>
                  <p>
                      <table style={{backgroundColor:'#000000',width:'100%' }} cellSpacing="1" cellPadding="3" >
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Date/Time</td>
                            <td style={{textAlign:'center'}} >
                              <LocalizationProvider dateAdapter={AdapterDateFns}>
                                <Stack spacing={1}>
                                    <DateTimePicker                                                                             
                                      value={dateTimePicker}
                                      onChange={dateTimePickerChange}
                                      renderInput={(params) => <TextField {...params} />}
                                      minDate={new Date()}
                                      inputFormat="dd-MM-yyyy HH:mm"
                                    />                                  
                                </Stack>
                              </LocalizationProvider>
                            </td>                            
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Title</td>
                            <td style={{textAlign:'center'}} >
                            <TextField onChange={event => setTestTitle(event.target.value)} value={testTitle} sx={{width:'99%',fontSize: 10}} variant="standard" />
                            </td>                            
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Total time for Test(minutes)</td>
                            <td style={{textAlign:'center'}} >
                            <TextField onChange={event => setTotalTime(event.target.value)} value={totalTime} style={{width:'99%'}} variant="standard" />
                            </td>
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                          <td>Correct Marks</td>
                          <td style={{textAlign:'center'}} >
                          <TextField onChange={event => handleMarkCorrectAns(event.target.value)} value={markCorrectAns} style={{width:'99%'}} type="number" variant="standard" />
                          </td>                            
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                          <td>Wrong Marks</td>
                          <td style={{textAlign:'center'}} >
                          <TextField onChange={event => setMarkIncorrectAns(event.target.value)} value={markIncorrectAns} style={{width:'99%'}} type="number" variant="standard" />
                          </td>
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                          <td>Not Answered Marks</td>
                          <td style={{textAlign:'center'}} >
                          <TextField onChange={event => setMarkNotAttempt(event.target.value)} value={markNotAttempt} style={{width:'99%'}} type="number" variant="standard" />
                          </td>
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Total Questions</td>
                            <td>{props.testDetail.totalQuestion}</td>                            
                        </tr>
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Question Type</td>
                            <td>{props.testDetail.questionType}</td>
                        </tr>                        
                        <tr style={{backgroundColor:'#FFFFFF'}} >
                            <td>Total Marks</td>
                            <td>{totalMarks}</td>
                        </tr>                        
                      </table>

                      <Box mt={2}>
                          <Button onClick={() => {handleClose()}} style={{marginRight:12}} size="small" variant="outlined" >Cancel</Button>
					    	          <Button onClick={() => {saveData()}} size="small" variant="contained" style={{backgroundColor:'#008000',color:'#FFF',marginRight:10}} >Save</Button>
					    	          <Button onClick={()=> window.location.href="classtestview?testId="+props.testDetail.topicTestId+"&testType=2&from=scheduledtest"} style={{marginRight:12}} size="small" variant="contained" color="primary" >View Test</Button>
                          {(props.testDetail.autoId!=null && props.testDetail.autoId>0)?<Button onClick={() => {deleteData()}} style={{marginRight:12}} size="small" variant="contained" color="secondary" >Delete Test</Button>:null}
								      </Box>

                  </p>
            </Grid>
          </DialogContent>
      </Dialog>
      
        <Stack spacing={2} sx={{ width: '100%' }}>
					<Snackbar open={showAlert} autoHideDuration={6000} onClose={hideAlert} anchorOrigin={{vertical,horizontal}}  >
						<Alert onClose={hideAlert} variant="filled" severity={severityAlert} sx={{ width: '100%' }}>
							{alertMessage}
						</Alert>
					</Snackbar>
				</Stack>

    </>
  );

});

export default CustomizedDialogs;