import React from 'react';
import clsx from 'clsx';
import { makeStyles } from '@material-ui/core/styles';
import SwipeableDrawer from '@material-ui/core/SwipeableDrawer';
import Button from '@material-ui/core/Button';
import Divider from '@material-ui/core/Divider';
import Collapse from '@mui/material/Collapse';
import List from '@mui/material/List';
import ListItemButton from '@mui/material/ListItemButton';
import ListItem from '@material-ui/core/ListItem';
import ListItemIcon from '@material-ui/core/ListItemIcon';
import ListItemText from '@material-ui/core/ListItemText';
import MenuIcon from '@material-ui/icons/Menu';
import ArrowRightIcon from '@mui/icons-material/ArrowRight';
import ExpandLess from '@mui/icons-material/ExpandLess';
import ExpandMore from '@mui/icons-material/ExpandMore';
import AssessmentIcon from '@material-ui/icons/Assessment';
import AssignmentIcon from '@material-ui/icons/Assignment';
import DescriptionIcon from '@mui/icons-material/Description';
import LogoutIcon from '@mui/icons-material/Logout';
import AccountCircleIcon from '@mui/icons-material/AccountCircle';
import LiveTvIcon from '@mui/icons-material/LiveTv';
import Avatar from '@mui/material/Avatar';
import Stack from '@mui/material/Stack';
import { useSelector } from 'react-redux';
import Cookies from 'js-cookie';

const useStyles = makeStyles({
  list: {
    width: 250,
  },
  fullList: {
    width: 'auto',
  },
});

export default function SwipeableTemporaryDrawer() {
  const userObj = useSelector(state => state.teacherDetails);
  const roleloggedin = Cookies.get('roleteachloggedin');
  const [openSubList, setOpenSubList] = React.useState(true);
  const [openReports, setOpenReports] = React.useState(true);

  const classes = useStyles();
  const [state, setState] = React.useState({
    top: false,
    left: false,
    bottom: false,
    right: false,
  });

  function handleClickSubList(){    
    setOpenSubList(!openSubList);
  };

  function handleClickReports(){    
    setOpenReports(!openReports);
  };

  const toggleDrawer = (anchor, open) => (event) => {
    if (event && event.type === 'keydown' && (event.key === 'Tab' || event.key === 'Shift')) {
      return;
    }
    setState({ ...state, [anchor]: open });
  };

  function goToLocation(url){
    window.location.href=url;
  }
  // function goToDashboard(){
  //   if(roleloggedin=='PRINCIPAL' || roleloggedin=='CHAIRPERSON'){
  //     window.location.href='maindashboard';
  //   }else{
  //     window.location.href='dashboard';
  //   }    
  // }
  function logout(){
    Cookies.remove('isteachloggedin');
    Cookies.remove('roleteachloggedin');
    Cookies.remove('schoolidloggedin');
    window.location.href='login';
  }


  const list = (anchor) => (
    <div
      className={clsx(classes.list, {
        [classes.fullList]: anchor === 'top' || anchor === 'bottom',
      })}
      role="presentation"      
    >
      <Stack direction="row" spacing={2} style={{margin: 20}} >
        <Avatar onClick={()=>{goToLocation('profile')}} style={{cursor:'pointer'}} alt={userObj.teacherName} src="/static/images/avatar/1.jpg" sx={{ width: 29, height: 29, marginRight:1 }} />
        <span onClick={()=>{goToLocation('profile')}} style={{cursor:'pointer', marginTop: 1, fontSize: 14}} >{userObj.teacherName}<br/>{userObj.schoolName}</span>
      </Stack>
      <Divider />
      <ListItem button onClick={()=>{goToLocation('selectclass')}} >
            <ListItemIcon><AssessmentIcon /></ListItemIcon>
            <ListItemText primary="Select Class" sx={{ fontSize: 12 }} />
      </ListItem>
      <ListItem button onClick={()=>{goToLocation('dashboard')}} >
            <ListItemIcon><AssessmentIcon /></ListItemIcon>
            <ListItemText primary="Dashboard" sx={{ fontSize: 12 }} />
      </ListItem>
      
      {roleloggedin==='TEACHER'?<>
      <ListItemButton onClick={()=>{handleClickSubList();toggleDrawer('left', true)}} >
        <ListItemIcon>
          <AssignmentIcon />
        </ListItemIcon>
        <ListItemText primary="Class Test" />
        {openSubList ? <ExpandLess /> : <ExpandMore />}
      </ListItemButton>
      <Collapse in={openSubList} timeout="auto" unmountOnExit>
        <List component="div" disablePadding>
          <ListItemButton onClick={()=>{goToLocation('selectclasstest')}} sx={{ pl: 4 }}>
            <ListItemIcon><ArrowRightIcon /></ListItemIcon>
            <ListItemText primary="Schedule New Test" />
          </ListItemButton>
          <ListItemButton onClick={()=>{goToLocation('scheduledtest')}} sx={{ pl: 4 }}>
            <ListItemIcon><ArrowRightIcon /></ListItemIcon>
            <ListItemText primary="Scheduled Test" />
          </ListItemButton>
        </List>
      </Collapse>
      </>:null}

      <ListItemButton onClick={()=>{handleClickReports();toggleDrawer('left', true)}} >
        <ListItemIcon>
          <DescriptionIcon />
        </ListItemIcon>
        <ListItemText primary="Reports" />
        {openReports ? <ExpandLess /> : <ExpandMore />}
      </ListItemButton>
      <Collapse in={openReports} timeout="auto" unmountOnExit>
        <List component="div" disablePadding>
          <ListItemButton onClick={()=>{goToLocation('classwiseanalytics')}} sx={{ pl: 4 }}>
            <ListItemIcon><ArrowRightIcon /></ListItemIcon>
            <ListItemText primary="Class Wise" />
          </ListItemButton>
          <ListItemButton onClick={()=>{goToLocation('studentwiseanalytics')}} sx={{ pl: 4 }}>
            <ListItemIcon><ArrowRightIcon /></ListItemIcon>
            <ListItemText primary="Student Wise" />
          </ListItemButton>
        </List>
      </Collapse>

      <ListItem button onClick={()=>{goToLocation('liveclasses')}} >
            <ListItemIcon><LiveTvIcon /></ListItemIcon>
            <ListItemText primary="Live Class" />
      </ListItem>

      <ListItem button onClick={()=>{goToLocation('students')}} >
            <ListItemIcon><DescriptionIcon /></ListItemIcon>
            <ListItemText primary="Students" />
      </ListItem>
      <ListItem button onClick={()=>{goToLocation('subjects')}} >
            <ListItemIcon><DescriptionIcon /></ListItemIcon>
            <ListItemText primary="Subjects" />
      </ListItem>
      <ListItem button onClick={()=>{goToLocation('classes')}} >
            <ListItemIcon><DescriptionIcon /></ListItemIcon>
            <ListItemText primary="Batches" />
      </ListItem>
      
      <ListItem button onClick={()=>{goToLocation('profile')}} >
            <ListItemIcon><AccountCircleIcon /></ListItemIcon>
            <ListItemText primary="My Profile" />
      </ListItem>
      <ListItem button onClick={()=>{logout()}} >
            <ListItemIcon><LogoutIcon /></ListItemIcon>
            <ListItemText primary="Logout" />
      </ListItem>
      
    </div>
  );

  return (
    <div>
          <Button style={{color:'#FFFFFF'}} onClick={toggleDrawer('left', true)}><MenuIcon /></Button>
          <SwipeableDrawer
            anchor='left'
            open={state['left']}
            onClose={toggleDrawer('left', false)}
            onOpen={toggleDrawer('left', true)}
          >
            {list('left')}
          </SwipeableDrawer>
    </div>
  );
}
