import React from 'react';
import {Box, Container, Grid, Button } from '@material-ui/core';
import LoadingButton from '@mui/lab/LoadingButton';
import Table from '@mui/material/Table';
import TableBody from '@mui/material/TableBody';
import TableCell from '@mui/material/TableCell';
import TableContainer from '@mui/material/TableContainer';
import TableHead from '@mui/material/TableHead';
import TableRow from '@mui/material/TableRow';
import Paper from '@mui/material/Paper';
import TextField from '@mui/material/TextField';
import Autocomplete from '@mui/material/Autocomplete';
import Typography from '@mui/material/Typography';
import PropTypes from 'prop-types';
import Tabs from '@mui/material/Tabs';
import Tab from '@mui/material/Tab';
import LinearProgress from '@mui/material/LinearProgress';
import {MetaTags} from 'react-meta-tags';
import axios from 'axios';
import Cookies from 'js-cookie';
import { useSelector } from 'react-redux';
import {API_URL} from '../utils/EnvVars';
import Header from "./HeaderMy";
import '../styles/bizofficer-a.css';
import moment from 'moment';
////import { MmlNone } from 'mathjax-full/js/core/MmlTree/MmlNodes/mmultiscripts';

  function TabPanel(props) {
	const { children, value, index, ...other } = props;
  
	return (
	  <div
		role="tabpanel"
		hidden={value !== index}
		id={`simple-tabpanel-${index}`}
		aria-labelledby={`simple-tab-${index}`}
		{...other}
	  >
		{value === index && (
		  <Box sx={{ p: 3 }}>
			<Typography>{children}</Typography>
		  </Box>
		)}
	  </div>
	);
  }

  TabPanel.propTypes = {
	children: PropTypes.node,
	index: PropTypes.number.isRequired,
	value: PropTypes.number.isRequired,
  };

	function a11yProps(index) {
	return {
		id: `simple-tab-${index}`,
		'aria-controls': `simple-tabpanel-${index}`,
	};
	}

  export default function Execute() {
	const userObj = useSelector(state => state.teacherDetails);
	const batchObj = useSelector(state => state.batchDetails);	
	const isloggedin = Cookies.get('isteachloggedin');
	const selectedClass = Cookies.get('selectedClass');
	const [loadingLinearProgress, setLoadingLinearProgress] = React.useState(true);
	const [searchClicked, setSearchClicked] = React.useState(false);
	const [filter, setFilter] = React.useState(false);
	const [topicsList, setTopicsList] = React.useState([]);
	const [topic, setTopic] = React.useState("");
	const [selfTestList, setSelfTestList] = React.useState([]);
	const [classTestList, setClassTestList] = React.useState([]);
	const [topicTestList, setTopicTestList] = React.useState([]);
	const [mockTestList, setMockTestList] = React.useState([]);


	///const authResult = new URLSearchParams(window.location.search); 

	var myCurrentDate=new Date();
	var myPastFilterDate=new Date(myCurrentDate);
    myPastFilterDate.setDate(myPastFilterDate.getDate() - 1);
	const [filterDate, setFilterDate] = React.useState(moment(myPastFilterDate).format('YYYY-MM-DD'));

	const [value, setValue] = React.useState(0);
	const handleChange = (event, newValue) => {
	  setValue(newValue);
	};

	// check if logged in
	React.useEffect(() => {
		if(!isloggedin){
			window.location.href='login';
		}else if(!selectedClass){
			window.location.href='selectclass';	
		}
	}, [isloggedin,selectedClass]); 

	React.useEffect(() => {
		if(userObj && batchObj){
			getApiDataTopicList(batchObj.subject);
		}
	}, [userObj]); 

	React.useEffect(() => {
		if(userObj && batchObj){
			getApiData(userObj.schoolId,batchObj.className,batchObj.subject);
		}
	}, [userObj,filter]); 
	
	async function getApiData(sid,clsName,subName){
		if(sid!=null && clsName!=null && subName!=null){
			try {
				let axiosHeader = {
					headers: {
						'Content-Type': 'multipart/mixed',
						'schoolId': userObj.schoolId,
						'userId': userObj.loginId,
						'token': userObj.token,
					}
				};

				let qryStr = "";
				if(searchClicked){					
					qryStr = '&topic='+topic+'&filterDate='+moment(filterDate).format('YYYY-MM-DD');
				}
				axios.get(API_URL+'/teacher-dashboard-students?schoolId='+sid+'&className='+clsName+'&subject='+subName+qryStr, axiosHeader) 
					.then(response => {
						setSearchClicked(false);
						setLoadingLinearProgress(false);
					if(response && response.data.responseTxt==='success'){	
						setSelfTestList(response.data.selfTestList);
						setClassTestList(response.data.classTestList);
						setTopicTestList(response.data.topicTestList);
						setMockTestList(response.data.mockTestList);

					}else if(response && response.data.responseTxt==='invalidToken'){
						Cookies.remove('isteachloggedin');
    					Cookies.remove('roleteachloggedin');
    					Cookies.remove('schoolidloggedin');
    					window.location.href='login';
					}else{
						//setRedirect(true);
						///setMessage("No data available");
					}

				})
			} catch (error) {
				const { response } = error;
				const { request, ...errorObject } = response; // take everything but 'request'
				console.log(errorObject);
			}
		}	
	}

	async function getApiDataTopicList(subName){
		if(subName!=null){
			try {
				axios.get(API_URL+'/subjecttopics?subject='+subName) 
					.then(response => {
					if(response && response.data.responseTxt==='success'){	
						setTopicsList(response.data.list);

					}else{
						//setRedirect(true);
						///setMessage("No data available");
					}

				})
			} catch (error) {
				const { response } = error;
				const { request, ...errorObject } = response; // take everything but 'request'
				console.log(errorObject);
			}
		}	
	}
	
	function search(){
		setSearchClicked(true);
		setFilter(!filter);
	}

	function onEnter(event){
		if(event.key === 'Enter'){
			search();
		}
	}

	function studentReport(sid,sname){
		window.location.href="studentreport?sid="+sid+"&sname="+sname;
	}

	function openAnalytics(opt,testId){
		if(opt===3){
			window.location.href="analytics?testId="+testId;
		}else{
			window.location.href="testanalytics?testId="+testId;
		}	
	}


		return (
			<div> 
				<MetaTags>
            		<title>Dashboard</title>
          		</MetaTags>				
				<Header />
				<Container style={{marginBottom:100}}>		
				<Box mt={1}>
						<Grid container spacing={2}>
							<Grid item   md={12} xs={12}>
								<h3 className="heading" >Dashboard: {batchObj?<a href="/selectclass" style={{textDecoration:'none',color:'#666'}}>{batchObj.className+' / '+batchObj.subject}</a>:null}</h3>
							</Grid>
						</Grid>
				</Box>				

				<Box mb={3} display="flex" alignItems="center" justifyContent="center">
					<Grid container spacing={2}>
						<Grid item md={3} xs={12} ></Grid>
						<Grid item md={2} xs={12} >
									<TextField
										fullWidth
										id="date"
										label="Date"
										type="date"
										defaultValue={filterDate}
										sx={{ marginTop:1 }}
										size="small"
										onChange={event => setFilterDate(event.target.value)}
										inputFormat="dd-MM-yyyy"
									/>
						</Grid>
						<Grid item md={2} xs={12} >			
									<Autocomplete 
									fullWidth
									value={topic}
									onChange={(event, newValue) => { setTopic(newValue); }}
									id="topictxt"
									popupIcon={""}
									options={topicsList}
									renderInput={(params) => <TextField {...params} label="Topic" size="small" sx={{ marginTop: 1 }} />}
									/>	
						</Grid>					
						<Grid item md={2} xs={12} style={{textAlign:'left'}} >					
									{searchClicked?
									<LoadingButton 
											loading
											loadingPosition="start"											
											variant="outlined"
											id="waitloginbtnid" 
											size="small"
											style={{width: 120, marginTop: 12, backgroundColor: '#12a812', color: '#FFF'}}
										>
											Wait...
									</LoadingButton>
									:
									<Button onClick={() => {search()}} style={{marginTop: 12, backgroundColor: '#FFF', color: '#333333'}}  size="small" variant="outlined" >Go</Button>
  									}
						</Grid>		
						<Grid item md={3} xs={12} ></Grid>	
					</Grid>				
				</Box>

				<Box sx={{ width: '100%'}}>
					<Box display="flex" justifyContent="center" width="100%" >
						<Tabs value={value} onChange={handleChange} variant="scrollable" aria-label="basic tabs example">
						<Tab label="Self Assessment" {...a11yProps(0)} />
						<Tab label="Class Assessment" {...a11yProps(1)} />
						<Tab label="Topic Test" {...a11yProps(2)} />
						<Tab label="Mock Test" {...a11yProps(3)} />
						</Tabs>
					</Box>
					{(searchClicked || loadingLinearProgress)?<div style={{marginTop: 10}}><LinearProgress /></div>:null}
					<TabPanel value={value} index={0}>
						{/* Self Assessment */}
						<TableContainer component={Paper}>
							<Table sx={{ minWidth: 650 }} aria-label="simple table">
								<TableHead>
								<TableRow>
									<TableCell>Student Name</TableCell>
									<TableCell>Last Test Title</TableCell>
									<TableCell>Date</TableCell>
									<TableCell align="right">Score</TableCell>
									<TableCell align="right">Percentage</TableCell>
								</TableRow>
								</TableHead>
								<TableBody>
								{selfTestList?selfTestList.map((row) => (
									<TableRow
									key={'dd'}
									sx={{ '&:last-child td, &:last-child th': { border: 0 } }}
									>
									<TableCell onClick={()=>{studentReport(row.studentId,row.studentName)}} style={{cursor:'pointer'}} component="th" scope="row">{row.studentName}</TableCell>
									<TableCell >{row.givenTest?<span onClick={()=>{openAnalytics(1,row.testId)}} style={{cursor:'pointer'}} >{row.testTitle}</span>:""}</TableCell>
									<TableCell >{row.givenTest?row.testDate:""}</TableCell>
									<TableCell align="right">{row.givenTest?row.score:""}</TableCell>
									<TableCell align="right">{row.givenTest?row.percentage+'%':""}</TableCell> 
									</TableRow>
								 )):null}
								</TableBody>
							</Table>
							</TableContainer>
					</TabPanel>
					<TabPanel value={value} index={1}>
						{/* Class Assessment */}
						<TableContainer component={Paper}>
							<Table sx={{ minWidth: 650 }} aria-label="simple table">
								<TableHead>
								<TableRow>
									<TableCell>Student Name</TableCell>
									<TableCell>Last Test Title</TableCell>
									<TableCell>Date</TableCell>
									<TableCell align="right">Score</TableCell>
									<TableCell align="right">Percentage</TableCell>
								</TableRow>
								</TableHead>
								<TableBody>
								{classTestList?classTestList.map((row) => (
									<TableRow
									key={'dd'}
									sx={{ '&:last-child td, &:last-child th': { border: 0 } }}
									>
									<TableCell onClick={()=>{studentReport(row.studentId,row.studentName)}} style={{cursor:'pointer'}} component="th" scope="row">{row.studentName}</TableCell>
									<TableCell >{row.givenTest?<span onClick={()=>{openAnalytics(4,row.testId)}} style={{cursor:'pointer'}} >{row.testTitle}</span>:""}</TableCell>
									<TableCell >{row.givenTest?row.testDate:""}</TableCell>
									<TableCell align="right">{row.givenTest?row.score:""}</TableCell>
									<TableCell align="right">{row.givenTest?row.percentage:""}</TableCell> 
									</TableRow>
								 )):null}
								</TableBody>
							</Table>
							</TableContainer>
					</TabPanel>
					<TabPanel value={value} index={2}>
						{/* Topic Test */}
						<TableContainer component={Paper}>
							<Table sx={{ minWidth: 650 }} aria-label="simple table">
								<TableHead>
								<TableRow>
									<TableCell>Student Name</TableCell>
									<TableCell>Last Test Title</TableCell>
									<TableCell>Date</TableCell>
									<TableCell align="right">Score</TableCell>
									<TableCell align="right">Percentage</TableCell>
								</TableRow>
								</TableHead>
								<TableBody>
								{topicTestList?topicTestList.map((row) => (
									<TableRow
									key={'dd'}
									sx={{ '&:last-child td, &:last-child th': { border: 0 } }}
									>
									<TableCell onClick={()=>{studentReport(row.studentId,row.studentName)}} style={{cursor:'pointer'}} component="th" scope="row">{row.studentName}</TableCell>
									<TableCell >{row.givenTest?<span onClick={()=>{openAnalytics(2,row.testId)}} style={{cursor:'pointer'}} >{row.testTitle}</span>:""}</TableCell>
									<TableCell >{row.givenTest?row.testDate:""}</TableCell>
									<TableCell align="right">{row.givenTest?row.score:""}</TableCell>
									<TableCell align="right">{row.givenTest?row.percentage:""}</TableCell> 
									</TableRow>
								 )):null}
								</TableBody>
							</Table>
							</TableContainer>
					</TabPanel>
					<TabPanel value={value} index={3}>
						{/* Mock Test */}
						<TableContainer component={Paper}>
							<Table sx={{ minWidth: 650 }} aria-label="simple table">
								<TableHead>
								<TableRow>
									<TableCell>Student Name</TableCell>
									<TableCell>Last Test Title</TableCell>
									<TableCell>Date</TableCell>
									<TableCell align="right">Score</TableCell>
									<TableCell align="right">Percentage</TableCell>
								</TableRow>
								</TableHead>
								<TableBody>
								{mockTestList?mockTestList.map((row) => (
									<TableRow
									key={'dd'}
									sx={{ '&:last-child td, &:last-child th': { border: 0 } }}
									>
									<TableCell onClick={()=>{studentReport(row.studentId,row.studentName)}} style={{cursor:'pointer'}} component="th" scope="row">{row.studentName}</TableCell>
									<TableCell >{row.givenTest?<span onClick={()=>{openAnalytics(3,row.testId)}} style={{cursor:'pointer'}} >{row.testTitle}</span>:""}</TableCell>
									<TableCell >{row.givenTest?row.testDate:""}</TableCell>
									<TableCell align="right">{row.givenTest?row.score:""}</TableCell>
									<TableCell align="right">{row.givenTest?row.percentage:""}</TableCell> 
									</TableRow>
								 )):null}
								</TableBody>
							</Table>
							</TableContainer>
					</TabPanel>
				</Box>



				</Container>
				
				

			</div>
		);
 
}