import React from 'react';
import {Box, Container, Grid, Button } from '@material-ui/core';
import Card from '@mui/material/Card';
import CardContent from '@mui/material/CardContent';
import ButtonBase from '@mui/material/ButtonBase';
import Table from '@mui/material/Table';
import TableBody from '@mui/material/TableBody';
import TableCell from '@mui/material/TableCell';
import TableContainer from '@mui/material/TableContainer';
import TableHead from '@mui/material/TableHead';
import TableRow from '@mui/material/TableRow';
import Paper from '@mui/material/Paper';
import TextField from '@mui/material/TextField';
import Typography from '@mui/material/Typography';
import PropTypes from 'prop-types';
import Tabs from '@mui/material/Tabs';
import Tab from '@mui/material/Tab';
import LinearProgress from '@mui/material/LinearProgress';
import {MetaTags} from 'react-meta-tags';
import axios from 'axios';
import Cookies from 'js-cookie';
import { useSelector } from 'react-redux';
import {API_URL} from '../utils/EnvVars';
import Header from "./HeaderMy";
import '../styles/bizofficer-a.css';
import moment from 'moment';
////import { MmlNone } from 'mathjax-full/js/core/MmlTree/MmlNodes/mmultiscripts';

  function TabPanel(props) {
	const { children, value, index, ...other } = props;
  
	return (
	  <div
		role="tabpanel"
		hidden={value !== index}
		id={`simple-tabpanel-${index}`}
		aria-labelledby={`simple-tab-${index}`}
		{...other}
	  >
		{value === index && (
		  <Box sx={{ p: 3 }}>
			<Typography>{children}</Typography>
		  </Box>
		)}
	  </div>
	);
  }

  TabPanel.propTypes = {
	children: PropTypes.node,
	index: PropTypes.number.isRequired,
	value: PropTypes.number.isRequired,
  };

	function a11yProps(index) {
	return {
		id: `simple-tab-${index}`,
		'aria-controls': `simple-tabpanel-${index}`,
	};
	}

  export default function Execute() {
	const userObj = useSelector(state => state.teacherDetails);
	const batchObj = useSelector(state => state.batchDetails);	
	const isloggedin = Cookies.get('isteachloggedin');
	const roleloggedin = Cookies.get('roleteachloggedin');
	const selectedClass = Cookies.get('selectedClass');
	const [redirect, setRedirect] = React.useState(false);
	const [myData, setMyData] = React.useState([]);
	const [topic, setTopic] = React.useState("");
	const [rows, setRows] = React.useState([]);
	///const authResult = new URLSearchParams(window.location.search); 

	var myCurrentDate=new Date();
	var myPastFromDate=new Date(myCurrentDate);
    myPastFromDate.setDate(myPastFromDate.getDate() - 1);
	const [fromDate, setFromDate] = React.useState(moment(myPastFromDate).format('YYYY-MM-DD'));

	const [value, setValue] = React.useState(0);
	const handleChange = (event, newValue) => {
	  setValue(newValue);
	};

	// check if logged in
	React.useEffect(() => {
		if(!isloggedin){
			window.location.href='login';
		}else if(!selectedClass){
			window.location.href='selectclass';	
		}else if(redirect){
			if(roleloggedin=='PRINCIPAL'){
				window.location.href='classwiseanalytics';
			}else{
				window.location.href='selectclasstest';
			}
		}
	}, [isloggedin,selectedClass,redirect]); 

	React.useEffect(() => {
		if(userObj && batchObj){
			///getApiData(userObj.schoolId,batchObj.className,batchObj.subject);	
		}
	}, [userObj]); 
	
	async function getApiData(sid,clsName,subName){
		if(sid!=null && clsName!=null && subName!=null){
			try {
				let axiosHeader = {
					headers: {
						'Content-Type': 'multipart/mixed',
						'schoolId': userObj.schoolId,
						'userId': userObj.loginId,
						'token': userObj.token,
					}
				};
				axios.get(API_URL+'/teacherdashboard?schoolId='+sid+'&classList='+clsName+'&subjectList='+subName,axiosHeader) 
					.then(response => {
						
					if(response && response.data.responseTxt==='success' && response.data.list[0]!=null){	
						setMyData(response.data.list);

					}else if(response && response.data.responseTxt==='invalidToken'){
						Cookies.remove('isteachloggedin');
    					Cookies.remove('roleteachloggedin');
    					Cookies.remove('schoolidloggedin');
    					window.location.href='login';
					}else{
						setRedirect(true);
						///setMessage("No data available");
					}

				})
			} catch (error) {
				const { response } = error;
				const { request, ...errorObject } = response; // take everything but 'request'
				console.log(errorObject);
			}
		}	
	}
	
	function search(){
		//setFilter(!filter);
	}

	function onEnter(event){
		if(event.key === 'Enter'){
			//search();
		}
	}


		return (
			<div> 
				<MetaTags>
            		<title>Dashboard</title>
          		</MetaTags>				
				<Header />
				{(document.readyState!="complete")?<LinearProgress />:null}
				<Container style={{marginBottom:100}}>		
				<Box mt={1}>
						<Grid container spacing={2}>
							<Grid item   md={12} xs={12}>
								<h3 className="heading" >Dashboard: {batchObj?<a href="/selectclass" style={{textDecoration:'none',color:'#666'}}>{batchObj.className+' / '+batchObj.subject}</a>:null}</h3>
							</Grid>
						</Grid>
				</Box>				

				<Box mb={3} style={{textAlign:'center'}}>
									<TextField
										id="date"
										label="Date"
										type="date"
										defaultValue={fromDate}
										sx={{ width: 200, marginRight:1, marginTop:1 }}
										size="small"
										onChange={event => setFromDate(event.target.value)}
										inputFormat="dd-MM-yyyy"
									/>
									<TextField
										id="keywordtxt"
										label="Search"
										defaultValue={topic}
										sx={{ width: 200, marginTop: 1 }}
										size="small"
										onChange={event => setTopic(event.target.value)}
										onKeyPress={(event)=>{onEnter(event)}}
									/>
									<Button onClick={() => {search()}} style={{marginBottom: -29, marginLeft: 10, backgroundColor: '#FFF', color: '#333333'}} size="small" variant="contained" color="secondary" >Go</Button>
				</Box>

				<Box sx={{ width: '100%'}}>
					<Box display="flex" justifyContent="center" width="100%" >
						<Tabs value={value} onChange={handleChange} variant="scrollable" aria-label="basic tabs example">
						<Tab label="Self Assessment" {...a11yProps(0)} />
						<Tab label="Class Assessment" {...a11yProps(1)} />
						<Tab label="Topic Test" {...a11yProps(2)} />
						<Tab label="Mock Test" {...a11yProps(3)} />
						</Tabs>
					</Box>
					<TabPanel value={value} index={0}>
						{/* Self Assessment */}
						<TableContainer component={Paper}>
							<Table sx={{ minWidth: 650 }} aria-label="simple table">
								<TableHead>
								<TableRow>
									<TableCell>Student Name</TableCell>
									<TableCell align="right">Last Test Score</TableCell>
									<TableCell align="right">Percentage</TableCell>
								</TableRow>
								</TableHead>
								<TableBody>
								{['a','a','a','a','a','a'].map((row) => (
									<TableRow
									key={'dd'}
									sx={{ '&:last-child td, &:last-child th': { border: 0 } }}
									>
									<TableCell component="th" scope="row">afasdf</TableCell>
									<TableCell align="right">100</TableCell>
									<TableCell align="right">80</TableCell>
									</TableRow>
								 ))}
								</TableBody>
							</Table>
							</TableContainer>
					</TabPanel>
					<TabPanel value={value} index={1}>
						Item Two
					</TabPanel>
					<TabPanel value={value} index={2}>
						Item Three
					</TabPanel>
					<TabPanel value={value} index={3}>
						Item Four
					</TabPanel>
				</Box>

				{/* <Box mt={1}>
						<Grid container spacing={2} className='cardboxcontainer' >
							{myData?myData.map((myRow,index)=>(		
								<ButtonBase key={index+'clstst'} onClick={()=>{window.location.href='dashboardtest?scheduleId='+myRow.scheduleId}} >						
								<Card sx={{ width: 275, minHeight: 150 }} >
									<CardContent>
										<Typography variant="h6" component="div">
											{myRow.testTitle}
										</Typography>
										<Typography sx={{ mb: 1.5 }} color="text.secondary">
											{myRow.className}
										</Typography>
										<Typography variant="body2">
											{myRow.testDate}
										</Typography>
									</CardContent>								
							  	</Card>
								</ButtonBase>
							)):null}						
						</Grid>
				</Box> */}


				</Container>
				
				

			</div>
		);
 
}