import React from 'react';
import {Box, Container, Grid } from '@material-ui/core';
import Table from '@mui/material/Table';
import TableBody from '@mui/material/TableBody';
import TableCell from '@mui/material/TableCell';
import TableContainer from '@mui/material/TableContainer';
import TableHead from '@mui/material/TableHead';
import TableRow from '@mui/material/TableRow';
import Paper from '@mui/material/Paper';
import ReactApexCharts from 'react-apexcharts';
import LinearProgress from '@mui/material/LinearProgress';
import {MetaTags} from 'react-meta-tags';
import axios from 'axios';
import Cookies from 'js-cookie';
//import { useSelector } from 'react-redux';
import {API_URL} from '../utils/EnvVars';
import Header from "./HeaderMy";
import '../styles/bizofficer-a.css';



  export default function Execute() {
	const isloggedin = Cookies.get('isteachloggedin');
	const [myData, setMyData] = React.useState({});
	const [studentsList, setStudentsList] = React.useState([]);
	const [filterRange, setFilterRange] = React.useState(null);	
	const [circleChartOneData, setCircleChartOneData] = React.useState({series: [0],options: {colors:['#279411'], chart: {height: 250,type: 'radialBar',},plotOptions: {radialBar: {hollow: {size: '50%',}},},labels: ['Score'],},});
	const [circleChartTwoData, setCircleChartTwoData] = React.useState({series: [0],options: {colors:['#fe3000'], chart: {height: 250,type: 'radialBar',},plotOptions: {radialBar: {hollow: {size: '50%',}},},labels: ['Time'],},});
	const [circleChartThreeData, setCircleChartThreeData] = React.useState({series: [0],options: {colors:['#f6a034'], chart: {height: 250,type: 'radialBar',},plotOptions: {radialBar: {hollow: {size: '50%',}},},labels: ['Accuracy'],},});
	const authResult = new URLSearchParams(window.location.search); 
	const scheduleId = authResult.get('scheduleId');
	
	// check if logged in
	React.useEffect(() => {
		if(!isloggedin){
			window.location.href='login';
		}
		// else if(redirect){
		// 	window.location.href='selfassessor';
		// }
	}, [isloggedin]); 

	React.useEffect(() => {
		if(scheduleId){
			getApiData(scheduleId);	
		}
	}, [scheduleId]); 
	
	async function getApiData(scheduleId){
		if(scheduleId){
			try {
				axios.get(API_URL+'/testdashboard?scheduleId='+scheduleId) 
					.then(response => {						
					if(response && response.data!=null){
						setMyData(response.data);	
						setStudentsList(response.data.studentsList);
						setCircleChartOneData({series: [response.data.averageScore],options: {colors:['#279411'], chart: {height: 250,type: 'radialBar',},plotOptions: {radialBar: {hollow: {size: '60%',}},},labels: ['Score'],},});
						setCircleChartTwoData({series: [response.data.averageTime],options: {colors:['#0f3cff'], chart: {height: 250,type: 'radialBar',},plotOptions: {radialBar: {hollow: {size: '60%',}},},labels: ['Time'],},});
						setCircleChartThreeData({series: [response.data.averageAccuracy],options: {colors:['#9e3ef2'], chart: {height: 250,type: 'radialBar',},plotOptions: {radialBar: {hollow: {size: '60%',}},},labels: ['Accuracy'],},});

					}else{
						///setRedirect(true);
						///setMessage("No data available");
					}
				})
			} catch (error) {
				const { response } = error;
				const { request, ...errorObject } = response; // take everything but 'request'
				console.log(errorObject);
			}
		}	
	}

	const removeFilter = () =>{
		setFilterRange(null);
		setStudentsList(myData.studentsList);
	}

	const handleFilterStudents = (minScore,maxScore,scoreRange) => {
			if(minScore && maxScore){
				setFilterRange(scoreRange);
				var result = new Array();
				var length = myData.studentsList.length;
				for(var j = 0; j < length; j++)
				{
					if(minScore<=myData.studentsList[j].score && maxScore>=myData.studentsList[j].score)
					{
						result.push(myData.studentsList[j]);
					}
				}
				setStudentsList(result);
			}
	};

	
		return (
			<div> 
				<MetaTags>
            		<title>Dashboard</title>
          		</MetaTags>				
				<Header />
				{(document.readyState!="complete")?<LinearProgress />:null}
				<Container style={{marginBottom:100}}>	

				{(myData!=null && myData.testTitle)?	
				<Box mt={1}>
						<Grid container spacing={2}>
							<Grid item   md={12} xs={12}>
								<h3 style={{fontSize: 16, textAlign:'center'}} >{myData.testTitle}</h3>
								<h4 style={{color:'#ff3c4e', textAlign:'center'}}>{myData.className}, Total Students: {myData.totalStudents}</h4>
							</Grid>
						</Grid>
				</Box>				
				:null}

				<Box mt={1}>
						<Grid container spacing={2}>
							<Grid item md={6} xs={12} >
								<Grid container spacing={2} >
									<Grid item   md={4} xs={12} >
										<ReactApexCharts options={circleChartOneData.options} series={circleChartOneData.series} type="radialBar" />
										<div style={{textAlign:'center',fontWeight:'bold',color:'#279411',marginTop:-18}} >Average Score</div>
									</Grid>
									<Grid item   md={4} xs={12} >
										<ReactApexCharts options={circleChartTwoData.options} series={circleChartTwoData.series} type="radialBar" />
										<div style={{textAlign:'center',fontWeight:'bold',color:'#0f3cff',marginTop:-18}} >Average Time</div>
									</Grid>
									<Grid item   md={4} xs={12} >
										<ReactApexCharts options={circleChartThreeData.options} series={circleChartThreeData.series} type="radialBar" />
										<div style={{textAlign:'center',fontWeight:'bold',color:'#9e3ef2',marginTop:-18}} >Average Accuracy</div>
									</Grid>
								</Grid>
								<Grid container spacing={2}>
									<Grid item md={12} xs={12} >
										<TableContainer component={Paper}>						
										<Table aria-label="simple table">
											<TableHead>
											<TableRow style={{backgroundColor:'#aad7f7'}}>
												<TableCell style={{textAlign:'center',fontWeight:'bold'}} >Marks %</TableCell>
												<TableCell style={{textAlign:'center',fontWeight:'bold'}} >Number of Students</TableCell>
											</TableRow>
											</TableHead>
											<TableBody>
											{(myData && myData.meritStudents!=null)?myData.meritStudents.map((myRow,index)=>(	
												<TableRow key={'ms'+index} className='cursorpointer' onClick={()=>{handleFilterStudents(myRow.minScore,myRow.maxScore,myRow.scoreRange)}} >
													<TableCell style={{textAlign:'center'}} >{myRow.scoreRange}</TableCell>
													<TableCell style={{textAlign:'center'}} >{myRow.totalStudents}</TableCell>
												</TableRow>
											)):null}	
											</TableBody>
										</Table>
										</TableContainer>										
									</Grid>
								</Grid>

							</Grid>
							<Grid item md={6} xs={12} >
							<TableContainer component={Paper}>						
								<Table aria-label="simple table">
									<TableHead>
									<TableRow style={{backgroundColor:'#aad7f7'}}>
										<TableCell style={{fontWeight:'bold',width:'60%'}} >
											Student Name
											{(filterRange!=null)?<span className='tags'>{filterRange} <i onClick={()=>{removeFilter()}} className='fa fa-times'></i></span>:null}
										</TableCell>
										<TableCell style={{textAlign:'center',fontWeight:'bold',width:'20%'}} >Admission No.</TableCell>
										<TableCell style={{textAlign:'center',fontWeight:'bold',width:'20%'}} >Score</TableCell>
									</TableRow>
									</TableHead>
									<TableBody>
									{(studentsList!=null)?studentsList.map((myRow,index)=>(	
										<TableRow onClick={()=> window.open("testanalytics?testId="+myRow.testSession, "_blank")} key={'s'+index} className='cursorpointer' >
											<TableCell >{myRow.studentName}</TableCell>
											<TableCell style={{textAlign:'center'}} >{myRow.admissionNumber}</TableCell>
											<TableCell style={{textAlign:'center'}} >{myRow.score}</TableCell>
										</TableRow>
									)):null}	
									</TableBody>
								</Table>
								</TableContainer>
							</Grid>
						</Grid>
				</Box>



				</Container>
				
				

			</div>
		);
 
}