import React from 'react';
import { DataGrid } from '@mui/x-data-grid';
import {Box, Container, Grid, Button} from '@material-ui/core';
import {MetaTags} from 'react-meta-tags';
import axios from 'axios';
import Cookies from 'js-cookie';
import LinearProgress from '@mui/material/LinearProgress';
import DialogLiveClass from '../components/DialogLiveClass';
import {Tooltip, Stack} from '@mui/material';
import { useSelector } from 'react-redux';
import {API_URL} from '../utils/EnvVars';
import Header from "./HeaderMy";
import '../styles/bizofficer-a.css';
///import 'font-awesome/css/font-awesome.min.css'; 

function dateFormat(datetime){
	if(datetime && datetime!=null){
		let datetimeArr = datetime.split(" ");
		let dtArr = datetimeArr[0].split("-");
		let tmArr = datetimeArr[1].split(":");
		datetime = dtArr[2]+"-"+dtArr[1]+"-"+dtArr[0]+" "+tmArr[0]+":"+tmArr[1];
	}
	return datetime;
}  

// function dateFormatTwo(datetime){
// 	if(datetime && datetime!=null){
// 		let datetimeArr = datetime.split(" ");
// 		let dtArr = datetimeArr[0].split("-");
// 		let tmArr = datetimeArr[1].split(":");
// 		datetime = dtArr[2]+"-"+dtArr[1]+"-"+dtArr[0]+" "+tmArr[0]+":"+tmArr[1]+":00";
// 	}
// 	return datetime;
// }  
  
const columns = [
	{ field: 'id', headerName: '#', width: 40 },
	{ field: 'className', headerName: 'Class', flex: 1, renderCell: (params) =>  (
		<Tooltip title={params.value} ><span>{params.value}</span></Tooltip>
	   ), },
	{ field: 'subject', headerName: 'Subject', flex: 1 },	
	{ field: 'startTime', headerName: 'Date/Time', type: 'date', width: 180, 
		valueGetter: (params) => {
		return dateFormat(params.value);
	  	}},
	{ field: 'duration', headerName: 'Duration(Min)', flex: 1 },	
	{ field: 'note', headerName: 'Note', flex: 1},
	{ field: 'status', headerName: 'Status', flex: 1 },
	{ field: 'modifiedDateTime', headerName: 'Modified', type: 'date', width: 180, 
		valueGetter: (params) => {
		return dateFormat(params.value);
	  	}}
  ];
  
  export default function Execute() {
	const userObj = useSelector(state => state.teacherDetails);	
	const isloggedin = Cookies.get('isteachloggedin');
	const childRef = React.useRef();
	const [dataDetail, setDataDetail] = React.useState({});
	const [pageLoading, setPageLoading] = React.useState(true);
	const [rows, setRows] = React.useState([]);

	// check if logged in
	React.useEffect(() => {
		if(!isloggedin){
			window.location.href='login';
		}
	}, [isloggedin]);

	React.useEffect(() => {
		if(userObj){
			getApiData(userObj.schoolId,userObj.loginId,userObj.token);	
		}
	}, [userObj]); 

	async function getApiData(sid,loginId,token){
		if(sid && loginId){
			try {
				axios.get(API_URL+'/teacher-liveclasses?schoolId='+sid+'&loginId='+loginId+'&token='+token) 
					.then(response => {					
						setPageLoading(false);	
						if(response && response.data && response.data.list && response.data.responseTxt==='success'){	
							setRows(response.data.list);
						}
				})
			} catch (error) {
				const { response } = error;
				const { request, ...errorObject } = response; // take everything but 'request'
				console.log(errorObject);
			}
		}	
	}

	function saveData(opt){
		if(opt===1){
			setDataDetail(null);
		}	
		childRef.current.handleClickOpen();
	}

	function dataDetails(obj){
		if(obj && rows[obj.id-1]){
			setDataDetail(rows[obj.id-1]);
			childRef.current.handleClickOpen();	
		}	
	}

	return (
		<div> 
				<MetaTags>
            		<title>Live Classes</title>
          		</MetaTags>
				
				<Header />
				{pageLoading?<LinearProgress />:null}
				<Container>	
					<Box mt={1}>
							<Grid container spacing={2}>
								<Grid item md={12} xs={12}>
									<span className="headingThree" >Live Classes</span>
									<span style={{marginTop:30}}>	
										<i onClick={()=>{saveData(1)}} title="Create New" className="fa fa-plus-circle" style={{fontSize:25, color:'#0158dc',marginLeft:15, cursor:'pointer'}} />
									</span>	
								</Grid>
							</Grid>
					</Box>

					<div className="tblReport" style={{height: '70vh', width: '100%'}}>
						<DataGrid
							rows={rows}
							columns={columns} 
							getCellClassName={(params) => {								
								if (params.field === 'status' && params.value && params.value !== null) {
									if(params.value=='Not Active'){									 
										return 'txtredbold';
									}else{
										return '';
									}	
								}
							  }}
							pageSize={50}
							rowHeight={40}
							rowsPerPageOptions={[50]}
							ActionsComponent={()=>{alert('Hello')}}		
							style={{fontSize:12}}	
							components={{
								NoRowsOverlay: () => (
								  <Stack height="100%" alignItems="center" justifyContent="center">
									<span style={{color:'#FF0000',fontWeight:'bold'}}>No live classes found!</span>
								  </Stack>
								)}}	
							onRowClick={itm => dataDetails(itm)}			
						/>
					</div>

				</Container>

			<DialogLiveClass dataDetail={dataDetail} ref={childRef} />

		</div>	
	);
  }