import React from 'react';
import { DataGrid } from '@mui/x-data-grid';
import {Box, Container, Grid} from '@material-ui/core';
import {MetaTags} from 'react-meta-tags';
import axios from 'axios';
import Cookies from 'js-cookie';
import LinearProgress from '@mui/material/LinearProgress';
import Tooltip from '@mui/material/Tooltip';
import { useSelector } from 'react-redux';
import {API_URL} from '../utils/EnvVars';
import Header from "./HeaderMy";
import '../styles/bizofficer-a.css';
///import 'font-awesome/css/font-awesome.min.css';

  
  
const columns = [
	{ field: 'id', headerName: '#', width: 40 },
	{ field: 'mockTestName', headerName: 'Title', minWidth: 250, renderCell: (params) =>  (
		<Tooltip title={params.value} ><span>{params.value}</span></Tooltip>
	   ), },
	{ field: 'testType', headerName: 'Type', width: 120 },
	{ field: 'submitDateTime', headerName: 'Date', width: 160 },
	{ field: 'totalQuestions', headerName: 'Total Questions', width: 180 },
	{ field: 'fullMarks', headerName: 'Full Marks', width: 145 },
	{ field: 'marksObtain', headerName: 'Marks Obtain', width: 145 },
	{ field: 'timeSpent', headerName: 'Time Spent', width: 145 }
	/*
	{
	  field: 'age',
	  headerName: 'Age',
	  type: 'number',
	  width: 130,
	},
	{
	  field: 'fullName',
	  headerName: 'Full name',
	  description: 'This column has a value getter and is not sortable.',
	  sortable: false,
	  width: 160,
	  valueGetter: (params) =>
		`${params.getValue(params.id, 'firstName') || ''} ${
		  params.getValue(params.id, 'lastName') || ''
		}`,
	},
	*/
  ];
  
  export default function Execute() {
	const userObj = useSelector(state => state.userDetails);
	const isloggedin = Cookies.get('isloggedin');
	const [rows, setRows] = React.useState([]);

	// check if logged in
	React.useEffect(() => {
		if(!isloggedin){
			window.location.href='login';
		}
	}, [isloggedin]);

	React.useEffect(() => {		
		if(userObj.organisationId && userObj.studentId){
			getApiData(userObj.organisationId,userObj.studentId);
		}
	}, [userObj]);

	async function getApiData(organisationId,studentId){
			axios.get(API_URL+'/reportanalytics?organisationId='+organisationId+'&studentId='+studentId)
			   .then(response => {
			 	///console.log("Just Checking >> "+response.data);  
				 setRows(response.data);				 				
			})
	}

	function goToDetail(obj){
		if(obj && rows[obj.id-1]){
			if(rows[obj.id-1].testTypeId==3){
				window.location.href="analytics?testId="+rows[obj.id-1].testSession;
			}else{
				window.location.href="testanalytics?testId="+rows[obj.id-1].testSession;
			}	
		}
	}

	return (
		<div> 
				<MetaTags>
            		<title>Report & Analytics</title>
          		</MetaTags>
				
				<Header />
				{(document.readyState!="complete")?<LinearProgress />:null}
				<Container>	
					<Box mt={1}>
							<Grid container spacing={2}>
								<Grid item md={12} xs={12}>
									<h3 className="heading" >Report & Analytics</h3>
									<h4 style={{color:'#f50057'}}>Click on any row to view analytics and details</h4>
								</Grid>
							</Grid>
					</Box>

					<div className="tblReport" style={{height: '70vh', width: '100%' }}>
						<DataGrid
							rows={rows}
							columns={columns}
							pageSize={50}
							rowHeight={40}
							rowsPerPageOptions={[50]}
							ActionsComponent={()=>{alert('Hello')}}		
							style={{fontSize:12}}	
							onRowClick={itm => goToDetail(itm)}			
						/>
					</div>

				</Container>

		</div>	
	);
  }