import React from 'react';
import { DataGrid } from '@mui/x-data-grid';
import {Box, Container, Grid} from '@material-ui/core';
import {MetaTags} from 'react-meta-tags';
import axios from 'axios';
import Cookies from 'js-cookie';
import LinearProgress from '@mui/material/LinearProgress';
import DialogScheduleTestDetails from '../components/DialogScheduleTestDetails';
import Tooltip from '@mui/material/Tooltip';
import { useSelector } from 'react-redux';
import {API_URL} from '../utils/EnvVars';
import Header from "./HeaderMy";
import '../styles/bizofficer-a.css';
///import 'font-awesome/css/font-awesome.min.css'; 

function dateFormat(datetime){
	if(datetime && datetime!=null){
		let datetimeArr = datetime.split(" ");
		let dtArr = datetimeArr[0].split("-");
		let tmArr = datetimeArr[1].split(":");
		datetime = dtArr[2]+"-"+dtArr[1]+"-"+dtArr[0]+" "+tmArr[0]+":"+tmArr[1];
	}
	return datetime;
}  
  
const columns = [
	{ field: 'id', headerName: '#', width: 40 },
	{ field: 'testTitle', headerName: 'Test Title', minWidth: 350, renderCell: (params) =>  (
		<Tooltip title={params.value} ><span>{params.value}</span></Tooltip>
	   ),
	   renderHeader: () => (<div style={{display: 'flex', flexDirection: 'column', alignItems: 'flex-start', lineHeight: 'normal'}}>
	   <div>
	   		Test Title
	   </div>
	   <div style={{color:'#f50057'}}>Click on any row</div>
	   </div>
	 	),
	},
	{ field: 'className', headerName: 'Class/Section', width: 180 },
	{ field: 'subject', headerName: 'Subject', width: 180 },
	{ field: 'testDateTime', headerName: 'Date/Time', type: 'date', width: 180, 
		valueGetter: (params) => {
		return dateFormat(params.value);
	  	}},
	{ field: 'totalTime', headerName: 'Time (Minutes)', width: 180 }
	/*
	{
	  field: 'age',
	  headerName: 'Age',
	  type: 'number',
	  width: 130,
	},
	{
	  field: 'fullName',
	  headerName: 'Full name',
	  description: 'This column has a value getter and is not sortable.',
	  sortable: false,
	  width: 160,
	  valueGetter: (params) =>
		`${params.getValue(params.id, 'firstName') || ''} ${
		  params.getValue(params.id, 'lastName') || ''
		}`,
	},
	*/
  ];
  
  export default function Execute() {
	const userObj = useSelector(state => state.teacherDetails);	
	const isloggedin = Cookies.get('isteachloggedin');
	const childRef = React.useRef();
	const [testDetail, setTestDetail] = React.useState({});
	const [loadingData, setLoadingData] = React.useState(true);
	const [rows, setRows] = React.useState([]);

	// check if logged in
	React.useEffect(() => {
		if(!isloggedin){
			window.location.href='login';
		}
	}, [isloggedin]);

	React.useEffect(() => {
		if(userObj && userObj!=null){
			getApiData(userObj.schoolId,userObj.loginId);	
		}
	}, [userObj]); 

	async function getApiData(sid,loginId){
		if(sid && loginId){
			try {
				let axiosHeader = {
					headers: {
						'Content-Type': 'multipart/mixed',
						'schoolId': userObj.schoolId,
						'userId': userObj.loginId,
						'token': userObj.token,
					}
				};
				axios.get(API_URL+'/teacherscheduledtest?schoolId='+sid+'&loginId='+loginId, axiosHeader) 
					.then(response => {	setLoadingData(false);
						if(response && response.data.responseTxt==='success' && response.data.list[0]!=null){	
							setRows(response.data.list);
	
						}else if(response && response.data.responseTxt==='invalidToken'){
							Cookies.remove('isteachloggedin');
							Cookies.remove('roleteachloggedin');
							Cookies.remove('schoolidloggedin');
							window.location.href='login';
						}
				})
			} catch (error) {
				const { response } = error;
				const { request, ...errorObject } = response; // take everything but 'request'
				console.log(errorObject);
			}
		}	
	}

	function showDetails(obj){
		///alert("obj >>> "+obj);
		if(obj && rows[obj.id-1]){
			setTestDetail(rows[obj.id-1]);
			childRef.current.handleClickOpen();	
		}	
	}

	return (
		<div> 
				<MetaTags>
            		<title>Scheduled Test</title>
          		</MetaTags>
				
				<Header />
				{loadingData?<LinearProgress />:null}
				<Container>	
					<Box mt={1}>
							<Grid container spacing={2}>
								<Grid item md={12} xs={12}>
									<h3 className="heading" >Scheduled Test</h3>
								</Grid>
							</Grid>
					</Box>

					<div className="tblReport" style={{height: '70vh', width: '100%' }}>
						<DataGrid
							rows={rows}
							columns={columns}
							pageSize={50}
							rowHeight={40}
							rowsPerPageOptions={[50]}
							ActionsComponent={()=>{alert('Hello')}}		
							style={{fontSize:12}}	
							onRowClick={itm => showDetails(itm)}			
						/>
					</div>

				</Container>

			<DialogScheduleTestDetails testDetail={testDetail} ref={childRef} />

		</div>	
	);
  }