import React from 'react';
import {Box, Container, Grid, Button } from '@material-ui/core';
import MenuItem from '@mui/material/MenuItem';
import Select from '@mui/material/Select';
import InputLabel from '@mui/material/InputLabel';
import FormControl from '@mui/material/FormControl';
import {MetaTags} from 'react-meta-tags';
import Cookies from 'js-cookie';
import { useDispatch, useSelector } from 'react-redux';
import { selectBatch } from '../store/batch.actions';
import Header from "./HeaderMy";
import '../styles/bizofficer-a.css';



  export default function Execute() {
	const userObj = useSelector(state => state.teacherDetails);	
	const dispatch = useDispatch();
	const isloggedin = Cookies.get('isteachloggedin');
	const [className, setClassName] = React.useState("noselect");
	const [subjects, setSubjects] = React.useState(null);
	const [subjectName, setSubjectName] = React.useState("noselect");
	const [message, setMessage] = React.useState(null);

	React.useEffect(() => {
		if(!isloggedin){
			window.location.href='login';
		}
	}, [isloggedin]); 

	function selectClassName(cls){
		setClassName(cls);
		let subjectArr = [];
		if(cls!=="noselect"){
			if(userObj && userObj.teacherAssociation && userObj.teacherAssociation[0]!=null){
				for(let j=0; j<userObj.teacherAssociation.length; j++){
					if(cls==userObj.teacherAssociation[j].className)
					{
						if(subjectArr.indexOf(userObj.teacherAssociation[j].subject)==-1){
							subjectArr.push(userObj.teacherAssociation[j].subject);	
						}				
					}
				}
			}
		}else{
			setSubjectName("noselect");
		}
		setSubjects(subjectArr);
	}

	function goToLocation(){
		if(className!="noselect" && subjectName!="noselect"){
			if(userObj && userObj.teacherAssociation && userObj.teacherAssociation[0]!=null){
				for(let j=0; j<userObj.teacherAssociation.length; j++){
					if(className===userObj.teacherAssociation[j].className && subjectName===userObj.teacherAssociation[j].subject)
					{
						dispatch(selectBatch(userObj.teacherAssociation[j]));						
						Cookies.set('selectedClass', className, { expires: new Date(new Date().getTime() + 3600000*24*2) });
						break;					
					}
				}
			}			
			window.location.href='dashboard';
		}else{
			setMessage("To continue, you must select class & subject");
		}
	}
	
		return (
			<div> 
				<MetaTags>
            		<title>Select Class</title>
          		</MetaTags>				
				<Header />
				<Container style={{marginBottom:100}}>		
				<Box mt={1}>
						<Grid container spacing={2}>
							<Grid item   md={12} xs={12}>
								<h3 className="heading" >Select: Class &amp; Subject</h3>
							</Grid>
						</Grid>
				</Box>				

				<Box mt={1}>
						<Grid container spacing={2} >

							<Grid item md={12} xs={12}>							    
								<FormControl style={{width:'100%',marginBottom:8}} >
									<InputLabel id="select-class-label">Class</InputLabel>										
										<Select 											
											labelId="select-class-label"
											label="Class"
											id="select-class"
											value={className}									
											onChange={event => selectClassName(event.target.value)}
										>
											<MenuItem value="noselect">Select Class</MenuItem>
											{(userObj!=null && userObj.classList)?userObj.classList.map((myClass,index)=>(
												<MenuItem key={'cls'+index} value={myClass}>{myClass}</MenuItem>
											)):null}
										</Select>
								</FormControl>
							</Grid>

							<Grid item md={12} xs={12}>							    
								<FormControl style={{width:'100%',marginBottom:8}} >
									<InputLabel id="select-subject-label">Subject</InputLabel>										
										<Select 											
											labelId="select-subject-label"
											label="Subject"
											id="select-subject"
											value={subjectName}									
											onChange={event => setSubjectName(event.target.value)}
										>
											<MenuItem value="noselect">Select Subject</MenuItem>
											{(subjects!=null)?subjects.map((mySub,index)=>(
												<MenuItem key={'cls'+index} value={mySub}>{mySub}</MenuItem>
											)):null}
										</Select>
								</FormControl>
							</Grid>

						</Grid>
				</Box>

				<Box mt={2}>
				  {message?<span style={{color:'#FF0000',fontWeight:'bold'}}>{message}</span>:null}
    	          <br/><Button onClick={() => {goToLocation()}} size="small" variant="contained" color="secondary" >Continue</Button>
		      	</Box>

				</Container>
				
				

			</div>
		);
 
}