import React from 'react';
import {Box, Container, Grid, Link} from '@material-ui/core';
import {MetaTags} from 'react-meta-tags';
import DialogScheduleTestDetails from '../components/DialogScheduleTestDetails';
import CircularProgress from '@mui/material/CircularProgress';
import axios from 'axios';
import Cookies from 'js-cookie';
import { makeStyles } from "@material-ui/core/styles";
import { useSelector } from 'react-redux';
import {API_URL} from '../utils/EnvVars';
import TreeViewComp from '../components/TreeViewComp';
import SearchInput from '../components/SearchInput';
import Header from "./HeaderMy";
import '../styles/bizofficer-a.css';


  
  export default function Execute() {
	const childRef = React.useRef();
	const userObj = useSelector(state => state.teacherDetails);
	const batchObj = useSelector(state => state.batchDetails);
	const isloggedin = Cookies.get('isteachloggedin');
	const selectedClass = Cookies.get('selectedClass');
	const [topicTestList, setTopicTestList] = React.useState([]);
	const [testDetail, setTestDetail] = React.useState({});
	const [selectedTopicId, setSelectedTopicId] = React.useState(0);
	const [searchQuery, setSearchQuery] = React.useState(null);
	const [searchFlag, setSearchFlag] = React.useState(null);
	const [showProgress, setShowProgress] = React.useState(false);
	const [templateId, setTemplateId] = React.useState(null);


	// check if logged in
	React.useEffect(() => {
		if(!isloggedin){
			window.location.href='login';
		}else if(!selectedClass){
			window.location.href='selectclass';	
		}
	}, [isloggedin,selectedClass]);

	function showDetails(obj){
		let dialogTestDetails = {"autoId":0,"topicTestId":obj.mockTestId,"topicId":obj.topicId,"loginId":userObj.loginId,"testTitle":obj.mockTestTitle,"totalTime":obj.patternDetails.totalTime,"markCorrectAns":obj.patternDetails.markCorrectAns,"markIncorrectAns":obj.patternDetails.markIncorrectAns,"markNotAttempt":obj.patternDetails.markNotAttempt,"questionType":obj.patternDetails.questionType,"totalMark":obj.patternDetails.totalMark,"totalQuestion":obj.patternDetails.totalQuestion,"className":batchObj.className,"subject":batchObj.subject};
		setTestDetail(dialogTestDetails);
		childRef.current.handleClickOpen();		
	}

	const selectTopic = (obj) => {
		setSearchFlag('Topic');
		setSearchQuery(obj.topicName);
		setSelectedTopicId(obj.topicId);
	}

	const searchBoxQuery = (searchFlag,obj) => {
		setSearchFlag(searchFlag);
		setSearchQuery(obj.title);	
		setSelectedTopicId(0);	
	}

	React.useEffect(() => {
		if(batchObj && batchObj!=null){			
			setTemplateId(batchObj.templateId);
		}
	}, [batchObj]);

	React.useEffect(() => {
		if(userObj!=null && searchQuery!=null && templateId>0){				
			setShowProgress(true);				
			getApiData(templateId,searchQuery,selectedTopicId);
		}
	}, [userObj, searchQuery, selectedTopicId]); 

	async function getApiData(templateId,topicName,topicId){		
		axios.get(API_URL+'/topictestlist?templateId='+templateId+'&topicName='+topicName+'&topicId='+topicId)
			   .then(response => {
			 	///console.log("Just Checking >> "+response.data); 
				if(response.data!=null){	  
					setTopicTestList(response.data);
					setShowProgress(false);
				}				 				
		})
	}
	
		return (
			<div> 
				<MetaTags>
            		<title>Schedule New Test</title>
          		</MetaTags>
				
				<Header />
				<Container>		
				<Box mt={1}>
						<Grid container spacing={2}>
							<Grid item   md={12} xs={12}>
								<h3 className="heading" >Schedule New Test: {batchObj?<a href="/selectclass" style={{textDecoration:'none',color:'#666'}}>{batchObj.className+' / '+batchObj.subject}</a>:null}</h3>

							</Grid>
						</Grid>
				</Box>				
				
				<Box mt={1}>
						<Grid container spacing={2}>
							<Grid item   md={5} xs={12} className="selectTopicSelfTest" >															
								<SearchInput label="Search Topic" flag="Topic" templateId={templateId} toCallParentMethod={searchBoxQuery} />
								<p className="headingTwo" style={{marginTop:10}}>Topic (Browse & Select)</p>								
								<TreeViewComp templateId={templateId} toCallParentMethod={selectTopic} />		
							</Grid>
							<Grid item   md={7} xs={12} className="selfTestForm animate-zoom" >

								<div className="btmbdrgry"><span className="headingTwo" >{searchQuery?<span>{searchFlag+': '+searchQuery}</span>:<span style={{fontSize:16,color:'#f50057'}}>Select topic from left side to get list</span>}</span>
								{showProgress?<CircularProgress style={{width:20,height:20}} />:null}
								</div>
								{(topicTestList!=null && topicTestList.length>0)?<span style={{fontSize:16,color:'#f50057'}}>Click below links to schedule new test</span>:null}								
								<Box component="form" noValidate >
										<ul className='topictestlist'>
											{
												(topicTestList!=null && topicTestList.length>0)?topicTestList.map((myRow,indextt)=>(
													<li key={'intt'+indextt}><Link onClick={()=>{showDetails(myRow)}} style={{cursor:'pointer', fontWeight:'bold',fontSize:13}} >{myRow.mockTestTitle}</Link></li>
												)):null
											}	
										</ul>
								</Box>
									
							</Grid>

						</Grid>
				</Box>


				</Container>

				<DialogScheduleTestDetails testDetail={testDetail} ref={childRef} />							
				{/* <DialogTopicTestDetails toCallStartTest={startMyTest} testDetail={testDetail} ref={childRef} /> */}
				{/* <DialogTestStart toCallDeleteCurrentStartNew={deleteCurrentStartNew} toCallContinueCurrentTest={continueCurrentTest} currentRunningTestTitle={currentRunningTestTitle} ref={childRefStartTest}  />							  */}

			</div>
		);
 
}