import React from 'react';
import {Box, Container, Grid, Link, Button} from '@material-ui/core';
import Alert from '@mui/material/Alert';
import Stack from '@mui/material/Stack';
import Snackbar from '@mui/material/Snackbar';
import {MetaTags} from 'react-meta-tags';
import InputLabel from '@mui/material/InputLabel';
import TextField from '@mui/material/TextField';
import NativeSelect from '@mui/material/NativeSelect';
import DialogTestStart from '../components/DialogTestStart';
import axios from 'axios';
import Cookies from 'js-cookie';
import { useSelector } from 'react-redux';
import {API_URL} from '../utils/EnvVars';
import TreeViewComp from '../components/TreeViewComp';
import SearchInput from '../components/SearchInput';
import Header from "./HeaderMy";
import '../styles/bizofficer-a.css';


  
  export default function Execute() {
	const userObj = useSelector(state => state.userDetails);
	const isloggedin = Cookies.get('isloggedin');
	const childRefStartTest = React.useRef();  
	const [questionTypeList, setQuestionTypeList] = React.useState([]);
	const [selectedTopicId, setSelectedTopicId] = React.useState(0);
	const [searchQuery, setSearchQuery] = React.useState(null);
	const [searchFlag, setSearchFlag] = React.useState(null);
	const [availableTotalQuestion, setAvailableTotalQuestion] = React.useState(0);
	const [questionType, setQuestionType] = React.useState("Any");
	const [totalQuestion, setTotalQuestion] = React.useState(30);
	const [totalTime, setTotalTime] = React.useState(30);
	const [marksCorrectAnswer, setMarksCorrectAnswer] = React.useState(1);
	const [marksIncorrectAnswer, setMarksIncorrectAnswer] = React.useState(0);
	const [marksNotAttempted, setMarksNotAttempted] = React.useState(0);
	const [showAlert, setShowAlert] = React.useState(false);
	const [alertMessage, setAlertMessage] = React.useState("");
	const [currentRunningTestTitle, setCurrentRunningTestTitle] = React.useState("");
	const [currentRunningTestSession, setCurrentRunningTestSession] = React.useState("");

	// check if logged in
	React.useEffect(() => {
		if(!isloggedin){
			window.location.href='login';
		}
	}, [isloggedin]);

	const vertical='top',horizontal='center';
	
	const selectTopic = (obj) => {
		setSearchFlag('Topic');
		setSearchQuery(obj.topicName);
		setSelectedTopicId(obj.topicId);
		setAvailableTotalQuestion(obj.questionCount);
	}

	const searchBoxQuery = (searchFlag,obj) => {
		setSearchFlag(searchFlag);
		setSearchQuery(obj.title);
		setAvailableTotalQuestion(obj.questionCount);
	}

	function startMyTest(){
		//alert("aaaa");
		if(!searchQuery){
			setShowAlert(true);
			setAlertMessage("Select your topic or keyword from left side.");
		}else{
			axios.get(API_URL+'/testcurrentrunning?organisationId='+userObj.organisationId+'&studentId='+userObj.studentId)
				.then(response => {
					if(response.data.responseTxt=="OK"){
						setCurrentRunningTestTitle(response.data.testName);
						setCurrentRunningTestSession(response.data.testSession);
						childRefStartTest.current.handleClickOpen();
					}else if(searchQuery){
						window.location='testsimulator?testId=0&testType=1&questionType='+questionType+'&totalQuestion='+totalQuestion+'&totalTime='+totalTime+'&marksCorrectAnswer='+marksCorrectAnswer+'&marksIncorrectAnswer='+marksIncorrectAnswer+'&marksNotAttempted='+marksNotAttempted+'&searchFlag='+searchFlag+'&searchQuery='+searchQuery+'&topicId='+selectedTopicId;
					}else{
						setShowAlert(true);
						setAlertMessage("Select your topic or keyword from left side.");
					}			 				
			}).catch((error) => {
				console.log("AXIOS ERROR: ", error);
			})	
		}	
	}
	function deleteCurrentStartNew(){		
		axios.get(API_URL+'/testrunningdelete?organisationId='+userObj.organisationId+'&studentId='+userObj.studentId)
			   .then(response => {
			 	///console.log("Just Checking >> "+response.data);
				if(response.data.responseTxt=="OK"){
				}else{
				}			 				
		}).catch((error) => {
			console.log("AXIOS ERROR: ", error);
		})		
		window.location='testsimulator?testId=0&testType=1&questionType='+questionType+'&totalQuestion='+totalQuestion+'&totalTime='+totalTime+'&marksCorrectAnswer='+marksCorrectAnswer+'&marksIncorrectAnswer='+marksIncorrectAnswer+'&marksNotAttempted='+marksNotAttempted+'&searchFlag='+searchFlag+'&searchQuery='+searchQuery+'&topicId='+selectedTopicId;
	}	
	function continueCurrentTest(){	
		window.location.href='testsimulator?testSession='+currentRunningTestSession+'&testType=1';
	}

	function hideAlert(){
		setShowAlert(false);
	}

	React.useEffect(() => {		
			if(userObj.templateId && userObj.organisationId){
				getApiData(userObj.templateId,userObj.organisationId);
			}
	}, [userObj]); 

	async function getApiData(templateId,organisationId){
			axios.get(API_URL+'/selftestformoptions?templateId='+templateId+'&organisationId='+organisationId)
			   .then(response => {
			 	///console.log("Just Checking >> "+response.data);  
				if(response!=null && response.data!=null && response.data[0]!=null){
					setQuestionTypeList(response.data[0].questionTypeList);
					setTotalQuestion(response.data[0].totalQuestions);
					setTotalTime(response.data[0].duration);
					setMarksCorrectAnswer(response.data[0].marksCorrectAns);
					setMarksIncorrectAnswer(response.data[0].marksIncorrectAns);
					setMarksNotAttempted(response.data[0].marksNotAnswer);	
				} 

			})
	}
	
		return (
			<div> 
				<MetaTags>
            		<title>Self Assessor</title>
          		</MetaTags>
				
				<Header />
				<Container>		
				<Box mt={1}>
						<Grid container spacing={2}>
							<Grid item   md={12} xs={12}>
								<h3 className="heading" >Self Assessor</h3>
							</Grid>
						</Grid>
				</Box>				
				
				<Box mt={1}>
						<Grid container spacing={2}>
							<Grid item   md={5} xs={12} className="selectTopicSelfTest" >
								<SearchInput label="Search Keyword" flag="Keyword" toCallParentMethod={searchBoxQuery} />
								<SearchInput label="Search Topic" flag="Topic" toCallParentMethod={searchBoxQuery} />
								<p className="headingTwo" style={{marginTop:10}}>Topic (Browse & Select)</p>								
								<TreeViewComp toCallParentMethod={selectTopic} />		
							</Grid>
							<Grid item   md={7} xs={12} className="selfTestForm animate-zoom" >

								<div className="btmbdrgry"><span className="headingTwo" >{searchQuery?<span>{searchFlag+': '+searchQuery}</span>:<span>Select topic from left side</span>}</span>{searchQuery?<span className="questionCount">Total Questions: {availableTotalQuestion}</span>:null}</div>

								<Box component="form" noValidate >
											<InputLabel variant="standard" htmlFor="questionTypeId" style={{marginTop:25, marginBottom:-28,fontSize:12}} >
												Question Type
											</InputLabel>
											<NativeSelect
											defaultValue={'Any'}
											inputProps={{
												name: 'questionType',
												id: 'questionTypeId',
											}}
											style={{width:'45%',marginTop:30,marginRight:'4%',fontSize:12}}											
											 onChange={event => setQuestionType(event.target.value)}
											>
												{questionTypeList?questionTypeList.map((myRow,index)=>(
													<option key={'op'+index} value={myRow.typeTitle} >{myRow.typeTitle}</option>
												)):null}											
											</NativeSelect>
										<TextField onChange={event => setTotalQuestion(event.target.value)} value={totalQuestion} style={{width:'45%',marginTop:15,marginRight:'4%'}} type="number" min="10" max="30" label="Total number of question" variant="standard" />
										<TextField onChange={event => setTotalTime(event.target.value)} value={totalTime} style={{width:'45%',marginTop:15,marginRight:'4%'}} type="number" defaultValue="30" min="5" max="30" label="Total time for Test (minute)" variant="standard" />
										<TextField onChange={event => setMarksCorrectAnswer(event.target.value)} value={marksCorrectAnswer} style={{width:'45%',marginTop:15,marginRight:'4%'}} type="number" defaultValue="1" min="1" max="50" step="0.1" label="Marks for correct answer" variant="standard" />
										<TextField onChange={event => setMarksIncorrectAnswer(event.target.value)} value={marksIncorrectAnswer} style={{width:'45%',marginTop:15,marginRight:'4%'}} type="number" defaultValue="0" min="0" max="50" step="0.1" label="Marks for incorrect answer" variant="standard" />
										<TextField onChange={event => setMarksNotAttempted(event.target.value)} value={marksNotAttempted} style={{width:'45%',marginTop:15,marginRight:'4%'}} type="number" defaultValue="0" min="0" max="50" step="0.1" label="Marks for questions not attempted" variant="standard" />

								</Box>	
								<Box mt={2}>
					    	          <Button onClick={() => {startMyTest()}} size="small" variant="contained" color="secondary" >Start Assessment</Button>
								</Box>	
								<Box mt={5} className="selectTopicTxt" >
									Set your fundamentals right. Create Self tests topic wise / keyword wise. Try to answer All Questions with HELP OF Smart Learning/Books/Teacher/Web. Once confident move to  Assessments.		
								</Box>	
							</Grid>

						</Grid>
				</Box>


				</Container>

				<Stack spacing={2} sx={{ width: '100%' }}>
					<Snackbar open={showAlert} autoHideDuration={6000} onClose={hideAlert} anchorOrigin={{vertical,horizontal}}  >
						<Alert onClose={hideAlert} variant="filled" severity="error" sx={{ width: '100%' }}>
							{alertMessage}
						</Alert>
					</Snackbar>
				</Stack>			

				<DialogTestStart toCallDeleteCurrentStartNew={deleteCurrentStartNew} toCallContinueCurrentTest={continueCurrentTest} currentRunningTestTitle={currentRunningTestTitle} ref={childRefStartTest}  />							

			</div>
		);
 
}