import React from 'react';
import { DataGrid } from '@mui/x-data-grid';
import {Box, Container, Grid} from '@material-ui/core';
import {MetaTags} from 'react-meta-tags';
import axios from 'axios';
import Cookies from 'js-cookie';
import LinearProgress from '@mui/material/LinearProgress';
import Tooltip from '@mui/material/Tooltip';
import { useSelector } from 'react-redux';
import {API_URL} from '../utils/EnvVars';
import Header from "./HeaderMy";
import '../styles/bizofficer-a.css';
///import 'font-awesome/css/font-awesome.min.css';

  
  
const columns = [
	{ field: 'id', headerName: '#', width: 40 },
	{ field: 'mockTestName', headerName: 'Title', minWidth: 250, renderCell: (params) =>  (
		<Tooltip title={params.value} ><span>{params.value}</span></Tooltip>
	   ),
	   renderHeader: () => (<div style={{display: 'flex', flexDirection: 'column', alignItems: 'flex-start', lineHeight: 'normal'}}>
	   <div>
	   		Title
	   </div>
	   <div style={{color:'#f50057'}}>Click on any row</div>
	   </div>
	 	),
	},
	{ field: 'testType', headerName: 'Type', width: 120 },
	{ field: 'submitDateTime', headerName: 'Date', width: 160 },
	{ field: 'totalQuestions', headerName: 'Total Questions', width: 180 },
	{ field: 'fullMarks', headerName: 'Full Marks', width: 145 },
	{ field: 'marksObtain', headerName: 'Marks Obtain', width: 145 },
	{ field: 'timeSpent', headerName: 'Time Spent', width: 145 }
	/*
	{
	  field: 'age',
	  headerName: 'Age',
	  type: 'number',
	  width: 130,
	},
	{
	  field: 'fullName',
	  headerName: 'Full name',
	  description: 'This column has a value getter and is not sortable.',
	  sortable: false,
	  width: 160,
	  valueGetter: (params) =>
		`${params.getValue(params.id, 'firstName') || ''} ${
		  params.getValue(params.id, 'lastName') || ''
		}`,
	},
	*/
  ];
  
  export default function Execute() {
	const userObj = useSelector(state => state.teacherDetails);	
	const isloggedin = Cookies.get('isteachloggedin');
	const [loadingData, setLoadingData] = React.useState(true);
	const [rows, setRows] = React.useState([]);
	const authResult = new URLSearchParams(window.location.search); 
	const studentId = authResult.get('sid');
	const studentName = authResult.get('sname');

	// check if logged in
	React.useEffect(() => {
		if(!isloggedin){
			window.location.href='login';
		}
	}, [isloggedin]);

	React.useEffect(() => {		
		if(studentId, userObj){
			getApiData(studentId);
		}
	}, [studentId, userObj]);

	async function getApiData(studentId){

			let axiosHeader = {
				headers: {
					'Content-Type': 'multipart/mixed',
					'schoolId': userObj.schoolId,
					'userId': userObj.loginId,
					'token': userObj.token,
				}
			};

			axios.get(API_URL+'/teacher-studentreports?studentId='+studentId, axiosHeader)
			   .then(response => { setLoadingData(false);
			 	///console.log("Just Checking >> "+response.data);
				 if(response && response.data.responseTxt==='success' && response.data.list[0]!=null){	
					setRows(response.data.list);

				}else if(response && response.data.responseTxt==='invalidToken'){
					Cookies.remove('isteachloggedin');
					Cookies.remove('roleteachloggedin');
					Cookies.remove('schoolidloggedin');
					window.location.href='login';
				}  
				 				 				
			})
	}

	function goToDetail(obj){
		if(obj && rows[obj.id-1]){
			if(rows[obj.id-1].testTypeId===3){
				window.location.href="analytics?testId="+rows[obj.id-1].testSession;
			}else{
				window.location.href="testanalytics?testId="+rows[obj.id-1].testSession;
			}	
		}
	}

	return (
		<div> 
				<MetaTags>
            		<title>{studentName}'s Report & Analytics</title>
          		</MetaTags>
				
				<Header />
				{loadingData?<LinearProgress />:null}
				<Container>	
					<Box mt={1}>
							<Grid container spacing={2}>
								<Grid item md={12} xs={12}>
									<h3 className="heading" >{studentName}'s Reports</h3>
								</Grid>
							</Grid>
					</Box>

					<div className="tblReport" style={{height: '70vh', width: '100%' }}>
						<DataGrid
							rows={rows}
							columns={columns}
							pageSize={50}
							rowHeight={40}
							rowsPerPageOptions={[50]}
							ActionsComponent={()=>{alert('Hello')}}		
							style={{fontSize:12}}	
							onRowClick={itm => goToDetail(itm)}			
						/>
					</div>

				</Container>

		</div>	
	);
  }