import React from 'react';
import { DataGrid } from '@mui/x-data-grid';
import {Box, Container, Grid, Button} from '@material-ui/core';
import TextField from '@mui/material/TextField';
import InputLabel from '@mui/material/InputLabel';
import MenuItem from '@mui/material/MenuItem';
import FormControl from '@mui/material/FormControl';
import Select from '@mui/material/Select';
import {MetaTags} from 'react-meta-tags';
import axios from 'axios';
import Cookies from 'js-cookie';
import LinearProgress from '@mui/material/LinearProgress';
import Tooltip from '@mui/material/Tooltip';
import { useSelector } from 'react-redux';
import {API_URL} from '../utils/EnvVars';
import Header from "./HeaderMy";
import '../styles/bizofficer-a.css';
///import 'font-awesome/css/font-awesome.min.css';

  
  
const columns = [
	{ field: 'id', headerName: '#', width: 40 },
	{ field: 'studentName', headerName: 'Student Name', minWidth: 400, renderCell: (params) =>  (
		<Tooltip title={params.value} ><span>{params.value}</span></Tooltip>
	   ),
	   renderHeader: () => (<div style={{display: 'flex', flexDirection: 'column', alignItems: 'flex-start', lineHeight: 'normal'}}>
		<div>
		  Student Name
		</div>
		<div style={{color:'#f50057'}}>Click on any row</div>
		</div>
	  ),
	},
	{ field: 'className', headerName: 'Class', width: 180 },
	{ field: 'admissionNumber', headerName: 'Admission No', width: 180 }
	/*
	{
	  field: 'age',
	  headerName: 'Age',
	  type: 'number',
	  width: 130,
	},
	{
	  field: 'fullName',
	  headerName: 'Full name',
	  description: 'This column has a value getter and is not sortable.',
	  sortable: false,
	  width: 160,
	  valueGetter: (params) =>
		`${params.getValue(params.id, 'firstName') || ''} ${
		  params.getValue(params.id, 'lastName') || ''
		}`,
	},
	*/
  ];
  
  export default function Execute() {
	const userObj = useSelector(state => state.teacherDetails);
	const batchObj = useSelector(state => state.batchDetails);
	const isloggedin = Cookies.get('isteachloggedin');
	const selectedClass = Cookies.get('selectedClass');
	const [loadingData, setLoadingData] = React.useState(true);
	const [filter, setFilter] = React.useState(false);
	const [studentName, setStudentName] = React.useState("");
	const [rows, setRows] = React.useState([]);

	
	// check if logged in
	React.useEffect(() => {
		if(!isloggedin){
			window.location.href='login';
		}else if(!selectedClass){
			window.location.href='selectclass';	
		}
	}, [isloggedin,selectedClass]);

	React.useEffect(() => {	
		if(userObj && batchObj && userObj!=null && batchObj!=null){
			if(userObj.schoolId>0){
				getApiData(userObj.schoolId,batchObj.className,studentName);
			}
		}
	}, [userObj,batchObj,filter]);

	async function getApiData(schoolId,selectClass,studentName){

		let axiosHeader = {
			headers: {
				'Content-Type': 'multipart/mixed',
				'schoolId': userObj.schoolId,
				'userId': userObj.loginId,
				'token': userObj.token,
			}
		};

		axios.get(API_URL+'/studentswisereportanalytics?schoolId='+schoolId+"&className="+selectClass+"&studentName="+studentName, axiosHeader)
		   .then(response => { 
			 setLoadingData(false);

			 if(response && response.data.responseTxt==='success' && response.data.list[0]!=null){	
				setRows(response.data.list);

			}else if(response && response.data.responseTxt==='invalidToken'){
				Cookies.remove('isteachloggedin');
				Cookies.remove('roleteachloggedin');
				Cookies.remove('schoolidloggedin');
				window.location.href='login';
			}
							 				
		})
	}

	function search(){
		setFilter(!filter);
	}

	function goToDetail(obj){
		if(obj && rows[obj.id-1]){
			window.location.href="studentreport?sid="+rows[obj.id-1].studentId+"&sname="+rows[obj.id-1].studentName;
		}
	}

	function onEnter(event){
		if(event.key === 'Enter'){
			search();
		}
	}

	return (
		<div> 
				<MetaTags>
            		<title>Student Wise Analytics</title>
          		</MetaTags>
				
				<Header />
				{loadingData?<LinearProgress />:null}
				<Container>	
					<Box mt={1}>
							<Grid container spacing={2}>
								<Grid item md={12} xs={12}>
									<h3 className="heading" >Student Wise Analytics: {batchObj?<a href="/selectclass" style={{textDecoration:'none',color:'#666'}}>{batchObj.className}</a>:null}</h3>
								</Grid>
							</Grid>
					</Box>

					<Box mt={1}>
							<Grid container spacing={2} columns={12}>
								<Grid item md={12} xs={12}>

									<FormControl style={{width:150,marginRight:60}}>
										<TextField
										id="studentname"
										label="Name"
										defaultValue={studentName}
										sx={{ width: 200 }}
										size='small'
										onChange={event => setStudentName(event.target.value)}
										onKeyPress={(event)=>{onEnter(event)}}
										/>
									</FormControl>

									<Button onClick={() => {search()}} style={{marginTop:3}} size="small" variant="contained" color="secondary" >Search</Button>
								</Grid>


							</Grid>
					</Box>

					<div className="tblReport" style={{marginTop: 5, height: '70vh', width: '100%' }}>
						<DataGrid
							rows={rows}
							columns={columns}
							pageSize={50}
							rowHeight={40}
							rowsPerPageOptions={[50]}
							ActionsComponent={()=>{alert('Hello')}}		
							style={{fontSize:12}}	
							onRowClick={itm => goToDetail(itm)}			
						/>
					</div>

				</Container>

		</div>	
	);
  }