import React from 'react';
import { DataGrid } from '@mui/x-data-grid';
import {Radio, FormControl, TextField, Stack, Snackbar, Alert, Dialog, DialogActions, DialogContent, DialogContentText, DialogTitle} from '@mui/material';
import {Box, Grid, Button} from '@material-ui/core';
import {MetaTags} from 'react-meta-tags';
import axios from 'axios';
import Cookies from 'js-cookie';
import LinearProgress from '@mui/material/LinearProgress';
import Tooltip from '@mui/material/Tooltip';
import DialogStudentSave from '../components/DialogStudentSave';
import { useSelector } from 'react-redux';
import {API_URL} from '../utils/EnvVars';
import Header from "./HeaderMy";
import '../styles/bizofficer-a.css';
import 'font-awesome/css/font-awesome.min.css';

var vertical='top',horizontal='center';
  
  
  export default function Execute() {
	const userObj = useSelector(state => state.teacherDetails);	
	const isloggedin = Cookies.get('isteachloggedin');
	const childRefNewSave = React.useRef();
	const [severityAlert, setSeverityAlert] = React.useState("error");
	const [showAlert, setShowAlert] = React.useState(false);
	const [alertMessage, setAlertMessage] = React.useState("");
	const [pageLoading, setPageLoading] = React.useState(true);
	const [selectedRow, setSelectedRow] = React.useState(0);
  
	const [deleteDialogShow, setDeleteDialogShow] = React.useState(false);
	const [filter, setFilter] = React.useState(false);
	const [keyword, setKeyword] = React.useState("");
	const [studentObj, setStudentObj] = React.useState({});
	const [rows, setRows] = React.useState([]);
	const [classes, setClasses] = React.useState([]);
	///const [open, setOpen] = React.useState(false);

	// check if logged in
	React.useEffect(() => {
		if(!isloggedin){
			window.location.href='login';
		}
	}, [isloggedin]);

	const columns = [
		{
			field: "Select",
			headerName: "",
			width: 90,
			sortable: false,
				renderCell: (cellValues) => {
				return (
				  <Radio 
					checked={cellValues.id === selectedRow}
					value={cellValues.id}
					name="radio-buttons"
					inputProps={{ 'aria-label': {cellValues} }}
				  />
				 )
			  }
		  },
		{ field: 'id', headerName: '#', width: 40 },
		{ field: 'studentId', headerName: 'User Id', flex: 1, renderCell: (params) =>  (
			<Tooltip title={params.value} ><span>{params.value}</span></Tooltip>
		   ), },
		{ field: 'studentName', headerName: 'Name', flex: 1, renderCell: (params) =>  (
			<Tooltip title={params.value} ><span>{params.value}</span></Tooltip>
		   ), 
		   
		},
		{ field: 'className', headerName: 'Batch', flex: 1, renderCell: (params) =>  (
			<Tooltip title={params.value} ><span>{params.value}</span></Tooltip>
		   ), }
	  ];
	

	React.useEffect(() => {		
		if(userObj && userObj!=null){
			getApiData(userObj.schoolId,userObj.loginId,userObj.token,keyword);
		}
	}, [userObj,filter]);

	async function getApiData(schoolId,loginId,token,keyword){
			let axiosHeader = {
				headers:{
					'Content-Type': 'multipart/mixed',
					'schoolId': schoolId,
					'userId': loginId,
					'token': token,
				}
			};
			axios.get(API_URL+'/teacher-list-students?keyword='+keyword, axiosHeader)
			   .then(response => {
				setPageLoading(false);
			 	///console.log("Just Checking >> "+response.data);  
				if(response.data.responseTxt==="success"){ 
				 	setRows(response.data.students);	
					setClasses(response.data.classes);
					return false;
				}else if(response.data.responseTxt==="unauthorized"){
					Cookies.remove('isteachloggedin');
    				window.location.href='login';
					return false;
				}			 				
			}).catch((error) => {
				// setSeverityAlert("error");
				// setShowAlert(true);
				// setAlertMessage(""+error);			
				// return false;
			})
	}

	function deleteData(){
		if(studentObj && userObj.emailId && userObj.token){
			let axiosHeader = {
					headers: {
					'Content-Type': 'multipart/mixed',
					'schoolId': userObj.schoolId,
					'userId': userObj.loginId,
					'token': userObj.token,
				}
			}; 

		  const data = new FormData();
		  data.append('autoId', studentObj.autoId);
		  data.append('studentId', studentObj.studentId);
				 
		  axios.post(API_URL+'/teacher-remove-students', data, axiosHeader)
				.then((response) => {
					//console.log("RESPONSE RECEIVED: ", response.data.responseTxt);
				if(response.data && response.data.responseTxt==="InvalidToken"){ 
					Cookies.remove('isteachloggedin');
					window.location.href='login';
				}else if(response.data.responseTxt==="success"){
					setSeverityAlert("success");					
					setShowAlert(true);
					setAlertMessage("Student has been removed.");
			  		window.location.reload();	
					return false;
				}else{
			  		setSeverityAlert("error");
					setShowAlert(true);
					setAlertMessage("This student could not be removed.");			
					return false;
				}
			}).catch((error) => {
					//console.log("AXIOS ERROR: ", error);
				})	
		}		
		
	}

	function newStudent(){	
		setStudentObj(null);	
		childRefNewSave.current.handleClickOpen();
	}

	function selectRow(obj){
		if(obj && rows[obj.id-1]){			
			setSelectedRow(rows[obj.id-1].id);
			setStudentObj(rows[obj.id-1]);
		}
	}

	function search(){
		setFilter(!filter);
	}

	function onEnter(event){
		if(event.key === 'Enter'){
			search();
		}
	}

	function hideAlert(){
		setShowAlert(false);
	}

	function deleteDialogHide(){
		setDeleteDialogShow(false);
	}
	
	return (
		<div> 
				<MetaTags>
            		<title>Students</title>
          		</MetaTags>
				
				<Header />
				{pageLoading?<LinearProgress />:null}

				<Box className='mainBox'>	

					<Box mt={1}>
							<Grid container spacing={2}>
								<Grid item md={12} xs={12}>
									<h3 className="heading" >Students</h3>
								</Grid>
							</Grid>
					</Box>

					<Box mt={1}>
							<Grid container spacing={2}>
								<Grid item md={12} xs={12}>

									<FormControl style={{width:150,marginRight:60}}>
										<TextField
										id="keywordtxt"
										label="Search"
										defaultValue={keyword}
										sx={{ width: 200 }}
										size='small'
										onChange={event => setKeyword(event.target.value)}
										onKeyPress={(event)=>{onEnter(event)}}
										/>
									</FormControl>

									<Button onClick={() => {search()}} style={{marginTop:-5}} size="small" variant="contained" color="secondary" >Search</Button>

									<span style={{marginTop:30}}>	
										<i onClick={()=>{newStudent()}} title="Create New Student" className="fa fa-plus-circle" style={{fontSize:30, color:'#0158dc',marginLeft:15, cursor:'pointer'}} />
										{selectedRow>0?<>
											<i onClick={()=>{setDeleteDialogShow(true)}} title="Remove Student" className="fa fa-trash" style={{fontSize:28, color:'#fc5555',marginLeft:15, cursor:'pointer'}} />
										</>:null}
									</span>	
								</Grid>
							</Grid>
					</Box>

					<div className="tblReport" style={{height: '62vh', width: '100%' }}>
						<DataGrid
							rows={rows}
							columns={columns}
							pageSize={50}
							rowHeight={40}
							rowsPerPageOptions={[50]}
							ActionsComponent={()=>{alert('Hello')}}		
							style={{fontSize:12}}	
							onRowClick={itm => selectRow(itm)}			
							components={{
								NoRowsOverlay: () => (
								  <Stack height="100%" alignItems="center" justifyContent="center">
									<span style={{color:'#FF0000',fontWeight:'bold'}}>No student found!</span>
								  </Stack>
								)}}	
						/>
					</div>

				</Box>

			<DialogStudentSave classes={classes} ref={childRefNewSave} />						
			
			<Stack spacing={2} sx={{ width: '100%' }}>
					<Snackbar open={showAlert} autoHideDuration={6000} onClose={hideAlert} anchorOrigin={{vertical,horizontal}}  >
						<Alert onClose={hideAlert} variant="filled" severity={severityAlert} sx={{ width: '100%' }}>
							{alertMessage}
						</Alert>
					</Snackbar>
				</Stack>

				<Dialog
					open={deleteDialogShow}
					onClose={deleteDialogHide}
					aria-labelledby="alert-dialog-section-title"
					aria-describedby="alert-dialog-section-description"
				>
					<DialogTitle id="alert-dialog-section-title">
						Alert
					</DialogTitle>
					<DialogContent>
					<DialogContentText id="alert-dialog-section-description">
						Are you sure, You want to remove student.
					</DialogContentText>
					</DialogContent>
					<DialogActions>
					<Button variant="outlined" size="small" onClick={()=>{deleteDialogHide()}}>Don't Delete</Button>
					<Button variant="contained" size="small" color="secondary" onClick={()=>{deleteData()}} autoFocus>Yes, Delete</Button>
					</DialogActions>
				</Dialog>	

		</div>	
	);
  }